/*!
######################################################

# OCOM-V1-LIB.JS

# OCOM GLOBAL ASSET RELEASE: ALPHA - DEV BUILD

# BUILD DATE: Fri Aug 30 2019 08:16:45 GMT-0700 (PDT)

# COPYRIGHT ORACLE CORP 2019 [UNLESS STATED OTHERWISE]

######################################################
*/



// OCOM NAMESPACE - AFTER LIBRARIES & PLUGINS but BEFORE any COMPONENTS

/*! GENERIC - LOAD MENU DATA */
/**
 * This file contains a data retrieval function (fetchMenuContent) and other utility functions used by components that need 
 * to fetch shared menu data from an html file (like U02 header and u10 footer).
 * 
 * It retrieves and returns the the html string of of a generated component (like /ocom/template-sample/ocom-global-menu.html) 
 * Author: dcorrea@oracle.com , utility functions Tor G.
 * 
 * @function fetchMenuContent
 * @param {jquery} endpoint - path to file that contains the html menu 
 * @param {jquery} contentCache - optional parameter with cached content
 * @requires jQuery
 * 
 */


var oracleDataMenu = oracleDataMenu || {};

oracleDataMenu.fetchMenuContent = function (endpoint, contentCache) {
	if (!endpoint.length) {
		return $.Deferred().reject();
	}

	// if passed a jQuery object of menu, return as html string
	// if url matches content already fetched, return the cached html string
	// otherwise we do the ajax call and pass to the ajax handler
	return (endpoint instanceof jQuery &&
			$.Deferred().resolve(endpoint[0].outerHTML)) ||
		// if this endpoint has already been fetched
		// 	return the cached promise
		contentCache[endpoint.split('#')[0]] ||
		// otherwise assign this ajax request to the cache
		// 	and make the call to the endpoint
		(contentCache[endpoint.split('#')[0]] =
			jQuery.ajax({
				url: endpoint,
				type: 'GET',
				contentType: 'text/plain; charset=UTF-8',
				crossDomain: true,
				// support for custom/modified headers config
				/* globals beforeMenuContentFetch */
				beforeSend: 'undefined' !== typeof beforeMenuContentFetch &&
					beforeMenuContentFetch
			}));
};


/*! SHARED UTILITY FUNCTIONS */

oracleDataMenu.classSelector = function (arr, mod) {
	return (Array.isArray(arr) &&
			arr.map(function (cls) {
				return (Array.isArray(mod) &&
						mod.map(function (m) {
							return (Array.isArray(cls) &&
									'.' + cls.join(m + ' .') + m) ||
								'.' + cls + m;
						}).join()) ||

					(Array.isArray(cls) &&
						'.' + cls.join(' .') + (mod || '')) ||

					'.' + cls + (mod || '');
			}).join()) ||

		(Array.isArray(mod) &&
			mod.map(function (m) {
				return '.' + arr + m;
			}).join()) ||

		'.' + arr + (mod || '');
};


oracleDataMenu.classList = function (arr) {
	return (Array.isArray(arr) && arr.filter(function (cls) {
		// remove any false refs
		return !!cls;
	}).join(' ')) || arr;
};

oracleDataMenu.createElement = function (tag, clsArr, attrObj) {
	var el = document.createElement(tag);
	clsArr = clsArr || [];
	clsArr = Array.isArray(clsArr) ? clsArr : [clsArr];
	attrObj = attrObj || {};
	Object.keys(attrObj).map(function (key) {
		el[key] = attrObj[key];
	});
	return $(el).addClass(oracleDataMenu.classList(clsArr));
};


/**
 *  Adds tabindex attribute and removes aria-hidden from descendant <a> tags
 * 	of the provided open submenu root that have a computed visibility of visible.
 * 	This passed in parameter should be a boolean check whether to do this,
 * 	since it is an expensive style calculation...
 */
oracleDataMenu.addAriaAttributes = function(needsAria) {
	return needsAria && this.each(function() {
		var $target = $(this);
		$target.find('a').get().forEach(function(a) {
			var link = a;
			window.requestAnimationFrame(
				function() {
					if(window.getComputedStyle(link, null).visibility === 'visible') {
						link.removeAttribute('aria-hidden');
						link.setAttribute('tabindex', 0);
					}
				});
		});
	}) || this;
};


/*! OCOM-FRAMEWORK */
/**
 * A framework for registering and executing component javascript
 * @class {Object} OCOM
 * @requires jQuery
 * @docs OCOM.md
 */

var OCOM = OCOM || {

	// Enable some debugging console output
	debug: /ocomdebug=1/.test(window.location.search),

	// Store a reference to the script context, for possible codebase adjustments
	codebase: document.currentScript ? document.currentScript.src.match(/\/([a-z0-9_\.\-]+)\.js$/i)[1] : '',

	// Track whether jQuery(document).ready has fired, so that if
	// there is a late component registration, it will be run immediately.
	docReady: false,

	// Store functions that have a global=true flag in an array, to be executed
	// always on document ready.  Avoids the need to set data-ocomid (eg. col-framework)
	globals: [],

	/**
	 *	Provides a service to register and index component javascript,
	 *		scoping jQuery to the context (CSS selector) defined in the parameter
	 *	@class OCOM.register
	 *  @requires jQuery
	 *  @param {function} fn - The function containing component code and handlers
	 *  @returns {function} a reference to the OCOM property containing the function
	 *  @example <caption>Direct assignment with named function</caption>
	 *  OCOM.register(function ex01($) { ... component code ... });
	 *  @example <caption>Assignment to variable, with recommended IIFE encapsulation</caption>
	 *  (function() {
	 *  	var ex01 = function($) { ... component code ... };
	 *  	OCOM.register(ex01);
	 *  })();
	 */
	/* globals OraclePerformance */
	register: function() {
		'use strict';

		var fn = arguments[0],
				globalFn = 'boolean' === typeof arguments[arguments.length - 1] ?
										arguments[arguments.length - 1] : null,
				newComponent = {};

		// Fix Function.name on browsers that do not support it (IE):
		if(!(function f() {}).name) {
			Object.defineProperty(Function.prototype, 'name', {
				get: function() {
					var name = (this.toString().match(/^\s*function\s+([^\(\s]*)\s*/) || [])[1];
					// For better performance only parse once, and then cache the
					// result through a new accessor for repeated access.
					Object.defineProperty(this, 'name', { value: name });
					return name;
				}
			});
		}

		// prevent overwriting existing function
		if(this[fn.name]) {
			if(OCOM.debug) { console.error('OCOM.' + fn.name + ' has already been defined'); }
			return false;
		}

		newComponent[fn.name] = function(context) {

				var thecontext = context || document,
						hasRunContext = (thecontext instanceof jQuery ? thecontext[0] : thecontext)
							.toString().replace(/(\[.*? |\])/g, ''),
						// alias $ to jQuery in thecontext
						/* jshint unused:false */
						$ = function(selector, context) {
							return new jQuery.fn.init(selector, thecontext);
						};

				if(OCOM.debug) {
					if(OCOM[fn.name].hasRun(hasRunContext)) {
						console.warn('OCOM.' + fn.name + ' has already run within ' + hasRunContext);
					}
					console.log(fn.name + ' running in ' + hasRunContext + ' context:');
				}

				if('OraclePerformance' in window) {
					OraclePerformance.mark(fn.name + '-initStart');
				}

				if(!OCOM[fn.name].hasRun(hasRunContext)) {
					OCOM[fn.name].hasRunContexts.push(hasRunContext);
				}

				// call the component function with assigned context
				fn.call(OCOM[fn.name], $);

				if('OraclePerformance' in window) {
					OraclePerformance.mark(fn.name + '-initEnd');
				}

			};

		try {
			// try to set name property of function, okay in most browsers
			// but in iOS 9 Function.name is unconfigurable
			Object.defineProperty(newComponent[fn.name], 'name', {
			  enumerable: false,
			  configurable: true,
			  writable: false,
			  value: fn.name
			});
		} catch(err) {
			/* noop */
		}

		Object.defineProperty(newComponent[fn.name], 'namespace', {
		  enumerable: false,
		  configurable: true,
		  writable: false,
		  value: 'OCOM'
		});

		// grab any extra properties or methods defined
		// and merge into this entity
		jQuery.extend(newComponent[fn.name], fn.prototype);

		// set a property on this component to store contexts
		// in which the function has been called
		newComponent[fn.name].hasRunContexts = [];
		newComponent[fn.name].hasRun = function(context) {
			// context = 'string' === typeof context ? $(context) : context;
			return this.hasRunContexts.some(function(c) {
				return c === context;
			});
		};

		// extend OCOM
		jQuery.extend(this, newComponent);

		// add to globals if flag is set
		if(globalFn && !this.globals.some(function(id) { return id === fn.name; })) {
			this.globals.push(fn.name);
		}

		// check if document.ready has already run and if so, execute immediately
		// 	unless an explicit false is passed to OCOM.register
		if(this.docReady && globalFn !== false) { this[fn.name](); }

		return this[fn.name];

	},

	/**
	 * Searches a given selector context for components.
	 * @class OCOM.findComponentElements
	 * @requires jQuery
	 * @param {string} context - A selector to traverse, defaults to <code>document</code>
	 * @return {array} An array of component/OCOM ids
	 * @example
	 *  OCOM.findComponentElements('.parentDiv');
	 *  &rdca; ["cb24", "cw43", "cn21"]
	 */
	findComponentElements: function(context) {
		'use strict';

		var components = [];

		context = context || document;

		$('[data-ocomid]', context).each(function() {

			var component = $(this);
			// check that component id is not already in the list, and add
			if(!components.some(function(c){return c === component.data('ocomid');})) {
				components.push(component.data('ocomid'));
			}

		});

		return components;

	},

	/**
	 * Convenience function to find components within a given context, check for
	 * 	OCOM method exists and has not run on page, and execute component js if true
	 * @class OCOM.runFoundComponents
	 * @requires jQuery
	 * @param {string} context - A selector to traverse, defaults to <code>document</code>
	 * @example
	 *  OCOM.runFoundComponents('.parentDiv');
	 */
	runFoundComponents: function(context) {
		'use strict';

		var hasRunContext;

		context = context || document;
		hasRunContext = (context instanceof jQuery ? context[0] : context).toString().replace(/(\[.*? |\])/g, '');

		this.findComponentElements(context).forEach(function(component) {
			return OCOM[component] && !OCOM[component].hasRun(hasRunContext) && OCOM[component](context);
		});

		return this;
	},

	/**
	 * Function to run components registered with the global=true flag if they have not
	 * 	already been called by runFoundComponents
	 * @class OCOM.runGlobalComponents
	 */
	runGlobalComponents: function(context) {
		'use strict';

		var hasRunContext;

		context = context || document;
		hasRunContext = (context instanceof jQuery ? context[0] : context).toString().replace(/(\[.*? |\])/g, '');

		this.globals.forEach(function(component) {
			return OCOM[component] && !OCOM[component].hasRun(hasRunContext) && OCOM[component](context);
		});

		return this;
	},

	/**
	 * Utility debug function to to list components that have run within a given context
	 * @class OCOM.listHasRunComponents
	 * @param {string} context - A selector to traverse, defaults to <code>document</code>
	 * @example
	 *  OCOM.listHasRunComponents('.parentDiv');
	 */
	listHasRunComponents: function(context) {
		'use strict';

		var components = [],
			 	hasRunContext;

		context = context || document;
		hasRunContext = context instanceof jQuery ? context[0] : context,

		Object.keys(OCOM).forEach(function(key) {
			if('OCOM' === OCOM[key].namespace && OCOM[key].hasRun(hasRunContext)) {
				components.push(key);
			}
		});

		return components.sort();
	}

};

OCOM.stylesLoaded =
	

/*! GENERIC-STYLESLOADED */
/**
 * Utility function to wait until non-blocking CSS assets have
 * 	loaded before executing a callback.
 *
 * 	@info  <p>Typically, since assets are loaded from same domain,
 * 	         this function can verify if there are CSS rules associated
 * 	         with a given stylesheet.  However, there are some cases
 * 	         (eg. staging, betamode, etc) where trying to access CSS rules
 * 	         throws an InvalidAccessError.  In these cases, a loadevent listener
 * 	         is attached to set <code>data-wscss="loaded"</code>.
 * 	         Failing that, the Deferred is set to resolve after a given timeout,
 * 	         to avoid endless polling.</p>
 * 	         <p><strong>NOTE:</strong> You shouldn't need to use this directly.
 * 	         	This function is imported and used by OCOM framework to determine
 * 	         	if it should wait to run component JS when async CSS is found
 * 	         	in the <code>head</code>.  Therefore, inside any component code registered
 * 	         	with <code>OCOM.register</code> it is <u>safe to assume styles have
 * 	         	already been applied</u>.</p>
 *
 * 	@class OCOM.stylesLoaded
 * 	@see [https://api.jquery.com/jQuery.Deferred/](jQuery.Deferred)
 * 	@returns {jQuery.Deferred} a jQuery Deferred object (Promise) which
 * 	                             resolves once <strong>all</strong>
 * 	                             <code>&lt;link data-wscss&gt;</code> assets have loaded
 * 	@example <caption>Anonymous callback</caption>
 *  OCOM.stylesLoaded().then(function() {
 *  	// do something now that styles have been applied ...
 *  });
 * 	@example <caption>Callback reference</caption>
 *  OCOM.stylesLoaded().then(callbackFn);
 */
(function($, window) {
	/* eslint-disable no-console */
	'use strict';

	// iOS 8.1-8.4 does not support window.performance.now, fallback to Date.now()
	var start = window.performance && window.performance.now() || Date.now(),
			timeout = 10000,
			cached = false,
			docContext = document,
			promise = $.Deferred(),
			DEBUG = 'OCOM' in window && OCOM.debug,
			ATTR_WSCSS = 'data-wscss',
			DATA_LOADED = 'loaded',
			DATA_EVLISTEN = 'loadEventListener',
			inDocSheets = function(link) {
				// checks if link.href has been applied to document
				return (
					Array.prototype.slice.call(docContext['styleSheets'])
						.map(function(sheet) {
							return sheet.href;
						})
						.some(function(href) {
							return href === link.href;
						})
				);
			},
			getSheetName = function(sheet) {
				return sheet.href && sheet.href.slice(sheet.href.lastIndexOf('/') + 1);
			},
			check = function(link) {

				var loaded = false,
						foundRules = 0,
						now = window.performance && window.performance.now() || Date.now(),
						isCrossDomain = !(new RegExp(window.location.origin).test(link.href)),
						isBlocking = !link.as && link.rel !== 'preload',
						isPreLoad = (
							link.as === 'style' &&
							link.rel === 'stylesheet' &&
							link.getAttribute(ATTR_WSCSS) !== 'error'
						),
						loadFired = link.getAttribute(ATTR_WSCSS) === DATA_LOADED,
						timeoutFallback = (now - start > timeout),
						log = '',
						// cache a jQuery instance for event listener and data
						$link = $(link);

				if(DEBUG) {
					log += '[' + parseInt(now, 10) + 'ms] ' + getSheetName(link);
				}

				try {
					// check if rules have been parsed and applied to document
					// In some browsers, if a stylesheet is loaded from a different domain,
					// calling cssRules results in SecurityError
					// https://developer.mozilla.org/en-US/docs/Web/API/CSSStyleSheet#Notes
					foundRules = link.sheet.cssRules.length;
					loaded = Boolean(foundRules) && inDocSheets(link);

				} catch(err) {

					// attach a listener for load
					if(!$link.data(DATA_EVLISTEN)) {

						// set attr value on load
						// set flag for listener has already been attached
						$link.one('error', $link.attr.bind($link, ATTR_WSCSS, 'error'))
							.one('load', $link.attr.bind($link, ATTR_WSCSS, DATA_LOADED))
							.data(DATA_EVLISTEN, true);
					}

					loaded =
						// CSSStyleSheet object exists in CSSOM
						// but doesn't reliably mean external content has loaded
						Boolean(link.sheet) &&
						// if cross-domain, we cannot access cssRules (eg. staging, betamode)
						//  so need to rely on preload handler, or our load event listener
						isCrossDomain &&
						// if its a blocking CSS (*-base.css) ignore rest of checks
						(isBlocking ||
						// catches preload support with onload="this.rel='stylesheet'"
						//  but can return false positive onerror="this.rel='stylesheet'"
						isPreLoad ||
						// catches load event listener
						loadFired) &&
						// make sure this sheet has been applied to document
						inDocSheets(link);
				}

				if(DEBUG) {
					log += [
						loaded || timeoutFallback ? ' ✓ready' : ' ✗not ready',
						isCrossDomain ? ' ✗crossdomain' : ' ✓sameorigin',
						(foundRules ? ' ✓' : ' ✗')
							+ 'cssRules(' + (isCrossDomain ? 'N/A' : foundRules) + ')',
						(inDocSheets(link) ? ' ✓' : ' ✗') + 'document.styleSheets',
						isBlocking ? ' ✓blocking'
							: isPreLoad ? ' ✓preloaded'
								: loadFired ? ' ✓onload fired'
									: timeoutFallback ?  ' ✓timeout fallback' : '',
					].join('\n');
					console.log(log);
				}

				// if things don't work due to CORS or 404,
				//  we should just go ahead after a reasonable timeout - 10sec
				return loaded || timeoutFallback;

			},
			stylesLoaded = function(context) {

				docContext = context || document;

				// check for async css files
				var sheets = $('link[' + ATTR_WSCSS + ']', docContext).get();

				// if check for stylesLoaded is true, cache for future (resize) calls
				// if no async css are found, length = 0 and returns true
				// otherwise, do check to look for CSS rules
				cached = cached ||
								!sheets.length ||
								sheets.every(check);

				// when our checks return true, we resolve the promise
				// otherwise, recheck at an interval until we can resolve
				return cached && promise.resolve()
								|| setTimeout(stylesLoaded.bind(null, docContext), 200) && promise;
			};

	return stylesLoaded;

}(jQuery, window));


// broadcast a ready event for JS defined before OCOM
jQuery(document).triggerHandler('OCOMReady');

jQuery(document).ready(function($) {
		'use strict';

		if(OCOM.debug) {
			console.group && console.group('OCOM');
			console.log('OCOM running within ' + OCOM.codebase);
			console.log('Found elements on page: ', OCOM.findComponentElements());
			console.log('OCOM status: ', OCOM);
		}

		// ensures non-blocking CSS assets have loaded
		// 	before running any component JS
		OCOM.stylesLoaded()
			.then(function() {
				// Loops through the array of component ids found on page and
				// calls each registered function if exists and has not run yet
				OCOM.runFoundComponents();

				// Loops through the array of component ids in OCOM.globals array and
				// calls each registered function if exists and has not run yet
				OCOM.runGlobalComponents();
			});

		OCOM.docReady = true;

		if(OCOM.debug) { return console.groupEnd && console.groupEnd(); }
});




// COMPONENTS

/*! U02 */
/* eslint no-unused-vars:0 */

//var GLOBAL_COUNTRY_HTML = '';

(function($, window) {
	'use strict';

	var CLS_OCOMBASE			= 'ocom-base',
			CLS_RESPONSIVE		= 'ocom-responsive',
			CLS_SMAP					= 'u02smap',
			CLS_NAV						= 'u02nav',
			CLS_LOCALNAV			= 'u02v1',
			CLS_LOCALW2				= 'u02w2',
			CLS_LOCALW3				= 'u02w3',
			CLS_SHOW					= 'u02show',
			CLS_INIT					= 'u02init',
			CLS_DTOP					= 'u02dtop',
			CLS_TAB						= 'u02tab',
			CLS_MOBILE				= 'u02mobi',
			CLS_TABNAV				= 'u02tabnav',
			CLS_MENULINK			= 'u02menulink',
			CLS_CONTENT				= 'u02menucontent',
			CLS_MLINK					= 'u02mlink',
			CLS_MAINMENU			= 'u02mainmenu',
			CLS_MEGAMENU			= 'u02megamenu',
			CLS_MEGACTR				= 'u02megactr',
			CLS_SKIPOPEN			= 'u02skipo',
			CLS_LOGO					= 'u02logo',
			CLS_LOCLABEL			= 'u02local',
			CLS_LOGOW2				= 'u02logow2',
			CLS_NOSPLIT				= 'u02noflyout',
			CLS_TOOLS 				= 'u02tools',
			CLS_NOTOOLS				= 'u02notools',
			CLS_TOOLPOP 			= 'u02toolpop',
			CLS_MTOOL 				= 'u02mtool',
			CLS_TICON					= 'u02ticon',
			CLS_NOOVERRIDE		= 'u02nooverride',
			CLS_LOGGEDOUT			= 'u02toolsloggedout',
			CLS_LOGGEDIN			= 'u02toolsloggedin',
			CLS_USER					= 'u02userinfo',
			CLS_USERDATA			= 'u02userdata',
			CLS_ULINK					= 'u02ulink',
			CLS_CMENU 				= 'u02countrymenu',
			CLS_REGN					= 'u02regn',
			CLS_CURREGN				= 'u02currentcr',
			CLS_DEFLTREGN			= 'u02currentdr',
			CLS_CURRCTRY			= 'u02currentcc',
			CLS_CMENUL1 			= 'u02cmenu-l1',
			CLS_CMENUL2 			= 'u02cmenu-l2',
			CLS_CMENUCOL 			= 'u02cmenuc1',
			CLS_CMENU3COL 		= 'u02cm3cols',
			CLS_CLINK 				= 'u02clink',
			CLS_CMENUPOP			= 'u02cmenupop',
			CLS_CONTACT				= 'u02contact',
			CLS_CTMENU				= 'u02contactmenu',
			CLS_MENUWRAP			= 'u02menuwrap',
			CLS_EQHEIGHT			= 'u02mheight',
			CLS_BTTNS					= 'u02bttns',
			CLS_HASBTTNS			= 'u02hasbttns',
			CLS_DROPDOWN			= 'u02dropdown',
			CLS_HASMENU				= 'u02menu-hasm',
			CLS_NOMENU				= 'u02menu-nomn',
			CLS_NOSUBMENU			= 'u02nosub',
			CLS_MENUL1				= 'u02menu-l1',
			CLS_MENUL2				= 'u02menu-l2',
			CLS_MENUL3				= 'u02menu-l3',
			CLS_MENUUL				= 'u02menu-ul',
			CLS_MENULI 				= 'u02menu-li',
			CLS_POINTER				= 'u02menu-l1z1',
			CLS_OFFSTATE			= 'u02z86d',
			CLS_MORE					= 'u02more',
			CLS_MORELIST			= 'u02morelist',
			CLS_PADDED				= 'u02padded',
			CLS_BACK					= 'u02menuback',
			CLS_OPEN					= 'u02opened',
			CLS_CLOSE					= 'u02closing',
			CLS_CLICKOPEN			= 'u02clickopen',
			CLS_STAYOPEN			= 'u02stayopen',
			CLS_L2OPEN				= 'u02l2open',
			CLS_L3OPEN				= 'u02l3open',
			CLS_HIDE					= 'u02hidefast',
			CLS_HIDEMENU			= 'u02hidemenu',
			CLS_TLINK					= 'u02tlink',
			CLS_BLINK					= 'u02blink',
			CLS_XLINK					= 'u02xlink',
			CLS_HLINK					= 'u02hlink',
			CLS_RTL 					= 'rtl',
			CLS_SEARCH 				= 'u02search',
			CLS_SEARCHPOP			= 'u02searchpop',
			CLS_SEARCHFORM		= 'u02searchform',
			CLS_SEARCHBTTN 		= 'u02searchbttn',
			CLS_FOCUS					= 'sfocus',
			CLS_ERROR					= 'serror',
			CLS_NOHOVER				= 'u02nohover',
			INPUT_SEARCH			= 'input#txtSearch',
			HTML_POINTER			= '<div class="' + CLS_POINTER + '"><i></i></div>',
			DATA_TFWD 				= 'tfwd',
			DATA_CLONED				= 'u02bttncloned',
			EV_MOUSEIN				= 'mouseenter',
			EV_MOUSEOUT				= 'mouseleave',
			EV_POINTOVER			= 'pointerover',
			EV_POINTDOWN			= 'pointerdown',
			EV_CLICK					= 'click',
			EV_KEYDOWN				= 'keydown',
			EV_TOUCH					= 'touchend',
			EV_TOUCHST				= 'touchstart',
			EV_FOCUS					= 'focus',
			EV_BLUR						= 'blur',
			EV_SUBMIT					= 'submit',
			EV_RESIZE					= 'resize',
			EV_ORIENT					= 'orientationchange',
			EV_READY					= 'u02ready',
			EV_MENUOPEN				= 'u02menuopen',
			EV_MENUCLOSE			= 'u02menuclose',
			EV_GLOBALRS				= [],
			NS_U02						= 'u02',
			NS_MOREMENU				= 'moremenu',
			winW 							= 0,
			navType 					= '',
			IS_TOUCH					= 'ontouchstart' in window,
			IS_RTL, 					// must initialize after document ready
			classList = function(arr) {
				return (Array.isArray(arr) && arr.filter(function(cls) {
					// remove any false refs
					return !!cls;
				}).join(' ')) || arr;
			},
			eventList = function(arr, namespc) {
				var ns = namespc || '';
				return classList(
					(Array.isArray(arr) &&
						arr.map(function(ev) {
							return [ev, ns].join('.');
						})) ||
						[arr, ns].join('.') ||
						arr
				);
			},
			classSelector = function(arr, mod) {

				return (Array.isArray(arr) &&
									arr.map(function(cls) {
										return (Array.isArray(mod) &&
															mod.map(function(m) {
																return (Array.isArray(cls) &&
																				'.' + cls.join(m + ' .') + m) ||
																				'.' + cls + m;
															}).join()) ||

														(Array.isArray(cls) &&
															'.' + cls.join(' .') + (mod || '')) ||

															'.' + cls + (mod || '');
									}).join()) ||

								(Array.isArray(mod) &&
									mod.map(function(m) {
										return '.' + arr + m;
									}).join()) ||

									'.' + arr + (mod || '');
			},
			createElement = function(tag, clsArr, attrObj) {
				var el = document.createElement(tag);
				clsArr = clsArr || [];
				clsArr = Array.isArray(clsArr) ? clsArr : [clsArr];
				attrObj = attrObj || {};
				Object.keys(attrObj).map(function(key) {
					el[key] = attrObj[key];
				});
				return $(el).addClass(classList(clsArr));
			};

	/**
	 * Adds tabindex attribute and removes aria-hidden from descendant <a> tags
	 * 	of the provided open submenu root that have a computed visibility of visible.
	 * 	This passed in parameter should be a boolean check whether to do this,
	 * 	since it is an expensive style calculation...
	 */
	jQuery.fn.addAriaAttributes = function(needsAria) {
		return needsAria && this.each(function() {
			var $target = $(this);
			$target.find('a').get().forEach(function(a) {
				var link = a;
				window.requestAnimationFrame(
					function() {
						if(window.getComputedStyle(link, null).visibility === 'visible') {
							link.removeAttribute('aria-hidden');
							link.setAttribute('tabindex', 0);
						}
					});
			});
		}) || this;
	};

	/**
	 * Removes tabindex attribute and adds aria-hidden for *all*
	 * 	descendant <a> tags that have a computed visibility of hidden.
	 * 	This passed in parameter should be a boolean check whether to do this,
	 * 	since it is an expensive style calculation...
	 */
	jQuery.fn.removeAriaAttributes = function(needsAria) {
		return needsAria && this.each(function() {
			var $target = $(this);
			$target.find('a').get().forEach(function(a) {
				var link = a;
				window.requestAnimationFrame(
					function() {
						if(window.getComputedStyle(link, null).visibility === 'hidden') {
							link.setAttribute('aria-hidden', true);
							link.setAttribute('tabindex', -1);
						}
					});
			});
		}) || this;
	};

	/**
	 * Creates a progressive flyout menu within the provided
	 *  nav container.
	 *
	 *  Expects a structure like:
	 *    *container*
	 *      > div.u02menu-l1
	 *        > ul
	 *          > li [x number of menu items]
	 *            > a
	 *            > div.u02menul1 [if submenu]
	 *              > ul
	 *                > li [x number of menu items]
	 *                  > a
	 *                  > div.u02menul2 [if submenu]
	 *                    > ul
	 *                      > li [x number of menu items]
	 *                        > a
	 *                        > div.u02menul3 [if submenu]
	 *                          > ul
	 *                            > li
	 *                              > a
	 */
	jQuery.fn.FlyoutMenu = function() {

		return this.each(function() {

			var $menu = $(this);

			$menu.find(classSelector([CLS_MENUL1,CLS_MENUL2,CLS_MENUL3]))
				.addClass(classList([CLS_MENUWRAP, CLS_EQHEIGHT]));
			$menu.find(classSelector([CLS_MENUL2,CLS_MENUL3]))
				.closest('li').addClass(CLS_HASMENU);

			$menu.find('li').each(function() {
				var $li = $(this),
						btxt;

				if ($li.hasClass(CLS_HASMENU)) {
					btxt = $li.children(classSelector(CLS_TLINK)).text();
					// clone submenu headings that are outbound links
					$li.children(classSelector(CLS_TLINK)).each(function() {
						return !/#open$/.test(this.href) &&
							$(this).clone()
								.prependTo($li.find('ul').first())
								.removeClass(CLS_TLINK).addClass(classList([CLS_XLINK, CLS_HLINK]))
								.wrap(createElement('li', CLS_NOSUBMENU)) || 1;
					});
					$li.find('ul').first()
						.prepend(createElement('li', [CLS_BACK, CLS_NOSUBMENU])
							.html(createElement('a', CLS_BLINK, { href: '#back' }).text(btxt)));
				} else {
					$li.addClass(CLS_NOSUBMENU);
				}
			});

			$menu.find(classSelector([CLS_MENUL1,CLS_MENUL2,CLS_MENUL3], ' > ul')).each(function() {

				var $ul = $(this).addClass(CLS_MENUUL);

				$ul.children('li').each(function() {

					var $li = $(this).addClass(CLS_MENULI);

					return ((!$li.find('a').closest('li').hasClass(CLS_HASMENU) &&
										!$li.find(classSelector(CLS_BLINK))[0]) &&
										$li.find('a').removeClass(CLS_TLINK).addClass(CLS_XLINK)) || 1;
				});
			});

			$menu.find(classSelector(CLS_MENUL1), ' > ul > li').each(function() {
				var $li = $(this);

				return (!$li.hasClass(CLS_HASMENU) &&
									$li.addClass(CLS_NOMENU)
										.children('a').removeClass(CLS_TLINK).addClass(CLS_XLINK)) || 1;
			});

		});
	};

	/**
	 * Utility function to position a direct
	 * 	submenu container, when that container extends beyond
	 * 	the bounds of the viewport (its parent <nav>).
	 * 	Used by jQuery.fn.MoreMenu upon initialization (page load)
	 * 	 and called after the window.resize event for recalc
	 */
	jQuery.fn.menuShift = function(lvl1, lvl2, notL1, moveTgt) {

		if(!this.length) { return this; }

		var $ctr = this.closest('.u02w1'),
				netW = $(window).width(),
				bounds = $ctr[0].getBoundingClientRect(),
				calcShift = function($el) {
					var rect = $el[0].getBoundingClientRect();
					return (rect.left < bounds.left && Math.abs(bounds.left - rect.left)) ||
									(rect.right > bounds.right && Math.abs(bounds.right - rect.right)) ||
									0;
				},
				DATA_XSHIFT = 'xshift';

		lvl1 = lvl1 || CLS_MENUL2;
		lvl2 = lvl2 || CLS_MENUL3;
		notL1 = notL1 || CLS_MORELIST;
		moveTgt = moveTgt || false;

		return this.each(function() {

			var $target = $(this),
					$menu1,
					$menu2,
					$offMenu,
					$moveMenu,
					shiftProp,
					shiftVal,
					widthVal;

			// unset any existing styles before running
			$target.find(classSelector(lvl1)).addBack().each(function() {
				var $el = $(this);
				if($el.data(DATA_XSHIFT)) {
					$el.css($el.data(DATA_XSHIFT), '')
						.css('width', '');
				}
			});

			$menu1 = $target.children(classSelector(lvl1));
			// use u02menu-l3 in calc only if we are not within the more menu
			// and if not mobile
			$menu2 = !$menu1.closest(classSelector(notL1)).length &&
								(navType !== 'MOBI') &&
								$menu1.find(classSelector(lvl2)).first();

			// assign which menu is used for the calc - set to false if no shift needed
			$offMenu = ($target.length && calcShift($target) !== 0 && $target) ||
									($menu1.length && calcShift($menu1) !== 0 && $menu1) ||
									($menu2.length && calcShift($menu2) !== 0 && $menu2);
			$moveMenu = (moveTgt && $target) || $menu1;

			if($offMenu && $offMenu.length)	{

				// run this on the next frame to make sure
				// 	unset styles have been recalc'd and applied
				window.requestAnimationFrame(function() {

					if($moveMenu.outerWidth() > netW) {
						$moveMenu.width(netW);
					}

					shiftProp = IS_RTL ? 'right' : 'left';
					shiftVal = calcShift($offMenu);

					// add the transform, store a ref to prop to unset on next call
					$moveMenu.css(shiftProp, ['-=', shiftVal, 'px'].join(''))
						.data(DATA_XSHIFT, shiftProp);

					widthVal = calcShift($moveMenu);

					if(widthVal !== 0) {
						$moveMenu.css('width', ['-=', widthVal, 'px'].join(''));
					}

					// force global resize handlers to run to correct
					// 	wrongly assigned dtop/mobi classes when content
					// 	was overflowing the window
					EV_GLOBALRS.forEach(function(ev) {
						setTimeout($(window).triggerHandler.bind($(window), ev), 0);
					});

				});
			}
		});
	};

	/**
	 * Creates a tab menu within the provided container, with a 'More' dropdown
	 *  for top level items that cannot fit within the container's width
	 *
	 *  Expects an existing structure on page
	 *    (must be injected if fetched by ajax)
	 *  nav
	 *    .u02w2 (can be nested deeper, eg. within u02w1)
	 *      *container*
	 *        div.u02menu-l1
	 *          > ul
	 *            > li [x number of menu items]
	 *              > a
	 *              > div.u02menul1 [if submenu]
	 *                > ul
	 *                  > li [x number of menu items]
	 *                    > a
	 *                    > div.u02menul2 [if submenu]
	 *                      > ul
	 *                        > li [x number of menu items]
	 *                          > a
	 *                          > div.u02menul3 [if submenu]
	 *                            > ul
	 *                              > li
	 *                                > a
	 *    .u02w3 (generated if not included in markup)
	 */
	jQuery.fn.MoreMenu = function() {

		return this.each(function(i) {

			var $ctr = $(this),
					$u02w2 = $ctr.closest(classSelector(CLS_LOCALW2)),
					$u02 = $ctr.closest('.u02'),
					$nav = $ctr.closest(classSelector(CLS_NAV)),
					TXT_MORE = $nav.data('moretxt') || 'More',
					$listCtr = $ctr.find(classSelector(CLS_MENUL1, ' > ul')),
					$btnCtr = ($nav.find('.u02w3').length && $nav.find('.u02w3')) ||
											createElement('div', 'u02w3').appendTo($nav.find('.u02w1')),
					$listItems = function() { return $listCtr.find('> li').not(classSelector(CLS_MORE)); },
					$moreCtr = createElement('li', [CLS_MORE, CLS_MENULI, CLS_HASMENU, $nav.find(classSelector(CLS_MEGAMENU)).length && CLS_MEGAMENU])
						.html(createElement('a', CLS_TLINK, { href: '#open' }).text(TXT_MORE))
						.appendTo($listCtr),
					$moreMenu = createElement('div', [CLS_MORELIST, CLS_MENUL2, CLS_MENUWRAP, CLS_EQHEIGHT])
						.append(createElement('ul', CLS_MENUUL))
						.appendTo($moreCtr).find(classSelector(CLS_MENUUL)),
					moreArr = [],
					working = false,
					resizeTimeout;

			function setupPointer() {

				var $pointer = $ctr.find(classSelector(CLS_POINTER)).length ?
					$ctr.find(classSelector(CLS_POINTER)) :
					$(HTML_POINTER);
				// move flyout pointer to u02menu-l2, since u02menu-l1
				//  contains top-level links
				$pointer.insertBefore($ctr.find(classSelector(CLS_MENUL2)));
			}

			function setupTabs($items) {
				// adds a data-sort attribute to ensure we can keep
				// the same order when adding/removing from more menu
				return $items.each(function(i) {
					$(this).data({
						sort: i,
						reqwidth: $(this).outerWidth()
					});
				});
			}

			function sortFn(a, b) {
				return $(a).data('sort') - $(b).data('sort');
			}

			function onWindowResized(e) {
				return !working && (working = true) &&
								window.requestAnimationFrame(handleMoreMenu);
			}

			function handleMoreMenu() {

				// make sure more menu padding is in place
				padListItemCtr();

				// first add back any items that will fit
				addBackItems();

				// check for items which have wrapped due to not enough space
				$listItems().each(handleListItem);

				// append items to more menu, sorted in the order they appeared
				$moreMenu.append(moreArr.sort(sortFn))
				// change behavior of .u02menu-hasm to open/close on click only
				// 	or if megamenu style, set it to always be open
					.find(classSelector(CLS_HASMENU))
					.addClass(function() {
						return classList([
							CLS_CLICKOPEN,
							$(this).hasClass(CLS_MEGAMENU) && CLS_STAYOPEN
						]);
					});

				clearTimeout(resizeTimeout);
				resizeTimeout = setTimeout(shiftMenu, 100);

				// toggle visibility of the more menu, unset flag
				return toggleMore() &&
								(working = false) &&
									$listItems().addAriaAttributes($u02.hasClass(CLS_TABNAV)) &&
									$moreMenu.removeAriaAttributes($u02.hasClass(CLS_TABNAV));
			}

			function addBackItems() {
				var $item;
				// if item fits in first row, we remove from moreArr, add back to list items
				while(moreArr.length && getAvailableWidth() >= $(moreArr[0]).data('reqwidth')) {
					$item = $(moreArr.shift());
					$item
						.find(classSelector([CLS_CLICKOPEN, CLS_STAYOPEN])).addBack()
						.removeClass(classList([CLS_CLICKOPEN, CLS_STAYOPEN]));
					$moreCtr.before($item);
				}
			}

			function handleListItem(i, el) {
				// if item has wrapped to second row,
				// we add to moreArr, if not there already
				return (el.offsetTop > 0 &&
								moreArr.indexOf(el) < 0 &&
								moreArr.unshift(el)) ||
				// otherwise return true to prevent .each short-circuit
								true;
			}

			function shiftMenu() {
				return $listItems().add(classSelector(CLS_MORE)).menuShift();
			}

			function toggleMore() {
				return $moreCtr.toggleClass(CLS_SHOW, !!moreArr.length);
			}

			function padListItemCtr() {
				return ($listCtr[0].style[(IS_RTL ? 'paddingLeft' : 'paddingRight')] = getPadW());
			}

			function getAvailableWidth() {
				// returns the available space between edge of the list container <ul>
				// and its parent container
				return $u02w2[0].offsetWidth - $listCtr[0].offsetWidth;
			}

			function getPadW() {
				return $moreCtr.find('> a').outerWidth() + 'px';
			}

			setupPointer();
			setupTabs($listItems());
			handleMoreMenu();

			$(window).off(eventList([EV_RESIZE, EV_ORIENT], [NS_U02, NS_MOREMENU, i].join('-')))
				.on(eventList([EV_RESIZE, EV_ORIENT], [NS_U02, NS_MOREMENU, i].join('-')), onWindowResized);

		});
	};

	/**
	 * Creates a megamenu within the provided container, by adding the needed
	 * 	container class, specifying which submenus need equal height and
	 * 	positioning and sizing the container with menuShift
	 *
	 *  Expects a structure
	 *  *container* li.u02megamenu or div.u02mlink if top-level, single-panel
	 *      div.u02menu-l[n]
	 *        > ul
	 *          > li [x number of menu items]
	 *            > a
	 *            > div.u02menul[n+1] [if submenu]
	 *              > ul
	 *                > li [x number of menu items]
	 *                  > a
	 */
	jQuery.fn.MegaMenu = function() {

		return this.each(function() {

			var $ctr = $(this),
					$menuctr = $ctr.children(classSelector([CLS_CONTENT, CLS_MENUL2, CLS_MENUL3]));

			function setupPointer() {
				// remove any other added pointers and put one before
				// 	the menucontent container
				return $ctr.find(classSelector(CLS_POINTER)).remove() &&
					$menuctr.before(HTML_POINTER) &&
					// 	add a class to set flex-basis to position pointer correctly
					$ctr.closest(classSelector(CLS_LOCALW2)).length &&
					$ctr.closest(classSelector(CLS_LOCALW2)).addClass(CLS_MEGACTR);
			}

			setupPointer();

			$ctr.closest(classSelector(CLS_MEGACTR))
				.find(classSelector([CLS_MENUL1, CLS_MENUL2, CLS_MENUL3]))
				.addClass(CLS_EQHEIGHT);

			$menuctr.menuShift(null, null, null, true);

		});
	};

	/**
	 * Provides a method for opening child menu of the target element
	 * 	and controlling the parent menu item for what level is open.
	 * 	Registers one time handlers for closing menu.
	 */
	jQuery.fn.openMenu = function() {

		return this.each(function() {

			var $target = $(this),
					$top = $target.parents(classSelector(CLS_OPEN)).last(),
					$u02 = $target.closest(classSelector(NS_U02)),
					$nav = $target.closest(classSelector(CLS_NAV)),
					cleanupOnLeave =
						!IS_TOUCH &&
						!$u02.hasClass(CLS_MOBILE) &&
						// no cleanup on megamenu deep submenus
						!$target.closest(classSelector(
							[CLS_MEGAMENU, [CLS_MEGAMENU, CLS_MENUL2]]
						)).not(classSelector(CLS_MLINK)).length &&
						!$target.hasClass(CLS_CLICKOPEN);

			$target
				.removeClass(CLS_CLOSE)
				.addClass(CLS_OPEN)
				.addAriaAttributes($u02.hasClass(CLS_TABNAV))
				.off(eventList(EV_MOUSEOUT, NS_U02))
				.one(eventList(EV_MOUSEOUT, NS_U02),
					(cleanupOnLeave && $target.closeMenu.bind($target)) || null);

			$target.siblings(classSelector(CLS_HASMENU)).not($target)
				// prevents double-open bug in mobile
				// 	(tapping sibling link while submenu is opening)
				// 	by turning off pointer-events during transition
				.addClass(classList([CLS_CLOSE, $u02.hasClass(CLS_MOBILE) && CLS_NOHOVER]))
				.each(function() {
					var $link = $(this);
					return $link
						.data('closeTimeout',
							setTimeout($link.removeClass.bind($link, CLS_CLOSE), 400)) &&
						$u02.hasClass(CLS_MOBILE) &&
						$link.data('nohoverTimeout',
							setTimeout($link.removeClass.bind($link, CLS_NOHOVER), 300)) ||
						this;
				})
				.find(classSelector([CLS_OPEN, CLS_L2OPEN, CLS_L3OPEN])).addBack()
				.removeClass(classList([CLS_OPEN, CLS_L2OPEN, CLS_L3OPEN]));

			$top
				.addClass(function() {
					return $(this).hasClass(CLS_L2OPEN) && CLS_L3OPEN || CLS_L2OPEN;
				});

			$nav.prev(classSelector(CLS_OFFSTATE))
				.addClass(CLS_SHOW)
				.on(eventList([
					(cleanupOnLeave && EV_MOUSEIN || null),
					EV_TOUCH,
					EV_CLICK], NS_U02), $target.closeMenu.bind($target));

			$target.trigger(EV_MENUOPEN);
		});
	};

	/**
	 * Provides a method for closing menus within the target element
	 * 	or close all that can be called on the top level <nav>
	 */
	jQuery.fn.closeMenu = function() {

		return this.each(function() {

			var $target = $(this),
					$top = $target.parents(classSelector(CLS_OPEN)).last(),
					$u02 = $target.closest(classSelector(NS_U02)),
					openClasses = [CLS_OPEN, CLS_HIDEMENU, CLS_L2OPEN, CLS_L3OPEN];

			if ($target.hasClass(CLS_NAV)) {

				$target.find(classSelector(openClasses))
					.removeClass(classList(openClasses)).end()
					.find(classSelector([[CLS_CMENUPOP, CLS_SHOW]]))
					.removeClass(CLS_SHOW).end()
					.prev(classSelector(CLS_OFFSTATE))
					.removeClass(CLS_SHOW)
					.off(eventList([
						EV_MOUSEIN,
						EV_TOUCH,
						EV_CLICK], NS_U02)).end()
					.removeAriaAttributes($u02.hasClass(CLS_TABNAV))
					// kill listener for menuopen for badge flyout
					.off(eventList(EV_MENUOPEN, [NS_U02, 'badge'].join('-')));

			} else {

				$target
					.addClass(CLS_CLOSE)
					.data('closeTimeout',
						setTimeout($target.removeClass.bind($target, CLS_CLOSE), 400))
					.removeClass(classList([CLS_OPEN, CLS_L2OPEN, CLS_L3OPEN]))
					.removeAriaAttributes($u02.hasClass(CLS_TABNAV))
					.find(classSelector(CLS_OPEN)).removeClass(CLS_OPEN).end()
					.find('a').blur();

				$top.removeClass(function() {
					return $(this).hasClass(CLS_L3OPEN) && CLS_L3OPEN || CLS_L2OPEN;
				});

				if(!$target.closest(classSelector(CLS_OPEN)).length) {
					$target.closest(classSelector(CLS_NAV))
						.prev(classSelector(CLS_OFFSTATE))
						.removeClass(CLS_SHOW);
				}

			}

			$target.trigger(EV_MENUCLOSE);

		});
	};

	/**
	 * Main initialization of U02 nav, both U02v0 (global nav)
	 * 	and U02v1 (local nav).  Returns a closure to scope all
	 * 	element selectors and event handlers to the initialized
	 * 	nav container.
	 * @param  {jQuery} $ctr  - the <nav> element (top level container)
	 * @param  {number} index - numeric index, eg. from jQuery.each(function(index) { })
	 */
	function init($ctr, index) {
		index = index || 0;

		return (function() {

			var	$nav = $ctr,
					$u02 = $nav.find('> .u02'),
					$u02m = $u02.find(classSelector(CLS_MLINK)),
					$others = $(classSelector(CLS_NAV)).not($nav),
					isGlobal = !$u02.hasClass(CLS_LOCALNAV),
					// provides unique namespacing for all
					// 	event handlers
					evList = function(arr, namespc) {
						var ns = [NS_U02, index];
						if(namespc) { ns.push(namespc); }
						ns = ns.join('-');
						return eventList.call(null, arr, ns);
					},
					contentCache = {},
					menucontent,
					cmenucontent,
					ctmenucontent,
					// window width reference
					wcheck = 0,
					// window scroll reference
					wscroll = 0,
					// flag for debouncing main resize handler
					u02working = false,
					// flag for short circuiting tool switch
					hasClosed = false,
					// setTimeout ref for debouncing equalHeight fn
					resizeTimeout;

			// checks if either .u02nav or ancestor (body) has class .rtl
			IS_RTL = $nav.add($others).closest(classSelector(CLS_RTL)).length;

			// menu content is either a link to external site map or
			// can be included in the markup
			menucontent = ($u02m.length &&
											$u02m.find(['a#u02menulink', classSelector(CLS_MENULINK)].join())
												.first().attr('href')) ||
											$u02.find(classSelector(CLS_CONTENT)).parent();

			cmenucontent = isGlobal &&
											$u02.find('a' + classSelector(CLS_REGN)).attr('href');

			ctmenucontent = isGlobal &&
											$u02.find('a' + classSelector(CLS_CONTACT)).attr('href');

			$nav.before(createElement('div', CLS_OFFSTATE));

			$u02.data(DATA_TFWD, true);

			// store a reference to the nav resize events,
			// 	to call after menu shift of local nav and toolpops
			// 	addresses race condition of overflow content that
			// 	gives an incorrect window.innerWidth
			// 	which can cause incorrectly set dtop/mobi classes
			EV_GLOBALRS.push(evList(EV_RESIZE));

			if(isGlobal) {

				// hamburger markup, toolpop pointers
				addIconMarkup();

				// inject badge flyout (only if has local label)
				addBadgeFlyout();

				// show/hide user name & menu
				/* globals USER */
				addUserInfo(USER);

				$u02.toggleClass(CLS_NOTOOLS, !$u02.find(classSelector(CLS_TOOLS)).length);

				// replace country menu source with OTN source on OTN pages
				if(/oracle\.com\/technetwork/.test(window.location.href) && cmenucontent) {
					$u02.find('a' + classSelector(CLS_REGN))
						.attr('href', function() {
							return this.href.split('#')[0] + '#u02countrymenu-otn';
						});
				}
			}

			return oracleDataMenu.fetchMenuContent(menucontent, contentCache)
				.fail(logError)
				.then(onMenuContentLoaded)
				.then(function($menu) {

					var $target = ($u02m.length && $u02m) || menucontent;

					$menu
						.FlyoutMenu()
						.appendTo(
							// if menu content was hard-coded into HTML,
							// we replace with generated markup
							$target.find(classSelector(CLS_CONTENT)).length &&
								$target.find(classSelector(CLS_CONTENT)).remove().end() || $target
						)
						.before(HTML_POINTER)
						.addClass(function() {
							return isGlobal && CLS_MAINMENU;
						});


					if(!isGlobal) {

						// change behavior of buttons with flyouts to click open
						$u02.find(classSelector([[CLS_BTTNS, CLS_HASMENU]]))
							.addClass(classList([CLS_CLICKOPEN, CLS_DROPDOWN]))
							.find(classSelector(CLS_TOOLPOP))
							.before(HTML_POINTER);

						if($u02.find(classSelector(CLS_MEGAMENU)).length) {

							// add hamburger markup
// 							$u02m.addClass('u02haml')
// 								.find('.u02mlinkw1 > a')
// 								.prepend(createElement('div', 'u02hamenu')
// 									.html(
// 										'<span class="m2"></span>' +
// 										'<span class="m3"></span>'
// 									));


							$u02.find(classSelector(CLS_MEGAMENU)).MegaMenu();

						} else {

							// must initialize after injecting so that
							// it has a reference to its nav container
							$menu.MoreMenu();

							// remove u02mlink class on local nav
							$u02m.removeClass(CLS_MLINK)
								.find('.u02mlinkw1')
								.remove();

							$menu
								// remove mheight class / inline styles from top level links
								.find(classSelector(CLS_MENUL1))
								.removeClass(CLS_EQHEIGHT)
								.css('cssText', '');
						}
					}
				})
				// regardless of menucontent fetch, always run initialization
				// 	event handlers without targets will fail silently
				.always(function() {

					// grep acct links for domain fixing
					updateLinks(isGlobal);
					resizeMenu();
					initDeviceType();
					initKeyboardEvents();
					initSearchEvents();
					initSkipPanelEvents();
					initToolPanelEvents();
					initMenuEvents();

					// if needed, other code can listen for 'u02ready'
					return $u02.addClass(CLS_INIT) && $nav.trigger(EV_READY) &&
									// only trigger resize event on responsive pages
									($nav.closest(classSelector([CLS_RESPONSIVE, 'f11'])).length &&
										$(window).off(evList([EV_RESIZE, EV_ORIENT]))
											.on(evList([EV_RESIZE, EV_ORIENT]), onWindowResized));
				});


			/////////////////////////////////////////////////////////////////////////////////////////////
			//  INSTANCE FUNCTIONS
			/////////////////////////////////////////////////////////////////////////////////////////////

			function addUserInfo(user) {
				// only called if isGlobal
				var $user = $u02.find(classSelector([[CLS_USER, CLS_USERDATA, CLS_ULINK]])),
						$avatar = $u02.find(classSelector([[CLS_USER, 'u02useravatar']])),
						NOT_FOUND = 'NOT_FOUND',
						usertxt = '',
						avatartxt = '';


				// legacy compatibility
				if(!$user.length) {
					$u02.find('.u02userinw1, .u02userinw2')
						.wrapInner(function() {
							return createElement('div','u02usertools')
								.append($(this).hasClass('u02userloggedin') &&
																				createElement('div', CLS_CONTENT));
						})
						.prepend(function() {
							return $(this).hasClass('u02userloggedin') &&
													createElement('div', CLS_USER)
														.append(createElement('div', CLS_USERDATA));
						}).end()
						.find('#u02userinfo').remove().end()
						.find('ul[id="u02usertools"], ul.u02usertools')
						.removeAttr('id')
						.removeClass('u02usertools')
						.wrap(function() {
							return $(this).closest('.u02userinw1')
								.hasClass('u02userloggedin') &&
															createElement('div', CLS_MENUL1);
						})
						.addClass(function() {
							return !$(this).closest('[class*="u02userinw"]')
								.hasClass('u02userloggedin') &&
															'u02usertools-ul';
						}).end()
						.find('a.u02bttn')
						.removeClass('u02bttn')
						.wrap(function() {
							return $(this).data('lbl') === 'signin' &&
														createElement('div', 'u02bttn');
						}).end()
						.find(classSelector(CLS_CONTENT, '> a'))
						.not(document.getElementById('#u02pfile-acct'))
						.wrap(createElement('li')).removeClass('u02bttn')
						.closest('li')
						.appendTo(classSelector(CLS_CONTENT, ' ul'));

					$user = $u02.find('#u02pfile-acct')
						.unwrap()
						.prependTo(
							$u02.find(classSelector([[CLS_USER, CLS_USERDATA]]))
						)
						.addClass(CLS_ULINK);
				}

				$u02.find('.u02userin')
					// THINK THIS IS NOT NEEDED...
					// .prepend('<h5 class="u02pttl u02userloggedin">' +
					// 						$u02.find('.u02signout').text() +
					// 					'</h5>\n' +
					// 					'<h5 class="u02pttl u02userloggedout">' +
					// 						$u02.find('.u02signin').text() +
					// 					'</h5>')
					.find(classSelector(CLS_CONTENT)).FlyoutMenu()
					.find(classSelector(CLS_EQHEIGHT))
				// no equal height needed
					.removeClass(CLS_EQHEIGHT)
				// remove any inline styles
					.css('cssText', '').end()
					// change behavior of .u02menu-hasm to open/close on click only
					.find(classSelector(CLS_HASMENU))
					.addClass(CLS_CLICKOPEN).end()
					// remove back nav
					.find(classSelector(CLS_BACK)).remove();


				if(!user || !user.guid) { return false; }

				if (user.username && user.username !== NOT_FOUND) {
					usertxt = user.username;
					avatartxt = user.username[0].toUpperCase();
				}
				if (user.firstname && user.firstname !== NOT_FOUND &&
							user.lastname && user.lastname !== NOT_FOUND) {
					usertxt = [user.firstname, user.lastname].join(' ');
					avatartxt = [user.firstname[0].toUpperCase(),
						user.lastname[0].toUpperCase()].join('');
				} else if (user.firstname && user.firstname !== NOT_FOUND) {
					usertxt = user.firstname;
					avatartxt = user.firstname[0].toUpperCase();
				} else {
					$user.addClass('u02usernoname');
				}

				$user
					.text(usertxt.trim())
					.attr('data-lbl', 'user-account');

				if($avatar.length) {
					// only use text if no icon or image
					if(!$avatar.children('div').first().is('[class*="u02icn"]') &&
							!$avatar.find('img').length) {
						$avatar.children('div').first().empty().append('<h6>'+avatartxt+'</h6>');
					}
				}

				$u02.find(classSelector(CLS_LOGGEDOUT))
					.removeClass(CLS_LOGGEDOUT)
					.addClass(CLS_LOGGEDIN);
			}

			function buildCountryMenu(html) {

				var $src = $u02.find(classSelector(CLS_REGN)),
						href = $src.length && $src.attr('href'),
						// needed if called from local nav menu content
						$tool = $nav.add($others).find('#u02cmenu'),
						$pointer = $(HTML_POINTER),
						$toolpop = createElement('div', [CLS_CMENUPOP, CLS_TOOLPOP]),
						cmid,
						$cmenu;

				// make sure that no-override flag has not been set by
				// 	country menu built from	local nav menu source
				if(isGlobal && $src.hasClass(CLS_NOOVERRIDE)) {
					return false;
				}

				cmid = href && href.split('#')[1] || CLS_CMENU;

				$cmenu = $('#' + cmid, html);

				$cmenu.find(classSelector(CLS_CMENUL1, ' > li')).each(function() {
					var $li = $(this),
							btxt = $li.children(classSelector(CLS_CLINK)).text();
					$li.find('> div > ul').first()
						.prepend(createElement('li', [CLS_BACK, CLS_NOSUBMENU])
							.html(createElement('a', CLS_BLINK, { href: '#back' }).text(btxt)));
				});

				$cmenu.find(classSelector(CLS_CMENUL2)).each(function() {
					var $menu = $(this);
					if ($menu.find(classSelector(CLS_CMENUCOL)).length === 3) {
						$menu.addClass(CLS_CMENU3COL);
						$menu.closest(classSelector(CLS_CMENU)).addClass(CLS_CMENU3COL);
					}
				});

				$cmenu.find(classSelector(CLS_CMENU, ' > ul'))
					.prepend(createElement('li', 'u02pttl-li')
						.html(createElement('h5', 'u02pttl').text($tool.find(classSelector(CLS_TICON)).text())));

				$cmenu.find(classSelector(CLS_CURREGN)).addClass(CLS_DEFLTREGN);

				$tool
					.append(!$tool.find(classSelector(CLS_POINTER)).length && $pointer)
					.append(!$tool.find(classSelector(CLS_TOOLPOP)).length && $toolpop)
					.find(classSelector(CLS_CMENUPOP)).html($cmenu).end()
					.find('h5.u02pttl, .u02ticon > span').text(function(i, txt) {
						return $cmenu.data('toollabel') || txt;
					});

				if ($tool.find(classSelector(CLS_CMENUPOP, ' .u02cmenu-simple')).length) {
					$tool.find(classSelector(CLS_CMENUPOP)).addClass(CLS_CMENUPOP + '-simple');
				} else {
					$tool.find(classSelector(CLS_CMENUPOP)).removeClass(CLS_CMENUPOP + '-simple');
				}

				$tool.find(classSelector(CLS_REGN)).attr('href', '#' + cmid)
				// flags no-override if countrymenu came from local menu source,
				// 	needed due to async timing of menucontent calls - local menu
				// 	may hit before global menu source
					.addClass(function() {
						return !isGlobal && CLS_NOOVERRIDE;
					});

				addAriaTree();

				return setCountryIndicator();
			}

			function buildContactMenu(html) {

				var $src = $u02.find(classSelector(CLS_CONTACT)),
						// needed if called from local nav menu content
						$tool = $nav.add($others).find('#u02contact'),
						$pointer = $(HTML_POINTER),
						$toolpop = createElement('div', [CLS_CONTACT,CLS_TOOLPOP]),
						isLocal = $u02.hasClass(CLS_LOCALNAV),
						ctmid,
						$ctmenu;

				// make sure that no-override flag has not been set by
				// 	country menu built from	local nav menu source
				if(!isLocal && $src.hasClass(CLS_NOOVERRIDE)) {
					return false;
				}

				// legacy markup support for #u02call
				if(!$tool.length) {
					$tool = $nav.add($others).find('#u02call')
						.attr('id', CLS_CONTACT)
						.removeClass('u02mbttn')
						.addClass(CLS_MTOOL)
						.find(classSelector(CLS_TICON))
						.removeClass('u02call o-call')
						.addClass(CLS_CONTACT).end();
				}

				ctmid = $src.length && $src.attr('href').split('#')[1] ?
					$src.attr('href').split('#')[1] : CLS_CTMENU;

				$ctmenu = $('#' + ctmid, html).length && $('#' + ctmid, html) ||
										// legacy support for u02modal content
										$('.u02callmodal', html).removeClass('u02mod').attr('id', CLS_CTMENU);

				$tool
					.append(!$tool.find(classSelector(CLS_POINTER)).length && $pointer)
					.append(!$tool.find(classSelector(CLS_TOOLPOP)).length && $toolpop)
					.find(classSelector(CLS_TOOLPOP)).html($ctmenu).end()
					.find(classSelector(CLS_TICON, '> span')).text(function(i, txt) {
						return $ctmenu.data('toollabel') || txt;
					});

				$tool.find('a' + classSelector(CLS_CONTACT)).attr('href', '#' + ctmid)
				// flags no-override if countrymenu came from local menu source,
				// 	needed due to async timing of menucontent calls - local menu
				// 	may hit before global menu source
					.addClass(function() {
						return isLocal && CLS_NOOVERRIDE;
					});
			}

			function updateLinks(isGlobal) {

				var $pacct = $u02.find('#u02pfile-acct, .u02ulink'),
						$pregs = $u02.find('#u02pfile-regs'),
						$psout = $u02.find('#u02pfile-sout'),
						hloco = window.location.host,
						turl = encodeURI(window.location.href.replace(/^http:/gi, 'https:'))
							.replace(/^https:\/\/www-content/gi, 'http://www-content');

				if($pacct.length) {
					$pacct.attr('href', $pacct.attr('href').replace(/nexturl=/gi, 'nexturl=' + turl));
				}
				if($pregs.length) {
					$pregs.attr('href', $pregs.attr('href').replace(/nexturl=/gi, 'nexturl=' + turl));
				}
				if($psout.length) {
					$psout.attr('href', $psout.attr('href').replace(/p_done_url=/gi, 'p_done_url=' + turl));
				}

				// if page is in a frame target top
				if (window.frameElement) {
					$u02.find('a', classSelector(CLS_SEARCHFORM)).attr('target', '_top');
				}

				return (/www-(sites|stage)\.oracle\.com/.test(hloco) &&
						(
							$pregs.attr('href', $pregs.attr('href')
								.replace(/www\.oracle\.com/,
									'www-portal-stage.oracle.com')) &&
							$psout.attr('href', $psout.attr('href')
								.replace(/login\.oracle\.com/,
									'login-stage.oracle.com'))
						)) ||
					(/^(?!portal-)stage\.oracle\.com/.test(hloco) &&
						(
							$pregs.attr('href', $pregs.attr('href')
								.replace(/www\.oracle\.com/,
									'www-content-stage.oracle.com'))
						)) ||
					(/www-(sites-)?dev/.test(hloco) &&
						(
							$pregs.attr('href', $pregs.attr('href')
								.replace(/www\.oracle\.com\/webapps/,
									'adc2170261.us.oracle.com')) &&
							$psout.attr('href', $psout.attr('href')
								.replace(/login\.oracle\.com/,
									'adc2201490.us.oracle.com'))
						)) ||
					(/www-content\.oracle/.test(hloco) &&
						(
							$pregs.attr('href', $pregs.attr('href')
								.replace(/www\.oracle\.com/,
									'www-content.oracle.com'))
						)) ||
					(/portal-stage\.oracle/.test(hloco) &&
						(
							$pregs.attr('href', $pregs.attr('href')
								.replace(/.*nexturl=/gi,
									'http://www-portal-stage.oracle.com/webapps/redirect/signon?nexturl='))
						));
			}

			function addIconMarkup() {

				// add hamburger markup
// 				$u02m.addClass('u02haml')
// 					.find('a')
// 					.prepend(createElement('div', 'u02hamenu')
// 						.html(
// 							'<span class="m1"></span>' +
// 							'<span class="m2"></span>' +
// 							'<span class="m3"></span>' +
// 							'<span class="m4"></span>'
// 						));

///				$u02m.addClass('u02haml').find('a').prepend(createElement('div', 'u02hamenu'));

				// add xtra object to toolpop (can't use before)
				$u02.find(classSelector(CLS_TOOLPOP))
					.before(HTML_POINTER);

				if($u02.find(classSelector(CLS_SEARCH)).length) {
					// add search link object for opening search on mobile
					$u02.find('.u02menu')
						.before(createElement('a', [], { id: 'mobisearch', href: '#search' })
							.html(createElement('span').text($u02.find('#u02skip2s').text())
								.html('<i class="u02i1"></i><i class="u02i2"></i>')));
				}

				$u02.find('.u02userlogins > a')
					.append(createElement('div', 'u02loginmenu')
						.html(
							'<span class="m2"></span>' +
							'<span class="m3"></span>'
						));
			}

			function addBadgeFlyout() {

				if(!$u02.find(classSelector(CLS_LOCLABEL)).length ||
					$u02.find(classSelector(CLS_LOGO)).hasClass(CLS_NOSPLIT)) { return false; }

				var $logo = $u02.find(classSelector(CLS_LOGO)),
						$ga = $logo.find('a'),
						$la = $u02.find(classSelector(CLS_LOCLABEL, ' a')),
						globalLink = $ga.attr('href'),
						globalTxt = $ga.attr('title') || $ga.text().trim(),
						localLink = $la.attr('href'),
						localTxt = $la.attr('title') || $la.text().trim();

				return createElement('div', CLS_LOGOW2)
					.append(createElement('a', null,
						{ href: localLink,
							title: localTxt,
							textContent: localTxt
						}))
					.append(createElement('hr'))
					.append(createElement('a', null,
						{ href: globalLink,
							title: globalTxt,
							textContent: globalTxt
						}))
					.appendTo($logo)
					.removeAriaAttributes($u02.hasClass(CLS_TABNAV))
					.addAriaAttributes($u02.hasClass(CLS_TABNAV))
					.before(HTML_POINTER) &&
									$logo.on(evList([EV_MOUSEIN, EV_TOUCH, EV_CLICK]), onBadgeTrigger);

				function onBadgeTrigger(e) {

					var namespc = [NS_U02, 'badge'].join('-');

					// follow links within flyout
					if($(e.target).is('a') &&
							$(e.target).closest(classSelector(CLS_LOGOW2)).length) {
						return true;
					}

					if(IS_TOUCH && (e.type === EV_MOUSEIN || e.type === EV_MOUSEOUT)) {
						return false;
					}

					e.preventDefault();

					return (!$logo.hasClass(CLS_OPEN) &&
									$nav.add($others).closeMenu() &&
									$u02.find('#mobisearch, #u02search').removeClass(CLS_SEARCHPOP) &&
									$logo.openMenu() &&
									$nav.add($others)
										.off(eventList(EV_MENUOPEN, namespc))
										.one(eventList(EV_MENUOPEN, namespc), $logo.closeMenu.bind($logo))) ||
									($logo.closeMenu() &&
									$nav.add($others).off(eventList(EV_MENUOPEN, namespc)));
				}
			}

			function toolSwitch($li) {

				// always blur search field
				$nav.add($others).find(INPUT_SEARCH).blur();

				// short circuit on load, resize handler
				if((!$li || $li == null) && hasClosed) { return true; }

				resetCountryMenu(function() {
					$u02.find(classSelector(CLS_CMENU))
					// set to data-attr to allow for clearing on region change
						.data('cmenuTimeout',
							setTimeout(cmenuEqualHeight, 400));
				});

				$u02.find(classSelector([[CLS_TOOLS, CLS_OPEN]]))
				// don't close toolpop if we're in a menu inside it
					.not(function() {
						return $li && !$li.hasClass(CLS_MTOOL) ||
										$li && $li.length &&
										$li.closest(classSelector(CLS_MTOOL))[0] === this;
					})
					.closeMenu();

				if ($li && $li.length) {

					$li.addClass(CLS_OPEN);

					if($li.hasClass(CLS_MTOOL)) {
						$li.addAriaAttributes($u02.hasClass(CLS_TABNAV));
						// prep height transition on user more menu
						$li.find(classSelector(CLS_MENUL2)).prepareHeightTransition();
					}

					if(!$u02.hasClass(CLS_MOBILE)) {
						$u02m.add($others).closeMenu();
					}

					$nav.prev(classSelector(CLS_OFFSTATE)).addClass(CLS_SHOW)
						.off(evList([EV_TOUCH, EV_CLICK], 'toolpop'))
						.one(evList([EV_TOUCH, EV_CLICK], 'toolpop'), toolSwitch.bind(null, null));

					// TOOL PANELS CLOSE ON LEAVE - DESKTOP
					$li.one(EV_MOUSEOUT,
						!IS_TOUCH &&
						$u02.hasClass(CLS_DTOP) &&
						$li.hasClass(CLS_MTOOL) &&
						function() {
							$li.addClass(CLS_NOHOVER);
							toolSwitch(null);
							setTimeout($li.removeClass.bind($li, CLS_NOHOVER), 600);
						});

					return $li.trigger(EV_MENUOPEN) && (hasClosed = false);

				} else {

					return $u02.find(classSelector(CLS_MTOOL))
						.off(EV_MOUSEOUT)
						.closeMenu() &&
						(hasClosed = true);
				}
			}

			function shiftToolPop() {
				var $toolpops = $u02.find(classSelector(CLS_TOOLPOP));
				return $u02.hasClass(CLS_DTOP) &&
								window.requestAnimationFrame(
									$toolpops.menuShift.bind($toolpops, null, null, null, true)) || 1;
			}

			function shiftMegaMenu() {

				var $megamenus = $u02.find(classSelector([[CLS_MEGACTR, CLS_MLINK], CLS_MEGAMENU]))
					.children(classSelector([
						CLS_CONTENT,
						navType !== 'MOBI' && CLS_MENUL2
					]));

				return (navType === 'MOBI' &&
								$u02.find(classSelector([[CLS_MEGACTR, CLS_MENUL2]]))
									// unset any previous width calc
									.css('width', '') || 1) &&
								$megamenus.length &&
									window.requestAnimationFrame(
										$megamenus.menuShift.bind($megamenus, CLS_MENUL1, null, null, true));
			}

			function onWindowResized(e) {
				return !u02working &&
					(u02working = true) &&
					window.requestAnimationFrame(resizeMenu.bind(null, e));
			}

			function resizeMenu(e) {

				//  iOS/Chrome reports false values for window.innerWidth
				//  	on orientationchange, so more reliable to just check
				//  	the width of the nav
				//  *BUT* because the presence of scrollbar can impact this size,
				//  	we can't use it to determine whether to set dtop/mobi class
				//  	so we use the content of the :before which gets set by CSS
				winW = $nav.outerWidth();

				// reliably gets 'DTOP', 'TAB' or 'MOBI' based on media query
				navType = window.getComputedStyle($u02[0], ':before').content.replace(/\W/g,'');

				// test if nav width has changed to prevent code running on iOS onscroll
				if (wcheck !== winW || (e && e.type === 'orientationchange')) {
					wcheck = winW;

					// defer equal height processing until resize is complete
					clearTimeout(resizeTimeout);

					$nav.closeMenu();

					// SET MOBILE
					if (navType === 'MOBI') {

						$u02.removeClass(classList([CLS_TAB, CLS_DTOP])).addClass(CLS_MOBILE);
						cloneButtons();

					// SET DESKTOP
					} else {

						$u02.addClass(CLS_DTOP)
							.toggleClass(CLS_TAB, navType === 'TAB')
							.removeClass(CLS_MOBILE);

						removeClonedButtons();

					}

					resizeTimeout = setTimeout(function() {
						return equalHeights() && shiftToolPop() && shiftMegaMenu();
					}, 100);

					// remove any menuclose listeners attached for targetEqualHeights
					$nav.find(classSelector(CLS_HASMENU)).off(evList(EV_MENUCLOSE));
				}

				return (u02working = false);
			}

			function equalHeights() {
				return $nav
					.find(classSelector(CLS_EQHEIGHT)).css('height', '').end()
					.find(classSelector(
						[
							[CLS_MAINMENU, CLS_MENUL1],
							[[CLS_LOCALNAV, CLS_DTOP].join('.'),
								CLS_MENUL1 + '> ul >', CLS_HASMENU
							]
						]))
					.not(classSelector(
						[
							CLS_MEGAMENU,
							[CLS_MEGAMENU, CLS_HASMENU]
						]))
					.each(function() {
						var $eqHts = $(this).find(classSelector(CLS_EQHEIGHT))
							.addBack(classSelector(CLS_EQHEIGHT)).addClass(CLS_SHOW);
						window.requestAnimationFrame(function() {
							$u02.find(classSelector(CLS_PADDED)).removeClass(CLS_PADDED);
							$eqHts.equalHeight(true).removeClass(CLS_SHOW);
							return !isGlobal && $u02.find(classSelector(CLS_MORELIST)).addClass(CLS_PADDED);
						});
					}) &&
					cmenuEqualHeight() &&
					megamenuEqualHeights() &&
					!isGlobal && $u02.find(classSelector([CLS_MEGAMENU, CLS_MENUL2])).addClass(CLS_PADDED);
			}

			function targetEqualHeights($target) {

				$u02.find(classSelector(CLS_EQHEIGHT)).css('height', '').end()
					.find(classSelector(CLS_PADDED)).removeClass(CLS_PADDED);

				var $eqHts = $target.parents(
							classSelector([
								CLS_MENUL2,
								navType !== 'DTOP' && CLS_MENUL1
							]))
							.find(classSelector(CLS_EQHEIGHT))
							.addBack(classSelector(CLS_EQHEIGHT))
							.filter(function() {
								// only include open menus
								return $(this).closest(classSelector([CLS_MLINK, CLS_HASMENU])).hasClass(CLS_OPEN);
							})
							.addClass(CLS_SHOW),
						// use the natural height of the open menu instead of the tallest
						eqHeight = $target.find(classSelector(CLS_EQHEIGHT))
							.first().outerHeight();

				return window.requestAnimationFrame(function() {
					$eqHts.css('height', eqHeight).removeClass(CLS_SHOW);
					return $u02.find(classSelector(CLS_MORELIST)).addClass(CLS_PADDED);
				}) &&
				$target.one(evList(EV_MENUCLOSE), function(e) {
					e.stopPropagation();
					// only reset on close if in mobile
					return navType === 'MOBI' && targetEqualHeights($target.parents(classSelector([CLS_HASMENU, CLS_MLINK])).first());
				});
			}

			function megamenuEqualHeights() {

				// only do equal height in tablet/mobile view
				return navType !== 'DTOP' &&
								$nav.find(classSelector(CLS_MEGACTR))
									.each(function() {

										var $eqHts = $(this).find(classSelector(CLS_EQHEIGHT))
											.addBack(classSelector(CLS_EQHEIGHT))
											// no u02menu-l3 in tablet
											.not(classSelector(navType === 'TAB' && CLS_MENUL3))
											// no u02menu-l2 for single-panel megamenu
											.not(classSelector($u02m.hasClass(CLS_MEGAMENU) && CLS_MENUL2))
											.addClass(CLS_SHOW);

										return (navType === 'TAB' &&
											$u02.find(classSelector([[CLS_MEGACTR, CLS_MENUL3]]))
												// unset any previous height calc for menu-l3 in tablet
												.css('height', '') || 1) &&
											window.requestAnimationFrame(function() {
												return $eqHts.equalHeight(true).removeClass(CLS_SHOW);
											});
									}) ||
									$nav.find(classSelector(CLS_EQHEIGHT)).css('height', '');
			}

			function cmenuEqualHeight(force) {

				// only need to do the current region - this gets re-called on region change
				var $cmenus = $u02.find(classSelector([CLS_CMENUL1, [CLS_CURREGN, CLS_CMENUL2]])),
						// iPad Chrome mis-reports window.innerWidth on orientationchange,
						// 	so we just base it off of media query css of toolpop panel
						doheight = $u02.find(classSelector(CLS_CMENUPOP)).width() > 340 || !!force;

				// clear any running timeout from resetCountryMenu
				clearTimeout($u02.find(classSelector(CLS_CMENU)).data('cmenuTimeout'));

				// unset existing equal height styles
				return $u02.find(classSelector([CLS_CMENUL1, CLS_CMENUL2], '[style*="height"]'))
					.css('height', '') &&
								(doheight && $cmenus.equalHeight(true)) || 1;
			}

			function resetCountryMenu(cb) {

				// reset region to default
				if (!$u02.find(classSelector([[CLS_CURREGN, CLS_DEFLTREGN]])).length) {
					$u02.find(classSelector(CLS_DEFLTREGN, ' > a')).focus();
					$u02.find(classSelector(CLS_CURREGN)).removeClass(CLS_CURREGN);
					$u02.find(classSelector(CLS_DEFLTREGN)).addClass(CLS_CURREGN);
				}

				$u02.find(classSelector([[CLS_CMENU, CLS_SHOW]])).removeClass(CLS_SHOW);

				return cb && cb();
			}

			/* globals PDITLocaleMap */
			function setCountryIndicator() {

				var $links = $(classSelector(CLS_CMENUPOP, ' a:not(.u02clink):not(.u02blink)')),
						siteid = $('meta[name="siteid"]').attr('content'),
						DATA_CURR = 'data-currentcc';

				return ('undefined' === typeof PDITLocaleMap || siteid == null) ||

					PDITLocaleMap.init().then(function(data) {

						var $label = $links
							// store a data-attr with a score for how many types of matches
							// 	are found for a given link, since englishcountryname may not
							// 	be what's displayed, so also have to check siteid against href
							.attr(DATA_CURR, function() {
								var matches = 0;
								matches += +(this.textContent === data[siteid].englishcountryname);
								matches += +(this.textContent === data[siteid].countryname);
								matches += +(this.textContent.localeCompare(data[siteid].countryname) === 0);
								matches += +(new RegExp('/' + siteid + '/', 'i').test(this.href));
								return matches;
							})
							// remove non-matches
							.filter(function() {
								return +$(this).attr(DATA_CURR) > 0;
							})
							// sort by highest match first
							.sort(function(a, b) {
								var aScore = +$(a).attr(DATA_CURR),
										bScore = +$(b).attr(DATA_CURR);
								return aScore > bScore ? -1
									: aScore < bScore ? 1
										: 0;
							})
							// return the first
							.eq(0);

						return $links.removeAttr(DATA_CURR) &&

							$label.length &&

							// remove any existing current tags
							$(classSelector(CLS_CMENUPOP))
								.find(classSelector([CLS_CURREGN, CLS_DEFLTREGN, CLS_CURRCTRY]))
								.removeClass(classList([CLS_CURREGN, CLS_DEFLTREGN, CLS_CURRCTRY])) &&

							// apply current tags to the match and parent region
							$label
								.closest(classSelector([CLS_CMENUL1], '> li'))
								.addClass(classList([CLS_CURREGN, CLS_DEFLTREGN])) &&

							// need to run equalHeight
							cmenuEqualHeight(true);
					});
			}

			function cloneButtons() {

				return $u02.hasClass(CLS_LOCALNAV) &&
								$u02.data(DATA_CLONED) == null &&
								$u02.data(DATA_CLONED, true)
									.find(classSelector(CLS_BTTNS))
									.clone()
									.removeClass(CLS_LOCALW3)
									.find(classSelector(CLS_SEARCH)).remove().end()
									.appendTo(
										$u02.find(classSelector(CLS_MEGACTR)).length &&
										$u02.find(classSelector(CLS_MENUL1)).addClass(CLS_HASBTTNS) ||
										$u02.find(classSelector(CLS_MENUL1, '> ul > li'))
											.find(classSelector(CLS_MENUL2)).addClass(CLS_HASBTTNS)
									);
			}

			function removeClonedButtons() {

				return $u02.hasClass(CLS_LOCALNAV) &&
								!$u02.hasClass(CLS_MEGAMENU) &&
								!!$u02.data(DATA_CLONED) &&
								$u02.removeData(DATA_CLONED)
									.find(classSelector(CLS_HASBTTNS))
									.removeClass(CLS_HASBTTNS)
									.find(classSelector(CLS_BTTNS))
									.remove();
			}

			function inputHasFocus(i) {
				return $(i).is(':focus') || $(i).hasClass(CLS_FOCUS);
			}

			function hasScrolled() {
				var newY = window.scrollY;
				return Math.abs(newY - wscroll) > 5;
			}

			function onMenuContentLoaded(data) {

				var // id ref from country tool link
						cid = /#\w+$/.exec(cmenucontent),
						cCls = classSelector([[CLS_SMAP, CLS_CMENU]]),
						cSelect = !!cid && [cid[0], cCls].join() || cCls,
						// id ref from contact tool link
						ctid = /#\w+$/.exec(ctmenucontent),
						ctCls = classSelector([[CLS_SMAP, CLS_CTMENU]]),
						ctSelect = !!ctid && [ctid[0], ctCls, '#o-call'].join() || [ctCls, '#o-call'].join(),
						$menu,
						$cmenu,
						$ctmenu;

				// convert H5's to A
				data = data.replace(/<([^h/>]*)h5/g, '<a class="' + CLS_TLINK + '" href="#open" ')
					.replace(/<\/h5>/g, '</a>');

				// if passed inline content from local nav (.u02w2), use > .u02menucontent
				// 	otherwise, confine the find to .u02smap (external site map) to prevent
				// 	picking up other header menucontent, eg. from .u02usertools
				$menu = $(data).hasClass(CLS_LOCALW2) && $(data).children(classSelector(CLS_CONTENT)) ||
					$(data).find(['#u02mainmenu', classSelector([[CLS_SMAP, CLS_CONTENT]])].join()).first();
				$cmenu = $(data).find(cSelect).first();
				$ctmenu = $(data).find(ctSelect).first();

				$menu.addClass(CLS_CONTENT)
					.find(classSelector([CLS_MENUL1, CLS_MENUL2], '> ul > li > a'))
					.addClass(CLS_TLINK)
					.attr('href', function() {
						// don't use or return this.href b/c it always resolves to full url
						var href = $(this).attr('href') || '';
						// if no href defined, set to #open
						return (!href.length ||
										/#open$/.test(href)) && '#open' ||
										href;
					});

				// for univeral pages force full path on all menu links in global nav
				if ($nav.hasClass(CLS_OCOMBASE) && isGlobal) {
					$menu.find('a[href^="/"]')
						.not('[href$="#open"]')
						.attr('href', function() {
							// don't use or return this.href b/c it always resolves to full url
							var href = $(this).attr('href');
							// don't rewrite country/contact menu links
							return !$(this).hasClass(CLS_TICON) &&
											'https://www.oracle.com' + href ||
											href;
						});
				}

				if($cmenu.length) {
					//GLOBAL_COUNTRY_HTML = data.replace(new RegExp(CLS_TLINK, 'g'), CLS_CLINK);
					buildCountryMenu(data.replace(new RegExp(CLS_TLINK, 'g'), CLS_CLINK));
				}

				// if a different menucontent url is set in country tool,
				// 	we have to fetch that content and override country menu
				if(isGlobal && 'undefined' !== typeof cmenucontent &&
						cmenucontent.split('#')[0].length &&
						cmenucontent.split('#')[0] !== menucontent.split('#')[0]) {
					oracleDataMenu.fetchMenuContent(cmenucontent, contentCache)
						.then(function(data) {
							//GLOBAL_COUNTRY_HTML = data.replace(/<([^h/>]*)h5/g, '<a class="' + CLS_CLINK + '" href="#open" ').replace(/<\/h5>/g, '</a>');
							buildCountryMenu(
								data
									.replace(/<([^h/>]*)h5/g, '<a class="' + CLS_CLINK + '" href="#open" ')
									.replace(/<\/h5>/g, '</a>')
							);
						})
						.fail(logError);
				}

				if ($ctmenu.length) {
					buildContactMenu(data);
				}

				// if a different menucontent url is set in contact tool,
				// 	we have to fetch that content and override contact menu
				if(isGlobal && 'undefined' !== typeof ctmenucontent &&
						ctmenucontent.split('#')[0].length &&
						ctmenucontent.split('#')[0] !== menucontent.split('#')[0]) {
					oracleDataMenu.fetchMenuContent(ctmenucontent, contentCache)
						.then(buildContactMenu)
						.fail(logError);
				}

				$u02.find(['#u02menulink', classSelector(CLS_MENULINK)].join())
					.attr({
						href: isGlobal && '#main-menu' || '#local-menu',
						'data-lbl': 'menu'
					})
					.closest('.u02menu').attr('data-trackas', 'menu');

				return $.Deferred().resolve($menu);
			}

			function initMenuEvents() {
				////////////////////////////////////////////////////////////////////////////////////////
				// MAIN MENU EVENTS
				////////////////////////////////////////////////////////////////////////////////////////

				// MENU OPEN ON HOVER - DESKTOP
				$nav.on(evList(EV_MOUSEIN),
					classSelector([[CLS_DTOP, CLS_MLINK], [CLS_DTOP, CLS_HASMENU]]),
					function(e) {
						var $target = $(this);

						// if clickopen menu return false on non-touch
						return (!IS_TOUCH && !$target.hasClass(CLS_CLICKOPEN)) &&
										$target.openMenu() &&
										(($u02.find(classSelector(CLS_MEGAMENU, classSelector(CLS_HASMENU))).length &&
											navType === 'TAB' &&
											!$target.closest(classSelector(CLS_MENUL2)).length) &&
											// run equal height from first menu for megamenu tablet
											// 	for initial open of hamburger
											targetEqualHeights(
												$target.hasClass(CLS_MLINK) &&
												navType === 'TAB' &&
												$target.find(classSelector(CLS_HASMENU)).first() ||
												$target
											) || 1) &&
										toolSwitch();
					});

				$nav.on(evList(EV_TOUCHST), function() {
					wscroll = window.scrollY;
				});

				// FOLLOW XLINKS
				$nav.on(evList([EV_CLICK, EV_TOUCH]),
					classSelector(CLS_XLINK),
					function(e) {
						return !hasScrolled() && true;
					});

				// MENU OPEN/CLOSE ON CLICK - DESKTOP / MOBILE
				$nav.on(evList([EV_CLICK, EV_TOUCH]),
					classSelector([CLS_MLINK, CLS_CLICKOPEN, CLS_HASMENU]),
					function(e) {
						var $target = $(this),
								// get the link that was clicked on -
								// 	samdung tablet is not assigning e.target correctly,
								// 	nor calling the first bound handler (the xlink handler above)
								// 	so we have explicitly assign e.target to innermost element (?!)
								$actual = $(e.target).is(classSelector(CLS_NOSUBMENU)) &&
														$(e.target).children('a') || $(e.target),
								isMainMenu = $target.hasClass(CLS_MLINK),
								isSubMenu = $target.hasClass(CLS_CLICKOPEN);


						if(e.type === EV_CLICK && $actual.closest('a').hasClass(CLS_XLINK)) {
							return true;
						}

						// prevent menu close if container is clicked or touch scrolling
						if(!$actual.closest('a').length &&
									$actual.closest($target).not($actual).length ||
									hasScrolled() ||
									hasClickPrevented($target) ||
									e.isDefaultPrevented()) {
							return;
						}

						if(e.cancelable) {
							e.preventDefault();
						}

						// follow outbound links & mobile persistent buttons
						//  closest allows for an inner wrap on anchor tag
						if($actual.closest('a').hasClass(CLS_XLINK) ||
								($actual.closest(classSelector(CLS_BTTNS)).length &&
									!$actual.closest(classSelector(CLS_DROPDOWN)).length)) {
							return $nav.closeMenu() && $actual.closest('a')[0].click();
						}

						$others.closeMenu();

						if($target.hasClass(CLS_OPEN)) {
							return ((!$target.hasClass(CLS_MEGAMENU) || $target.hasClass(CLS_MLINK)) || navType !== 'TAB') &&
											$target.closeMenu() &&
												isMainMenu &&
												$nav.find(classSelector([[CLS_MOBILE, CLS_TOOLS]])).closeMenu() &&
												toolSwitch();
						}

						$u02.find(classSelector(CLS_SEARCHPOP)).removeClass(CLS_SEARCHPOP);
						$target.openMenu();

						if(($u02.hasClass(CLS_LOCALNAV) && navType === 'MOBI') ||
								($u02.find(classSelector(CLS_MEGAMENU,
									classSelector(CLS_HASMENU))).length &&
									navType === 'TAB' &&
									!$target.closest(classSelector(CLS_MENUL2)).length)) {
							// run equal height from first menu for megamenu tablet
							// 	for initial open of hamburger
							targetEqualHeights(
								$target.hasClass(CLS_MLINK) &&
								navType === 'TAB' &&
								$target.find(classSelector(CLS_HASMENU)).first() ||
								$target
							);
						}

						$others.off(evList(EV_MENUOPEN)).on(evList(EV_MENUOPEN), $target.closeMenu.bind($target));


						return toolSwitch(isSubMenu && $target) &&
										isMainMenu &&
										$nav.find(classSelector([[CLS_MOBILE, CLS_TOOLS]])).openMenu();
					});

				// MENU OPEN SUB MENU LINKS - DESKTOP
				$nav.on(evList([EV_CLICK, EV_TOUCH]), classSelector(CLS_TLINK),
					function(e) {

						var $actual = $(e.target),
								$target = $actual.closest(classSelector(CLS_HASMENU));

						if(hasScrolled() || hasClickPrevented($target) || e.isDefaultPrevented()) { return; }

						// in the case of megamenu, with top level outbound links
						// 	and submenu is shown in dtop, we hijack the click,
						// 	convert to xlink and refire
						// 	to be handled by menu-hasm handler
						if($u02.find(classSelector(CLS_MEGAMENU)).length &&
								$u02.hasClass(CLS_DTOP) &&
								!/#open$/.test($actual.closest('a').attr('href'))) {
							return $actual.closest('a').addClass(CLS_XLINK)[0].click();
						}

						if(e.cancelable) {
							e.preventDefault();
						}

						return ($target.hasClass(CLS_OPEN) &&
										((!$target.hasClass(CLS_MEGAMENU) || $target.hasClass(CLS_MLINK)) || navType !== 'TAB') &&
										$target.closeMenu()) ||
										$others.closeMenu() &&
										$target.openMenu() &&
										((($u02.hasClass(CLS_LOCALNAV) &&
											navType === 'MOBI') ||
											// run target eq heights for megamenu-multi in tab
											($u02.find(classSelector(CLS_MEGAMENU,
												classSelector(CLS_HASMENU))).length &&
												navType === 'TAB' &&
												!$target.closest(classSelector(CLS_MENUL2)).length)) &&
											targetEqualHeights($target) || 1) &&
										toolSwitch();
					});

				// MENU HIDE UL BG FASTER - DESKTOP
				$nav.on(evList(EV_MOUSEIN), classSelector([[CLS_DTOP, CLS_NOSUBMENU]]),
					function() {
						$(this).closest('ul').addClass(CLS_HIDE);
						setTimeout(function() {
							$u02.find(classSelector(CLS_HIDE)).removeClass(CLS_HIDE);
						}, 1100);
					});

				//  MENU HIDE UL BG FASTER - DESKTOP
				$nav.on(evList(EV_MOUSEIN), classSelector([[CLS_DTOP, CLS_HASMENU]]),
					function() {
						$u02.find(classSelector(CLS_HIDE)).removeClass(CLS_HIDE);
					});

				// MENU CLOSE SUB MENU LINKS ON FOCUS OF SIBLINGS LINKS - DESKTOP
				$nav.on(evList(EV_FOCUS), classSelector([CLS_MENUL1, CLS_MENUL2], ' > ul > li > a'),
					function() {
						var $items = $(this).closest(classSelector(CLS_HASMENU))
							.siblings(classSelector(CLS_OPEN));
						return $items.length && $items.closeMenu();
					});

				// MENU BACK LINKS
				$nav.on(evList([EV_CLICK, EV_TOUCH]), classSelector(CLS_BACK),
					function(e) {

						if(e.isDefaultPrevented()) { return; }

						e.preventDefault();

						return $(this).closest(classSelector(CLS_HASMENU)).closeMenu();
					});

				$nav.on(evList(EV_MENUOPEN), classSelector([[CLS_TAB, CLS_MEGACTR, CLS_MLINK]]),
					function(e) {
						var $target = $(e.target);
						return $target.hasClass(CLS_MLINK) &&
							$target.find(classSelector(CLS_MEGAMENU)).first().openMenu();
					});
			}

			function initKeyboardEvents() {
				////////////////////////////////////////////////////////////////////////////////////////
				// KEYBOARD EVENTS
				////////////////////////////////////////////////////////////////////////////////////////

				$nav.on(evList(EV_KEYDOWN),
					function(e) {

						if (e.keyCode === 27) { // escape

							if ($u02.find(classSelector(CLS_OPEN)).length) {
								// CAN'T FIND ANY USAGE OF .u02glinks ?
								// if ($('.u02glinks a').first().is(':visible')) {
								// 	$('.u02glinks a').first().focus();
								// } else {
								// 	$('.u02tools a').first().focus();
								// }
								if ($u02.hasClass(CLS_MOBILE)) {
									$nav.closeMenu();
								} else {
									$nav.find(classSelector(CLS_OPEN)).last().closeMenu();
								}
							}

						// set u02 tfwd attr to true/false to flag tabbing direction
						} else if (e.keyCode === 9 && $u02.length) {

							$u02.data(DATA_TFWD, !e.shiftKey);

						}

					});
			}

			function initDeviceType() {

				var namespc = [NS_U02, 'input'].join('-');

				$nav.add($others).off(eventList([EV_MOUSEIN, EV_TOUCHST, EV_KEYDOWN], namespc))
					.on(eventList(EV_KEYDOWN, namespc), onFirstTab)
					.on(eventList([EV_MOUSEIN, EV_POINTOVER], namespc), onFirstMouseover)
					.on(eventList([EV_TOUCHST, EV_POINTDOWN], namespc), onFirstTouch);

				function onFirstTab(e) {
					return (e.keyCode === 9) &&
										// just run this on first tab instead of tool panel initialization
										$u02.find(classSelector(CLS_TOOLS))
											.removeAriaAttributes(true).addAriaAttributes(true) &&
										$nav.add($others)
											.find(classSelector(NS_U02)).addClass(CLS_TABNAV).end()
											.off(eventList(EV_KEYDOWN, namespc))
											.on(eventList(EV_CLICK, namespc), onFirstClick) || 1;
				}

				function onFirstClick() {
					return $nav.add($others)
						.find(classSelector(NS_U02)).removeClass(CLS_TABNAV).end()
						.off(eventList(EV_CLICK, namespc))
						.on(eventList(EV_KEYDOWN, namespc), onFirstTab);
				}

				function onFirstMouseover(e) {

					// generally a very bad idea, but here we have to prevent
					// the subsequent mouseenter event from firing and unsetting IS_TOUCH
					if(e.type === EV_POINTOVER) { e.stopImmediatePropagation(); }

					// MS Edge/IE ONLY fires mouseevents for touch
					// 	but listening for pointerevents will reveal pointerType
					var gotTouch = e.pointerType === 'touch';

					return $nav.add($others)
						.off(eventList([EV_MOUSEIN, EV_POINTOVER, EV_POINTDOWN, EV_TOUCHST], namespc))
						.on(
							eventList(
								// if touch, keep listening for mouseenter
								gotTouch ?
									[EV_MOUSEIN, EV_POINTOVER]
									: [EV_TOUCHST, EV_POINTDOWN], namespc
							),
							!gotTouch && onFirstTouch || onFirstMouseover) &&
								// to prevent a falsey return: !(undefined) = true
								!(IS_TOUCH = gotTouch);
				}

				function onFirstTouch(e) {

					var gotTouch = e.type === EV_TOUCHST || e.pointerType === 'touch';

					return $nav.add($others)
						.off(eventList([EV_MOUSEIN, EV_TOUCHST, EV_POINTOVER, EV_POINTDOWN], namespc))
						.on(eventList([EV_MOUSEIN, EV_POINTOVER], namespc), onFirstMouseover) &&
								// to prevent a falsey return: !(undefined) = true
								!(IS_TOUCH = gotTouch);
				}
			}

			function initSearchEvents() {

				////////////////////////////////////////////////////////////////////////////////////////
				// SEARCH EVENTS
				////////////////////////////////////////////////////////////////////////////////////////

				var $search = $u02.find(INPUT_SEARCH),
						$form = $search.closest(classSelector(CLS_SEARCHFORM)),
						$submit = $form.find(classSelector(CLS_SEARCHBTTN)),
						DATA_UNFOCUS = 'unfocusTimeout',
						// AUTOCOMPLETE CONFIG - can be overridden/extended by window.autocompleteOptions
						options = function(request, response) {
							/* globals autocompleteOptions */
							return jQuery.extend(
								{
									// gets changed to full path on build -->
									// 	https://www.oracle.com/search/autosuggest.json....
									url: '/search/autosuggest.json/browse',
									data: {
										Dy: 1,
										contentPaths: '/content/Web/Shared/Auto-Suggest Panel',
										templateTypes: 'AutoSuggestPanel',
										Ntt: request.term + '*'
									},
									success: function(result) {
										var dsv = [],
												regexp = new RegExp(request.term.replace(/[-[\]{}()*+?.,\\/^$|#\s]/g, '\\$&')),
												// checks for existence of additional autocomplete suggestions
												// 	fetched from generic-add-autocomplete.js
												adds = 'undefined' !== typeof autocompleteVals ?
													autocompleteVals.reduce(function(arr, term) {
														if (regexp.test(term)) {
															arr.push({
																label: term
															});
														}
														return arr;
													}, []) : [];
										if (result.contents[0].autoSuggest[0].totalNumResults > 0) {
											dsv = result.contents[0].autoSuggest[0]
												.dimensionSearchGroups[0]
												.dimensionSearchValues;
										}
										return response(adds.concat(dsv));
									},
									error: function() {
										return null;
									}
								},
								// if defined, will overwrite default properties
								// url, data, success, error
								'function' === typeof autocompleteOptions ?
									autocompleteOptions(request, response) : false);
						};

				// bail out if this is local nav
				if(!$search.length) { return; }

				// fix any missing trackas attr
				$search.closest('.u02search').attr('data-trackas', 'header');

				// unset any previous search entry on load
				$search.val($search[0].defaultValue);

				// ON SEARCH FOCUS, CLOSE MENUS, RESET TIMEOUT,
				// 	ATTACH BLUR HANDLERS IN DESKTOP
				$search.on(evList([EV_FOCUS, EV_POINTOVER, EV_MOUSEIN]), focusSearch);

				/* globals autocompleteVals */
				$search.awesomplete({
					appendTo: classSelector(CLS_SEARCH),
					source: function(request, response) {

						// get default (oracle.com) options or local overrides
						var opts = options(request, response);

						$.ajax({
							url: opts.url,
							dataType: 'json',
							data: opts.data,
							success: opts.success,
							error: opts.error
						});
					},
					minLength: 2,
					autoFocus: false,
					select: function(event, ui) {
						// ui.item = awesomplete input = #txtSearch
						$search.val(ui.item.value);
						$form.submit();
					}
				});

				$form.on(evList(EV_SUBMIT), function(e) {

					var i = $search[0];

					if (inputHasContent($search)) {
						return true;
					} else if (!inputHasFocus(i)) {
						e.preventDefault();
						return $search.addClass(CLS_FOCUS).focus();
					} else {
						e.preventDefault();
						$search.addClass(CLS_ERROR);
						i.value = i.defaultValue;
						i.disabled = 'disabled';
						return setTimeout(function() {
							i.disabled = '';
							$search.removeClass(CLS_ERROR);
							i.value = i.value.replace(i.defaultValue, '');
							i.focus();
						}, 500);
					}
				});

				// MOBILE SEARCH POP UP TOGGLE
				$nav.on(evList([EV_CLICK, EV_TOUCH]), classSelector(CLS_MOBILE, ' #mobisearch'),
					function(e) {

						e.preventDefault();

						$u02.find('#mobisearch, #u02search').toggleClass(CLS_SEARCHPOP);

						// if open, focus input
						return ($u02.find('#mobisearch').hasClass(CLS_SEARCHPOP) &&
											$search.focus() &&
											$search.trigger(EV_MENUOPEN)) || cleanup();
					});

				function focusSearch(e) {

					if(e.isDefaultPrevented()) { return; }

					e.preventDefault();

					clearTimeout($search.data(DATA_UNFOCUS));

					$nav.add($others).closeMenu();

					// prevent looping, only call focus if mouseenter
					return (e.type === EV_MOUSEIN && $search.focus() || 1) &&
						$search.addClass(CLS_FOCUS) &&
						$u02.hasClass(CLS_DTOP) &&
						attachBlurHandlers();
				}

				function attachBlurHandlers() {

					return $search.off(evList(EV_BLUR)).on(evList(EV_BLUR), function(e) {
						return ($u02.hasClass(CLS_TABNAV) && !$u02.data(DATA_TFWD) ||
												!$u02.hasClass(CLS_TABNAV)) &&
												cleanup(e);
					}) &&
					$form.off(evList(EV_MOUSEOUT)).one(evList(EV_MOUSEOUT), function(e) {
						// if touch, don't set a timeout for cleanup
						$search.data(DATA_UNFOCUS, !IS_TOUCH && setTimeout(cleanup.bind(null, e), 1100));
					}) &&
					$submit.off(evList(EV_BLUR)).on(evList(EV_BLUR), function(e) {
						return ($u02.hasClass(CLS_TABNAV) && $u02.data(DATA_TFWD) ||
											!$u02.hasClass(CLS_TABNAV)) &&
											cleanup(e);
					});
				}

				function inputHasContent($input) {
					var i = $input[0],
							scrubbed = i.value.trim();
					return scrubbed.length && scrubbed !== i.defaultValue;
				}

				function cleanup(e) {
					var isBtnBlur = $submit.is(':active') ||
													// firefox bugfix - doesn't set active on searchbttn
													(e && e.originalEvent &&
														e.originalEvent.explicitOriginalTarget &&
														$submit.is(e.originalEvent.explicitOriginalTarget));
					return !inputHasContent($search) &&
									!isBtnBlur &&
									$submit.off(evList(EV_BLUR)) &&
									$search.off(evList(EV_BLUR)) &&
									$search.removeClass(CLS_FOCUS).blur();
				}
			}

			function initSkipPanelEvents() {
				////////////////////////////////////////////////////////////////////////////////////////
				// SKIP PANEL EVENTS
				////////////////////////////////////////////////////////////////////////////////////////
				var $skipmenu = $nav.find('#u02skip2content');

				// should be added regardless of tabnav initialization
				$skipmenu.removeAttr('tabindex').addAriaAttributes(true);

				// SHOW SKIP BAR
				$nav.on(evList(EV_FOCUS), '#u02skip2content a', function() {
					$skipmenu.addClass(CLS_SKIPOPEN).trigger(EV_MENUOPEN);
					$u02.addClass(CLS_TABNAV);
					return $nav.on(evList(EV_KEYDOWN, 'skip'), function(e) {
						return (e.keyCode === 27) && // escape
										$nav.off(evList(EV_KEYDOWN, 'skip')) &&
										// don't return false - prevents key nav
										$skipmenu.removeClass(CLS_SKIPOPEN) || 1;
					});
				});

				// SKIP TO SEARCH
				$nav.on(evList(EV_CLICK), '#u02skip2s', function(e) {

					e.preventDefault();
					$skipmenu.removeClass(CLS_SKIPOPEN);

					if ($u02.hasClass(CLS_MOBILE)) {
						$u02.find('#mobisearch').click();
					}
					return $u02.find(INPUT_SEARCH).addClass(CLS_FOCUS).focus();
				});

				// SKIP TO CONTENT
				$nav.on(evList(EV_CLICK), '#u02skip2c', function(e) {
					var $nextel = $nav.add($others).last().next(),
							skipSelectors = ['#breadCrumb', '.u03'];

					e.preventDefault();
					$skipmenu.removeClass(CLS_SKIPOPEN);


					if ($nextel.length) {
						while($nextel.is(skipSelectors.join()) || ($nextel.find('a').length < 1) ) {
							$nextel = $nextel.next();
						}
						return $nextel.find('a').first().length &&
										$nextel.find('a').first().focus();
					} else {
						return $u02.find('#maincontent').next('a').length &&
										$u02.find('#maincontent').next('a').focus();
					}

				});

				// HIDE SKIP BAR ON EXIT OF LAST LINK, JUMP TO MENU
				$nav.on(evList(EV_BLUR), '#u02skip2content li:last-child a', function() {
					return $u02.data(DATA_TFWD) &&
									$skipmenu.removeClass(CLS_SKIPOPEN) &&
									!inputHasFocus(INPUT_SEARCH) &&
									$('a#u02menulink').focus();
				});

				// HIDE SKIP BAR ON EXIT OF FIRST LINK GOING BACKWARDS
				$nav.on(evList(EV_BLUR), '#u02skip2content li:first-child a', function() {
					return !$u02.data(DATA_TFWD) && $skipmenu.removeClass(CLS_SKIPOPEN);
				});

				// MAIN MENU CLOSE ON FOCUS OF SKIP LINK
				$nav.on(evList(EV_FOCUS), classSelector(CLS_DTOP, ' #u02skip2s'),
					function() {
						if (!$u02.data(DATA_TFWD)) {
							$('#u02skip2content').addClass(CLS_SKIPOPEN);
							$nav.closeMenu();
						}
					});
			}

			function initToolPanelEvents() {
				////////////////////////////////////////////////////////////////////////////////////////
				// TOOL MENU EVENTS
				////////////////////////////////////////////////////////////////////////////////////////

				// TOOL PANELS OPEN ON HOVER - DESKTOP
				$nav.on(evList(EV_MOUSEIN), classSelector([[CLS_DTOP, CLS_MTOOL]]),
					function(e) {
						var $li = $(this);
						return !IS_TOUCH && toolSwitch($li);
					});

				// TOOL PANELS OPEN/CLOSE ON CLICK - DESKTOP/MOBILE
				$nav.on(evList([EV_CLICK, EV_TOUCH]), classSelector(CLS_MTOOL, '> a'),
					function(e) {
						var $li = $(this).closest(classSelector(CLS_MTOOL));

						return !e.isDefaultPrevented() &&
										!hasClickPrevented($li) &&
										toolSwitch(!$li.hasClass(CLS_OPEN) && $li) &&
										e.preventDefault();
					});

				// COUNTRY MENU REGION SELECT - DESKTOP/MOBILE
				$nav.on(evList([EV_CLICK, EV_TOUCH]), classSelector(CLS_CLINK),
					function(e) {
						var $a = $(this),
								$others = $u02.find(classSelector(CLS_CLINK)).not($a);

						if(hasScrolled() || hasClickPrevented($a) || e.isDefaultPrevented()) { return; }

						if(e.cancelable) {
							e.preventDefault();
						}

						$u02.find(classSelector(CLS_CURREGN)).removeClass(CLS_CURREGN);
						$others.removeAriaAttributes($u02.hasClass(CLS_TABNAV)).blur();
						$a.closest('li').addClass(CLS_CURREGN);
						addAriaTree();

						// always do equalHeight on menu open
						return cmenuEqualHeight(true) &&
										$a.closest('ul').addClass(CLS_SHOW)
											.addAriaAttributes($u02.hasClass(CLS_TABNAV));
					});

				// COUNTRY MENU BACK TO REGION LINKS
				$nav.on(evList([EV_CLICK, EV_TOUCH]), classSelector([[CLS_CMENU, CLS_BLINK]]),
					function(e) {

						e.preventDefault();

						return $u02.find(classSelector([[CLS_CMENU, CLS_SHOW]]))
							.removeClass(CLS_SHOW) &&
								resetCountryMenu(cmenuEqualHeight);
					});
			}

			//Adds an aria tree to the country selector
			function addAriaTree() {
				var label = $u02.find(classSelector(CLS_REGN)).find('span');
				$u02.find(classSelector(CLS_CMENU)).attr('role','tree');
				$u02.find(classSelector(CLS_CLINK)).attr({
					'role': 'treeitem',
					'aria-selected': 'false',
					'aria-expanded': 'false',
					'aria-labelledby': label.text()
				});
				$u02.find(classSelector(CLS_CURREGN, '> a')).attr({
					'role': 'treeitem',
					'aria-selected': 'true',
					'aria-expanded': 'true',
					'aria-labelledby': label.text()
				});
				$u02.find(classSelector(CLS_CMENUL2)).find('a').attr('role','treeitem');
			}

			function logError(xhr, status, error) {
				/* eslint no-console:0 */
				var endpoint = this && this.url;
				return endpoint && console.warn(
					endpoint && 'U02: Unable to load content from ' + endpoint + ' (' + xhr.statusText + ')' ||
					xhr.message && [xhr.message, xhr.stack].join('\n')
				);
			}

			/**
			 * Firefox does not prevent emulated mouse events from
			 * 	touchend events, so set a timeout to return false
			 * 	for 200ms interval after a touchend event
			 */
			function hasClickPrevented($tgt) {
				var $target = $tgt;
				return $target.data('clickPrevent') ||
					$target.data('clickPrevent', setTimeout(function() {
						$target.removeData('clickPrevent');
					}, 600)) && false;
			}

		})();
	}

	$(document).ready(function($) {

		var $navs = $('nav.u02nav'),
				stylesLoaded = function() {
					return !$navs.length ||
						$navs.css('position') === 'relative';
				},
				initFn = function(i) { init($(this), i); },
				navsFn = $navs.each.bind($navs, initFn),
				initInterval;

		// remove stuff from sitemap/menucontent that needs to be removed
		// 	(only used on site map page)
		$('.u02smap')
			.addClass(CLS_OCOMBASE)
			.find('.u02modal, .u02contact').remove().end()
			.find(classSelector([CLS_MENUL1, CLS_MENUL2], ' > ul > li > hr')).parent().remove().end();

		// rewrite legacy o-call buttons to open lightbox with contactmenu content
		$('a.o-call:not(.u02ticon)').each(function() {
			return $(this).attr({
				rel: 'lightbox',
				href: '#u02contactmenu',
				'data-theme': 'light'
			});
		});

		// make sure styles have loaded before initializing
		//  - otherwise equalHeight calcs are thrown off -
		//  if not, set an interval to recheck
		return (stylesLoaded() && navsFn()) ||
						(initInterval = setInterval(function() {
							return stylesLoaded() &&
											// ! to return true
											!clearInterval(initInterval) &&
											navsFn();
						}, 50));
	});

})(jQuery, window);

/* ############################################################################################# */
/* ####			DEBUG	ONLY			#################################################################### */
/* ############################################################################################# */

// $(document).ready(function($) {
// 	'use strict';
// 	return /u02debug=1/.test(window.location.search) &&
// 					$('.u02nav').first()
// 						.on('u02ready', function() {
// 							// $('.u02z86d').remove();
// 							//  ...other things you want to open/check here ...
// 						});
// });

// cookie to test hello, name cookie on localhost - DO NOT COMMIT THIS FILE WITH THIS UNCOMMENTED!!!!

// fakeuser
// document.cookie = 'ORA_UCM_INFO=3~93446F2E9B0E5ADEE040548C2D706F69~JeanLuc~Picard~jeanluc.picard@oracle.com';

// no name
// document.cookie = 'ORA_UCM_INFO=3~93446F2E9B0E5ADEE040548C2D706F69~NOT_FOUND~NOT_FOUND~jeanluc.picard.picard.picard@oracle.com';

// no acct
// document.cookie = 'ORA_UCM_INFO=3~93446F2E9B0E5ADEE040548C2D706F69~Jean Luc~Picard';

/* ####		END DEBUG		########################################################################## */


/*! U03 */
OCOM.register(function u03($) {
	// fall back if pubs don't use a space around BRs in title/breadcrumb
	$('.u03 br').before(' ');

	
	
	function u03btnadjust(){
		var v4Width = 0;
		var btnWidth = 0;
		var brdWidth = 0;
		var v4Width = $('.u03v4 .u03w2').width();
		var winWidth = $(window).width();
		$('.u03v4 .u03w4 .obttn5').each(function(index) {
			btnWidth += parseInt($(this).width(), 10);
		});
		var brdWidth = $('.u03v0 .u03w1 > ul').width();
		var ttlWidth = $('.u03v4 h1').width();
		if (btnWidth + brdWidth > (v4Width-20) ||
				ttlWidth + btnWidth > (v4Width-20) ||
				ttlWidth + btnWidth > (winWidth-55)) {
			$('.u03v4 .u03w4').addClass('obttnwrap');
		}
		else {
			$('.u03v4 .u03w4').removeClass('obttnwrap');
		}
	}

	if($('.u03v4')[0] && $('.u03v0')[0]){
		u03btnadjust();
		$('.u03v4 .u03w4 .obttns').css('opacity', '1');
		$(window).on('load resize', function(){
			u03btnadjust();
		});
	
		// add class for v4's with no breadcrumb b/c people are dumb
		if(!$('.u03v0 li')[0]){
			$('.u03v0').addClass('u03breadfree');
		}

	}
	
	//$(window).on('load', function(){
		//$('.u03v4 .u03w4 .obttns').css('opacity', '1');
	//});
	
	
});

/*! U10 */
OCOM.register(function u10($) {
	if ($('.u10')[0] || $('#u10')[0]) {

		//Load content from xml link
		var cmenucontent = false,contentCache;
		if ($('#u10cmenu a').first().attr('data-url')){
			cmenucontent = $('#u10cmenu a').first().attr('data-url');
			contentCache = { 0: cmenucontent};
		}

		// backwards compatibility for only using id on u10v0
		$('[id="u10"]').addClass('u10').not('.u10v0').removeAttr('id');

		$('.u10w3').append('<div class="u10btn"></div>');
		$('ul.u10-links li').last().addClass('u10last');


		$('.u10w6.icn-googleplus').closest('.u10w2').remove();

		$('#teconsent > a').removeAttr('role');

		//Listener for mobile drawers, allows for opening/closing and rotating arrow.
		$('.u10').on('click', '.u10w3 h5, .u10btn', function () {
			var $u10tog = $(this).parents('div.u10w3'),
				$u10act = $('div.u10active');
			$u10tog.toggleClass('u10active');
			$u10act.not($u10tog).removeClass('u10active');
		});

		if (window.frameElement) {
			$('.u10 a').attr('target', '_top');
		}
		
		//Add a column at the bottom left to fit the Free Cloud Trial link. Temporary change (this column needs to become a markup change):
		//$('.u10w5').append('<div class="footer-promo"><a href="#" title="Free Cloud Trial">Free Cloud Trial</a></div>');


		//Accessibility
		//Remove text from the Social Icon links
		$('.scl-icons a').text(' ');
		//Make plus minus buttons on mobile accessible
		$('.u10w3 .u10btn').replaceWith('<a class="u10btn"></a>');
		$('.u10w3').on('click keydown', '.u10btn', function (e) {
			e.preventDefault();
		});

		//Inject break items that enable the mobile version layout (required for flex display)
		var firstLink = $('.u10-links li:first-child').clone().addClass('last');
		$('.u10-links li:nth-child(3)').after('<li class="u10break"></li>');
		$('.u10last').after(firstLink);
		$('.u10last').after('<li class="u10break"></li>');

		//Populate country menu (test if it exist first!)
		if(cmenucontent){
			getCountryData(cmenucontent, contentCache);
		}
		
		//Listener for click to open country menu
		$('body #u10cmenu').on('click', function (e) {
			$('body').removeClass('u10hide');
			//If opening on mobile, clone the desktopversion and append to a modal
			if ($(window).width() < 770) {
				if (!($('.u10modal').length)) {
					var $mobileMenu = $('#u10cmenu').clone(true);
					$mobileMenu.find('.u10pttl-li').append('<div class="closeModal"></div>');
					$('body').addClass('noScroll').append('<div class="u10modal show"></div>');
					if (menuData == undefined) {
						$('.u10modal').html($mobileMenu);
					} else {
						$('.u10modal').html(menuData);
					}
					$('.u10modal #u10cmenu').addClass('u10opened mobile');
				}
			} 
			//Desktop version
			else {
				//If desktop country menu is open
				if ($('.u10.u10v6 #u10countrymenu').length){
					//If a region was clicked on, keep dialog open. If a country link was clicked on, go to link. Otherwise, close menu.
					if (!e.target.classList.contains('u10clink')) {
						$(this).addClass('u10opened');
						if (e.target.href){
							window.location = e.target.href;
						}
					}
				}
				else {
					var CLS_CMENUL1 = 'u10cmenu-l1',
					CLS_CURREGN = 'u10currentcr',
					CLS_CMENUL2 = 'u10cmenu-l2';
					$('.u10.u10v6 #u10cmenu').html(menuData).addClass('u10opened');
					var $cmenus = $('.u10').find(oracleDataMenu.classSelector([CLS_CMENUL1, [CLS_CURREGN, CLS_CMENUL2]]));
					$cmenus.equalHeight(true);
				}

			}
			
		menuData = $(this);
		});

	}
}, true);

//Load country data in a non-blocking way

function asyncrWait() {
	var deferred = $.Deferred();
	setTimeout(function () {
		deferred.resolve("generating async wait");
	}, 0);
	return deferred.promise();
}

function loadGlobalVar() {
	var deferred = $.Deferred();
	if (GLOBAL_COUNTRY_HTML !== '') {
		deferred.resolve("loaded country data");
	}
	return deferred.promise();
}

function getCountryData(cmenucontent, contentCache) {
	var CLS_CLINK = 'u10clink';

	var d = jQuery.Deferred(),
		p = d.promise();
	p.then(asyncrWait).then(

		oracleDataMenu.fetchMenuContent(cmenucontent, contentCache)
		.then(function (data) {
			buildCountryMenu(data
				.replace(/<([^h/>]*)h5/g, '<a class="' + CLS_CLINK + '"')
				.replace(/<\/h5>/g, '</a>').replace(/u02/g, 'u10'));
		}));
	d.resolve();
}


function buildCountryMenu(html) {

	var CLS_REGN = 'u10regn',
		CLS_CMENU = 'u10countrymenu',
		CLS_CMENUL1 = 'u10cmenu-l1',
		CLS_CMENUL2 = 'u10cmenu-l2',
		CLS_TICON = 'u10ticon',
		CLS_CLINK = 'u10clink',
		CLS_CURREGN = 'u10currentcr',
		CLS_CURRENTCTRY = 'u10currentcc',
		CLS_DEFLTREGN = 'u10currentdr',
		CLS_TOOLPOP = 'u10toolpop',
		CLS_NOOVERRIDE = 'uu10ooverride',
		CLS_LOCALNAV = 'u10v6',
		CLS_CMENUPOP = 'u10menupop',
		isGlobal = false,

		cmenuEqualHeight = function (force) {

			// only need to do the current region - this gets re-called on region change
			var $cmenus = $('body').find(oracleDataMenu.classSelector([CLS_CMENUL1, [CLS_CURREGN, CLS_CMENUL2]])),
				// iPad Chrome mis-reports window.innerWidth on orientationchange,
				// 	so we just base it off of media query css of toolpop panel
				doheight = $('body').find(oracleDataMenu.classSelector(CLS_CMENUPOP)).width() > 340 || !!force;

			// clear any running timeout from resetCountryMenu
			clearTimeout($('body').find(oracleDataMenu.classSelector(CLS_CMENU)).data('cmenuTimeout'));

			// unset existing equal height styles
			return $('body').find(oracleDataMenu.classSelector([CLS_CMENUL1, CLS_CMENUL2], '[style*="height"]'))
				.css('height', '') &&
				(doheight && $cmenus.equalHeight(true)) || 1;
		},



	addAriaTree = function () {
		var label = $('.u10').find(oracleDataMenu.classSelector(CLS_REGN)).find('span');
		$('.u10').find(oracleDataMenu.classSelector(CLS_CMENU)).attr('role', 'tree');
		$('.u10').find(oracleDataMenu.classSelector(CLS_CLINK)).attr({
			'role': 'treeitem',
			'aria-selected': 'false',
			'aria-expanded': 'false',
			'aria-labelledby': label.text()
		});
		$('.u10').find(oracleDataMenu.classSelector(CLS_CURREGN, '> a')).attr({
			'role': 'treeitem',
			'aria-selected': 'true',
			'aria-expanded': 'true',
			'aria-labelledby': label.text()
		});
		$('.u10').find(oracleDataMenu.classSelector(CLS_CMENUL2)).find('a').attr('role', 'treeitem');
	};


	if ($('.u10').hasClass(CLS_LOCALNAV)) { //only pull country data when loading u10v6

		var $src = $('.u10').find(oracleDataMenu.classSelector(CLS_REGN)),
			href = $src.length && $src.attr('href'),
			// needed if called from local nav menu content
			$tool = $('.u10').find('#u10cmenu'),
			$toolpop = oracleDataMenu.createElement('div', [CLS_CMENUPOP, CLS_TOOLPOP]),
			cmid,
			$cmenu;

		// make sure that no-override flag has not been set by
		// 	country menu built from	local nav menu source
		if (isGlobal && $src.hasClass(CLS_NOOVERRIDE)) {
			return false;
		}

		cmid = href && href.split('#')[1] || CLS_CMENU;

		$cmenu = $('#' + cmid, html);

		$cmenu.find(oracleDataMenu.classSelector(CLS_CMENU, ' > ul'))
			.prepend(oracleDataMenu.createElement('li', 'u10pttl-li')
				.html(oracleDataMenu.createElement('h5', 'u10pttl').text($tool.find(oracleDataMenu.classSelector(CLS_TICON)).text())));

		$cmenu.find(oracleDataMenu.classSelector(CLS_CURREGN)).addClass(CLS_DEFLTREGN);

		$tool
			.append(!$tool.find(oracleDataMenu.classSelector(CLS_TOOLPOP)).length && $toolpop)
			.find(oracleDataMenu.classSelector(CLS_CMENUPOP)).html($cmenu).end()
			.find('h5.u10pttl, .u10ticon > span').text(function (i, txt) {
				return $cmenu.data('toollabel') || txt;
			});

		if ($tool.find(oracleDataMenu.classSelector(CLS_CMENUPOP, ' .u10cmenu-simple')).length) {
			$tool.find(oracleDataMenu.classSelector(CLS_CMENUPOP)).addClass(CLS_CMENUPOP + '-simple');
		} else {
			$tool.find(oracleDataMenu.classSelector(CLS_CMENUPOP)).removeClass(CLS_CMENUPOP + '-simple');
		}

		$tool.find(oracleDataMenu.classSelector(CLS_REGN)).attr('href', '#' + cmid)
			// flags no-override if countrymenu came from local menu source,
			// 	needed due to async timing of menucontent calls - local menu
			// 	may hit before global menu source
			.addClass(function () {
				return !isGlobal && CLS_NOOVERRIDE;
			});

		cmenuEqualHeight(true);
		$('.' + CLS_CURRENTCTRY).closest('.' + CLS_CMENUL2).addClass('selected-region');
		addAriaTree();

		// COUNTRY MENU REGION SELECT - DESKTOP
		$('body').on('click', '.u10.u10v6 .u10clink', function (e) {
				var $a = $(this);

				$('.u10').find(oracleDataMenu.classSelector(CLS_CURREGN)).removeClass(CLS_CURREGN);
				$a.closest('li').addClass(CLS_CURREGN);

				addAriaTree();

				// always do equalHeight on menu open
				cmenuEqualHeight(true);

				//Handle menu changes on mobile
				$('.' + CLS_CMENUL2).removeClass('selected-region');
				$a.next('.' + CLS_CMENUL2).addClass('selected-region');

			});

		// COUNTRY MENU REGION SELECT - MOBILE
		$('body').on('click', '.u10modal .u10clink', function (e) {
			
			var $a = $(this),
				$others = $('.u10modal').find(oracleDataMenu.classSelector(CLS_CLINK)).not($a);

			//Remove active class form other regions
			$others.each(function(){
				$(this).closest('li').removeClass(CLS_CURREGN);
			});

			//Add current region
			$a.closest('li').toggleClass(CLS_CURREGN);
			
			//Handle menu changes on mobile
			$('.u10modal .' + CLS_CMENUL2).removeClass('selected-region');
			$a.next('.u10modal .' + CLS_CMENUL2).addClass('selected-region');

		});

		$('body').on('click', '.u10modal .closeModal', function (e) {
			e.preventDefault();
			$('body').removeClass('noScroll');
			menuData = $('.u10modal #u10cmenu').clone(true).addClass('u10opened');
			$('.u10modal').remove();
			$('.u10.u10v6 #u10cmenu').removeClass('u10opened');
		});
	}

	$(function () {
		var resizeEnd;
		$(window).on('resize', function () {
			clearTimeout(resizeEnd);
			resizeEnd = setTimeout(function () {
				$(window).trigger('resize-end');
			}, 200);
		});
	});

	$(window).on('resize-end', function () {

		if ($(window).width() < 770) {
			if (($('#u10cmenu').hasClass('u10opened') && !($('.u10modal').length))) {
				var $mobileMenu = $('#u10cmenu').clone(true);
				if ($('.closeModal').length == 0) {
					$mobileMenu.find('.u10pttl-li').append('<div class="closeModal"></div>');
				}
				$('body').addClass('noScroll').append('<div class="u10modal show"></div>');
				$('.u10modal').html($mobileMenu);
				$('.u10modal #u10cmenu').addClass('u10opened mobile');
				$('.u10.u10v6 #u10cmenu .u10menupop.u10toolpop').empty().removeClass('u10opened');
			}
		} 
		else {
			if ($('.u10modal').length) {
				var CLS_CMENUL1 = 'u10cmenu-l1',
					CLS_CURREGN = 'u10currentcr',
					CLS_CMENUL2 = 'u10cmenu-l2';
				var $desktopMenu = $('.u10modal #u10cmenu .u10menupop.u10toolpop').clone(true);
				//$('.u10modal .u10menupop.u10toolpop').remove();
				$('body').removeClass('u10hide');
				$('.u10.u10v6 #u10cmenu .u10menupop.u10toolpop').remove();
				$('.u10.u10v6 #u10cmenu').append($desktopMenu);
				var $cmenus = $('.u10').find(oracleDataMenu.classSelector([CLS_CMENUL1, [CLS_CURREGN, CLS_CMENUL2]]));
				$cmenus.equalHeight(true);
				$('body').removeClass('noScroll');
				$('.u10modal').empty().remove();
				$('#u10cmenu').addClass('u10opened');
			}
		}
	});
}

$(document).on('mouseup touchend', function(e){
	if ($(e.target).closest(".u10.u10v6 #u10cmenu").length === 0) { 
		$('body').addClass('u10hide');
	} 
}); 

//Global variable to hold a temporary copy of the country menu in case all instances get deleted.
var menuData;


/*! CG19 - OCRSL */
OCOM.register(function ocrsl($) {
	'use strict';
	$('.o-crsl').each(function(){
		if(!$(this).hasClass('crsl-customjs')){

			var $container = $(this),
				$slider = $container.find('.crsl-slider'),
				$nav = $('<div class="crsl-nav slick-nav"></div>').appendTo($container),
				colnum = 1,
				mobilecol = 1,
	//			navfor = $container.data('crslnavfor') ? $container.closest('section').find('.'+$container.data('crslnavfor')).first() : false,
	//			navfor = $container.data('crslnavfor') ? '.'+$container.data('crslnavfor') : false,
	//			fornav = $container.data('crslfornav') ? '.'+$container.data('crslfornav') : false,
	//			focusOn = (navfor) ? true : false,
	//			navfor = (fornav) ? fornav : navfor,
				r2l = $container.closest('.rtl')[0] ? true : false,
				hasDots = $container.hasClass('crsl-no-dots') ? false : true,
				hasArrows = $container.hasClass('crsl-no-arrows') ? false : true,
				speed = $container.attr('data-speed') ? $container.attr('data-speed') : 300,
				setautoplay = $container.attr('data-slideautoplay') ? true : false;
				if(setautoplay == true) {
					var setautoplayspeed = $container.attr('data-slideautoplay') * 1000;
				}
			// set column number
			if ($container.hasClass('col5')) {
				colnum = 5;
			}else if ($container.hasClass('col4')) {
				colnum = 4;
			}else if ($container.hasClass('col3')) {
				colnum = 3;
			}else if ($container.hasClass('col2')) {
				colnum = 2;
			}

			// 2 up mobile option allow for 2 up on mobile
			if ($container.is('.col-2upmobile') && !$container.is('.col1')) {
				mobilecol = 2;
			}

			// add class if more than minimum number is present to show nav on full desktop
			if($container.find('.col-item').length > colnum){
				$container.addClass('crsl-full');
			}

			//JS breakpoint must match the breakpoint in the CSS
			var responsiveConfig = {
				'col1': [], // no breakpoints
				'col2': [
					{
						breakpoint: 770,
						settings: {
							slidesToShow: mobilecol,
							slidesToScroll: mobilecol
						}
					}
				],
				'col3': [
					{
						breakpoint: 1081, // first must be 1px higher than css breakpoint (when arrows are still on sides)
						settings: {
							slidesToShow: 2,
							slidesToScroll: 2
						}
					},
					{
						breakpoint: 600,
						settings: {
							slidesToShow: mobilecol,
							slidesToScroll: mobilecol
						}
					}
				],
				'col4': [
					{
						breakpoint: 1301,
						settings: {
							slidesToShow: 3,
							slidesToScroll: 3
						}
					},
					{
						breakpoint: 974,
						settings: {
							slidesToShow: 2,
							slidesToScroll: 2
						}
					},
					{
						breakpoint: 600,
						settings: {
							slidesToShow: mobilecol,
							slidesToScroll: mobilecol
						}
					}
				],
				'col5': [
					{
						breakpoint: 1301,
						settings: {
							slidesToShow: 4,
							slidesToScroll: 4
						}
					},
					{
						breakpoint: 1080,
						settings: {
							slidesToShow: 3,
							slidesToScroll: 3
						}
					},
					{
						breakpoint: 600,
						settings: {
							slidesToShow: 2,
							slidesToScroll: 2
						}
					},
					{
						breakpoint: 450,
						settings: {
							slidesToShow: mobilecol,
							slidesToScroll: mobilecol
						}
					}
				]
			};

			$slider.slick({
				appendArrows: $nav,
				appendDots: $nav,
				infinite: false,
				lazyLoad: 'ondemand',
				dots: hasDots,
				arrows: hasArrows,
				swipe: true,
				autoplay: setautoplay,
				autoplaySpeed:setautoplayspeed,
				rtl: r2l,
				touchMove: true,
	//			asNavFor: navfor,
	//			focusOnSelect: focusOn,
				slidesToShow: colnum,
				slidesToScroll: colnum,
				speed: speed,
				// IE Hack to prevent css transform issues and use js animation instead
				useCSS: /(MSIE |Trident\/)/.test(window.navigator.userAgent) ? false : true,
				responsive: responsiveConfig['col'+colnum]
			});
		}
	});
	
	    $(".o-crsl .crsl-slider").on('afterChange', function(event, slick, currentSlide){
			bc_pauseAll(false,$(this).closest('.o-crsl'));
	    });
	
}, true);

/* EXPANDOCOLS */
OCOM.register(function expandocols($) {
	'use strict';

	$('.expando .col-framework, .col-framework.expando').each(function() {

		// .col-framework.expando is LEGACY support
		// new markup should be section.expando > div.cwidth > .col-framework
		var $container = $(this).closest('.expando'),
				$panels = $container.find('.col-item'),
				// don't try to wrap if col-framework is inside of expando
				needsWrap = !$(this).closest('[data-ocomid="expando"]').length,
				resizeTimeout;

		var wrapPanels = function($ctr, $panels) {

			var minPanels			 = $ctr.data('expandomin'),
					numPanels 		 = getNumPanels($panels, minPanels),
			    $visiblePanels = getVisiblePanels($ctr),
			    hasExpando     = $ctr.find('[data-ocomid="expando"]').length,
			    $expando       = hasExpando ?
															$ctr.find('[data-ocomid="expando"]') :
															$('<div class="col-w1" data-ocomid="expando">');

			if($panels.length > numPanels) {

				if(!hasExpando) {

					$expando
						.data('moretxt', $ctr.data('moretxt'))
						.data('closetxt', $ctr.data('closetxt'));

					$panels.slice(numPanels).wrapAll($expando);

					OCOM.expando($ctr);

				} else {

					$panels.slice(numPanels).appendTo($expando);

				}
			}

			// move panels out of expando if they fit into first row
			while($visiblePanels.length < numPanels) {
				$expando.find('.col-item').first()
					.insertAfter($visiblePanels.parent().find('> .col-item').last());
				numPanels = getNumPanels($panels);
				$visiblePanels = getVisiblePanels($ctr);
			}

			// if expando is empty, remove it
			if(!$ctr.find('[data-ocomid="expando"] > .col-item').length) {
				$ctr.find('[data-ocomid="expando"]').remove();
				$ctr.find('.expando-btn').remove();
			}

		};

		var onWindowResized = function($ctr, $panels) {
			clearTimeout(resizeTimeout);
			resizeTimeout = setTimeout(wrapPanels.bind(null, $ctr, $panels), 250);
		};

		// get number of panels that can fit within page width
		var getNumPanels = function($panels, min) {
			var w    = $panels[0].offsetWidth,
			    ctrW = $container[0].offsetWidth,
			    fit  = Math.floor(ctrW / w);

			// if min is a multiple of fit, use min (eg. two rows)
			// otherwise, we're at an intermediate breakpoint (eg. 3-up of 4col)
			// 	so just use fit
			return min % fit === 0 ? min : fit;
		};

		// get panels that are not contained in expando
		var getVisiblePanels = function($ctr) {
			return $ctr.find('.col-w1:not([data-ocomid="expando"]) > .col-item');
		};

		// store a reference to this instance for event handling
		if(!$container.data('instanceId')) {
//			$container.data('instanceId', new Date().getTime());
			$container.data('instanceId', Math.floor(Math.random() * 10000000)+'-'+Math.floor(Math.random() * 100000));
		}

		if($panels.length && needsWrap) {
			wrapPanels($container, $panels);
			$(window)
				.off('resize.' + $container.data('instanceId'))
				.on('resize.' + $container.data('instanceId'), onWindowResized.bind(null, $container, $panels));
		}
	});
}, true);

/* INVIEWCOLS */
OCOM.register(function inviewcols($) {
	$('.col-framework:not(.col-noanimation)').inView();
}, true);



/*! CC02 */
OCOM.register(function otable($) {
	'use strict';

	var resizeTimeout;

	$('.otable-sticky').each(function() {

		var $otable = $(this),
				$w1 = $otable.find('.otable-w1'),
				$w2 = $otable.find('.otable-w2');

		// prevent dupes - only need one clone
		if($w1.find('.otable-scroll').length) { return; }

		return (
			$w2.clone(true)
				.addClass('otable-scroll')
				.appendTo($w1)
		);
	});


	function onWindowResized(e) {
		clearTimeout(resizeTimeout);
		return (
			resizeTimeout = setTimeout(function() {
				$('.otable-sticky, .otable-scrolling').each(function() {
					var $otable = $(this),
							$w1 = $otable.find('.otable-w1'),
							// if sticky, returns the clone, otherwise just need the w2
							$scrollTbl = $otable.find('.otable-w2').last();

					return $w1.toggleClass('scrolling', $scrollTbl.outerWidth() > $w1.outerWidth());
				});
			}, 200)
		);
	}

	return onWindowResized() &&
		$(window).off('resize.otable').on('resize.otable', onWindowResized);

}, true);


/*! CC04 */
OCOM.register(function cc04($) {
	'use strict';

	var $cc04 = $('.cc04');

	(function(){
		 var originalAddClassMethod = jQuery.fn.addClass;
		 jQuery.fn.addClass = function(){
			var result = originalAddClassMethod.apply( this, arguments );
			jQuery(this).trigger('cc04colorchange');
			return result;
		 }
	})();

	$(function(){
		$('.cc04 .col-item.slick-slide').on('cc04colorchange', function(event){
			var activecc04 = event.currentTarget;
			updateColors(activecc04);
		});
	});

	function updateColors(v) {
		var v = $(v);
		//Page Heros
		if (v.closest('.pghero')[0]) {
			if ( v.is('.cc04dark') ) {
				v.closest('.cc04').addClass('cc04dark').removeClass('cc04light');
				$('body').addClass('cc04dark').removeClass('cc04light');
			}else{
				v.closest('.cc04').addClass('cc04light').removeClass('cc04dark');
				$('body').addClass('cc04light').removeClass('cc04dark');
			}
		}
		//All Others
		else {
			if ( v.is('.cc04dark') ) {
				v.closest('.cc04').addClass('cc04dark').removeClass('cc04light');
			}else{
				v.closest('.cc04').addClass('cc04light').removeClass('cc04dark');
			}
		}
	}

	setTimeout(function() {
		$('.cc04 .slick-slide.slick-active').each(function(){
			updateColors(this);
		});

		if($('.ct12')[0]) {
			$cc04.addClass('ct12active');
		}else{
			$cc04.addClass('ct12inactive');
		}
	}, 1);

});


/*! CB18 */
OCOM.register(function cb18($) {
	'use strict';

	var cb18 = $('div.cb18').parent();
		$('.cb18w4').addClass('cb18filtersloaded');

// Hide and show filters if there is a v4 on the page
	if ( $('.cb18resultsblock .cb19v4').length ) {
		$('.cb18w4').removeClass('cb18filtersloaded');
		$('.cb18results').hide();
		$('.cb18resultsblock').addClass('cb18morepad');
		$('.cb18mobiletabs').addClass('cb18filtersleft');
		$('#cb18mfilter').addClass('cb18noresults');
		$('#cb18msort').addClass('cb18noresults');
	}

// Close Filters on load if they aren't set as active from endeca
	$('.cb18catlist:not(.active)').slideUp(0);

// Hide and show filters on mobile
	cb18.find('.cb18contentwrap .cb18mobiletabs li').on('click', function(){
		if ($(this).hasClass('active'))
			{
				$('#cb18mfilter, #cb18msort').removeClass('cb18show');
				$(this).removeClass('active');
			}
		else
			{
				$(this).siblings().removeClass('active');
				$(this).addClass('active');
				$('#cb18mfilter, #cb18msort').removeClass('cb18show');
				var target = $(this).attr('data-cb18');
				$("#"+target).addClass('cb18show');
			}
	});

	$(".cb19 .cb19w3 .cb19lnks .cb19w7:only-child, .cb19 .cb19w3 .cb19lnks .cb19w9:only-child, .cb19 .cb19w3 .cb19lnks .cb19w10:only-child").addClass('cb19noborder');

// Filter accordian
	//cb18.find('.cb18fcategory h4').click(function() {
	cb18.find('.cb18fcategory h4').on('click', function(){
		$(this).closest('cb18w3').find('h4').toggleClass('active');
		$(this).toggleClass('active');
		$(this).closest('cb18w3').find('.cb18catlist').removeClass('active').slideUp(250);
		$(this).siblings('.cb18catlist').toggleClass('active').slideToggle(250);
	});

// Close Dropdowns if you click anywhere else
	$('html').click(function(e) {
		if( !$(e.target).hasClass('cb18sort') ) {
			$('ul.cb18sort').children('li:not(.init)').hide().removeClass("selected");
			$('ul.cb18sort').children('li.init').removeClass('icn-cv-up').addClass('icn-cv-down').addClass("selected");
			enableScroll();
		}
	});

// Keyboard nav on dropdowns
	$('ul.cb18sort').children('li').removeClass("selected");
	$('ul.cb18sort').children('li.init').addClass("selected");

	var cb18keys = {37: 3, 38: 2, 39: 1, 40: 4, 33: 1, 34: 1, 13: 5};

	function preventDefault(e) {
		e = e || window.event;
		if (e.preventDefault)
			e.preventDefault();
		e.returnValue = false;
	}

	function preventDefaultForScrollKeys(e) {

		var keysortlist = $('ul.cb18sort.active');
		var keysortlistchild = $('ul.cb18sort.active li');

		if (cb18keys[e.keyCode] == 2) { // up
			 var selected = $(keysortlist).find(".selected");
			 $(keysortlistchild).siblings().removeClass("selected");
			 if (selected.prev().length == 0) {
				 selected.siblings().last().addClass("selected");
			 } else {
				selected.siblings().removeClass("selected");
				 selected.prev().addClass("selected");
			 }
			 preventDefault(e);
			return false;
		}
		if (cb18keys[e.keyCode] == 4) { // down
			 var selected = $(keysortlist).find(".selected");
			 $(keysortlistchild).siblings().removeClass("selected");
			 if (selected.next().length == 0) {
				 selected.siblings().first().addClass("selected");
			 } else {
				selected.siblings().removeClass("selected");
				 selected.next().addClass("selected");
			 }
			 preventDefault(e);
			return false;
		}
		if (event.keyCode==13){// enter
			 var selected = $("ul.cb18sort li.selected");
			$(selected).find('a').trigger('click');
			$(keysortlist).children().removeClass("selected");
			$(keysortlist).find("li.init").addClass("selected");
			 preventDefault(e);
			return false;
		}
	}

	function disableScroll() {
		document.onkeydown	= preventDefaultForScrollKeys;
	}

	function enableScroll() {
		document.onkeydown = null;
	}

// Open and close dropdowns
	cb18.find("ul.cb18showlist").on("click", ".init", function() {
		var thelist = $(this).closest('ul');
		var sortlist = $('ul.cb18sortlist');
		if ($(thelist).hasClass('active')) {
			enableScroll();
			$(thelist).removeClass('active');
			$(thelist).children('li:not(.init)').removeClass('selected').hide();
			$(thelist).children('li.init').removeClass('icn-cv-up').addClass('icn-cv-down');
		}
		else {
			disableScroll();
			$(sortlist).removeClass('active').find('li:not(.init)').each(function() {
				$(this).hide();
				$(this).removeClass('selected');
			});
			$(thelist).find('li:not(.init)').hover(
				function(){
					$(this).toggleClass('selected');
					$(this).siblings().removeClass('selected');
				}
			);
			$(sortlist).find('li.init').removeClass('icn-cv-up').addClass('icn-cv-down');
			$(thelist).addClass('active');
			$(thelist).find('li:not(.init)').each(function() {
				$(this).toggle();
			});
			$(thelist).find('li.init').toggleClass("icn-cv-down icn-cv-up");
			return false;
		}
	});

	cb18.find("ul.cb18sortlist").on("click", ".init", function() {
		var thelist = $(this).closest('ul');
		var showlist = $('ul.cb18showlist');
		if ($(thelist).hasClass('active')) {
			enableScroll();
			$(thelist).removeClass('active');
			$(thelist).children('li:not(.init)').removeClass('selected').hide();
			$(thelist).children('li.init').removeClass('icn-cv-up').addClass('icn-cv-down');
		}
		else {
			disableScroll();
			$(showlist).removeClass('active').find('li:not(.init)').each(function() {
				$(this).hide();
				$(this).removeClass('selected');
			});
			$(thelist).find('li:not(.init)').hover(
				function(){
					$(this).toggleClass('selected');
					$(this).siblings().removeClass('selected');
				}
			);
			$(showlist).find('li.init').removeClass('icn-cv-up').addClass('icn-cv-down');
			$(thelist).addClass('active');
			$(thelist).find('li:not(.init)').each(function() {
				$(this).toggle();
			});
			$(thelist).find('li.init').toggleClass("icn-cv-down icn-cv-up");
			return false;
		}
	});

	cb18.find('.cb18selectedfilters li a').each(function(index) {
		if ($(this).siblings('.cb18filtersub').length) {
			$(this).parent().addClass('cb18haschildren');
		}
	});

	$(window).on('load', function () {
		movenoresults();
	});

	//$(window).load(function() {
	//	movenoresults();
	//});

	$(window).on('resize', function(){
		movenoresults();
	});

	function movenoresults(){
		if ($(".cb18mobiletabs").is(':hidden')) {
			$(".cb18w10").addClass("cb18lesspadding");
			$(".cb18resultstxt").addClass("cb18lesspadding");
		}
		else {
			$(".cb18w10").removeClass("cb18lesspadding");
			$(".cb18resultstxt").removeClass("cb18lesspadding");
		}
	}

	cb18.find('.cb18selectedfilters li.cb18clall').on("click", function() {
		window.searchMetric = '';
		window.searchWord = '';
		window['s_prop4'] = '';
		window['s_eVar22'] = '';
		window['s_eVar23'] = '';
	});

	cb18.find("a[data-s_prop4]").on("click", function() {
		var delin = ($(this).attr('href').indexOf('?') < 0) ? '?' : '&';
		window.searchMetric = $(this).attr('data-s_prop4');
		hijaxArgs = 's_prop4';
	});
	
	if($('.cb18searchform').hasClass('cb18embed') && ($('.cb18embcls').length == 0)) {
		$('.cb18swrap').append('<div class="cb18embcls icn-close"></div>');
		$('.cb18embcls').on("click", function(e) {
			var cb18results = cb18.find('.cb18wrap');
			cb18results.css("visibility", "visible").slideUp(501, function() {
				$(this).css("opacity", 1.0).css("visibility", "hidden").animate({"opacity": 0.0}, 200);
				$('.cb18embcls').css("opacity", 1.0).css("visibility", "hidden").animate({"opacity": 0.0}, 200);
			});
		});
	}

// Search Form Interaction
	$(".cb18searchform").each( function (i, w1) {
		var cb18form = $(w1),
				searchField = cb18form.find("#cb18txtSearch").get(0);
		
		$(searchField).attr('data-dvalue',$(searchField).val()); // set val to data since defaultValue tripping on ajax replacement
		if ($(searchField).val()) {
			$(".cb18w11").show();}
		else {
			$(".cb18w11").hide();}

		cb18form.on("mouseenter", function (e) {
			if (searchField.defaultValue !== searchField.value) {
				$(e.currentTarget).find(".cb18form1").show();
			}
		});
		cb18form.find(".cb18forminput input").on("focus", function (e) {
			$(e.currentTarget).css({color: "#252525"});
			if ( $(e.currentTarget).attr('placeholder') ){
				$(e.currentTarget).data('placeholder', $(e.currentTarget).attr('placeholder')).removeAttr('placeholder');
			}

			if ($(e.currentTarget).val()) {
				$(e.currentTarget).closest(".cb18searchform").find(".cb18w11").show();
			}
		});
		cb18form.find("input[type='text']").on("input", function (e) {
			if ($(e.currentTarget).val()) {
				$(e.currentTarget).closest(".cb18searchform").find(".cb18w11").show();
			} else {
				$(e.currentTarget).closest(".cb18searchform").find(".cb18w11").hide();
			}
		});

		cb18form.find("input[type='reset']").on("click", function (e) {
			e.stopImmediatePropagation();
			window.searchMetric = "Remove: " + $(searchField).attr('value');
			window.searchWord = '';
			$(searchField).attr('value','');
			$(e.currentTarget).closest(".cb18w11").hide();
			cb18form.attr('data-resetting',1);
		//	if($(searchField).attr('data-dvalue') != ''){
				setTimeout(function(){ // have to delay submit to prevent cleared value from being passed
					cb18form.submit();
				}, 10);
		//	}
		});

		if(cb18form.hasClass('cb18embed')) {
			cb18form.submit(function() {
				var cb18results = cb18.find('.cb18wrap');
				if ( $(cb18results).css('display') == 'none' || $(cb18results).css("visibility") == "hidden"){
					$('.cb18 .awesomplete .ui-autocomplete').attr("hidden",true);
					cb18results.css("visibility", "hidden").slideDown(1001, function() {
						$(this).css("opacity", 0.0).css("visibility", "visible").animate({
							"opacity": 1.0
						}, 300);
						$('.cb18embcls').css("opacity", 0.0).css("visibility", "visible").animate({
							"opacity": 1.0
						}, 300);
					});
				}
			});
		}

	});

// Auto Complete
var appendtarget = $('div.cb18sright');
var cpath = (appendtarget.find('[data-contentpaths]')[0]) ? appendtarget.find('[data-contentpaths]').attr('data-contentpaths') : '/content/Web/Shared/Auto-Suggest Panel';
appendtarget.addClass('autocompleteparent');

/* globals autocompleteVals */
$(".cb18searchform:not(.noautosuggest) input#cb18txtSearch").awesomplete({
	appendTo: appendtarget,
	source: function( request, response ) {
		var regexp = new RegExp(request.term.replace(/[-[\]{}()*+?.,\\/^$|#\s]/g, '\\$&')),
					adds = autocompleteVals ? autocompleteVals.reduce(function(arr,term) {
						if(regexp.test(term)) {
							arr.push({
								label: term
							});
						}
						return arr;
					},[]) : [];
		jQuery.ajax({
			url: '/search/autosuggest.json/browse',
			dataType: "json",
			data: {
				Dy: 1,
				contentPaths: cpath,
				templateTypes: "AutoSuggestPanel",
				Ntt: request.term+"*"
			},
			success: function( data ) {
				var dsv = [];
				//Seth added .length line
				//if(data.contents.length > 0) {
					if(data.contents[0].autoSuggest[0].totalNumResults > 0){
						dsv = jQuery.map( data.contents[0].autoSuggest[0].dimensionSearchGroups[0].dimensionSearchValues, function(item) {
							return{
								label : item.label
							}
						});
					}
				//}
				
				response(adds.concat(dsv));
			},
			error: function(){
				return null;
			}
		});
	},
	minLength: 3,
	autoFocus: false,
	select: function(event, ui) {
		//$(".ui-autocomplete").hide();
		$("input#cb18txtSearch").val(ui.item.value);
		$("input#cb18txtSearch").closest('form.cb18searchform').submit();
	},
	open: function(event, ui) {
		$('.ui-autocomplete').off('menufocus hover mouseover mouseenter');
	}
});



	$('.cb18selectedfilters li a').hover(function () {
		if ($(this).siblings('.cb18filtersub').length) {
			$(this).siblings('.cb18filtersub').find('li > a').addClass('cb18hover');
		}
	}, function () {
	 $('.cb18filtersub li a').removeClass('cb18hover');
	});

});

// same function exist in compass version, and changes here should be reflected there
runSearchMetrics = function (){
	var pageLocation = location.href.split("?");
	
	//Get search vars from data attr if nohijaxurl
	if ($('.nohijaxurl')[0]){
		var pageLocation = $('.nohijaxurl').data('nohijaxurl').split("?");
	}	
	
	if (pageLocation[1]) {
		pageLocation = pageLocation[1].split('&')[0].split('=');
		if (pageLocation[0] == 'Ntt' && pageLocation[1] != '') {
			window.searchWord = 'Search: ' + pageLocation[1];
		}
	}
	if (window.searchMetric) {
		window.searchMetric = window.searchMetric.replace('gt;', '>');
		window.s_prop4 = window.searchMetric;
		window.s_eVar22 = window.searchMetric;
	} else if (window.searchWord) {
		window.s_prop4 = window.searchWord;
		window.s_eVar22 = window.searchWord;
	} else {
		window.s_prop4 = window.s_eVar22 = '';
	}
	window.s_prop6 = $(".cn15active a").text();
	if (window.s_eVar23) {
		if ($(".cn15active a").text() == 1 || $(".cn15active a").text() == '') {
			window.s_eVar23 += ':' + (window.searchMetric || window.searchWord);
		}
	} else {
		window.s_eVar23 = window.searchMetric || window.searchWord;
	}

	OCOM.cb18();
	
	bc_embedsetup($('.cb18resultsblock'));

//	var pingOK=s_beacon();
//	if(pingOK){
//		window.searchMetric = '';
//		s_code=s.t();
//		if(s_code){
//			document.write(s_code);
//		}
//	}

}



/*! CB27 */
OCOM.register(function cb27($) {
	'use strict';

	var settings = {
				endpoint: '/a/ocom/docs/global-json/feature-banner-content.json',
				colorDefault: 'burgundy',
				templateName: 'cb27-banner',
				storageKey: 'cb27banner',
				$target: $('[class^="u10"]').first()
			},
			event5 = {
				endpoint: '/a/ocom/docs/global-json/event-banner-content.json',
				storageKey: 'cb27banner-event5',
				$target: $('[class^="u19"]').first()
			},
			isActive = checkMetaTag(),
			codebase = 'undefined' !== typeof OCOM && OCOM.codebase || '',
			loco = window.location.href,
			stage = /localhost/.test(loco) ? '' : 'https://www-sites.oracle.com',
			$cb27 = $('<section class="cb27 cb27v6 cb27sticky" data-trackas="global-promo-banner"></section>'),
			CLS_SHOW = 'cb27show',
			CLS_STUCK = 'cb27stuck',
			CLS_UNSTUCK = 'cb27unstuck',
			fetched = false,
			pgVars = getPageVars(),
			datetime = new Date().toISOString(),
			minWinW = 460,
			minWinH = 600,
			contentData,
			delay,
			scrollThreshold,
			themes = {
				'burgundy': {
					obttn: 'obttn6',
					bkgnd: 'bgburgundy',
					iconcolor: 'fill-lightburgundy',
					bttncolor: 'bttn-darkburgundy'
				},
				'darkburgundy': {
					obttn: 'obttn5',
					bkgnd: 'bgdarkburgundy',
					iconcolor: 'fill-lightburgundy',
					bttncolor: 'bttn-darkburgundy'
				},
				'darkgrey': {
					obttn: 'obttn5',
					bkgnd: 'bgdarkgrey',
					iconcolor: 'fill-lightgrey',
					bttncolor: 'bttn-darkgrey'
				},
				'blue': {
					obttn: 'obttn6',
					bkgnd: 'bgblue',
					iconcolor: 'fill-lightblue',
					bttncolor: 'bttn-darkblue'
				},
				'darkblue': {
					obttn: 'obttn5',
					bkgnd: 'bgdarkblue',
					iconcolor: 'fill-lightblue',
					bttncolor: 'bttn-darkblue'
				},
				'darkslate': {
					obttn: 'obttn5',
					bkgnd: 'bgdarkslate',
					iconcolor: 'fill-lightslate',
					bttncolor: 'bttn-darkslate'
				},
				'orangered': {
					obttn: 'obttn5',
					bkgnd: 'bgorangered',
					iconcolor: 'fill-lightorange',
					bttncolor: 'bttn-red'
				},
				'burgundyred': {
					obttn: 'obttn5',
					bkgnd: 'bgburgundyred',
					iconcolor: 'fill-lightburgundy',
					bttncolor: 'bttn-darkburgundy'
				},
				'burgundyblue': {
					obttn: 'obttn5',
					bkgnd: 'bgburgundyblue',
					iconcolor: 'fill-lightburgundy',
					bttncolor: 'bttn-blue'
				},
				'bluegreen': {
					obttn: 'obttn5',
					bkgnd: 'bgbluegreen',
					iconcolor: 'fill-lightblue',
					bttncolor: 'bttn-green'
				},
				'redblue': {
					obttn: 'obttn5',
					bkgnd: 'bgredblue',
					iconcolor: 'fill-lightorange',
					bttncolor: 'bttn-blue'
				}
			};

	/* globals $import, jsfilepath */
	function init() {

		var hbsLoaded = $('script[src$="ocom-handlebars.js"]').length,
				interval;

		// initialize outer scope vars with local overrides
		jQuery.extend(settings, codebase === 'event5' && event5);

		contentData = getSessionStorage(settings.storageKey);

		// if we've checked and set sessionStorage to false,
		// 	don't check again for remainder of session
		if(contentData === false) { return false; }

		contentData = getUnexpiredEntries(contentData);
		delay = contentData && contentData[0] ? contentData[0].delay : 0;
		scrollThreshold = contentData && contentData[0] ? contentData[0].onscroll : 0;

		/* globals isStageSite */
		settings.endpoint =
			typeof isStageSite === 'function' && isStageSite() ?
				stage+'/a/'+settings.endpoint.split('/a/')[1] :
				settings.endpoint;

		if(!hbsLoaded) { $import(jsfilepath+'ocom-handlebars.js'); }

		interval = setInterval(function () {
			if(window.WS && window.WS.tpl && window.WS.tpl[settings.templateName]) {
				clearInterval(interval);
				fetchBannerData();
			}
		}, 10);
	}

	function fetchBannerData() {

		// check for new theme properties on sessionStorage
		// if not found, set to null to get ajax data again
		if(contentData && contentData.length && contentData[0].bkgnd) {
			setBannerColor(themes[contentData[0].color].bkgnd);
		} else {
			contentData = null;
		}

		window.HBSINJECT.initialize({
			feedsrc: settings.endpoint,
			data: contentData && contentData[0],
			cache: true,
			targetObj: $cb27,
			templateName: settings.templateName,
			beforeInjectionCallback: !contentData ? prepJSON : false,
			afterInjectionCallback: checkData
		});
	}

	function prepJSON(json) {

		if('object' !== typeof json || json instanceof Error) {
			/* eslint no-console:0 */
			return console.warn('CB27: Error with ' + settings.endpoint + ' (' + json + ')');
		}

		if('undefined' === typeof json.languages) {
			return removeSessionStorage(settings.storageKey);
		}

		var options = getEntryByKey(json.languages, 'all'),
				// check if color is one of our defined themes, otherwise use default
				color = (Object.keys(themes).indexOf(options.color) > -1 && options.color) ||
									settings.colorDefault,
				data = getUnexpiredEntries(getEntryByKey(json.languages, pgVars.lang)),
				entry = data && getValidEntries(data)[0] || null,
				// used for html entity conversion
				$t = $('<textarea />'),
				theme;

		// set flag that we've checked the file
		fetched = true;
		delay = options.delay > -1 ? parseInt(options.delay, 10) : delay;
		scrollThreshold = options.onscroll > -1 ? parseInt(options.onscroll, 10) : scrollThreshold;

		if(entry) {

			// check for override of global color theme
			entry.color = (entry.color &&
											Object.keys(themes).indexOf(entry.color) > -1 &&
											entry.color) || color;

			theme = themes[entry.color];

			jQuery.extend(entry, theme);

			// allow for entry level override of unhide settings
			entry.delay = entry.delay &&
										(delay = entry.delay) && delay ||
											delay;
			entry.onscroll = entry.onscroll &&
												(scrollThreshold = entry.onscroll) && scrollThreshold ||
													scrollThreshold;

			entry.description = $t.html(entry.description).text();
			entry.sites = Array.isArray(entry.sites) ? entry.sites : entry.sites.split(',');

			setBannerColor(theme.bkgnd);

			setSessionStorage(settings.storageKey, data);

			return entry;

		} else {

			removeSessionStorage(settings.storageKey);

		}

		return false;
	}

	function getValidEntries(data) {

		if(!data) { return null; }

		data = Array.isArray(data) ? data : [data];

		return data.filter(
			function(entry) {

				// valid until proven otherwise
				var isValid = true;

				// if paths is defined, must check url path for match
				if(entry.paths) {
					// true if array item is a regexp match to url
					isValid = entry.paths.some(function(path) {
						return new RegExp(escapeForRegExp(path), 'i').test(loco);
					});
				}

				// if excludes is defined, must check url path for non-match,
				// 	or that excludes is empty
				if(entry.excludes) {
					// true if NO array item is a regexp match to url
					isValid = !entry.excludes.some(function(exclude) {
						return new RegExp(escapeForRegExp(exclude), 'i').test(loco);
					}) || entry.excludes.length === 0;
				}

				return isValid;

			}) || [];
	}

	function getUnexpiredEntries(data) {

		if(!data) { return null; }

		data = Array.isArray(data) ? data : [data];

		return (
			data.filter(removeExpiredEntries)
				.sort(sortByExpires) || []
		);
	}

	function checkData() {

		var isExpired = datetime > contentData[0].expires,
				isValidSite = new RegExp('\\b'+pgVars.siteid+'\\b', 'i').test(contentData[0].sites.join(' ')),
				isTNsite = /technetwork/.test(loco);

		if(!pgVars.siteid && isTNsite) {
			isValidSite = new RegExp('\\btechnetwork\\b', 'i').test(contentData[0].sites.join(' '));
		}

		if(isExpired || !isValidSite) {
			removeSessionStorage(settings.storageKey);
			// check for new data, but only if we haven't already
			//  fetched the JSON file
			return !fetched && fetchBannerData();
		}

		if(scrollThreshold > 0) {
			return !isExpired && isValidSite && $(window).on('scroll.cb27', onWindowScrolled);
		} else {
			return !isExpired && isValidSite && showBanner();
		}
	}

	/* globals Waypoint */
	function showBanner() {

		// there can be only one... and this one trumps the static cb27v6
		$('.cb27sticky').not($cb27).removeClass('cb27sticky');

		settings.$target.before($cb27);

		$cb27.find('.obttns > div:last > a').attr('data-lbl', contentData[0].datalbl);
		$cb27.find('.obttns > div:nth-last-child(2) > a').attr('data-lbl', contentData[0].datalbl2);
		$cb27[0].style.setProperty('--marginBtm', -$cb27.outerHeight() + 'px');

		$cb27.on('click.cb27', '.icn-close', dismissBanner);

		setTimeout(function() {

			$cb27.addClass(function() {
				return (contentData[0] && contentData[0].unstuck) || !allowSticky() ?
					[CLS_SHOW, CLS_UNSTUCK].join(' ') : [CLS_SHOW, CLS_STUCK].join(' ');
			});

			settings.$target.waypoint(function(dir) {
				$cb27
					.toggleClass(CLS_UNSTUCK, dir === 'down' || !allowSticky() || contentData[0].unstuck)
					.toggleClass(CLS_STUCK, dir === 'up' && allowSticky() && !contentData[0].unstuck);
			},
			{
				offset: function() {
					return Waypoint.viewportHeight() - $cb27.outerHeight();
				}
			});

		}, delay);
	}

	function onWindowScrolled(e) {

		var scroll = window.scrollY ||
									window.pageYOffset || // IE 9+
									document.documentElement.scrollTop; // IE < 9

		if(scroll > scrollThreshold) {
			delay = 0;
			$(window).off('scroll.cb27');
			showBanner();
		}
		return false;
	}

	function allowSticky() {
		return Waypoint.viewportHeight() >= minWinH &&
						window.innerWidth >= minWinW &&
						document.location.href.indexOf('screenshot') < 0;
	}

	function getEntryByKey(objArr, key) {
		var arr =
			objArr.filter(function(obj) {
				return Object.keys(obj)[0] === key;
			});
		return arr.length && arr[0][key] ? arr[0][key] : false;
	}

	function getPageVars() {
		return {
			siteid: $('meta[name="siteid"]').attr('content') || false,
			countryid: $('meta[name="countryid"]').attr('content') || false,
			country: $('meta[name="country"]').attr('content') || false,
			lang: $('meta[name="Language"]').attr('content') || false
		};
	}

	function setBannerColor(color) {
		$cb27.addClass(color);
	}

	/* globals JSON */
	function getSessionStorage(key) {
		return JSON.parse(sessionStorage.getItem(key));
	}

	function setSessionStorage(key, data) {
		contentData = data;
		return sessionStorage.setItem(key, JSON.stringify(data));
	}

	function removeSessionStorage(key) {
		contentData = null;
		sessionStorage.setItem(key, false);
	}

	function dismissBanner() {

		var sess = getUnexpiredEntries(getSessionStorage(settings.storageKey)),
				entries = getValidEntries(sess);

		// because array.filter creates a new array we need to find
		// 	the index ref of the current content within session data
		sess[sess.indexOf(entries[0])].unstuck = true;

		setSessionStorage(settings.storageKey, sess);

		$cb27.removeClass(CLS_SHOW);
		$cb27.off('click.cb27');
		setTimeout($cb27.addClass.bind($cb27, CLS_UNSTUCK), 800);
	}

	function sortByExpires(a, b) {
		// sort by expiring first
		return new Date(a.expires).getTime() - new Date(b.expires).getTime();
	}

	function removeExpiredEntries(entry) {
		return entry.expires > datetime;
	}

	function escapeForRegExp(str) {
		return str.replace(/[-[\]{}()*+?.,\\/^$|#\s]/g, '\\$&');
	}

	/**
	 * allows for page level disabling with
	 * 	<meta name="cb27banner" content="disable" />
	 */
	function checkMetaTag() {
		var $meta = $('meta[name*="cb27banner"]');
		return !($meta.length && $meta.attr('content') === 'disable');
	}

	return isActive && init();

}, true);


/*! CB27v8 */

OCOM.register(function cb27v8($) {
	'use strict';

	/* globals Waypoint, JSON */

	var CLS_CB27 = 'cb27v8',
			CLS_INIT = 'cb27init',
			CLS_SHOW = 'cb27show',
			CLS_STUCK = 'cb27stuck',
			CLS_UNSTUCK = 'cb27unstuck',
			EV_CLICK = 'click.cb27v8',
			EV_SCROLL = 'scroll.cb27v8',
			minWinW = 460,
			minWinH = 600,
			$cb27 = $('.' + CLS_CB27),
			scrollThreshold = $cb27.attr('data-onscroll') || 200,
			storageKey = CLS_CB27 + $cb27.attr('id'),
			state = getSessionStorage(storageKey),
			isSticky = !state || state !== CLS_UNSTUCK,
			isCompSample = /compsample/.test(window.location.href);

	function showBanner() {

		$cb27[0].style.setProperty('--marginBtm', -$cb27.outerHeight() + 'px');
		$cb27.on(EV_CLICK, '.icn-close', dismissBanner);

		$cb27.addClass(function() {
			return !isSticky || !allowSticky() ?
				[CLS_SHOW, CLS_UNSTUCK].join(' ') : [CLS_SHOW, CLS_STUCK].join(' ');
		});

		return isSticky && allowSticky() && trackSticky();

	}

	function dismissBanner() {

		$cb27
			.removeClass(CLS_SHOW)
			.off(EV_CLICK);

		setSessionStorage(storageKey, CLS_UNSTUCK);

		return setTimeout($cb27.addClass.bind($cb27, CLS_UNSTUCK), 800);
	}

	function onWindowScrolled(e) {

		var scroll = window.scrollY ||
				window.pageYOffset || // IE 9+
				document.documentElement.scrollTop; // IE < 9

		return (scroll > scrollThreshold) &&
			$(window).off(EV_SCROLL) &&
			$cb27.addClass(CLS_INIT) &&
			showBanner();
	}

	function handleCompSample() {
		return isCompSample &&
			$cb27.addClass(CLS_INIT) &&
			showBanner();
	}

	function allowSticky() {
		return isCompSample ||
			$cb27[0].hasAttribute('id') &&
			Waypoint.viewportHeight() >= minWinH &&
			window.innerWidth >= minWinW &&
			!/screenshot/.test(window.location.href);
	}

	function trackSticky() {
		return (
			$cb27.next().waypoint(function(dir) {
				$cb27
					.toggleClass(CLS_UNSTUCK, dir === 'down' || !allowSticky() || !isSticky)
					.toggleClass(CLS_STUCK, dir === 'up' && allowSticky() && isSticky);
			}, {
				offset: function() {
					return Waypoint.viewportHeight() - $cb27.outerHeight();
				}
			})
		);
	}

	function getSessionStorage(key) {
		return sessionStorage.getItem(key);
	}

	function setSessionStorage(key, data) {
		return sessionStorage.setItem(key, data);
	}

	// there can be only one...
	return $cb27.length === 1 &&
		$(window).on(EV_SCROLL, onWindowScrolled) &&
		handleCompSample();

});


/*! CB46 */
OCOM.register(function cb46($) {
	$('.cb46[data-autorotate]').ocomautorotate();
});

$(window).on("load", function () {
	var interval = [],
		injectFeed = function (cb46) {
			var feedsrc = $(cb46).attr("data-feedsrc"),
				template = $(cb46).attr("data-template"),
				twitImg = $(cb46).attr("data-twitimage");
			if (feedsrc && template) {
				window.HBSINJECT.initialize({
					feedsrc: feedsrc,
					targetObj: cb46,
					templateName: template,
					beforeInjectionCallback: function (jsonresults) {
						jsonresults.twit_image = twitImg;
						return jsonresults;
					}
				});
			}
		};
	$(".cb46").each( function (i, cb46) {
		if (propertyExists(cb46, "data-template")) {
			interval[i] = setInterval( function () {
				if (objLoaded("HBSINJECT", "initialize")) {
					clearInterval(interval[i]);
					injectFeed(cb46);
				}
			}, 10);
		}
	});
});

/*! CB50 - OCOM */
OCOM.register(function cb50($) {
  'use strict';

  $('.cb50v3').each(function(i) {

	  var $cb50 = $(this),
	  		$hdgs = $cb50.find('.col-item-w2'),
	  		resizeTimeout;

		// lazy loading images
		$cb50.on('inview',function() {
				$(this).find('img').each(function(i, img){
						if(img.getAttribute('data-src')) {
			    		img.setAttribute('src', img.getAttribute('data-src'));
			    		img.removeAttribute('data-src');
			    	}
				});
			})
			.inView();

		// equalize heights of colored bkgnd headings
		$hdgs.equalHeight(true);

		// use the index as instance counter for unique event handlers
		$(window).off('resize.cb50-' + i).on('resize.cb50i' + i, onWindowResized );

		function onWindowResized(e) {
			clearTimeout(resizeTimeout);
			resizeTimeout = setTimeout($hdgs.equalHeight.bind($hdgs, true), 250);
		}

	});

});

/*! CB50 - HBS */
OCOM.register(function cb50hbs($) {
	'use strict';

	var $cb50v2arr = $('.cb50[data-feedsrc]'),
			wordmapData,
			interval;

	/* globals Wordmaps */
	Wordmaps.init().then(function(data) {
		wordmapData = data;
		interval = setInterval(init, 10);
	});

	function prepJSON(json) {

		var
				$cb50 = this,
				/* only needed for v3 support
				$t = $('<textarea />'),
				*/
				colors = [
					'orange',
					'burgundy',
					'darkblue',
					'green',
					'blue'
				],
				bgcolors = [
					'bgvlightgrey',
					'bglightslate',
					'bgvlightgrey',
					'bgvlightslate',
					'bglightgrey'
				],
				count = 0;

		return {

			items: json.map(function(item) {

				/* NOTE: only need to parse resource_text
				 *  	if v3 needs support - not currently required
				var
					// to avoid breaking layout strip out all tags
					orig = item.resource_text ? item.resource_text.replace(/(&lt;|<)\/?(.*?)(&gt;|>)/ig, '') : '',

					// weird trick to convert html entities by stuffing into
					// textarea and pulling innerText back out
					dsc = $t.html(orig).text(),

					// At least 30 & up to 200 chars, ending at punctuation
					regexp = new RegExp('^\\s*(.{30,150}(?=[.?!])[.?!]?)'),
					match = regexp.exec(dsc) ?
										regexp.exec(dsc)[1] :
										dsc.split(' ').slice(0, 15).join(' ') + '&hellip;';
				*/

				// check for image, if null don't pass to template
				if(item.image_link == null) { return null; }

				/* description is only needed if v3 needs support
				// 	pass boolean isV3 to template for conditional desc container
				item.isV3 = $cb50.hasClass('cb50v3');
				item.description = match;
				*/

				item.tag = item.content_type.length &&
										item.content_type.map(function(type) {
											return wordmapData[type];
										})[0];

        // set a flag if resource is a gated asset that should
        //  trigger a lightbox form pop up
        item.isGated = item.isGated === 'Y';

        // set iframe params for lightbox
        item.iframeW = $cb50.data('iframewidth') || 1180;
        item.iframeH = $cb50.data('iframeheight') || 700;

				// trim leading/trailing whitespace from title
				item.title = item.title.trim();

				// get the next color
				item.color = colors[count];
				item.bgcolor = bgcolors[count];
				count = (count === colors.length - 1) ? 0 : count + 1;

				return item;

			})
			// discard those that are null
			.filter(function(item) {
				return !!item;
			})
			// return the first four (CB50 only supports 4 panels)
			.slice(0, 4)
		};
	}

	function init() {

		/* globals objLoaded */
		if(objLoaded('HBSINJECT', 'initialize')) {

			clearInterval(interval);

			$cb50v2arr.each(function(i, cb50) {

				var $cb50 = $(cb50),
						$target = $cb50.find('.ofeed'),
						feedsrc = $cb50.attr('data-feedsrc'),
						template = $cb50.attr('data-template');

				if(feedsrc && template) {

					window.HBSINJECT.initialize({
						feedsrc: feedsrc,
						cache: true,
						targetObj: $target,
						templateName: template,
						beforeInjectionCallback: prepJSON.bind($cb50),
						afterInjectionCallback: function() {
							$target.addClass('hbs-initialized');
							$cb50.find('.col-framework').inView();
							/* eq height of description container only needed if v3 needs support
							return $cb50.hasClass('cb50v3') && OCOM.cb50();
							*/
						}
					});
				}
			});
		}
	}

});


/*! CB64 */
OCOM.register(function cb64($) {
	'use strict';

	$('.cb64').each(function() {

		$(this).find('.icn-img:not(.bggreen)').each(function(){
			var icntxt = $(this).attr('class').replace(/icn-img/,'').split('icn-')[1].split(' ')[0];
			$(this).attr('class','icn-img icn-circle fill-white bggreen icn-'+icntxt);
		});

		$(this).find('.cb64w5 .obttns > div.icn-padlock').each(function(){
			$(this).removeClass('icn-padlock').find('> a').addClass('icn-padlock');
		});




		// don't do any of this on the wrapper
		if($(this).hasClass('cb64v3')) { return; }

		var $cb64 = $(this),
				shouldFilter = !$cb64.hasClass('cb64nofilter'),
				$articles = $cb64.find('.cb64w1').not('.cb64search').find('.cb64w3'),
				$hdg = $cb64.find('.cb64catHdg'),
				$btn = $cb64.find('.cb64-bttn-more'),
				$searchpanels = $cb64.find('.cb64search'),
				btntextinitial = $cb64.find('.cb64-bttn-more a').text(),
				icnRegExp = /icn-(?!heading)[\w\-]+/,
				hasIcn = icnRegExp.exec($hdg.attr('class')),
				iconclassinitial = hasIcn ? hasIcn[0] : '',
				maxrecords = $cb64.attr('data-maxrecords') || 5;

		$('.cn25').on('filterResults', 'a', function(event, filter, btntext, iconclass) {
			filterResults(filter, btntext, iconclass, event.currentTarget);
		});

		filterResults(null, '', iconclassinitial, $hdg);

		function truncateResults(btntext) {

			var $results = $articles.not('.filtered');

			// loose equality to check for undefined
			if (maxrecords == 0) {
				maxrecords = $results.length;
			}

			btntext = btntext || '';

			setTimeout(function() {
				fadeInSequential($results.slice(0, maxrecords));
			}, 100);

			if ($results.length > maxrecords) {
				$results.closest('.cb64w2').addClass('truncated');
				$btn.on('click', showTruncatedResults);
				if(shouldFilter) {
					$btn.find('a').text([btntextinitial, btntext].join(' '));
				}
			} else {
				$results.closest('.cb64w2').removeClass('truncated');
				$btn.off('click', showTruncatedResults);
			}

			return false;
		}

		function showTruncatedResults(e) {

			e.preventDefault();

			var $results = $articles.filter('.hidden').not('.filtered');

			fadeInSequential($results);

			$results.closest('.cb64w2').removeClass('truncated');
			$btn.off('click', showTruncatedResults);

			return false;
		}

		function filterResults(filter, btntext, iconclass, caller) {

			$articles.addClass('hidden').removeClass('filtered');

			if(filter) {
				$articles.not('[data-categories*="' + filter + '"]')
					.addClass(shouldFilter && 'filtered');
			}

			if ($searchpanels.length) {
				$searchpanels
					.addClass('hidden')
					.filter('#' + ( filter || caller.text().toLowerCase() )+ '-search')
					.removeClass('hidden');
			}

			$hdg.addClass('switch');
			setTimeout(function() {
				$hdg.text($(caller).text()).removeClass('switch');
				if (iconclass) {
					$hdg.attr('class', $hdg.attr('class').replace(icnRegExp, iconclass));
				}
			}, 200);

			truncateResults(btntext);

			return false;
		}

		function fadeInSequential($els) {

			var $el = $els.eq(0);

			setTimeout(function() {
				$el.removeClass('hidden');
				return ($els = $els.slice(1)).length && fadeInSequential($els);
			}, 200);

			return false;
		}

		$cb64.triggerHandler('cb64ready');

	});
});

/*! CB64v3 */
OCOM.register(function cb64v3($) {
	'use strict';

	$('.cb64v3').each(function() {
		var $ctr = $(this);

		$('.cn25').on('filterResults', 'a', function(event, filter) {

			return filter === $ctr.attr('id') &&
							$ctr.addClass('cb64show') ||
							$ctr.removeClass('cb64show');

		});
	});
});

/*! CB64-HBS */
OCOM.register(function cb64hbs($) {
	'use strict';

	var $cb64arr = $('.cb64[data-feedsrc]'),
			wordmapData,
			interval;

	/* globals Wordmaps */
	Wordmaps.init().then(function(data) {
		wordmapData = data;
		interval = setInterval(init, 10);
	});

	function prepJSON(json) {

		var $cb64 = this,
				// only used for html entity conversion, just create it once
				$t = $('<textarea />');

		return {

			items: json.map(function(item) {

				var
						// to avoid breaking layout strip out all tags
						orig = item.summary ? item.summary.replace(/(&lt;|<)\/?(.*?)(&gt;|>)/ig, '') : '',

						// weird trick to convert html entities by stuffing into
						// textarea and pulling innerText back out
						dsc = $t.html(item.summary).text();

				item.description = dsc;

				// set a flag if resource is a gated asset that should
				//  use a lock-icn & trigger a lightbox form pop up
				item.isGated = item.isGated === 'Y';

				// set iframe params for lightbox
				item.iframeW = $cb64.data('iframewidth') || 1180;
				item.iframeH = $cb64.data('iframeheight') || 700;

				// trim leading/trailing whitespace from title
				item.title = item.title.trim();

				// create a comma separated list of data-categories for filtering
				item.tags = item.content_type.length &&
										item.content_type.map(function(type) {
											return !!wordmapData[type] &&
															wordmapData[type].toLowerCase()
																.replace(/[\(\)\[\]]/g, '')
																.replace(/ - /g, ' ').replace(/\s/g, '-') || '';
										}).join();

				return item;

			})

		};
	}

	function init() {

		/* globals objLoaded */
		if(objLoaded('HBSINJECT', 'initialize')) {

			clearInterval(interval);

			$cb64arr.each(function(i, cb64) {

				var $cb64 = $(cb64),
						$target = $cb64.find('.ofeed'),
						feedsrc = $cb64.attr('data-feedsrc'),
						template = $cb64.attr('data-template');

				if(feedsrc && template) {

					window.HBSINJECT.initialize({
						feedsrc: feedsrc,
						cache: true,
						targetObj: $target,
						templateName: template,
						beforeInjectionCallback: prepJSON.bind($cb64),
						afterInjectionCallback: function() {
							$target.addClass('hbs-initialized');
							return OCOM.cb64();
						}
					});
				}
			});
		}
	}

});


/*! CB65 */
OCOM.register(function cb65($) {

	function applyEqualHeight() {
		  $('.cb65w1 header.eq-height').equalHeight();

		  var numRows = $('.cb65w1 article:first-child > ul > li').length;

		  for (var i = 1; i <= numRows; i++){
			  var el = '.cb65w1 article > ul > li:nth-child(' + i + ')';
			  $(el).equalHeight();
		  }

		  $('.cb65w1 a.eq-height').equalHeight();
	}

	if($('.cb65')[0]){

		// add inview class to animate
		$('.cb65').inView();

		applyEqualHeight();

		$(window).resize(function() {
		  applyEqualHeight();
		});
	}

});






/*! CB66 */
OCOM.register(function cb66($){

	$('.cb66').inView();

	$('.cb66w1').each(function(){
		if($(this).find('img.cb66bgimg')[0]){
			$(this).css('background-image','url('+$(this).find('img.cb66bgimg').attr('src')+')');
		}
	});
});


/*! CB70 */
OCOM.register(function cb70($) {

	if(!$('.cb70')[0]) { return false; }

	var $cb70btn 	= $('.cb70w1 a[class*=icn]'),
		$cb70w1		= $('.cb70w1'),
		$cb70w2		= $('.cb70w2');

	$cb70w2.prepareHeightTransition();

	$cb70btn.click(function(e){

		e.preventDefault();

 		$cb70w1.toggleClass('open');
 		$cb70btn.toggleClass('icn-plus-cf icn-min-cf');

		if($cb70w1.is('.open') && !$cb70w2.find('.cb70w3').first().inViewport()){
			$('html, body').animate({ scrollTop: ($cb70w2.offset().top - $(window).height()) + 300 }, 600);
		}
	});
});


/*! CB71 */
OCOM.register(function cb71($) {
	'use strict';
	/*
	$('.cb71cta').on('mouseenter', function (e) {
        $(e.currentTarget).siblings(".o-zoom").addClass('o-zoom-hover');
	});
	$('.cb71cta').on('mouseleave', function (e) {
        $(e.currentTarget).siblings(".o-zoom").removeClass('o-zoom-hover');
	});
	$('.cb71w7').find('.cb71cta').on('click', function (e) {
		$(e.currentTarget).siblings('.o-zoom').trigger('click');
	});
	*/
	// clone heading for mobile positioning
	$('.cb71w7').each( function (i, context) {
		var w1 = $(context).closest('.cb71w1'),
			h2 = $(w1).find('.cb71w3 h2')[0],
			h2a = $(h2).clone();
		if (h2) {
			$(context).closest('.cb71w5').prepend(h2a);
		}
	});
	$('.cb71').inView();
});


/*! CB74 */
OCOM.register(function cb74($) {
	'use strict';

	$('.cb74 .col-framework').addClass(function() { return $(this).find('.col-item').length < 3 && 'col-altbreak'; } );

	var $hdgs = $('.cb74:not(.cb74v2,.cb74v3) .col-item-w1'),
			onWindowResized = function() {
				clearTimeout(resizeTimeout);
				resizeTimeout = setTimeout(function() {
					$hdgs.equalHeight();
				}, 50);
			},
			resizeTimeout;

	$hdgs.equalHeight();
	$(window).off('resize.cb74').on('resize.cb74', onWindowResized);
	
});


/*! CB77 */
OCOM.register(function cb77($){
	$('.cb77').inView();
});


/*! CB82 */
OCOM.register(function cb82($) {
  'use strict';
  	var hash = window.location.hash;

	if(!$('.cb82')[0]){ return false; }

		$('.cb82v0').each(function(){
			var $container = $(this),
			$panels = $container.find('.cb82w2'),
			// data-slick="{&quot;slidesToShow&quot;: 4, &quot;slidesToScroll&quot;: 4}"
			$navslider = $('<div class="cb82w1"></div>').insertBefore($panels);
			// data-slick="{&quot;slidesToShow&quot;: 4, &quot;slidesToScroll&quot;: 4, &quot;responsive&quot;: [{&quot;breakpoint&quot;:900, &quot;settings&quot;:{&quot;slidesToShow&quot;: 3}}]}"			
			// data-slick='{"slidesToShow": 4, "slidesToScroll": 4, responsive": [{"breakpoint":900,"settings":{"slidesToShow": 3, "slidesToScroll": 3}}]}'
			// data-slick='{"slidesToShow": 3, "infinite": true, "dots": false, "responsive": [{"breakpoint":600,"settings":{"slidesToShow": 2}}]}'
			$(this).find('.cb82w3').each(function(){

				var color = $(this).attr('data-color'),
					id = $(this).attr('data-id') ? '#' + $(this).attr('data-id') + '"' : '',
					hasGradient = color.indexOf("gradient") > -1 ? true : false,
					barcolor = $(this).closest('.cb82.txtlight')[0] ? 'bgdarkblue' : 'bgblue';
				if (hasGradient) {
					color = color.replace('-gradient','');
				}
				
				// var txt = $(this).find('h4').attr('data-icontitle');
				if ($(this).attr('data-icn')) {
					var icn = ($(this).attr('data-icn')) + (" icn-img ");
				} else {
					var icn = ('');
					$(this).parents('.cb82v0').addClass('cb82noicn');
				}
				
				if ($(this).find('h3,h4').attr('data-icontitle')){
					var txt = $(this).find('h3,h4').attr('data-icontitle');				
				} else {
					var txt = $(this).find('h3,h4').text();
				}

				if (id) {
					if (hasGradient) {
						if ($(this).parents('.cb82v0').hasClass('cb82-circle')) {
							$(this).parents('.cb82w2').siblings('.cb82w1').append('<a class="border-'+color+'" href="' + id + '"><div class="icn-circle fill-icngradient-'+ color + ' ' +icn+' bgwhite"></div><span class="cb82gradient">'+txt+'</span><i class="' + barcolor + '"></i></a>');
						} else if ($(this).parents('.cb82v0').hasClass('cb82noicn')) {
							$(this).parents('.cb82w2').siblings('.cb82w1').append('<a class="border-'+color+'" href="' + id + '"><span class="cb82gradient">'+txt+'</span><i class="' + barcolor + '"></i></a>');				
						} else if (!$(this).parents('.cb82v0').hasClass('cb82-noicn')) {			
							$(this).parents('.cb82w2').siblings('.cb82w1').append('<a class="border-'+color+'" href="' + id + '"><div class="'+icn+'fill-icngradient-'+color+'"></div><span class="cb82gradient">'+txt+'</span><i class="' + barcolor + '"></i></a>');
						}
					} else {
						if ($(this).parents('.cb82v0').hasClass('cb82-circle')) {
							$(this).parents('.cb82w2').siblings('.cb82w1').append('<a class="border-'+color+'" href="' + id + '"><div class="icn-circle '+icn+'beforewhite bg'+color+'"></div><span>'+txt+'</span><i class="bg'+color+'"></i></a>');
						} else if ($(this).parents('.cb82v0').hasClass('cb82noicn')) {
							$(this).parents('.cb82w2').siblings('.cb82w1').append('<a class="border-'+color+'" href="' + id + '"><span>'+txt+'</span><i class="bg'+color+'"></i></a>');				
						} else if (!$(this).parents('.cb82v0').hasClass('cb82-noicn')) {			
							$(this).parents('.cb82w2').siblings('.cb82w1').append('<a class="border-'+color+'" href="' + id + '"><div class="'+icn+'before'+ color+'"></div><span>'+txt+'</span><i class="bg'+color+'"></i></a>');
						}
					}	
				} else {
					if (hasGradient) {
						if ($(this).parents('.cb82v0').hasClass('cb82-circle')) {
							$(this).parents('.cb82w2').siblings('.cb82w1').append('<div class="border-'+color+'"><div class="icn-circle fill-icngradient-'+ color + ' ' +icn+' bgwhite"></div><span class="cb82gradient">'+txt+'</span><i class="' + barcolor + '"></i></div>');
						} else if ($(this).parents('.cb82v0').hasClass('cb82noicn')) {
							$(this).parents('.cb82w2').siblings('.cb82w1').append('<div class="border-'+color+'"><span class="cb82gradient">'+txt+'</span><i class="' + barcolor + '"></i></div>');				
						} else if (!$(this).parents('.cb82v0').hasClass('cb82-noicn')) {			
							$(this).parents('.cb82w2').siblings('.cb82w1').append('<div class="border-'+color+'"><div class="'+icn+'fill-icngradient-'+ color+'"></div><span class="cb82gradient">'+txt+'</span><i class="' + barcolor + '"></i></div>');
						}
					} else {
						if ($(this).parents('.cb82v0').hasClass('cb82-circle')) {
							$(this).parents('.cb82w2').siblings('.cb82w1').append('<div class="border-'+color+'"><div class="icn-circle '+icn+'beforewhite bg'+color+'"></div><span>'+txt+'</span><i class="bg'+color+'"></i></div>');
						} else if ($(this).parents('.cb82v0').hasClass('cb82noicn')) {
							$(this).parents('.cb82w2').siblings('.cb82w1').append('<div class="border-'+color+'"' + id + '><span>'+txt+'</span><i class="bg'+color+'"></i></div>');				
						} else if (!$(this).parents('.cb82v0').hasClass('cb82-noicn')) {			
							$(this).parents('.cb82w2').siblings('.cb82w1').append('<div class="border-'+color+'"' + id + '><div class="'+icn+'before'+color+'"></div><span>'+txt+'</span><i class="bg'+color+'"></i></div>');
						}
					}
				}
			});

		});

		$('.cb82v1').each(function(){
			var cb82v1 = $(this),
			$panels = cb82v1.find('.cb82w2'),
			// $topPanels = cb82v1.find('.cb82w8'),
			$navslider = $('<div class="cb82w1"></div>').insertBefore($panels),
			$topslider = $('<div class="cb82w8 cwidth"></div>').insertBefore($navslider);

			cb82v1.find('.cb82w3').each(function(){
				
				var cb82w3 = $(this),
				icn = cb82w3.attr('data-icn'), 
				img = cb82w3.attr('data-img'),
				imgt = cb82w3.attr('data-imgt'), 
				cb82w12 = (cb82w3.find('.cb82xinfo')[0]) ? cb82w3.find('.cb82xinfo').html() : '',
				ohilitetxt = (cb82w3.is('[data-ohilite]')) ? '<div class="ohilite"><div><span>'+cb82w3.attr('data-ohilite')+'</span></div></div>' : '',
				id = cb82w3.attr('data-id') ? '#' + cb82w3.attr('data-id') + '"' : '';
				if (cb82w3.attr('data-icn')) {
					var icn = (cb82w3.attr('data-icn')) + (" icn-img ");
				} else {
					var icn = ('');
					cb82w3.parents('.cb82v1').addClass('cb82noicn');
				}

				// $('img[src="undefined"]').remove();
				// cb82w3.find('.cb82xinfo').remove();

				cb82w3.find('.cb82w4').wrap('<div class="cb82w4a cwidth"><div class="cb82w4b"></div></div>');
				cb82w3.parents('.cb82w2').siblings('.cb82w1').wrap('<div class="cb82w1a cwidth"></div>')
				cb82w3.parents('.cb82w2').siblings('.cb82w8').append('<div class="cb82w9"><div class="cb82w10"><div class="cb82w11"><div class="cb82w13 '+imgt+'">'+ohilitetxt+'<img src="'+img+'"></div></div><div class="cb82w12">'+cb82w12+'</div></div></div>');
				// cb82w3.parents('.cb82w2').siblings('.cb82w8').append('<div class="cb82w9"><div class="cb82w10"><div class="cb82w11"><div class="cb82w13">'+ohilitetxt+'<img src="'+img+'"></div></div><div class="cb82w12">'+cb82w12+'</div></div></div>');
				var cb82w5 = cb82w3.find('.cb82w5');
				// var txt = cb82w3.find('h4').text();
				if (cb82w5.find('h3,h4').attr('data-icontitle')){
					var txt = cb82w5.find('h3,h4').attr('data-icontitle');				
				} else {
					var txt = cb82w5.find('h3,h4').text();
				}
				var price = cb82w3.attr('data-price');

				
	   			//	 	  if ($(this).parents('.cb82v0').hasClass('cb82-circle')) {
				// 				$(this).parents('.cb82w2').siblings('.cb82w1').append('<div class="border-'+color+'"><div class="icn-circle '+icn+'beforewhite bg'+color+'"></div><span>'+txt+'</span><i class="bg'+color+'"></i></div>');
				// } else if ($(this).parents('.cb82v0').hasClass('cb82noicn')) {
				// 				$(this).parents('.cb82w2').siblings('.cb82w1').append('<div class="border-'+color+'"><span>'+txt+'</span><i class="bg'+color+'"></i></div>');				
				// } else if (!$(this).parents('.cb82v0').hasClass('cb82-noicn')) {			
				// 				$(this).parents('.cb82w2').siblings('.cb82w1').append('<div class="border-'+color+'"><div class="'+icn+'before'+color+'"></div><span>'+txt+'</span><i class="bg'+color+'"></i></div>');
				// }
				if (id) {
					if (cb82w3.parents('.cb82v1').hasClass('cb82noicn')) {
					cb82w3.parents('.cb82w2').siblings('.cb82w1a').children('.cb82w1').append('<a href="' + id + '"><span>'+txt+'</span><i></i></a>');
					} else {
					cb82w3.parents('.cb82w2').siblings('.cb82w1a').children('.cb82w1').append('<a href="' + id + '"><div class="icn-img icn-circle '+icn+'"></div><span>'+txt+'</span><i></i></a>');
					}
				} else {
					if (cb82w3.parents('.cb82v1').hasClass('cb82noicn')) {
					cb82w3.parents('.cb82w2').siblings('.cb82w1a').children('.cb82w1').append('<div><span>'+txt+'</span><i></i></div>');
					} else {
					cb82w3.parents('.cb82w2').siblings('.cb82w1a').children('.cb82w1').append('<div><div class="icn-img icn-circle '+icn+'"></div><span>'+txt+'</span><i></i></div>');
					}
				}
// 				cb82w3.parents('.cb82w2').siblings('.cb82w8').append('<div class="cb82w9"><div class="cb82w10"><div class="cb82w11"><div class="cb82w13"><div class="ohilite"><div><span>'+ohilitetxt+'</span></div></div><img src="'+img+'"></div></div><div class="cb82w12"><div class="obttns"><div><a href="placeholder.html">Buy now</a></div></div><p>Prices starting at '+price+'</p></div></div></div>');
				cb82w3.parents('.cb82w2').siblings('.cb82w8').find('.cb82w13').each(function(){
					$('img[src="undefined"]').parents('.cb82w11').remove();
				});
			});

		});

		$('.cb82v0 .cb82w2').each(function(key, item) {

		var sliderIdName = 'cb82slider' + key;
		var sliderNavIdName = 'cb82sliderNav' + key;

		this.id = sliderIdName;
		$('.cb82v0 .cb82w1')[key].id = sliderNavIdName;

		var sliderId = '#' + sliderIdName;
		var sliderNavId = '#' + sliderNavIdName;

		$(sliderId).on('init.slick', function(event, slick){
			$(this).parents('.cb82v0').addClass('cb82h');
		});

		// $(sliderNavId).on('init.slick', function (event, slick) { 
			
		// 	var slickSlide = $(this).find('.slick-slide');
		// 	$(slickSlide).height('auto');
		// 	var slickTrackHeight = $(this).find('.slick-track').height();
		// 	$(slickSlide).css('height', slickTrackHeight + 'px');
		// 	console.log('init');
		// });


		$(sliderId).slick({
			slidesToShow: 1,
			slidesToScroll: 1,
			infinite: false,
			arrows: false,
			speed: 400,
			fade: true,
			cssEase: 'ease-in-out',
			swipe: true,
			// asNavFor: sliderNavId,
			adaptiveHeight: true
		});

		$(sliderNavId).slick({
			slidesToShow: 6,
			slidesToScroll: 6,
			asNavFor: sliderId,
			dots: false,
//			appendDots:$(this).parents('.cb82v0'),
			arrows: true,
			speed: 800,
			focusOnSelect: false,
			swipe: false,
			infinite: false,
			responsive: [
				{
					//Must match the breakpoint in the CSS
					breakpoint: 1080,
					settings: {
						slidesToShow: 4,
						slidesToScroll: 4
					}
				},
				{
					breakpoint: 601,
					settings: {
						slidesToShow: 1,
						slidesToScroll: 1
					}
				}
			]

		});
		$(sliderNavId).find('.slick-slide').on('click', function (event) {

			var color = $($('.cb82w3')[$(event.currentTarget).index()]).attr('data-color'),
				prevColor = $($('.cb82w3')[$(this).siblings('.slick-current').index()]).attr('data-color'),
				hasGradient = color.indexOf("gradient") > -1 ? true : false,
				prevHasGradient = prevColor && prevColor.indexOf("gradient") > -1 ? true : false;

			if (prevHasGradient) {
				swapGradient (prevColor,$(this).siblings('.slick-current'),1)
			} else {
				//$(this).siblings('.slick-current').find('.icn-circle').addClass('bg' + prevColor).removeClass('bgwhite');
				//$(this).siblings('.slick-current').children('div').addClass('beforewhite').removeClass('before' + prevColor);
			}

			$(this).siblings().removeClass('slick-current');
			$(this).parents('.cb82w1').siblings('.cb82w2').slick('slickGoTo', $(this).data('slickIndex'));
			$(this).addClass('slick-current');

			if (hasGradient) {
				swapGradient (color,$(this),0)
			} else {
				//$(this).find('.icn-circle').addClass('bgwhite').removeClass('bg' + color);
				//$(this).children('div').removeClass('beforewhite').addClass('before' + color);
			}
		});

		// $(sliderNavId).on('setPosition beforeChange', function (event, slick) { 
			
		// 	var slickSlide = $(this).find('.slick-slide');
		// 	$(slickSlide).height('auto');
		// 	var slickTrackHeight = $(this).find('.slick-track').height();
		// 	$(slickSlide).css('height', slickTrackHeight + 'px');
		// 	console.log('setposition and beforeChange');
		// });
		
		$(sliderId).on('beforeChange', function (event, slick, currentSlide, nextSlide) {
			var current = $(this).find('.slick-current').data('slickIndex'),
				color = $(this).find('.slick-current').attr('data-color'),
				nav = $(this).siblings('.cb82w1'),
				hasGradient = color && color.indexOf("gradient") > -1 ? true : false;
			if (hasGradient) {
				swapGradient (color,$(nav).find('.slick-current'),1);
			} 
			$(this).find('.slick-slide[data-slick-index="' + current + '"]').fadeTo(200,0);
		});

		$(sliderId).on('afterChange', function (event, slick, currentSlide, nextSlide) {
			var current = $(this).find('.slick-current').data('slickIndex'),
				nav = $(this).siblings('.cb82w1'),
				color = $(this).find('.slick-current').attr('data-color'),
				hasGradient = color && color.indexOf("gradient") > -1 ? true : false;

			$(nav).slick('slickGoTo', (current));

			if (hasGradient) {swapGradient (color,$(nav).find('.slick-current'),1);}

			$(nav).find('.slick-slide').removeClass('slick-current');

			$(nav).find('.slick-slide[data-slick-index="' + current + '"]').addClass('slick-current');
			
			if (hasGradient) {swapGradient (color,$(nav).find('.slick-current'),0);};

			$(this).find('.slick-slide[data-slick-index="' + current + '"]').fadeTo(200,1);
		});
		$(sliderNavId).on('breakpoint', function (e) {
			// check for gradient in non-current slides
			var context = $(e.currentTarget); // the carousel div
			$(context).find('.slick-slide').each( function (i, slide) {
				var color = $($(slide).closest('.cb82').find('.cb82w3')[$(slide).index()]).attr('data-color');
				if (color && color.indexOf("gradient") > -1 ) {
					if (!$(slide).hasClass('slick-current')) {
						if ($(slide).find('.bg-icngradient-' + color.replace('-gradient',''))[0]) {
							swapGradient(color,$(slide),1);
						}
					}
				}
			});

			//console.log($(context).find('.slick-slide'));

		})
	});
	
		$('.cb82v1 .cb82w2').each(function(key, item) {

			var sliderIdName = 'cb82v1slider' + key;
			var sliderIdNametop = 'cb82v1slidertop' + key;
			var sliderNavIdName = 'cb82v1sliderNav' + key;

			this.id = sliderIdName;
			$('.cb82v1 .cb82w1')[key].id = sliderNavIdName;
			$('.cb82v1 .cb82w8')[key].id = sliderIdNametop;

			var sliderId = '#' + sliderIdName;
			var sliderIdtop = '#' + sliderIdNametop;
			var sliderNavId = '#' + sliderNavIdName;

			$(sliderId).on('init.slick', function(event, slick){
				$(this).parents('.cb82v1').addClass('cb82h');
			});

			$(sliderId).slick({
				slidesToShow: 1,
				slidesToScroll: 1,
				infinite: false,
				arrows: false,
				speed: 400,
				fade: true,
				swipe: true,
				// asNavFor: sliderNavId,
				adaptiveHeight: true
			});
			$(sliderIdtop).on('init.slick', function(event, slick){
				// console.log('initTop');
				var cb82hilt = $(this).find('.slick-current .ohilite');
				var cb82w12 = $(this).find('.slick-current .cb82w12');
				$(cb82hilt).parents('.cb82w11').removeClass('ohilite-on');
				$(cb82w12).parents('.cb82w10').addClass('cb82w12-on');
				if ($(cb82hilt).length > 0){
					$(cb82hilt).parents('.cb82w11').addClass('ohilite-on');
				}
			});
			$(sliderIdtop).on('afterChange', function(event, slick){
				$(this).slick('refresh');
			});

			$(sliderIdtop).slick({
				slidesToShow: 1,
				slidesToScroll: 1,
				infinite: false,
				arrows: false,
				speed: 700,
				fade: true,
				cssEase: 'cubic-bezier(0.175, 0.885, 0.32, 1.275)',
				swipe: false,
				adaptiveHeight: true
			});

			$(sliderNavId).slick({
				slidesToShow: 6,
				slidesToScroll: 6,
				asNavFor: sliderId,
				arrows: true,
				speed: 800,
				focusOnSelect: false,
				swipe: false,
				infinite: false,
				responsive: [
					{
						//Must match the breakpoint in the CSS
						breakpoint: 1080,
						settings: {
							slidesToShow: 4,
							slidesToScroll: 4
						}
					},
					{
						breakpoint: 601,
						settings: {
							slidesToShow: 1,
							slidesToScroll: 1
						}
					}
				]

			});


			$(sliderNavId).find('.slick-slide').on('click', function (event) {
			
				$(this).siblings().removeClass('slick-current');
				$(this).parents('.cb82w1a').siblings('.cb82w2, .cb82w8').slick('slickGoTo', $(this).data('slickIndex'));
				$(this).addClass('slick-current');

			});

			$(sliderId).on('beforeChange', function (event, slick, currentSlide, nextSlide) {
				var current = $(this).find('.slick-current').data('slickIndex');
				$(this).find('.slick-slide[data-slick-index="' + current + '"]').fadeTo(200,0);
			});

			$(sliderId).on('afterChange', function (event, slick, currentSlide, nextSlide) {

				// $(this).addClass('what');
				var current = $(this).find('.slick-current').data('slickIndex');
				var nav = $(this).siblings('.cb82w1a').children('.cb82w1');
				var top = $(this).siblings('.cb82w8');
				$(nav).slick('slickGoTo', (current));
				$(nav).find('.slick-slide').removeClass('slick-current');
				$(nav).find('.slick-slide[data-slick-index="' + current + '"]').addClass('slick-current');

				$(top).slick('slickGoTo', (current));
				$(top).find('.slick-slide').removeClass('slick-current');
				$(top).find('.slick-slide[data-slick-index="' + current + '"]').addClass('slick-current');

				$(this).find('.slick-slide[data-slick-index="' + current + '"]').fadeTo(200,1);
			});

			$(sliderIdtop).on('beforeChange', function(event, slick, currentSlide, nextSlide){
				var current = $(this).find('.slick-current').data('slickIndex');
				var slidex = $(this).find('.cb82w8');

				var cb82hilt = $(this).find('.slick-slide[data-slick-index="' + current + '"] .ohilite');
				var cb82w12 = $(this).find('.slick-slide[data-slick-index="' + current + '"] .cb82w12');

				$(cb82hilt).parents('.cb82w11').removeClass('ohilite-on');
				$(cb82w12).parents('.cb82w10').removeClass('cb82w12-on');

				// console.log('onbeforeChange sliderIdtop');
				// $(this).find('.slick-slide[data-slick-index="' + current + '"]').fadeTo(100,0);
			});

			$(sliderIdtop).on('afterChange', function(event, slick, currentSlide, nextSlide){
				var current = $(this).find('.slick-current').data('slickIndex');
				var slidex = $(this).find('.cb82w8');
				var cb82hilt = $(this).find('.slick-slide[data-slick-index="' + current + '"] .ohilite');
				var cb82w12 = $(this).find('.slick-slide[data-slick-index="' + current + '"] .cb82w12');

				$(cb82hilt).parents('.cb82w11').addClass('ohilite-on');
				$(cb82w12).parents('.cb82w10').addClass('cb82w12-on');
				// console.log('onafterChange sliderIdtop');

				// $(this).find('.slick-slide[data-slick-index="' + current + '"]').fadeTo(100,1);

			});
		});

		$('.cb82w9 .cb82w13 img').on('load',function(){
			$('.cb82w13').css('order',1);
			$(this).closest('.slick-slider').slick('resize');
		});


		if (hash && $('.cb82 a[href="' + hash + '"]')[0]) {
			$('.cb82 a[href="' + hash + '"]').trigger('click');
		}
		$(window).on( 'hashchange', function (e) {
	  		hash = window.location.hash;
	  		if (hash && $('.cb82 a[href="' + hash + '"]')[0]) {
				$('.cb82 a[href="' + hash + '"]').trigger('click');
			}
	  	});
	  	$('.cb82').each( function (i, cb) {
		  	var cur = $(cb).find('.slick-current'),
		  		color = $($(cb).find('.cb82w3')[$(cur).index()]).attr('data-color');
		  	if (color && color.indexOf("gradient") > -1 ) {
			  	swapGradient(color,cur,0);
		  	}
	  	});

	  	function swapGradient (color,context,mode) {
			color = color.replace('-gradient','');
			if (mode == 0) {
				$(context).find('.icn-circle').addClass('bg-icngradient-' + color).removeClass('bgwhite');
				if ($(context).find('.icn-circle')[0]) {
					$(context).children('div').addClass('beforewhite').removeClass('fill-icngradient-' + color);
				}
			} else {
				$(context).find('.icn-circle').removeClass('bg-icngradient-' + color).addClass('bgwhite');
				$(context).children('div').removeClass('beforewhite').addClass('fill-icngradient-' + color);
			}
			
		}

});


/*! CB90 */
OCOM.register(function cb90($) {
	'use strict';

	// legacy
/*
	$('.cb90w3 .cb90w5 + .cb90w7,.cb90w3 .cb90w5').on({
	     mouseenter: function() {
	        $(this).closest('.cb90w3').find(".cb90w5,.cb90w5 + .cb90w7").addClass('cb90zoomhvr');
	     },
	     mouseout: function() {
	        $(this).closest('.cb90w3').find('.cb90zoomhvr').removeClass('cb90zoomhvr');
	     }
	});
*/
	// new 
	$('.cb90').each( function (i, cb) {
		$(cb).find('.cb90zoom').each( function (j, zoom) {
			var cta = $(zoom).siblings('.cb90cta'),
				ctaContent = $(cta)[0] ? $(cta).find('a').html() : '',
				newContent,
				zoomSibling;
			$(zoom).removeClass('cb90zoom').addClass('ozoom');
			
			

			if ($(cta)[0]) {
				$(zoom).addClass('ozoom-cta');
			} else {
				// old cb90v0x0.1 cta format, which is consecutive lightbox anchors
				if ($(zoom).next('a')[0] && $(zoom).next('a').attr('href') == $(zoom).attr('href')) {
					ctaContent = $(zoom).next('a').html();
					$(zoom).addClass('ozoom-cta');
					$(zoom).next('a').remove();
				}
			}
			if (ctaContent) {
				newContent = $('<span class="ozoom-txt">' + ctaContent + '</span>')
				$(zoom).append(newContent);
				$(cta).remove();
			}
		});

	});
	/*
	$('.cb90zoom + .cb90cta > a[rel^="light"],a.cb90zoom').on({
	     mouseenter: function() {
	        $(this).closest('.cb90w3').find(".cb90zoom").addClass('cb90zoomhvr');
	     },
	     mouseout: function() {
	        $(this).closest('.cb90w3').find('.cb90zoomhvr').removeClass('cb90zoomhvr');
	     }
	});
	*/

	$('.cb90w11 .cb90-right').each(function(){
		$(this).closest('.cb90w11').addClass('cb90right');
	});
 
});


/*! CB98 */
OCOM.register(function cb98($) {
	'use strict';

	$('.cb98').each(function(){
		var $w5cnt = $(this).find('header .cb98w5 .cb98w7');
		var $w6cnt = $(this).find('header .cb98w6 .cb98w7');
		var $w8cnt = $(this).find('header .cb98w8 .cb98w7');
		var $w5title = $(this).find('.cb98w5 h5');
		var $w6title = $(this).find('.cb98w6 h5');
		var $w8title = $(this).find('.cb98w8 h5');

		$w5cnt.clone().insertBefore($w5title);
		$w6cnt.clone().insertBefore($w6title);	
		$w8cnt.clone().insertBefore($w8title);	
	});
});

/*! CB100 */
OCOM.register(function cb100($) {
	'use strict';
	
	setTimeout(function(){
		$('.cb100 a').on("click", function(e) {
			if ($('.ct12')[0]) {
				var cb100space = $('.ct12').height();
			}
			e.preventDefault();
			var target = $(this).attr("href");
			var scrollToPosition = $(target).offset().top - cb100space;
			$('html').animate({ 'scrollTop': scrollToPosition }, 600, function(){
				window.location.hash = "" + target;
				$('html').animate({ 'scrollTop': scrollToPosition }, 0);
			});
		});
	
	}, 300);

});

/*! CB105 */
OCOM.register(function cb105($) {
	'use strict';

	$('.cb105').each(function () {

		var $cb105 = $(this),
			CLS_OPEN = 'cb105open',
			CLS_PLUS = 'icn-plus',
			CLS_MIN = 'icn-min',
			VK_ENTER = 13,
			CLS_PLUSMIN = [CLS_PLUS, CLS_MIN].join(' '),
			allListItems = '.cb105w1 > ul > li',
			allRegionHeadings = '.cb105w1 > ul > h4',
			listItems = '> li',
			openItems = '.' + CLS_OPEN,
			icon = '.icn-img',
			toggleAll = '.cb105toggle-all';

		$cb105
			.find(allListItems).attr('tabindex','0').attr('role','region')
			.prepend('<a role="button" aria-expanded="false" aria-role="presentation" class="icn-img ' + CLS_PLUS + '"></a>').end()
			.find('.cb105w2').attr('aria-role','section').attr('aria-hidden','true').prepareHeightTransition().find('.cta-list');
		
		$(this).find(allRegionHeadings).attr('aria-role','heading');
		$(this).find('.cb105w2 a').attr('tabindex','-1');

		$cb105.find(allListItems).find('h5').attr('aria-role','heading');
		$cb105.find('h5').attr('aria-role','heading');
		$cb105.find('.cb105w1 header a').attr('role','button').attr('aria-role','presentation').attr('tabindex','0');
		
		$cb105.find('.cb105w2 a').attr('aria-hidden','true').attr('tabindex','-1');
		$cb105.find(openItems).children(icon).toggleClass(CLS_PLUSMIN).attr('aria-expanded','true').attr('aria-label','Close button');
		$cb105.find(openItems).find('.cb105w2 a').attr('aria-hidden','false').attr('tabindex','0');

		$cb105.find('.cb105open').find('.cb105w2').attr('aria-hidden','false');
		$cb105.find(allListItems).find('a[role="button"][aria-expanded="false"]').attr('tabindex','-1').attr('aria-label','Open button');

		//Initial accessibility setup for Toggle All button.
		var $allToggle = $('.cb105toggle-all');
		updateToggleAllA11y();


		$cb105.on('click', allListItems, function (e) {
			// After clicking on the list item, detect if the click occured within a link (making sure the anchor link has no classes --  as otherwise we're dealing with a toggle icon), and navigate to the link's target. 
			// Otherwise, toggle the element open/close state.	

			if (e.target.nodeName === 'A' && e.target.className === "") {
				if (e.target.target === "_blank") {
					window.open(e.target.href, '_blank');
				} 
				if (e.target.rel === "vbox") {
					return;
				}
				if (e.target.target === "") {
					window.location = e.target.href;
				}
				e.preventDefault();
			} 

		
			else {
				var $ul = $(this).closest('ul'),
					$ctr = $ul.find(toggleAll).length && $ul || $cb105;

				if (e.isDefaultPrevented()) {
					return;
				}

				e.preventDefault();

				var toggleItem = $(this).toggleClass(CLS_OPEN).children(icon).toggleClass(CLS_PLUSMIN) &&
					$ctr.find(openItems).length === $ctr.find(
						$ctr.is('ul') ? listItems : allListItems).length &&
					$ctr.find(toggleAll).removeClass(CLS_PLUS).addClass(CLS_MIN) ||
					$ctr.find(toggleAll).removeClass(CLS_MIN).addClass(CLS_PLUS);

					if ( $(this).hasClass('cb105open') )  {
						$(this).attr('aria-expanded','true');
						$(this).find('a').attr('tabindex','0').attr('aria-hidden','false');
						$(this).find('a[role="button"]').attr('tabindex','0').attr('aria-label','Close button');
						$(this).closest('li').find('.cb105w2').attr('aria-hidden','false');
						$(this).focus();
					}
					else  {
						$(this).attr('aria-expanded','false');
						$(this).find('a').attr('tabindex','-1').attr('aria-hidden','true');
						$(this).find('a[role="button"]').attr('tabindex','-1').attr('aria-label','Open button');
						$(this).closest('li').find('.cb105w2').attr('aria-hidden','true');
					}
			}
			updateToggleAllA11y();
		});

		//Event listeners for Toggle All button and section buttons.

		$cb105.find(toggleAll).on({
			keydown: function(e) {
				if (e.keyCode === VK_ENTER) {
					toggleAllItems(e);
				}
			},

			click: function(e) {
				toggleAllItems(e);
			}
		});

		$cb105.find(allListItems).keyup(function(e) {
			if (e.keyCode === VK_ENTER) {
				$(this).click();
			}
		});



		function toggleAllItems(e) {
			var $allToggle = $('.cb105toggle-all'),
				$ctr = $allToggle.closest('ul').length && $allToggle.closest('ul') || $cb105;

			e.preventDefault();

			var closeAll = $allToggle.toggleClass(CLS_PLUSMIN) &&
				$allToggle.hasClass(CLS_MIN) &&
				$ctr.find($ctr.is('ul') ? listItems : allListItems).addClass(CLS_OPEN)
				.children(icon).removeClass(CLS_PLUS).addClass(CLS_MIN) ||
				$ctr.find($ctr.is('ul') ? listItems : allListItems).removeClass(CLS_OPEN)
				.children(icon).removeClass(CLS_MIN).addClass(CLS_PLUS);
			
			if ( $allToggle.hasClass('icn-min') )  {
				$cb105.find('.icn-min').attr('aria-label','Close button');
				$allToggle.attr('aria-label','Close all');
				$cb105.find('li').attr('aria-expanded','true');
				$('.cb105w2 a').attr('aria-hidden','false').attr('tabindex','0');
			}
			if ( $allToggle.hasClass('icn-plus') )  {
				$cb105.find('.icn-plus').attr('aria-label','Open button');
				$allToggle.attr('aria-label','Open all');
				$cb105.find('li').attr('aria-expanded','false').attr('aria-hidden','true');
				$('.cb105w2 a').attr('aria-hidden','true').attr('tabindex','-1');
			}
		}

		function updateToggleAllA11y() {
			if ($allToggle.hasClass('icn-min'))  {
				$allToggle.attr('aria-label','Close all');
			}
			else if ($allToggle.hasClass('icn-plus'))  {
				$allToggle.attr('aria-label','Open all');
			}
		}	
	});
});

/*! CB106 */
OCOM.register(function cb106($) {
	'use strict';

	$('.cb106').each(function () {
		var cb106 = $(this);

		//Copy text from left column into other columns
		cb106.find('.cb106w2title', this).each(function (i) {
			var data = $(this).text();
			cb106.find('.cb106w4', this).each(function (v) {
				$(this).find('ul').eq(i).before("<span class='cb106w2title'>" + data + "</span>");
			});
		});

		//V0
		if ($(this).is('.cb106v0')) {
			//Copy heading from left column into other columns
			cb106.find('.cb106cat li', this).each(function (i) {
				var data = $(this).text();
				cb106.find('.cb106w4', this).each(function (v) {
					$(this).find('li').eq(i).prepend("<span class='cb106t2'>" + data + "</span>");
				});
			});
		}

		//V1
		if ($(this).is('.cb106v1')) {
			// Copy checks from columns and apply icon to mobile titles
			cb106.find('.cb106w4', this).each(function (i) {
				cb106.find('.cb106w4 .cb106w2title', this).each(function (v) {
					var cb106w2t = $(this);
					var cb106w2l = cb106w2t.next();
					if (cb106w2l.find('.icn-img').length) {
						cb106w2t.addClass('beforegreen icn-checkmark');
					}
				});
			});
		}

		cb106.find('.cb106w1', this).each(function () {
			// Clone btns to other sections
			cb106.find(".cb106w7 .obttns").clone().insertBefore(cb106.find(".cb106w6 .cb106features"));
			//Duplicate data columns for tablet side scrolling
			cb106.find('.cb106w2').clone().insertAfter(cb106.find('.cb106w2').addClass('cb106w2-scroll'));
		});

	});

	//Put the icon in the mobile section titles
	$('.cb106v0 .cb106w4 .cb106w2title').append("<div class='icn-img icn-plus-cs'>&nbsp;</div>");

	//Change bg color of every other title
	$('.cb106w4 .cb106w2title:even').addClass('bgvlightgrey');

	//Toggle visibiity of subsections on mobile
	$('.cb106v0 .cb106w4 .cb106w2title').click(function () {
		$(this).find('.icn-img').toggleClass('icn-min-cs icn-plus-cs');
		$(this).next('ul').slideToggle();
	});

	// Mobile sections show and hide
	$('.cb106features').on('click', function () {
		$(this).toggleClass('icn-plus-cs icn-min-cs');
		$(this).find('span').toggle();
		$(this).closest('.cb106w4').find('.cb106w9').slideToggle();
	});

	var resizeCells = true;

	function adjustCellHeights() {
		// Adjust cell size if looking at desktop
		if (window.innerWidth > 770 && resizeCells && $('.cb106').hasClass('cb106v0')) {
			$('.cb106w2, .cb106w3').wrapAll("<div class='cb106w0' />");
			$('.cb106w2-scroll').hide();

			// Move cell titles inside adjacent row below
			var titleArray = $('.cb106w2title');
			titleArray = titleArray.slice(0, $('.cb106w2').last().find('ul').length);

			//Get current heights of left cells
			var cellHeights = [];
			$('.cb106w2').last().find('ul').each(function (index) {
				$(this).prepend(titleArray[index]);
				cellHeights.push($(this).height());
				$(this).height(cellHeights[index]);
			});
			//console.log ('cellHeights',cellHeights);

			$('.cb106w2 > .cb106w2title').hide();

			$('.cb106w4').each(function () {
				$(this).find('.cb106w9 > ul').each(function (index) {
					$(this).height(cellHeights[index]);
				});
			});
			resizeCells = false;
		}
	}


	$(document).ready(function () {
		adjustCellHeights();
	});

	// Update cell height on resize
	$(function () {
		var resizeEnd;
		$(window).on('resize', function () {
			clearTimeout(resizeEnd);
			resizeEnd = setTimeout(function () {
				adjustCellHeights();
			}, 150);
		});
	});

});

/*! CB107 */
OCOM.register(function cb107($) {
	'use strict';

// if(!$('.cb107')[0]) { return false; }

	// $('.cb107w3 .col4.col-framework .col-item').each(function(){
	// 	$('.col-item-w4').equalHeight();
	// });
function applyEqualHeight() {
	
	$('.cb107w3 .col-w1 .cb107title').equalHeight(true);
	$('.cb107w3 .col-w1 .cb107price').equalHeight(true);
	$('.cb107w3 .col-w1 .cb107user').equalHeight(true);
	$('.cb107w3 .col-w1 .cb107text').equalHeight(true);
}

$('.cb107w3 .col-framework').on('inview', applyEqualHeight);

// $('.cb107w3 .col-framework').on('inview', function(){
// 	applyEqualHeight();
// });	

$(window).on('resize', applyEqualHeight);

});

/*! CB114 */
OCOM.register(function cb114($) {
    if ($('.cb114')[0]) {
        if ($('html').hasClass('touch')) {

            var $clickableItem = $('.col-item a');
            $('.col-item a')
                .bind('touchstart', function (e) {
                    touchStartPos = $(window).scrollTop();
                })
                .bind('touchend', function (e) {
                    var distance = touchStartPos - $(window).scrollTop();
                    if (!(distance > 50 || distance < -50)) {
                        //tap
                        if ($(this).hasClass('active')) {
                            e.preventDefault();
                            window.location.href = $(this)[0].href;
                        } else {
                            $('.cb114inner').each(function () {
                                $(this).removeClass('active', 'touched', 'hideOverlay');
                            });
                            $(this).addClass('active');
                            e.preventDefault();
                        }
                    } else {
                        $(this).addClass('hideOverlay');
                    }
                });

            $($clickableItem).on('click', function (e) {
                if ($(this).hasClass("touched")) {
                    $(this).removeClass("touched");
                }
            });

            $($clickableItem).hover(function (e) {
                $('.cb114inner').each(function () {
                    $(this).removeClass('active', 'touched');
                });
                $(this).addClass('active');
            });

            $('.cb114').click(function (evt) {
                if (!$(evt.target).is('.col-item a')) {
                    $('.cb114inner').each(function () {
                        $(this).removeClass('active', 'touched');
                    });
                }
            });

        }
    }

});

/*! CB117 */
OCOM.register(function cb117($) {
	'use strict';

	$('.cb117').each(init);

	
	function init() {
		var $context = $(this);
		// remove overlay class
		if ($context.hasClass("bkg-overlay")) {
			$context.removeClass("bkg-overlay");
		}
		// remove category background
		$context.find(".cb117category.bgdarkblue").removeClass("bgdarkblue");	
	}
});


/**
 * @file cb118 Large Photo Gallery Component
 * @author David Correa <david.correa@oracle.com>
 */


jQuery(document).ready(function ($) {

	if ($('.cb118')[0]) {

		var cb118slider = $('.cb118w1');
		var sliderImages = [];
		var currentSlickSlide = 0;
		var touchmoved;


		$('.cb118w2 img').wrap('<div class="cb118imgwrapmove"/>').wrap('<div class="cb118imgwrapinner"/>');
		$('.cb118w2').wrapInner($("<div class='cb118w2inner'></span>"));
		$('.cb118w4').wrap('<div class="cb118w4wrap"/>');

		$('.cb118').each(function () {
			$(this).find('.cb118w2 img').each(function () {
				var imgpath = $(this).attr('data-bgimg');
				sliderImages.push(imgpath);
			});
		});

		/**
		 * Before the carousel is instantiated, generate info box and 1/3 blue overlay on the screen with the background of the second slide.
		 */

		cb118slider.on('init', function (event, slick) {
			currentSlickSlide = slick.currentSlide;
			cb118slider.append(generateInfoPanel(1, slick.slideCount));

			var nextImage = $('[data-slick-index=1] img');
			var nextImageSrc = nextImage[0].dataset.bgimg;
			$('.thumbs-list').hide();
			$('.slide-preview').css('background-image', 'url(' + nextImageSrc + ')');
			draw9Up();
		});

		/**
		 * Slick carousel initialization
		 */
		cb118slider.slick({
			nextArrow: $('.next'),
			prevArrow: $('.previous'),
			verticalSwiping: false,
			dots: false,
			arrows: true,
			infinite: true,
			autoplay: false,
			centerMode: false,
			focusOnChange: true,
			pauseOnHover: false,
			//lazyLoad: 'ondemand',
			speed: 900,
			useCSS: true,
			useTransform: true,
			fade: true,
			swipe: true,
			touchMove: true,
			initialSlide: 0,
			slidesToShow: 1,
			slidesToScroll: 1
		});


		/**
		 * Click listeners for custom buttons since they're generated dyanmically and Slick can't pick them up on init
		 */
		$('.previous').click(function (ev) {
			cb118slider.slick('slickPrev');
		});

		$('.next').click(function (ev) {
			cb118slider.slick('slickNext');
		});



		/**
		 * Click listener to the "6-up" icon, which displays thumbnails
		 */
		$(document).on('click touchend', '.cb118moreimages, .cb118moreimages-mobile', function (ev, sliderImages) {
			$('.cb118').addClass('showThumbs');
			$('.cb118moreimages').hide();
			$('.cb118w1').hide();
			$('.thumbs-list').css('display', 'flex');
			populateThumbList(this.sliderImages,showCloseButton());
			ev.stopImmediatePropagation();
		});



		/**
		 * Click listener for the close icon when displaying thumbnail view
		 */
		$(document).on('click touchend', '#close-thumb-list', function (e) {
			e.stopImmediatePropagation();
			if(e.type == 'touchend'){
				$(this).off('click');
			}
			$('.cb118w1').show();
			$('.cb118').removeClass('showThumbs');
			$('.cb118moreimages').fadeIn(450);
			//$('.thumbs-list').fadeOut(800);
			e.preventDefault();
			
			cb118slider.slick('reinit');
			$('.thumbs-list').hide();
			
		});



		/** 
		 * Click listener for thumnails. Adds an active class around the active thumbnail and slides the carousel to the active slide based on the 'data-last-value' attribute on the image
		 */
		$(document).on('click touchend', '.thumbs-wrapper img', function (e) {
			if(e.type == 'touchend'){
				$(this).off('click');
			}
			if(touchmoved != true){
				$(cb118slider).slick("slickGoTo", $(this).data('lastValue'));
				$('#close-thumb-list').fadeOut(150);
				$('.thumbs-wrapper div').removeClass('active');
				$(this).parent().addClass('active');
			}
		}).on('touchmove', function(e){
			touchmoved = true;
		}).on('touchstart', function(){
			touchmoved = false;
		});


		/**
		 * Before the slide transition, update the info panel data (description and slide index), add 'slide-left' class to assist with parallax effect
		 */
		cb118slider.on('beforeChange', function (event, slick, currentSlide, nextSlide) {
			currentSlickSlide = nextSlide;

			//Get slider position of the next + 1 slide (thirdSlide)
			var thirdSlide = 0;
			if (nextSlide <= (slick.slideCount - 2)) {
				thirdSlide = nextSlide + 1;
			} else {
				thirdSlide = 0;
			}

			// Determine if the carousel is moving to the left or to the right
			if (Math.abs(nextSlide - currentSlide) == 1) {
				direction = (nextSlide - currentSlide > 0) ? "right" : "left";
			} else {
				direction = (nextSlide - currentSlide > 0) ? "left" : "right";
			}

			updateInfoPanel(currentSlickSlide, slick.slideCount);

			//Add helper classes for parallax effect
			var decl = currentSlide - nextSlide;
			$('.cb118').removeClass('cb118loaded');
			$('.slick-active').addClass('cb118active');

			if (decl === 1 || decl === (slick.slideCount - 1) * (-1)) {
				cb118slider.addClass('cb118-prev');
			} else {
				cb118slider.addClass('cb118-next');
			}

			/**
			 * Establish a delay to remove the classes after the transition is over, and populate the background images for the blue segment
			 * When the carousel is moving, we create a number of duplicate slides to simulate the animation, while the actual carousel does its job in the background.
			 * 
			 * @var .slide-dup-moving : Contains the 'next' slide to the right, initially placed on the 1/3 blue segment, and moving into view and becoming the active slide
			 * @var .slide-preview :  Helper element. Also contains the 'next' slide to the right, also initially placed on the 1/3 blue segment, but stays in place while .slide-dup-moving shifts position. 
			 * Allows us to always have a deck of slides on the blue segment, instead of a blue gap during the transition.
			 * @var .overlay-1-3 : A simple blue overlay extending 1/3 of the screen. Helps produce the effect of the 'old' slide being placed on top of the deck on the blue side
			 */

			var nextImage = $('[data-slick-index=' + thirdSlide + '] img');
			var nextImageSrc = nextImage[0].dataset.bgimg;

			if (direction == "left") {
				
				$('.slide-dup-moving').html('<div class="cb118imgwrapinner"><img src="' + nextImageSrc + '" alt="placeholder"></div>').show();
				$('.slide-dup-moving').hide();
				setTimeout(function () {
					setTimeout(function () {
						$('.slide-preview').removeClass('slide-left');
						$('.slide-dup-moving').show();
					}, 500);
					$('.slide-preview').css('background-image', 'url(' + nextImageSrc + ')');
				}, 400);
			} else if (direction == "right") {
				
				//Preventing FF Flash
				$('.slide-dup-moving').html('<div class="cb118imgwrapinner"><img src="' + nextImageSrc + '" alt="placeholder"></div>').show();
				$('.slide-preview').addClass('slide-left');
				setTimeout(function () {
					$('.slide-preview').css('background-image', 'url(' + nextImageSrc + ')');
					$('.slide-preview').removeClass('slide-left');
				}, 900);
			}
		});

		/**
		 * After the slide transition, reset css classes to get ready for another parallax effect on the next slide
		 */
		cb118slider.on('afterChange', function (event, slick, currentSlide, nextSlide) {
			$('.cb118w1').show();
			$('.cb118moreimages').show();
			$('.thumbs-list').hide();
			cb118slider.removeClass('cb118-prev cb118-next');
			$('.slick-slide').removeClass('cb118active');
		});
	}

	/**
	 * Generates the slide duplicates so the current slide appears 'sticky' during transition. Adds the 1/3 right blue overlay preview for the next slide, adds the 6-up icon for thumbnails, and the custom carousel arrows
	 * @param {int} currentSlide - The current 0-based slide index
	 * @param {int} slideCount - The total 0-based slide count for the carousel
	 * @return {string} html - Retuns the html object to be injected on the page
	 */
	function generateInfoPanel(currentSlide, slideCount) {
		var descr = $('.slick-current .slide-desc').html();
		var thumbsList = '<div class="thumbs-list bg-neutral-150"></div>';
		$('.cb118w2outer').append(thumbsList);
		var html = '<div class="slide-preview"></div><canvas id="cb118moreimages" class="cb118moreimages" width="50" height="50"></canvas><div class="cb118infopanel"><div class="pagination"><span class="active">' + currentSlide + '</span> / ' + slideCount + '</div><div class="descr">' + descr + '</div><div class="slick-nav cb118nav"><div class="icn-img icn-cv-left fill-white bg-neutral-150 previous">&nbsp;</div><div class="icn-img icn-cv-right fill-white bg-neutral-150 next">&nbsp;</div></div><canvas id="cb118moreimages-mobile" class="cb118moreimages-mobile" width="50" height="50"></canvas>';
		return html;
	}


	/**
	 * Update pagination, description and arrow state
	 * @param {int} currentSlide - The current 0-based slide index
	 * @param {int} slideCount - The total 0-based slide count for the carousel 
	 */
	function updateInfoPanel(currentSlide, slideCount) {
		$('.cb118infopanel .pagination').html('<span class="active">'+(currentSlide + 1) + '</span> / ' + slideCount);
		var nextSlide = $('.slick-slide[data-slick-index="' + currentSlide + '"]');

		$('.cb118infopanel .descr').html(nextSlide[0].firstChild.children[1].innerHTML).scrollTop(0);
	}


	/**
	 * Generates the HTML for the 9-up thumbnail list beased on the slide images on the carousel.
	 */
	function populateThumbList() {
		var slidesHtml = '';
		var colCount = '';
		var colClass = 'col-multi';

		if (sliderImages.length == 9) {
			colCount = 'col3';
			colClass = 'col-altbreak cb118-9up';
		} else if (sliderImages.length > 6) {
			colCount = 'col4 col-altbreak-4';
		} else if ((sliderImages.length >= 3) && (sliderImages.length <= 6)) {
			colCount = 'col3';
			colClass = 'col-altbreak';
		} else {
			colCount = 'col2';
		}

		$(sliderImages).each(function (index) {
			slidesHtml = slidesHtml + '<div class="col-item"><div><img src="' + this + '" data-last-value="' + index + '"/></div></div>';
		});

		var html = '<div class="thumbs-wrapper thumbs-' + colCount + '"><div id="close-thumb-list" class="icn-img icn-close close-thumbs">&nbsp;</div><div class="col-framework cb118thumbmargins ' + colCount + ' '+ colClass + ' col-gutters inview"><div class="col-w1 col-noanimation">' + slidesHtml + '</div></div>';
		$('.thumbs-list').html(html);
		var currentSlide = $('.thumbs-list img')[currentSlickSlide];
		$(currentSlide).parent().addClass('active');
		return html;
	}

	/**
	 * Displays the close button after the thumbnail list is showing after a slight delay to avoid iPad touch issues.
	 * 
	 */

	function showCloseButton(){
		var resizeTimer;
		resizeTimer = setTimeout(function() {
			$('.close-thumbs').fadeIn('fast');
			clearTimeout(resizeTimer);
		}, 600); 
	}

	/**
	 * Draws the '9-up' icons for desktop and tablet views on a canvas. Switches to thumbnail view.
	 */
	function draw9Up() {
		var cx = {
			desktop: {
				'id': 'cb118moreimages',
				'color': '#3F3A36'
			},
			mobile: {
				'id': 'cb118moreimages-mobile',
				'color': '#3F3A36'
			}
		};

		// Loop through the cx object, which contains the id and color values. Sets up the canvas for drawing and then calls the drawSquares function
		for (var prop in cx) {
			cx[prop].context = document.getElementById(cx[prop].id);
			if (cx[prop].context.getContext) {
				cx[prop].contextSpace = cx[prop].context.getContext('2d');
				cx[prop].contextSpace.fillStyle = cx[prop].color;
				drawSquares(cx[prop].contextSpace);
			}
		}

		// Creates a set of 9 squares (10px by 10px), with a 20px separation from each other's origin like: context.fillRect(0, 0, 10, 10);
		function drawSquares(context) {
			for (i = 0; i <= 2; i++) {
				for (l = 0; l <= 2; l++) {
					context.fillRect(i*20, l*20, 10, 10);
				}
			}
		}
	}
});

/*! CB120 */
OCOM.register(function cb120($) {
	'use strict';
	$('.cb120').inView();
});


/*! CB121 */
OCOM.register(function cb121($) {
	'use strict';
	
	$('body').addClass('cb121_loaded');

	$(document).on('click','.cb121w1 li a',function(e){
		$(this).parent('li').addClass('active');
	});
	
	$(document).on('close.lightbox', function() {
		$('.cb121w1 li').removeClass('active');
	});

});


/*! CB123 */
OCOM.register(function cb123($) {
	'use strict';
	
	//if(!$('.cb123')[0]){ return false; }

	//$('.cb123').each(function(){

	//});
	


});


/**
 * @file cb124 Employee Profile Video Tiles
 * @author David Correa <david.correa@oracle.com>
 */


OCOM.register(function cb124($) {
	$('.cb124').on({
		touchstart: function() { $(this).addClass('cb124touched');},
	   });

	/* $('.cb124tile').each(function () {
		if ($(this).attr('data-quote')) {
			$(this).find('.cb124desc').prepend('<div class="icn-img icn-large-quote">&nbsp;</div>');
		}
	});	*/

	$('.cb124').each(function (index) {
		var that = $(this);


		/* replace icons with new redwood light pill icons */
		that.find(".cb124tile.icn-vidplay").removeClass("icn-vidplay").addClass("icn-play-bttn");

		   
		var timer = setInterval(function() { 
			var $imgsLoaded = $(that).find('img.lazyloaded'),
			$imgs = $(that).find('img');
			if ($imgs.length == $imgsLoaded.length) {
				var adjustTileHeight = function(isCarousel) {
					var heightInfo = [];
					//Get height of every active tile (in view) if this is a the carousel version.
					if (isCarousel){
						$(that).find('.col-item.slick-active .cb124tileheader').each(function (index) {
							heightInfo.push($(this).height());
						});	
					}

					//Get all heights if this is a the non-carousel version.
					else {
						$(that).find('.col-item .cb124tileheader').each(function (index) {
							heightInfo.push($(this).height());
						});		
					}

					//Sort heights, get largest one.
					heightInfo.sort(function(a, b){return a-b;});

					//If there's a difference in height, calculate it and add the offset to the overlay positioning.
					if ( heightInfo[0] !== heightInfo[heightInfo.length] ) {
						//Get largest tile height and account for padding (remove units).
						var tilePadding = $(that).find('.cb124w3').css('padding-top').replace("px", "");
						var titleHeaderHeight = heightInfo[heightInfo.length-1]+tilePadding*2;
						var tileTotalHeight = $(that).find('.cb124w2').height();
						var tileHeaderOffset = (titleHeaderHeight*100)/tileTotalHeight;						
						$(that).find('.cb124w3').css('top',100-tileHeaderOffset+'%');
						//$(that).find('.cb124desc').css('margin-bottom',tileHeaderOffset/2+'%');
					}
				};				

				if ( $(that).find('.cb124w1 > div').hasClass('o-crsl')) {
					// Adjust overlay height on Slick position change (slide change/window resize).
					$(that).find('.o-crsl').on('setPosition', function(){
						adjustTileHeight(true);
					});
				}

				else {
					adjustTileHeight();
					var resizeTimer;
					$(window).on('resize', function(e) {
						clearTimeout(resizeTimer);
						resizeTimer = setTimeout(function() {
							adjustTileHeight();
						}, 300);
					});
				}

				// Clear interval once all images are loaded.
				clearInterval(timer);
			}
		}, 50);
	});		
});

/*! CB126 */
(function($) {
	var component,
		// VARIABLES
		_component = '.cb126',
		_elementLimits = {
			'tablet': 6,
			'mobile': 4
		},
		// METHODS
		_getBreakpoint = function () {
			return window.getComputedStyle(document.querySelector(_component), ':before').getPropertyValue('content').replace(/\"/g, '');
		},
		_initialize = function () {
			$(_component).each ( function (i, cb) {
				var hideTxt = $(cb).attr('data-hidetxt'),
					showTxt = $(cb).attr('data-showtxt');

				$(cb).find('.cb126w3').on('mouseenter', function (e) {
					$(e.currentTarget).siblings('.cb126active').removeClass('cb126active');
					$(e.currentTarget).addClass('cb126active');
				});
				$(cb).find('.cb126w3').on('mouseleave', function (e) {
					$(e.currentTarget).removeClass('cb126active');
				});
				_injectButton(cb);
				$(cb).find('.cb126w8, .cb126w7 > span').on('click', function (e) {
					if ($(e.currentTarget).closest('.cb126w1').hasClass('cb126truncate-show')) {
						$(e.currentTarget).closest('.cb126w1').removeClass('cb126truncate-show');
						$(e.currentTarget).closest('.cb126w1').find('.cb126w7 > span').text(showTxt);
						$(e.currentTarget).closest('.cb126w1').find('.cb126w8 > div').removeClass('icn-min-cf');
						$(e.currentTarget).closest('.cb126w1').find('.cb126w8 > div').addClass('icn-plus-cf');
					} else {
						$(e.currentTarget).closest('.cb126w1').addClass('cb126truncate-show');
						$(e.currentTarget).closest('.cb126w1').find('.cb126w7 > span').text(hideTxt);
						$(e.currentTarget).closest('.cb126w1').find('.cb126w8 > div').removeClass('icn-plus-cf');
						$(e.currentTarget).closest('.cb126w1').find('.cb126w8 > div').addClass('icn-min-cf');

					}
				});
				_truncate(cb);
				// listen for cn25
				$(window).on('filterComplete', function () {
					//console.log('on filterComplete')
					_truncate(cb);
				});
				$(window).off('resize.cb126').on('resize.cb126', function () {
					_truncate(cb);
				});
				// check for cn25
				//console.log('cn25ActivateFilter')
				$(window).trigger('cn25ActivateFilter');

			});
		},
		_injectButton = function (context) {
			var showTxt = $(context).attr('data-showtxt'),
				btn = $('<div class="cb126w7"><span>' + showTxt + '</span><div class="cb126w8"><div class="icn-img icn-circle fill-orange icn-plus-cf">&nbsp;</div></div></div>');
			$(context).find('.cb126w1').append(btn);
		},
		_truncate = function (context) {
			$(context).find('.cb126w1').each( function (j, w1) {
				var visItems = 0,
					breakpoint = _getBreakpoint(),
					limit = breakpoint == 'desktop' ? 99999 : _elementLimits[breakpoint],
					items,
					itemsCount;
				
				//reset
				$(w1).removeClass('cb126truncate');
				$(w1).find('.cb126hidden').removeClass('cb126hidden');
				items = $(w1).find('.col-item:visible');
				itemsCount = items.length;

				//truncate items beyond limit
				if (breakpoint !== 'desktop' && itemsCount > limit) {
					$(w1).addClass('cb126truncate');

					for (var j = limit; j <= itemsCount; j++) {
						$(items[j]).addClass('cb126hidden');
					}
				}	
			});
		};
	component = function cb126($) {
		_initialize();
	};
	OCOM.register(component);
})(jQuery);

/*! CB129 */

OCOM.register(function cb129($) {
	'use strict';

	$('.cb129').each(function() {

		var $cb129 = $(this),
				CLS_OPEN = 'cb129open',
				CLS_PLUS = 'icn-plus',
				CLS_MIN = 'icn-min',
				CLS_PLUSMIN = [CLS_PLUS, CLS_MIN].join(' '),
				DATA_TOGGLE = 'toggleTimeout',
				ctrItems = '.cb129w3',
				listItems = '.cb129w4',
				openItems = '.' + CLS_OPEN,
				icon = '.cb129icn',
				toggleAll = '.cb129toggle-all';

		$cb129
			.find(ctrItems).append(function() {
				var $w4 = $(this).closest(ctrItems).next(listItems);
				return $w4.length &&
								// icn-plus/min for expanding content (has .cb129w4)
								'<div class="cb129icn ' + ($w4.hasClass(CLS_OPEN) ? CLS_MIN : CLS_PLUS) + '"></div>' ||
								// icn-arrow for links only
								'<div class="cb129icn icn-arrow"></div>';
			}).end()
			.find(listItems).prepareHeightTransition();

		$cb129
			.on('click', ctrItems, function() {

				return $(this)
					.find('.icn-plus, .icn-min').toggleClass(CLS_PLUSMIN).end()
					.next(listItems).toggleClass(CLS_OPEN) &&
					// if all open, toggle closeAll
					$cb129.find(openItems).length === $cb129.find(listItems).length &&
					$cb129.find(toggleAll).removeClass(CLS_PLUS).addClass(CLS_MIN) ||
					$cb129.find(toggleAll).removeClass(CLS_MIN).addClass(CLS_PLUS);

			})
			.on('click', toggleAll, function(e) {

				var $a = $(this),
						$w4 = $cb129.find(listItems),
						d = 0;

				e.preventDefault();

				return $a.toggleClass(CLS_PLUSMIN) &&
								$w4.each(function(i) {

									var $el = $(this),
											$w3 = $el.prev(ctrItems);

									$el.data(DATA_TOGGLE, setTimeout(function() {
										clearTimeout($el.data(DATA_TOGGLE));
										$el.removeData(DATA_TOGGLE);
										return $a.hasClass(CLS_MIN) &&
														$el.addClass(CLS_OPEN) &&
														$w3.children(icon).removeClass(CLS_PLUS).addClass(CLS_MIN) ||
														$w4.removeClass(CLS_OPEN) &&
														$w3.children(icon).removeClass(CLS_MIN).addClass(CLS_PLUS);
									}, d));

									d += 120 - i * 10;
								});

			});
	});
});


/*! CB137 */

OCOM.register(function cb137($) {
	'use strict';

	$('.cb137.cb137v0').each(function(i, cb) {

		$(cb).find('.col-item').on('mouseenter', function (e) {
			if ($(e.currentTarget).closest('.no-touch')[0]) {
				$(e.currentTarget).addClass('cb137on');
			}
		});
		$(cb).find('.col-item').on('mouseleave', function (e) {
			if ($(e.currentTarget).closest('.no-touch')[0]) {
				$(e.currentTarget).removeClass('cb137on');
			}
		});
		$(cb).find('.col-item').on('click', function (e) {
			if (!$(e.currentTarget).closest('.no-touch')[0]) {
				if ($(e.currentTarget).hasClass('cb137on')) {
					$(e.currentTarget).removeClass('cb137on');
				} else {
					$(e.currentTarget).siblings('.cb137on').removeClass('cb137on');
					$(e.currentTarget).addClass('cb137on');
				}
			}
		});
	});
});

/*! CB140 */
OCOM.register(function cb140($) {
	'use strict';

	$('.cb140[data-feedsrc]').each(hbsCheck);

	/* globals propertyExists, objLoaded */
	function hbsCheck() {
		return (
			objLoaded('HBSINJECT', 'initialize') &&
			propertyExists(this, 'data-feedsrc') &&
			propertyExists(this, 'data-template') &&
			init.call(this) ||
			setTimeout(hbsCheck.bind(this), 10)
		);
	}

	function init() {

		var $cb140 = $(this),
				$cb140w2 = $cb140.find('.ofeed'),
				feedsrc = $cb140.attr('data-feedsrc'),
				template = $cb140.attr('data-template');

		window.HBSINJECT.initialize({
			feedsrc: feedsrc,
			targetObj: $cb140w2,
			templateName: template,
			beforeInjectionCallback: prepJSON,
			afterInjectionCallback: $cb140w2.addClass.bind($cb140w2, 'hbs-initialized')
		});

		return this;
	}

	function prepJSON(json) {
		return (
			'object' === typeof json &&
			'contents' in json &&
			'records' in json.contents[0] &&
			json.contents[0].records.length &&
			{ records: json.contents[0].records.map(mapRecord) }
		);
	}

	function mapRecord(record) {
		return (
			'object' === typeof record &&
			'attributes' in record &&
			{
				date: record.attributes.DisplayDate,
				title: record.attributes.Title,
				description: record.attributes.Description,
				url: record.attributes.DisplayURL
			}
		);
	}
});


/*! CB149 */

// Search Form Interaction
$(".cb149searchform").each( function (i, w1) {
	var cb149form = $(w1),
			searchField = cb149form.find("#cb149txtSearch").get(0);
	
	if ($(searchField).val()) {
		$(".cb149w5").show();
	}
	else {
		$(".cb149w5").hide();
	}

	cb149form.find(".cb149input input").on("focus", function (e) {
		$(e.currentTarget).css({color: "#252525"});
		if ( $(e.currentTarget).attr('placeholder') ){
			$(e.currentTarget).data('placeholder', $(e.currentTarget).attr('placeholder')).removeAttr('placeholder');
		}
		if ($(e.currentTarget).val()) {
			$(e.currentTarget).closest(".cb149searchform").find(".cb149w5").fadeIn(200);
		}
	});

	cb149form.find("input[type='text']").on("input", function (e) {
		if ($(e.currentTarget).val()) {
			$(e.currentTarget).closest(".cb149searchform").find(".cb149w5").fadeIn(200);
		} else {
			$(e.currentTarget).closest(".cb149searchform").find(".cb149w5").fadeOut(200);
		}
	});

	cb149form.find("input[type='reset']").on("click", function (e) {
		e.stopImmediatePropagation();
		//window.searchMetric = "Remove: " + $(searchField).attr('value');
		//window.searchWord = '';
		$(searchField).attr('value','');
		$(e.currentTarget).closest(".cb149w5").fadeOut(100);
		cb149form.attr('data-resetting',1);
		//setTimeout(function(){ // have to delay submit to prevent cleared value from being passed
		//	cb149form.submit();
		//}, 10);
	});

});


// Auto Complete
var appendtarget = $('div.cb149w3');
var cpath = (appendtarget.find('[data-contentpaths]')[0]) ? appendtarget.find('[data-contentpaths]').attr('data-contentpaths') : '/content/Web/Shared/Auto-Suggest Panel';
appendtarget.addClass('autocompleteparent');

/* globals autocompleteVals */
$(".cb149searchform:not(.noautosuggest) input#cb149txtSearch").awesomplete({
	appendTo: appendtarget,
	source: function( request, response ) {
		var regexp = new RegExp(request.term.replace(/[-[\]{}()*+?.,\\/^$|#\s]/g, '\\$&')),
					adds = autocompleteVals ? autocompleteVals.reduce(function(arr,term) {
						if(regexp.test(term)) {
							arr.push({
								label: term
							});
						}
						return arr;
					},[]) : [];
		$.ajax({
			url: '/search/autosuggest.json/browse',
			dataType: "json",
			data: {
				Dy: 1,
				contentPaths: cpath,
				templateTypes: "AutoSuggestPanel",
				Ntt: request.term+"*"
			},
			success: function( data ) {
				var dsv = [];
				if(data.contents[0].autoSuggest[0].totalNumResults > 0){
					dsv = $.map( data.contents[0].autoSuggest[0].dimensionSearchGroups[0].dimensionSearchValues, function(item) {
						return{
							label : item.label
						}
					});
				}
				response(adds.concat(dsv));
			},
			error: function(){
				return null;
			}
		});
	},
	minLength: 3,
	autoFocus: false,
	select: function(event, ui) {
		$(".ui-autocomplete").hide();
		$("input#cb149txtSearch").val(ui.item.value);
		$("input#cb149txtSearch").closest('form.cb149searchform').submit();
	},
	open: function(event, ui) {
		$('.ui-autocomplete').off('menufocus hover mouseover mouseenter');
	}
});



/*! CB152 */

OCOM.register(function cb152($) {
	'use strict';
	var data = {},
		jsonURL = 'https://itra.oraclecloud.com/itas/.anon/myservices/api/v1/products?parentProductPartNumber=B88206',
		limit = 200,
		offset = 0,
		suffix = ['CZK','HUF','PLN','RON','SEK'];
	function clearPrices(context) {
		//$(context).find("[data-model]").text('').removeClass("cb152preinjection");
		$(context).find("[data-model]").text('');
	}
	function disableCurrencyMenu(context) {
		$(context).attr("disabled", "disabled");
	}
	function enableCurrencyMenu(context) {
		$(context).removeAttr("disabled");
	}
	function getData(context, limit, offset, currency, feedURL) {
		if (data.hasOwnProperty(currency) && Object.keys(data[currency]).length > 0 && offset == 0) {
			// don't make request if currency object already exists and the offset is zero
			injectPrices(context, currency);
		} else {
			jQuery.when(
				loadJSON(currency, limit, offset, feedURL)
			).done(
				function (d) {
					var items,
						length,
						partsAr,
						partsArLen,
						trailingZero;
					if (typeof d == 'object' && d.hasOwnProperty('items') && d.hasOwnProperty('hasMore')) {
						// build pricing object
						length = d.items.length;
						if (!data.hasOwnProperty(currency)) {
							data[currency] = {};
						}
						for (var i = 0; i < length; i++) {
							data[currency][d.items[i].partNumber] = {
								prices: d.items[i].prices
							}
						}
						if ($(context).find(".cb152currencies > option:selected").attr('data-symbol')) {
							if (suffix.indexOf(currency) >= 0) {
								data[currency]['suffix'] = true;
							}
							data[currency]['currencySymbol'] = $(context).find(".cb152currencies > option:selected").attr('data-symbol');
						} else {
							data[currency]['currencySymbol'] = '';
							console.log('Warning: currency symbol not provided for ' + currency)
						}
						
						// continue to send requests until hasMore is false
						if (d.hasMore == true) {
							getData(context, limit, offset + limit, currency)
						} else {
							injectPrices(context, currency);
							//console.log(data)
						}
					} else if (typeof d == 'object' && Object.keys(d).length) {
						if (!data.hasOwnProperty(currency)) {
							data[currency] = {};
							partsAr = Object.keys(d);
							partsArLen = Object.keys(d).length;
							for (var i = 0; i < partsArLen; i++) {
								console.log(d[partsAr[i]][currency].match(/\.[\d]{1}$/))
								if (d[partsAr[i]][currency].match(/\.[\d]{1}$/)) {
									trailingZero = '0';
								} else {
									trailingZero = '';
								}
								data[currency][partsAr[i]] = {
									prices: [
										{model:'default',value: d[partsAr[i]][currency] + trailingZero}
									]
								}
							}
							if ($(context).find(".cb152currencies > option:selected").attr('data-symbol')) {
								if (suffix.indexOf(currency) >= 0) {
									data[currency]['suffix'] = true;
								}
								data[currency]['currencySymbol'] = $(context).find(".cb152currencies > option:selected").attr('data-symbol');
							} else {
								data[currency]['currencySymbol'] = '';
								console.log('Warning: currency symbol not provided for ' + currency)
							}
							injectPrices(context, currency);
							//console.log(data)
						}
						

					} else {
						console.log('Error: server replied with no data.')
					}
				}
			);
		}
	}
	function init() {
		var $cb152 = $(this),
			feedURL = $(this).attr("data-feedsrc");
		disableCurrencyMenu($cb152.find(".cb152currencies"));
		clearPrices($cb152);
		$cb152.addClass("cb152loading");
		getData($cb152, limit, offset, $cb152.find(".cb152currencies").val(),feedURL);

		$cb152.find(".cb152currencies").on("change", function (e) {
			feedURL = $(e.currentTarget).closest(".cb152").attr("data-feedsrc");
			disableCurrencyMenu($(e.currentTarget));
			clearPrices($cb152);
			$cb152.addClass("cb152loading");
			getData($cb152,limit, offset, $(e.currentTarget).val(),feedURL);
		});
	}
	function injectPrices(context, currency) {
		var partNumber,
			model,
			priceLength,
			p1,p2;
		$(context).removeClass("cb152loading");
		//$(context).find("[data-model]").css({opacity:0})
		$(context).find("[data-model]").addClass("cb152preinjection");
		$(context).find("[data-partnumber]").each( function (i, item) {
			partNumber = $(item).attr('data-partnumber');

			if ($(item).attr('data-model')) {
				model = $(item).attr('data-model');
				data[currency][partNumber].prices.forEach( function (price) {
					if (price.hasOwnProperty("model") && price.model.toLowerCase() == model.toLowerCase()) {
						if(data[currency].hasOwnProperty('suffix')) {
							$(item).text(price.value + ' ' + data[currency].currencySymbol);
						} else {
							$(item).text(data[currency].currencySymbol + ' ' + price.value);
						}
						//$(item).animate({opacity:1},250, function (){$(item).removeAttr("style")});
						setTimeout(function(){$(item).removeClass("cb152preinjection")},5);
						return;
					}
				});
			} else if ($(item).find("[data-model]")[0]) {
				$(item).find("[data-model]").each( function (j, child) {
					model = $(child).attr('data-model');
					data[currency][partNumber].prices.forEach( function (price) {
						if (price.hasOwnProperty("model") && price.model.toLowerCase() == model.toLowerCase()) {
							if(data[currency].hasOwnProperty('suffix')) {
								$(child).text(price.value + ' ' + data[currency].currencySymbol);
							} else {
								$(child).text(data[currency].currencySymbol + ' ' + price.value);
							}
							//$(child).animate({opacity:1},250, function (){$(item).removeAttr("style")});
							//$(child).removeClass("cb152preinjection");
							setTimeout(function(){$(child).removeClass("cb152preinjection")},5);
							return;
						}
					});
				});
			}
		});
		enableCurrencyMenu($(context).find(".cb152currencies"));
	}
	function loadJSON(currency, limit, offset, feedURL) {
		var currencyCode = currency ? currency : 'USD',
			url = feedURL ? feedURL : jsonURL;
		if (url.indexOf("?") >= 0) {
			if (limit) {
				url = url + '&limit=' + limit;
			}
			if (offset) {
				url = url + '&offset=' + offset;
			}
		}
		
		return jQuery.ajax({
			headers: {'X-Oracle-Accept-CurrencyCode': currencyCode},
			url: url,
			method: 'GET',
			dataType: 'json',
			crossDomain: true
		});
	}
	

	// initialize
	$('.cb152').each(init);
});


/* CG14 */
$(document).on('click', 'a.sharelink', function(e) {

	e.preventDefault();

	var shareurl = window.location.href;

	if ( $(this).is("[data-esubject]") ) {
		if ($(this).attr('data-esubject').indexOf('%PAGETITLE%') > -1) {
			var sharetitle = document.title;
			var esubject = $(this).attr('data-esubject').replace(/%PAGETITLE%/g, sharetitle);
		}else {
			var esubject = $(this).attr('data-esubject');
		}
	}

	var ebody = $(this).attr('data-ebody');
		var ptcl = window.location.protocol+'//';
		var domain = window.location.host;

		if ($(this).is("[data-url]") && $(this).attr('data-url').indexOf('/') == 0){
				shareurl = ptcl+domain+ $(this).attr('data-url');
		}else if ($(this).is("[data-url]") && $(this).attr('data-url').indexOf('http') > -1){
				shareurl = $(this).attr('data-url');
		}else if ($(this).is("[data-url]") && $(this).attr('data-url').indexOf('//') > -1){
				shareurl = ptcl+ $(this).attr('data-url');
		}else if ($(this).is("[data-url]") && $(this).attr('data-url').indexOf('/') != 0){
				shareurl = document.location.href.replace(/\/[^\/]+$/,'') +'/'+ $(this).attr('data-url');
		}else if($(this).is("[data-url]")){
				shareurl = $(this).attr('data-url');
		}

	var shareln = 22;
	shareurl = encodeURIComponent(shareurl);

	if ($(this).attr('data-sharetype') == 'facebook') {
		window.open('https://www.facebook.com/sharer/sharer.php?u='+shareurl, 'fb-share', "height=300,width=400");
	}else if ($(this).attr('data-sharetype') == 'twitter') {
		var vialn	 = ($(this).is("[data-via]")) ? $(this).attr("data-via").length + 6 : 0;
		var viavar = ($(this).is("[data-via]")) ? "&via="+$(this).attr("data-via") : '';
		var textvar = '';
		if ($(this).is("[data-text]")){
			var textln	 = ($(this).is("[data-text]")) ? $(this).attr("data-text").length + 2 : 0;
			// truncate text if url/via/text are greater than 140 characters
			if((140 - (shareln + textln + vialn)) < 0){
				textvar = '&text='+$(this).attr("data-text").slice(0,(137 - (shareln + textln + vialn))) +'%E2%80%A6 %E2%80%93';
			}else{
				textvar = '&text='+$(this).attr("data-text") + ' %E2%80%93';
			}
		}
		window.open('https://twitter.com/share?url='+shareurl+viavar+textvar, 'twitter-share', "height=550,width=420");
	}else if ($(this).attr('data-sharetype') == 'linkedin') {
		window.open('http://www.linkedin.com/shareArticle?url='+shareurl, 'linkedin-share', "height=550,width=420");
	}else if ($(this).attr('data-sharetype') == 'googleplus') {
		window.open('https://plus.google.com/share?url='+shareurl, 'googleplus-share', "height=620,width=500");
	}else if ($(this).attr('data-sharetype') == 'weibo') {
		window.open('http://service.weibo.com/share/share.php?url='+shareurl, 'weibo-share', "height=620,width=900");
	}else if (($(this).attr('data-sharetype') == 'email') && $(this).is('[data-esubject]') && $(this).is('[data-ebody]')) {
		location.assign('mailto:?subject='+esubject+'&body='+ebody+'%0A%0A'+shareurl, 'email-share');

	}else if (($(this).attr('data-sharetype') == 'email') && $(this).is('[data-ebody]')) {
		location.assign('mailto:?&body='+ebody+'%0A%0A'+shareurl, 'email-share');

	}else if (($(this).attr('data-sharetype') == 'email') && $(this).is('[data-esubject]')) {
		location.assign('mailto:?subject='+esubject+'&body='+shareurl, 'email-share');

	}else if ($(this).attr('data-sharetype') == 'email') {
		location.assign('mailto:?body='+shareurl, 'email-share');
	}

});

/* share widget */
$(document).on('click', 'a.sharewidget', function(e) {

	e.preventDefault();

	if($('.shareopen')[0]) {
		$('.shareopen').removeClass('shareopen');
		$('.sharewidgetw2').addClass('shareoc');
		setTimeout(function() {
			$('.shareoc').remove();
		},400);
	}

	var sharelink = $(this);
	var shareset = 'facebook,twitter,linkedin,googleplus,email';

	if ($(this).is('[data-share]')){
		shareset = $(this).attr('data-share').replace(/ /gi,'');
	}

	var shareurl = '';
	if ($(this).is('[data-url]')){
		shareurl = ' data-url="'+$(this).attr('data-url')+'"';
	}

	var sharecode = '';
	shareset = shareset.split(',');
	for (i = 0; i < shareset.length; ++i) {


		var esubj = '';
		if ($(this).is('[data-esubject]') && shareset[i] == 'email'){
			esubj = ' data-esubject="'+$(this).attr('data-esubject')+'"';
		}

		var ebody = '';
		if ($(this).is('[data-ebody]') && shareset[i] == 'email'){
			ebody = ' data-ebody="'+$(this).attr('data-ebody')+'"';
		}

		var viavar = ($(this).is("[data-via]") && shareset[i] == "twitter") ? ' data-via="'+$(this).attr("data-via") + '"' : '';
		var textvar = ($(this).is("[data-text]") && shareset[i] == "twitter") ? ' data-text="'+$(this).attr("data-text") + '"' : '';

		sharecode += '<a class="sharelink" data-sharetype="'+shareset[i]+'"'+shareurl+viavar+textvar+esubj+ebody+'><div class="icn-img icn-sicons icn-'+shareset[i]+'"><em>'+shareset[i]+'</em></div></a>';
	}

	if(!sharelink.next('.sharewidgetw2')[0]){

		if(!$(this).closest('.cmps-bttns')[0] && !$(this).closest('div.sharewidget')[0] && !$(this).closest('span.sharewidgetw1')[0]){
			$(this).wrapAll('<span class="sharewidgetw1"></span>');
		}

		if($(this).hasClass('rightshare')){
			$(this).closest('.cmps-share,div.sharewidget,span.sharewidgetw1').addClass('rightshare');
		}

		if($(this).hasClass('topshare')){
			$(this).closest('.cmps-share,div.sharewidget,span.sharewidgetw1').addClass('topshare');
		}

		if($(this).closest('.cmps-bttns')[0] || $(this).closest('div.sharewidget')[0] || $(this).closest('span.sharewidgetw1')[0]){
			$(this).closest('div').addClass('shareopen');
		}

		sharelink.after('<div class="sharewidgetw2 shareoc">'+sharecode+'<i></i></div>');
		setTimeout(function() {
			sharelink.next('.shareoc').removeClass('shareoc');
		},1);
	}


});

$(document).on('mousedown', function(e) {
	if(!$(e.target).closest('.sharewidgetw2')[0] && !$(e.target).closest('.sharewidget')[0]){
		if($('.shareopen')[0]) {
			$('.shareopen').removeClass('shareopen');
			$('.sharewidgetw2').addClass('shareoc');
			setTimeout(function() {
				$('.shareoc').remove();
			},400);
		}
	}
});


/* qr code pop up widget */
$(document).on('click', 'a.qrcode', function(e) {

	e.preventDefault();

	if($('.qropen')[0]) {
		$('.qropen').removeClass('qropen');
		$('.qrcodew2').addClass('qroc');
		setTimeout(function() {
			$('.qroc').remove();
		},400);
	}

	var qrlink = $(this);
	var imgpath = ($(qrlink).attr('data-qrcode'));
	var qroff = $(this).offset();

	if(!qrlink.next('.qrcodew2')[0]){

		if(!$(this).closest('.cmps-bttns')[0] && !$(this).closest('div.qrcode')[0] && !$(this).closest('span.qrcodew1')[0]){
			$(this).wrapAll('<span class="qrcodew1"></span>');
		}

		if($(this).closest('.cmps-bttns')[0] || $(this).closest('div.qrcode')[0] || $(this).closest('span.qrcodew1')[0]){
			$(this).closest('div').addClass('qropen');
		}

		qrlink.after('<div class="qrcodew2 qroc"><img class="" src="'+imgpath+'"></div>');
		setTimeout(function() {
			qrlink.next('.qroc').removeClass('qroc');
		},1);
		
		if (qroff.left < 26) {	
			qrlink.next('.qroc').css({left: 0, right: "auto"});
		}

	}
	return false;
});

$(document).on('mousedown', function(n) {
	if(!$(n.target).closest('.qrcodew2')[0] && !$(n.target).closest('.qrcode')[0]){
		if($('.qropen')[0]) {
			$('.qropen').removeClass('qropen');
			$('.qrcodew2').addClass('qroc');
			setTimeout(function() {
				$('.qroc').remove();
			},400);
		}
	}
});



/*! CG20 EXPANDO */
OCOM.register(function expando($) {
	'use strict';

	$('[data-ocomid="expando"]').each(function() {

		var $expando = $(this),
				$container = $expando.closest('.expando')[0] ?
					$expando.closest('.expando') : $expando.closest('section'),
				type = $expando.data('type') || 'block',
				moretxt = $expando.data('moretxt') || '',
				$btn = /(inline|link)/.test(type) ?
								$('<a class="expando-btn">' +
										'<span class="expando-txt">' + moretxt + '</span>' +
									'</a>') :
								$('<div class="expando-btn">' +
										'<div class="expando-btn-w1"><span class="expando-txt">' + moretxt + '</span>' +
										'<div class="icn-img icn-plus-cf"></div></div>' +
									'</div>');

		// check initialized flag to prevent button duping
		if($expando.data('initialized')) { return false; }

		// class it up if not already in markup
		$container.addClass('expando');

		$expando.prepareHeightTransition();

		$btn.addClass(type);

		if(/fixed/.test(type)) {
			$expando.before($btn);
		} else {
			$expando.after($btn);
		}

		$btn.on('click', expand.bind($expando, $btn));

		// set initialized flag to prevent button duping
		$expando.data('initialized', true);

	});

	function expand($btn) {

		var $expando = $(this),
				$txt = $btn.find('.expando-txt'),
				moretxt = $expando.data('moretxt') || '',
				closetxt = $expando.data('closetxt') || '',
				count = 0,
				interval;

		$txt.addClass('switch');

		interval = setInterval(function() {
			switch (count) {
				case 0:
						$expando.toggleClass('expanded');
						break;
				case 1:
					$txt.text($expando.hasClass('expanded') ?
						closetxt :  moretxt);
					break;
				case 2:
					$btn
						.toggleClass('expanded')
						.find('.icn-img')
						.toggleClass('icn-plus-cf')
						.toggleClass('icn-min-cf');
					break;
				case 3:
					$txt.removeClass('switch');
					break;
				default:
					count = 0;
					clearInterval(interval);
					break;
			}
			count++;
		}, 120);


	}

});


/*! CN15 */
jQuery(document).on("click","li.cn15end a,li.cn15active a",function(e) {
	e.stopImmediatePropagation();
	e.preventDefault();
	return false;
});




/*! CN21 */
OCOM.register(function cn21($) {
	'use strict';

	if ($(".cn21").length > 0) {
		$(".cn21").find('.bttn-red').removeClass('bttn-red').removeClass('obttn7').addClass('obttn2 bttn-black');
	}

	// Scroll to anchor on load
	$(window).on('load', function() {

		if ($(".cn21v0 .cn21w1 ul li").length > 0) {
			var navitem = $('.cn21v0 .cn21w1 ul li'),
					nav_totalheight = navitem.outerHeight();
			if (window.location.hash != '') {
				goToByScroll(window.location.hash.substr(1));
			}
		}

		function goToByScroll(id) {
			if ($("#" + id)[0]) {
				$('html,body').animate({
					scrollTop: $("#" + id).offset().top - nav_totalheight + 1
				}, 750);
			}
		}
	});

	// Waypoint
	if ($('.cn21')[0]) {

		// add target class for waypoints if not in markup
		$('.cn21w3 ul li a').each(function() {
			var id = $(this).attr('href').split('#')[1],
					$target = $('#' + id);
			if($target.length && !$target.hasClass('atarget')) { $target.addClass('cn21target'); }
		});

		$('.cn21w3 ul li a').on('click', function(e) {
			if (!$(e.currentTarget).closest('.cn21w4')[0]) {
				e.preventDefault();
				history.pushState({}, "", this.href);
				var navitem = $('.cn21w2'),
						nav_totalheight = navitem.outerHeight();
				if ($('#' + $(this).attr('href').split('#')[1])[0]) {
					$('html,body').animate({ scrollTop: $('#' + $(this).attr('href').split('#')[1]).offset().top - (90 - 1) }, 750, function() {}) /* note: if '90' changes, css styles must also change; -1 to trigger the sticky event on the first menu item when clicking to it from further down the page */
				}
			}
		});

		var navitem = $('.cn21w1'),
				nav_totalheight = navitem.outerHeight();

		// element to be sticky
		var $stickyEl = $(".cn21w5");

		// element that will stop the sticky element
		var $stopEl = $('#u19');

		// activate stickiness for event5
		if ($(".f11v7")[0]) {
			var cn21stick = new Waypoint.Sticky({
				element: $stickyEl[0],
				wrapper: '<div class="article-sticky-wrapper" style="height:' + nav_totalheight + 'px" />',
				stuckClass: 'sticky',
				handler: function(dir) {
					if (dir === "down") {
						$stickyEl.closest(".article-sticky-wrapper").attr("style", "height:90px");
					} else {
						$stickyEl.closest(".article-sticky-wrapper").attr("style", "height:" + nav_totalheight + "px");
					}
				}
			});

			$stopEl.waypoint({
				handler: function(direction) {
					if (direction == 'down') {
						// when scrolling down
						// replace pos:fixed with absolute and set top value to
						// the distance from $stopEl to viewport top minus the
						// height of the stickyElement
						var footerOffset = $stopEl.offset();
						$stickyEl.css({
							position: 'absolute',
							top: footerOffset.top - $stickyEl.outerHeight()
						});
					} else if (direction == 'up') {
						// remove the inline styles so sticky styles apply again
						$stickyEl.attr('style', '');
					}
				},
				// trigger the waypoint when the bottom of stickyEl touches top of stopEl
				offset: function() {
					return $stickyEl.outerHeight();
				}
			});
		}

		
		$('.atarget, .cn21target').waypoint({
			handler: function(direction) {
				var $el = getRelatedNavigation(this.element);
				$el.closest("ul").find(".cn21active").removeClass("cn21active");
				if (direction === "down") {
					$el.addClass("cn21active");
				} else {
					$el.removeClass("cn21active");
				}
			},
			offset: nav_totalheight + 5
		});

		$('.atarget, .cn21target').waypoint({
			handler: function(direction) {
				var $el = getRelatedNavigation(this.element);
				$el.closest("ul").find(".cn21active").removeClass("cn21active");
				if (direction === "down") {
					$el.removeClass("cn21active");
					$el.addClass("cn21past");
				} else {
					$el.addClass("cn21active");
					$el.removeClass("cn21past");
				}
			},
			offset: function() { return -$(this.element).height() + 123; }
		});
	}

	function getRelatedNavigation(el) {
		return $('.cn21w3 ul li a[href*="#' + $(el).attr('id') + '"]');
	}

	function getRelatedNavigationMobile(el) {
		//return $('select#cn20select').find('option[value*=' + $(el).attr('id') + ']').attr("selected",true);
	}

});


/*! CN25 */
OCOM.register(function cn25($) {

	'use strict';

	var $links = $('.cn25w3 a')
  .attr('role', 'tab');
	var $active = setActiveLink();
	var legacyComponents = ['.cb64'];

	$('.cb64').on('cb64ready', function(e) {
		showSelectedCategoryContent($active);
	});

	// ADD CLASS FOR CN25'S WITH ONLY 4 ITEMS FOR BETTER TABLET EXP
	$('.cn25').each(function(){
		var cn25 = $(this);
		if(cn25.hasClass('cn25v0') && cn25.find('a').length == 4){
			cn25.addClass('cn25has4');
		 }else if(cn25.hasClass('cn25v1') && cn25.find('a').length == 3){
		 	cn25.addClass('cn25has3');
		}
	});

	$('.cn25').on('click', 'a', onLinkClickHandler);

	$(window).on('resize', hideInactiveLinks);

	// INVOKE FILTER ON DEFAULT TAB FOR COMPONENTS OTHER THAN .CB64
	hideNonLegacyInactiveLinks($active);
	$(window).on('cn25ActivateFilter', function() {
		hideNonLegacyInactiveLinks($active);
	});

	function setActiveLink() {

		var hash = window.location.hash,
			category;

		$active = $('.cn25 a.active');

		if (!$active.length) {
			if (hash.length > 0) {
			$active = $('.cn25 a[href="' + hash + '"]').first(); // only get first if multiple matches
			if(!$active[0]) {
				// could not find a match
				$active = $links.first();
			}
			} else {
			$active = $links.first();
			}
		}

		$active
			.addClass('active')
			.addClass('icn-cv-down')
			.addClass('beforewhite')
      .attr('aria-selected', 'true');


		if(window.history.pushState) {
			window.history.pushState(null, null, $active.attr('href'));
		} else {
			window.location.hash = $active.attr('href');
		}

		hideInactiveLinks();

		return $active;
	}

	function onLinkClickHandler(e) {

	var $link = $(e.target);

	e.preventDefault();


	if (!$link.hasClass('active')) {

		$links.each(function() {
			$(this).removeClass('active icn-cv-down beforewhite').removeAttr('aria-selected');
      $(this).closest('.cn25w3').removeClass('open');
		});
		$link.addClass('active')
		setActiveLink();
		showSelectedCategoryContent($link);

	} else {
		// show/hide dropdown in mobile view
		// $links.not($link).toggleClass('hide');
		$links.closest('.cn25w3').toggleClass('open');
	}

	return false;
	}

	function isLegacy (catObj) {
	for ( var n = 0; n < legacyComponents.length; n++) {
		if ($(catObj).closest(legacyComponents[n])[0]) {
		return true;
		}
	}
	return false;
	}

	function hideInactiveLinks() {
		if (window.getComputedStyle(document.querySelector('.cn25'), ':before').getPropertyValue('content').replace(/\"/g, '') != 'mobile') {
			$('div.cn25w3.open').removeClass('open');
		}
		return false;
	}

	function hideNonLegacyInactiveLinks($active) {

		var legacy = false,
			category = $active.attr('href').replace(/#/, '');

		// IF NON-LEGACY CATEGORIES EXIST...
		$("[data-categories~=" + category + "]").each( function (i, cat) {
			if ($(cat)[0] && isLegacy(cat)) {
				legacy = true;
				return false;
			}
		});
		if (!legacy) {
			showSelectedCategoryContent($active);
		}

	}

	function showSelectedCategoryContent($link) {
		var category = $link.attr('href').replace(/#/, ''),
			toHide = [],
			toShow = [];

		$link.trigger('filterResults', [
			category,
			$link.data('viewmore'),
			$link.data('icn')
		]);


		// GLOBAL CATEGORY VISIBILITY
		$("[data-categories]").each ( function (i, cat) {
			var attr = $(cat).attr('data-categories'),
			pattern = new RegExp("(^" + category + " )|(^" + category + "$)|( " + category + " )|( " + category + "$)");

			if (!isLegacy(cat)) {
			if (category == 'all') {
				toShow.push($(cat));
			} else {
				if (pattern.test(attr)) {
				toShow.push($(cat));
				} else {
				toHide.push($(cat));
				}
			}
			$(cat).css({opacity:0}).addClass("hidden-category");
			}
		});

		for (var j = 0; j < toShow.length; j++) {
			$(toShow[j]).removeClass("hidden-category");
			$(toShow[j]).show(0);
			$(toShow[j]).animate({opacity:1},250);
		}


		$(window).trigger("filterComplete");

		return false;
	}

});


/*! CN26 */
OCOM.register(function cn26($) {
  'use strict';

	$('.cn26').each(function(){
		var component,
			_alphabet,
			_categories,
			_selectLabelDefault = 'Select...',
			_cmpClass = ".cn26",
			cn26 = $(this),
			_addArrow = function (context) {
				var arrow = $('<i class="icn-img icn-arrow-down"></i>');
				if (!$(context).find(".icn-arrow-down")[0]) {
					$(context).append(arrow.clone());
				}
			},
			_bindMenuEvents = function () {
				var target, targetOffset, ct12ht;
				cn26.find('a').each( function (i, anchor) {
					$(anchor).on("click", function (e) {
						e.preventDefault();
						target = $(e.currentTarget).attr("href");
						ct12ht = _ct12adjustment();
						if ($(target)[0]) {
							targetOffset = $(target).offset();
							$('html, body').animate({scrollTop: targetOffset.top - ct12ht}, 1000);
						}
					});
				});
				cn26.find('select').each( function (i, sel) {
					 var label = $(sel).closest('.cn26').find("[data-selectlabel]").attr("data-selectlabel");
					$(sel).on("change", function (e) {
						//newIndex = $(e.currentTarget).prop('selectedIndex');
						target = $(e.currentTarget).val();
						ct12ht = _ct12adjustment();
						if (target) {
							if ($('#' + target)[0]) {
								targetOffset = $('#' + target).offset();
								$('html, body').animate({scrollTop: targetOffset.top - ct12ht}, 1000);
							}
						}
					});
				});
			},
			_buildMobMenu = function () {
				var mobMenu = $('<div class="cn26mobile"><select></select><div class="icn-img icn-cv-down"></div></div>'),
					label, sel, nav, newOpt, href, txt;
					cn26.find('.cn26w1').append(mobMenu.clone());
					sel = cn26.find('.cn26mobile select');
					label = cn26.find("[data-selectlabel]").attr("data-selectlabel");
					nav = cn26.find('nav li');
					$(sel).append($('<option>' + label + '</option>'));
					$(nav).each( function (j, el) {
						href = $(el).find('a').attr('href');
						if ($(el).closest('.cn26col3').length !== 0 && $(el).find('a span small').length !== 0) {
							txt = $(el).find('a span').contents().not($(el).find('a span').children()).text()
						} else {
							txt = $(el).find('a').text();
						}
						if (href) {
							newOpt = $('<option value="' + href.replace(/#/,'') + '">' + txt + '</option>');
							$(sel).append(newOpt);
						}
					});
			},
			_ct12adjustment = function () {
				var ct12 = $(".ct12v0")[0];
				return ct12 && !_isMobile(".ct12") ? $(ct12).height() + 10 : 0;
			},
			_isMobile = function (contextClass) {
				var targetClass = contextClass ? contextClass : '.cn26',
					breakpoint = window.getComputedStyle($(targetClass)[0],':before').getPropertyValue('content').replace(/\"/g, '');
				if (breakpoint == "mobile") {
					return true;
				}
				return false;
			};

			// build mobile menus
			if(!cn26.find('select')[0]){
				_buildMobMenu();
				_bindMenuEvents();
			}
			
			cn26.find('nav').each( function (i, nav) {
				_addArrow($(nav).find("a .cn26w2"));
			});
		});

});


/*! CT12 */
window.ct12Interval = 0;
var ct12 = (function () {

	var component,
		_ct12width = 0,
		_context = {},
		_swap = {},
		_ct12sticky,
		/**
		 * Activates the 'more' menu and returns an array of tabs that should be 
		 * moved from the navigation menu to the 'more' menu
		 */
		_activateMenu = function (items, w2W) {
			var totalWRecheck = 0,
				pops = [],
				w3W;
			//make 'more' menu tab visible
			$(_swap).addClass("ct12menu");
			//get width of 'more' menu tab 
			w3W = $(_context).find(".ct12w3 > div").outerWidth();
			//determine if w3's visibility requires additional tabs popped
			$(items).each(function (j, addl) {
				if (!$(addl).hasClass("ct12w3")) {
					totalWRecheck = totalWRecheck + +$(addl).outerWidth();
					if ($(addl).hasClass("ct12w3")) {
						return false;
					}
					if (totalWRecheck + w3W > w2W) {
						pops.push(addl);
					}
				}
			});
			return pops; //return additional list of additional popped items
		},
		/**
		 * Wraps last word with span that has the right arrow
		 */
		_addArrows = function () {
			$(_context).find(".ct12w6").each(function (i, w6) {
				var a = $(w6).prev("a,span"),
					str = $(a).text();
					str = '<span class="ct12w5 icn-cv-down-after">' + str + '</span>';
					$(a).html(str);
				});
		},
		/**
		 * Inject markup for displaying tab states: current and rollover
		 */
		_addBars = function () {
			$(_context).find(".ct12w2 > ul > li").each(function (i, li) {
				$(li).append('<span class="ct12bar"></span>');
			});
		},
		/**
		 * Add click event handler for tabs. It should only be active for tablet/mobile.
		 */
		_addMenuClickEvent = function () {
			// nav links
			$(_context).find(".ct12w2 > ul > li > div > span").on("click", function (e) {
				var li1 = $(e.currentTarget).closest("li"),
					menu = $(e.currentTarget).closest("ul").find(".ct12w3"),
					classes = $(li1).attr("class"),
					target = _extractTarget(classes);
				// disable click menu when hover is 'on'
				if ($(e.currentTarget).closest(".ct12hoverOn")[0] && !$(e.currentTarget).hasClass("ct12w6")) {
					return false;
				}
				// ct12navActive indicates that a menu pulldown is open
				if ($(li1).hasClass("ct12navActive")) {
					if (e.type !== 'mouseenter') {
						$(li1).removeClass("ct12navActive");
					}
				} else {
					$(_context).find(".ct12navActive").removeClass("ct12navActive");
					$(li1).addClass("ct12navActive");
				}
				if ($(menu).hasClass("ct12menuOpen")) { // clicked to close or when another menu is open
					// Note: the more menu is used for all tabs at tablet and mobile breakpoints

					//console.log(1)
					// The next conditional is true if the tab clicked is the 'more' menu tab
					if ($(e.currentTarget).closest(".ct12w3")[0]) {
						//console.log(3)

						// The next conditional is true if the 'more' menu has no links and the menu link was clicked to close
						if (!$(menu).find(".ct12pushed")[0]) {
							//if (!$(menu).hasClass("ct12navActive")) {
							//	$(menu).removeClass("ct12menuOpen");
							//}
							if ($(menu).closest('.ct12cta-none')[0]) {
								$(menu).find(".ct12more > ul > li").hide();
								//console.log(20)
							} else {
								// don't hide last item, because it'll be the CTA
								$(menu).find(".ct12more > ul > li").not(":last").hide();

								if ($(_context).find('.ct12w4:visible')[0]) {
									//$(menu).find(".ct12cta .obttns").hide();
									$(_context).find(".ct12w1").addClass("ct12cta-hidden");

									//console.log(12)

								} else {
									//$(menu).find(".ct12cta .obttns").show();
									$(_context).find(".ct12w1").removeClass("ct12cta-hidden");

									//console.log(13)

								}
							}
							if (!$(li1).closest("ul").find(".ct12navActive")[0]) {
								$(menu).removeClass("ct12menuOpen");
							}
							// The next conditional is true if a tab other than the 'more' menu tab is being clicked to close
						} else if ($(menu).find(".ct12pushed").is(":visible")) {

							if (e.type !== 'mouseenter') {
								$(menu).removeClass("ct12menuOpen");
							}
						} else {
							// 'more' menu link clicked while the 'more' menu is open from a different tab...
							if ($(menu).closest('.ct12cta-none')[0]) {
								$(menu).find(".ct12more > ul > li").hide();
							} else {
								// don't hide last item, because it'll be the CTA
								$(menu).find(".ct12more > ul > li").not(":last").hide();
								if ($(_context).find('.ct12w4:visible')[0]) {
									//$(menu).find(".ct12cta .obttns").hide();
									$(_context).find(".ct12w1").addClass("ct12cta-hidden");
									//console.log(10)

								} else {
									//$(menu).find(".ct12cta .obttns").show();
									$(_context).find(".ct12w1").removeClass("ct12cta-hidden");
									//console.log(11)

								}
							}
							$(menu).find(".ct12pushed").show();
						}
					} else {
						//console.log(4)

						if ($(menu).find("[data-ref='" + target + "']").is(":visible")) {
							//console.log(5)

							// the tab clicked corresponds to a set of visible links in the more menu
							if (e.type !== 'mouseenter') {
								$(menu).removeClass("ct12menuOpen");
							}
						} else {
							//console.log(6)

							if ($(menu).closest('.ct12cta-none')[0]) {
								$(menu).find(".ct12more > ul > li").hide();
							} else {
								//console.log(7)

								// don't hide last item, because it'll be the CTA
								$(menu).find(".ct12more > ul > li").not(":last").hide();
								if ($(_context).find('.ct12w4:visible')[0]) {
									// if menu is open at time of the click
									// and link other than more menu was clicked
									// and the target was not visible at the time of the click
									// and if the CTA exists
									// and the CTA is visible
									//$(menu).find(".ct12cta .obttns").hide();
									$(_context).find(".ct12w1").addClass("ct12cta-hidden");
									//console.log(8)
								} else if (_isMobile()) {
									// if menu is open at time of the click
									// and link other than more menu was clicked
									// and the target was not visible at the time of the click
									// and if the CTA exists
									// and the CTA is not visible
									// and the breakpoint is mobile where the CTA is always hidden as of 11/18
									//$(menu).find(".ct12cta .obttns").hide();
									$(_context).find(".ct12w1").addClass("ct12cta-hidden");
									//console.log(14)
								} else {
									// if menu is open at time of the click
									// and link other than more menu was clicked
									// and the target was not visible at the time of the click
									// and if the CTA exists
									// and the CTA is not visible
									//$(menu).find(".ct12cta .obttns").show();
									$(_context).find(".ct12w1").removeClass("ct12cta-hidden");
									//console.log(9)
								}
							}
							$(menu).find("[data-ref='" + target + "']").show().attr("tabindex", "0").attr("role", "none");
						}
						if ($(e.currentTarget).closest('.ct12cta-on')[0]) {
							//$(menu).find('.ct12cta .obttns').hide();
							$(_context).find(".ct12w1").addClass("ct12cta-hidden");
						}
					}
				} else { // clicked to open

					//console.log(2)

					// hide previously displayed menu items
					if ($(menu).closest('.ct12cta-none')[0]) {
						// if there is no CTA...
						$(menu).find(".ct12more > ul > li").hide();
					} else {
						// don't hide last item, because it'll be the CTA
						$(menu).find(".ct12more > ul > li").not(":last").hide();
						//$(menu).find(".ct12more > ul > li .obttns").hide();
						$(_context).find(".ct12w1").addClass("ct12cta-hidden");

					}

					// show current menu items
					if ($(e.currentTarget).closest(".ct12w3")[0]) {
						// if the more menu was clicked...
						$(menu).find(".ct12pushed").show().attr("role", "presentation").attr("tabindex", "0");
						$(menu).find(".c12parentlabel").show().attr("role", "presentation").attr("tabindex", "0");
						if ($(_context).find('.ct12w4:visible')[0]) {
							//$(menu).find(".ct12cta .obttns").hide();
							if (!$(e.currentTarget).closest('.ct12cta-none')[0]) {
								$(_context).find(".ct12w1").addClass("ct12cta-hidden");
							}
						} else {
							//$(menu).find(".ct12cta .obttns").show();
							$(_context).find(".ct12w1").removeClass("ct12cta-hidden");
						}
					} else {
						$(menu).find("[data-ref='" + target + "']").show();
						//$(menu).find(".ct12cta .obttns").hide();
						if (!$(e.currentTarget).closest('.ct12cta-none')[0]) {
							$(_context).find(".ct12w1").addClass("ct12cta-hidden");
						}
					}
					$(menu).addClass("ct12menuOpen");
				}
				$(_context).find(".ct12screen").on("mouseenter", function () {
					$(menu).removeClass("ct12menuOpen");
				});
			});
		},

		/**
		 * Inject markup for triangles on mobile/tablet click menu
		 */
		_addTriangles = function () {
			$(_context).find(".ct12w2 > ul > li").append('<span class="ct12tri"></span>');
		},
		/**
		 * Adjusts which tabs are in the main navigation or 'more' menu based on the
		 * width of the browser window.
		 */
		_adjustItemsMob = function () {
			var ul = $(_context).find("ul").first(),
				ulW = $(ul).outerWidth(),
				w1W = $(_context).find(".ct12w1").width(), //width of component content
				w2W = $(_context).find(".ct12w2").outerWidth(), //tabs container width
				w3W = $(_context).find(".ct12w3 > div").outerWidth(), //more menu tab width
				btn = $(_context).find(".ct12w4"), //width of CTA container
				totalW = 0,
				totalWRecheck = 0,
				items = [],
				itemCount,
				pops = [], //list of tabs to be popped
				unpops = [], //list of tabs that should not be popped
				breakpoint = _getBreakpoint();
			//reorder tabs -- current tab should be the first and thus be the last tab to fall off the menu
			$(ul).children().each(function (i, item) {
				if ($(item).hasClass("ct12current")) {
					items.unshift(item);
				} else {
					items.push(item);
				}
			});

			itemCount = $(items).length;
			// add class that indicates whether cta is visible or not
			if ($(_context).find('.ct12w4:not(:visible)')[0] && $(_context).find('.ct12cta-on')[0]) {
				$(_context).find('.ct12w1').removeClass('ct12cta-on');
			} else if ($(_context).find('.ct12w4:visible')[0] && !$(_context).find('.ct12cta-on')[0]) {
				$(_context).find('.ct12w1').addClass('ct12cta-on');
			}
			$(items).each(function (i, li) {

				if ($(li).hasClass("ct12w3")) {
					$(this).attr('role', 'menu').attr('tabindex', '-1');
					return false;
				}
				$(li).removeClass("ct12popped");
				_removeItemFromSwap(li);
				totalW = totalW + +$(li).outerWidth();

				/*if (breakpoint == "mobile" || breakpoint == "tablet-small") {
					if ($(li).hasClass("ct12t1") || $(li).hasClass("ct12current")) {
						//display first tab and current tab
						unpops.push(li);
					} else {
						if (i == 1 && $(items[0]).hasClass("ct12current")) {
							//if 1st tab is selected, also display 2nd tab (as specified in the PSD)
							unpops.push(li);
						} else {
							pops.push(li);
						}
					}
					if (i == itemCount - 2) {
						//activate menu -- but if the text is still too long, hide tabs that would normally not be hidden
						var tmp = _activateMenu($(unpops), w2W);
						pops = pops.concat(tmp);
					}
				} else*/

				if ($(btn).is(":visible")) {
					// handle button
					// refresh test width
					w2W = $(_context).find(".ct12w2").outerWidth();
					if ($(_swap).hasClass("ct12menu")) {
						// items max is -1 because ct12w3 is skipped 
						if ((i + 1 == items.length - 1) && (totalW < w2W)) {
							$(_swap).removeClass("ct12menu");
						} else if (totalW + w3W > w2W) {
							pops.push(li);
						}
					} else {
						if (totalW > w2W) {
							pops = _activateMenu(items, w2W);
							return false;
						}
					}
				} else if ($(_context).find(".ct12menu")[0]) {
					//console.log('btn not vis, but menu found')

					// handle links with pulldown that's already activated

					//console.log((+totalW + +w3W ) + ' > ' + w2W + ' ?')

					if (totalW + w3W > w2W) {
						//console.log('yes');
						if (!$(li).hasClass("ct12popped")) {
							pops.push(li);
						}
					} else if (i == itemCount - 2 && (($(_context).find('.ct12cta-none')[0] && totalW <= w1W) || (totalW + (w1W * .25)) <= w1W)) {
						//console.log('no 1: next to last item AND ( (no cta exists AND total li width < ul width) OR (total li width + 25% of ul width <= ul width) )')
						//console.log($(_context).find('.ct12cta-none')[0] && totalW <= w1W);
						//console.log((totalW + (w1W * .25)) <= w1W );

						$(_context).find(".ct12inactive").removeClass("ct12inactive");
						$(_context).find(".ct12full").removeClass("ct12full");

						//console.log(breakpoint)
						//console.log('neither tablet-small nor mobile and ct12w4 exists?')
						//console.log(breakpoint !== 'tablet-small' && breakpoint !== 'mobile' && $(_context).find('.ct12w4')[0])
						//console.log('neither tablet-small nor mobile and .ct12w3 .ct12pushed exists?')
						//console.log(breakpoint !== 'tablet-small' && breakpoint !== 'mobile' && !$(_context).find('.ct12w3 .ct12pushed')[0])

						if ((breakpoint !== 'tablet-small' && breakpoint !== 'mobile' && $(_context).find('.ct12w4')[0]) || (breakpoint !== 'tablet-small' && breakpoint !== 'mobile' && !$(_context).find('.ct12w3 .ct12pushed')[0])) {
							$(_context).find(".ct12menu").removeClass("ct12menu");
						} else if (breakpoint == 'tablet-small' && !$(_context).find('.ct12w3 .ct12pushed')[0] && !$(_context).find('.ct12w4')[0]) {
							//console.log('breakpoint is tablet-small and there are no pushed items')
							$(_context).find(".ct12menu").removeClass("ct12menu");
						}
						return false;
					} else {
						//console.log('no 2')
						//console.log($(_context).find('.ct12cta-none')[0] && totalW <= w1W);
						//console.log((totalW + (w1W * .25)) <= w1W );
					}

				} else {
					//console.log('btn not vis, and menu not found');

					if ((totalW > w2W) || $(_context).find('.ct12w4')[0]) {
						pops = _activateMenu(items, w2W);
						return false;
					}
				}
			});

			if (pops.length > 0) {
				pops.reverse();
				for (var i = 0; i < pops.length; i++) {
					_pushItemToSwap(_popItemFromNav(pops[i]));
				}
				if (_isMobile()) {
					$(_context).find(".ct12w3").removeClass("ct12mobnopops");
				}
			} else {
				if (_isMobile()) {
					$(_context).find(".ct12w3").addClass("ct12mobnopops");
				} else {
					$(_context).find(".ct12w3").removeClass("ct12mobnopops");
				}
				//deactivate menu
				//if ($(btn).is(":visible")) {
				//	$(_swap).removeClass("ct12menu");
				//}
			}
			if (!$(_context).find(".ct12loaded")[0]) {
				$(_context).find(".ct12w1").addClass("ct12loaded");
			}
		},
		_adjustPulldownPosition = function () {
			
			var ul = $(_context).find("ul").first(),
				w1padding = parseInt($(_context).find(".ct12w1").css('padding-left')),
				w1W = $(_context).find(".ct12w1").width(), //tabs container width
				w3W = $(_context).find(".ct12w3 > div").outerWidth(), //more menu tab width
				menu,
				menuW = $(_context).find('.ct12w6').width(), //width of dropdown menu
				offset = 0,
				breakpoint = _getBreakpoint(),
				opClass = '';

			if (breakpoint == 'mobile' || breakpoint == 'tablet-small') {
				$(_context).find('.ct12more > ul').removeAttr('style');
				$(_context).find('.ct12w5').attr('tabindex', '0').attr('role', 'menuitem');
			} else {
				$(ul).find('li').not('.ct12popped').each(function (i, li) {
					opClass = $(li).hasClass('ct12w3') ? 'ct12more' : 'ct12w6';

					menu = $(li).find('.' + opClass)[0];

					if (menu) {
						offset = $(menu).offset().left + menuW - w1W - w1padding;
						if (opClass == 'ct12more') {
							offset = offset + 99999;
						}
						//console.log($(menu).offset().left + ' + ' + menuW + ' - ' + w1W + ' - ' + w1padding + ' = ' + offset)

						if (offset > 0) {
							// adjust position of the child UL rather than .ct12w6 div because the div has pseudoelements
							// adjust position to the right in case it's a RTL language
							
							var offsetPosNeg = -1;
							if ( $('body').hasClass('rtl')) { offsetPosNeg = 0;}
							$(li).find('.' + opClass + ' > ul').css({
								left: offset * offsetPosNeg,
								position: 'relative'
							});
						} else {
							$(li).find('.' + opClass + ' > ul').removeAttr('style');
						}
					}
				});
			}

		},
		/**
		 * Change the CTA class if the component is used in the hero
		 */
		_changeBtnClass = function () {
			if ($(_context).siblings(".herotabs")[0]) {
				$(_context).find(".obttn4").removeClass("obttn4").addClass("obttn6");
				return true;
			}
			return false;
		},
		/**
		 * closes menus that are open
		 */
		_clearMenu = function () {
			var menu = $(_context).find(".ct12more");
			if (!$(_context).find(".ct12hoverOn")[0]) {
				$(menu).find("> ul > li").not(":last").hide();
			}
			$(menu).find(".ct12expand").removeClass("ct12expand");
			$(_context).find(".ct12menuOpen").removeClass("ct12menuOpen");
			$(_context).find(".ct12navActive").removeClass("ct12navActive");
		},
		/**
		 * Injects a copy of the CTA in the nav bar into the 'more' menu 
		 */
		_cloneBtn = function () {
			var originalBtn = $(_context).find(".obttns"),
				newBtn = $(originalBtn).clone(),
				newItem = $('<li class="ct12cta"></li>').append(newBtn);
			if ($(originalBtn)[0]) {
				$(newItem).find(".obttn4").removeClass("obttn4");
				$(newItem).find(".obttn6").removeClass("obttn6");
				$(_swap).find("ul").first().append(newItem);
			} else {
				$(_context).find('.ct12w1').addClass('ct12cta-none');
			}

		},
		/**
		 * Injects a copy of the pulldown nav items in the nav bar into the 'more' menu 
		 */
		_cloneNavItems = function () {
			var classes, newc, ul2;
			$(".ct12w2 > ul > li > div > .ct12w6 > ul").each(function (i, ul) {
				classes = $(ul).closest("li").attr("class");
				newc = _extractTarget(classes);
				if (newc) {
					ul2 = $(ul).clone();
					$(ul2).children("li").attr("data-ref", newc);
					$(_swap).find(".ct12more > ul").prepend($(ul2).html());
				}
			});
		},
		/**
		 * Returns the identifying class name ("ct12t1", "ct12t2", etc.).
		 * See: _numberTabs
		 */
		_extractTarget = function (classes) {
			var classAr = classes.split(' ');
			for (var j = classAr.length - 1; j > -1; j--) {
				if (classAr[j].match(/ct12t\d/)) {
					return classAr[j];
				}
			}
		},
		/**
		 * Returns string representation of breakpoint name ("desktop","mobile", etc.)
		 */
		_getBreakpoint = function () {
			return window.getComputedStyle($(_context)[0], ':before').getPropertyValue('content').replace(/\"/g, '');
		},
		/**
		 * Creates the 'more' menu 
		 */
		_injectMenu = function (label) {
			//$(_context).find(".ct12w2 > ul").append('<li class="ct12w3" role="tabpanel" tabindex="-1"><div tabindex="-1"><span><span class="ct12w5 icn-cv-right-after" role="menuitem">' + label + '</span></span><div class="ct12more" tabindex="0" role="menu" id="menu1" aria-labelledby="menubutton1" aria-activedescendant="mi1"><ul></ul></div></div></li>');
			$(_context).find(".ct12w2 > ul").append('<li class="ct12w3" role="tabpanel" tabindex="-1"><div tabindex="-1"><span><span class="ct12w5 icn-cv-down-after" role="menuitem">' + label + '</span></span><div class="ct12more" role="menu" aria-labelledby="menubutton1"><ul></ul></div></div></li>');
		},
		_isMobile = function () {
			var breakpoint = window.getComputedStyle($(_context)[0], ':before').getPropertyValue('content').replace(/\"/g, '');
			if (breakpoint == "mobile") {
				return true;
			}
			return false;
		},
		/**
		 * Deactivate menu stickiness and hover states for mobile
		 */
		_mobileCheck = function () {
			var breakpoint = _getBreakpoint();
			if (breakpoint == "mobile" || breakpoint == "tablet-small") {
				$(_context).find(".ct12hoverOn").removeClass("ct12hoverOn");
				if ($(".ct12-sticky-wrapper")[0]) {
					//_ct12sticky.destroy();
					$(".ct12").unwrap(".ct12-sticky-wrapper");
				}
				_resizeBar();
			} else {
				$(_context).find(".ct12w2").not(".ct12hoverOn").addClass("ct12hoverOn");
				$(_context).find(".ct12more > ul > li").removeAttr("style");
				if (!$(".ct12-sticky-wrapper")[0]) {
					$(".ct12").wrap('<div class="ct12-sticky-wrapper"></div>');
				}
				$(_context).find(".ct12mobnopops").removeClass("ct12mobnopops");
				_resizeBar(true);
			}
		},
		/**
		 * Assigns an identifying class name to each tab.
		 * Format: ct12tX
		 */
		_numberTabs = function () {
			var ul = $(_context).find("ul").first();
			$(ul).children().each(function (i, li) {
				$(li).addClass("ct12t" + (+i + 1));
			});
		},
		/**
		 * Hides target tab in the nav
		 */
		_popItemFromNav = function (item) {
			$(item).addClass("ct12popped");
			//$(item).attr("role", "none");
			$(item).attr("aria-hidden", "false");
			return item;
		},
		/**
		 * Hides last tab in the nav
		 */
		_popLastItemFromNav = function () {
			var ul = $(_context).find("ul").first(),
				lastLi = $(ul).children().last();
			return _popItemFromNav(lastLi);
		},
		/**
		 * Injects item into 'more' menu
		 */
		_pushItemToSwap = function (item) {
			var newItem = $(item).clone();
			newItem.addClass("ct12pushed").removeClass("ct12popped").attr('role', 'none').attr('tabindex', '-1');
			newItem.find(".afterwhite").removeClass("afterwhite");
			if ($(newItem).find(".ct12w6")[0]) {
				$(newItem).find("> div > span > span").addClass("ct12parentlabel").attr('role', 'none').attr('tabindex', '0');
			}
			$(_swap).find("ul").first().prepend(newItem);
		},
		/**
		 * Position top triangle of 'more' menu
		 */
		_reposArrow = function () {
			var left = $(_context).find(".ct12w3").offset().left,
				itemW = $(_context).find(".ct12w3").width() / 2,
				arrow = $(_context).find(".ct12w3 > span").not(".ct12bar");
			$(arrow).css({
				left: (left + itemW) + 'px'
			});
		},
		/**
		 * Deletes items from the 'more' menu
		 */
		_removeItemFromSwap = function (item) {
			var c = $(item).attr("class"),
				classAr = [];
			if (c) {
				classAr = c.split(' ');
				for (var i = classAr.length - 1; i > -1; i--) {
					if (classAr[i].match(/ct12t\d/)) {
						$(_swap).find('.ct12more > ul > .' + classAr[i]).remove();
						break;
					}
				}
			}
		},
		/**
		 * resize last ct12bar at mobile/tablet because its container is fixed position
		 */
		_resizeBar = function (clear) {
			var width,
				left;
			if ($(".ct12w3")[0] && $(".ct12w3 .ct12bar")[0]) {
				if (clear) {
					$(".ct12w3 .ct12bar").removeAttr("style");
				} else {
					$(".ct12w3 .ct12bar").css({
						width:$(".ct12w3").width(),
						left:$(".ct12w3").offset().left
					});
				}
				
			}		
		},
		/**
		 * Enables sticky menu
		 */
		_stickify = function () {
			_ct12sticky = new Waypoint.Sticky({
				element: $(_context)[0],
				wrapper: '<div class="ct12-sticky-wrapper" />',
				stuckClass: 'ct12stuck',
				handler: function (dir) {
					if (dir === "down") {
						if (($('.herotabs')[0]) || ($('.herotoptabs')[0])) {
							$(_context).closest(".ct12-sticky-wrapper").addClass('ct12notransform');
						}
					} else {
						$(_context).closest(".ct12-sticky-wrapper").removeClass('ct12notransform');
						_ct12sticky.waypoint.disable();
						_ct12sticky.waypoint.enable();
					}
				}
			});
		};

	/**
	 * Adds accessibility features and tab control
	 */
	_addAlly = function () {
		
		$('.ct12w4').attr("role", "none");
		$('.ct12w5').attr("tabindex", "0").attr('role', 'menuitem');
	
		$('.ct12w2 ul').first().attr("role", "menubar").children().each(function () {
			$(this).find('div').first().attr('tabindex','-1').attr('role','none');
	
			//check if menu has an inner menu or if it's just a link
			if ($(this).has('.ct12w6').length) {
				//$(this).find('span > span').attr('tabindex', '0').attr('aria-haspopup', 'true').attr('aria-controls', 'menu1');
				var $innerList = $(this).find('ul');
				$innerList.attr("role", "menu").each(function () {
					//$(this).find('li').attr('tabindex','-1');
					//$(this).attr('id','menu1');
					$(this).find('a').attr('tabindex', '0').attr("role", "menuitem");
				});
			} else {
				//$(this).attr("role", "none").attr('tabindex','-1');
				//$(this).find('div').attr('tabindex','-1').attr("role", "none");
				$(this).find('a').attr('tabindex', '0').attr("role", "menuitem");
			}
		});

		var focusableElementsString = 'ul[role=menubar] > li:not(.ct12popped):not(.ct12navActive) > div > a, ul[role=menubar] > li:not(.ct12popped):not(.ct12navActive) > div > span:not(.ct12w6) > span ';
		var allTabs = document.querySelectorAll(focusableElementsString);
		focusableElements = Array.prototype.slice.call(allTabs);
		//console.log('alltabs',allTabs);
		var firstTabStop = focusableElements[0];
		var lastTabStop = focusableElements[focusableElements.length - 1];
		var firstLinkStop, lastLinkStop, currMenuTarget;

		focusableElements.forEach(function (element) {

			if ($(element).is("a")) {
				$(element).addClass('aria-a').attr('tabindex', '0');
				element.addEventListener('keyup', trapTabKeyA);

			} else if ($(element).is("span")) {
				$(element).addClass('aria-b').attr('tabindex', '0');
				element.addEventListener('keyup', trapTabKeyB);
			}
		});

		//Menu link with no sub-menu
		function trapTabKeyA(e) {
			if (e.keyCode === 9) {
				$('.ct12w2 ul li').removeClass('ct12navActive');
				$('.ct12w2 ul li').removeClass('ct12menuOpen');
			}
		}

		//Menu menu link with sub-menu
		function trapTabKeyB(e) {

			if (e.keyCode === 9) {
				//TODO: Setup hander for last element
				if ($(this).parents('li').hasClass('ct12navActive')) {
					//console.log('focusing on first element', $(this).parents('li').find('.ct12w6'));
					$(this).parents('li').find('.ct12w6').focus();
					e.preventDefault();
					//return false;
				}
			}			
			if (e.keyCode === 13) {
				// Default setup
				focusableElements.forEach(function (element) {
					if (element != document.activeElement) {
						$(element).closest('div').removeClass('hovered');
						$(element).closest('li').removeClass('ct12navActive');
					}
				});
				if ($(this).closest('li').hasClass('ct12navActive')) {
					//console.log('trap C closed');
					$(this).closest('li').removeClass('ct12navActive');
					$(this).closest('div').removeClass('hovered');
					$(this).find('.ct12w6').hide();
				}
				else {
					//console.log($(this),'trap C open');
					$(this).closest('li').addClass('ct12navActive');
					$(this).closest('div').first().addClass('hovered');
					$(this).closest('li').find('.ct12w6').show();
					$('.ct12menu .ct12more ul').show();
					
					$('.ct12menu').addClass('ct12menuOpen');
					var classes = $(".ct12navActive").attr("class");
					currMenuTarget = _extractTarget(classes);
					//console.log('currMenuTarget',currMenuTarget);
					
					$('.ct12more').show().focus();
					$('.ct12more li:not([data-ref="' + currMenuTarget + '"])').hide(); 
					//$('.ct12more li.ct12cta').show();
					$('.ct12more li[data-ref="' + currMenuTarget + '"]').show();
					$('.' + currMenuTarget).find('ul').first().show();
					//$('li[data-ref="' + currMenuTarget + '"] .ct12w5').focus();	
					console.log ($('li[data-ref="' + currMenuTarget + '"] a').first());
					$('li[data-ref="' + currMenuTarget + '"] a').first().focus(); 
					
					if ($(".ct12navActive").hasClass('ct12menu')) {
						$('.ct12more li').hide();
						$('.ct12more .ct12pushed').show();
						$('.ct12more .ct12pushed .ct12w6 li').show();
						//$('.' + currMenuTarget).find('ul').first().show();

					}

					// Add inner link listener to pass focus to next main menu on last link tab
					var focusableLinksString = '.ct12more li[data-ref="' + currMenuTarget + '"] > span > a ';
					var allLinks = document.querySelectorAll(focusableLinksString);

					focusableLinks = Array.prototype.slice.call(allLinks);
					//console.log(focusableLinks);
					firstLinkStop = focusableLinks[0];
					lastLinkStop = focusableLinks[focusableLinks.length - 1];

					focusableLinks.forEach(function (element) {
						//$(element).attr('id', 'mi1').show();
						addEventListener('keydown', trapInnerTabKey);
					});


					//Last tab listener to hide all menus (for both regular and more menus)
					var lastTab, lastSelectedTab;

					if (_getBreakpoint() == 'desktop') {
						lastTab = allTabs[allTabs.length - 2];
					} else {
						lastTab = allTabs[allTabs.length - 1];
					}
					lastSelectedTab = $(lastTab).closest('li').first();
					//console.log(lastSelectedTab);
					if ($(lastSelectedTab).hasClass(currMenuTarget)) {
						$('.ct12more').show();
						$('.ct12menu').addClass('ct12navActive');
						$('.' + currMenuTarget).find('ul').first().show();
						//console.log($('li.' + currMenuTarget + ' ul[role="menu"] li:visible a:last-of-type').last());

						$('li.' + currMenuTarget + ' ul[role="menu"] li:visible a:last-of-type').last().on('keydown', function (ev) {
							if (ev.keyCode === 9) {
								//console.log('tab out on last element of last tab');
								$('.' + currMenuTarget).removeClass('ct12navActive'); //hide desktop menu
								$('.' + currMenuTarget).removeClass('ct12menuOpen'); //hide mobile menu
								$('.' + currMenuTarget).find('div').first().removeClass('hovered');
								$('.' + currMenuTarget).find('ul').first().hide();
								//console.log('last', $('.' + currMenuTarget).find('ul'));
							}
						});
					}
					}
			}			
		}

		// Inner link listener
		function trapInnerTabKey(e) {
			// Check for TAB key press
			if (e.keyCode === 9) {
				//console.log('inner trap');
				var $prev = $('.' + currMenuTarget);
				
				// SHIFT + TAB
				if (e.shiftKey) {
					if (document.activeElement === firstLinkStop) {
						//console.log('first element - SHIFT FOCUS TO PREV ITEM TAB');
						$prev.find('.ct12w5').focus();
						e.preventDefault();
					}

					// TAB
				} else {
					if (document.activeElement === lastLinkStop) {
						$prev.nextAll('li').not('.ct12popped').first().focus();
						$('ul[role="menubar"] li').removeClass('ct12navActive');

						//Next element is More menu
						if ($prev.nextAll('li').not('.ct12popped').first().hasClass('ct12menu')) {
							//console.log('next element is more menu');
							
							$('.ct12more').hide();
							//console.log('target class', currMenuTarget);
							$('li[data-ref="' + currMenuTarget + '"]').hide();
							$prev.nextAll('li').find('span > span').focus();
							$prev.nextAll('li').find('.ct12pushed').show();
							$prev.nextAll('li').find('.ct12pushed li').show();

						} else {
							$('.ct12w3').removeClass('ct12menuOpen');
							$('li[data-ref="' + currMenuTarget + '"]').hide();
							$prev.nextAll('li').first().find('div > span > span').focus();
							//console.log('next',$prev.nextAll('li').first());
						}
						e.preventDefault();
					}
				}
			}
		}
	};


	// this function will be registered with OCOM as OCOM.ct12
	// this needs to be a named function, using component id
	component = function ct12($) {
		// $ is scoped to the context given in OCOM.ct12(context) - defaults to document
		_context = $(".ct12").first();
		var label = $(_context).attr("data-moretxt");
		
		window.ct12Interval = setInterval(function () {
			if (Boolean($('link[href$="ocom-v1-styles.css"]')[0].sheet)) {
				clearInterval(ct12Interval);
				_injectMenu(label);
				_swap = _context.find(".ct12w3").first();
				_addArrows();
				_addBars();
				_addTriangles();
				_numberTabs();
				_changeBtnClass();
				_cloneBtn();
				_cloneNavItems();
				_adjustItemsMob();
				_reposArrow();
				_addMenuClickEvent();
				_mobileCheck();
				_adjustPulldownPosition();
				_addAlly();
				_ct12width = $(_context).width();
			}
		}, 250);
		$(window).off('resize.ct12').on('resize.ct12', function () {
			if (_ct12width != $(_context).width()) {
				_adjustItemsMob();
				_reposArrow();
				_mobileCheck();
				_adjustPulldownPosition();
				_clearMenu();
				_addAlly();
				_ct12width = $(_context).width();
			}
		});
	};
	return component;
})();
OCOM.register(ct12);

/*! CT13 */
window.ct13Interval = [];
window.ct13CssInterval = 0;
(function($) {
	var component,
		_context,
		_component,
		_componentClass,
		_resizeTimeout,
		_addMobIcons = function (context) {
			$(context).find(".ct13w4 a,.ct13w7 a").each( function (i, a) {
				$(a).append('<span class="ct13icn"><span class="icn-img icn-plus"></span></span>');
			});
		},
		_adjustMenuHeight = function (context) {
			var slideH, imgH, contentH;
			if (_getBreakpoint() == "desktop" || _getBreakpoint() == "tablet") {
				if ($(context).hasClass("ct13v3")) {
					contentH = $(context).find(".ct13current .ct13w6").outerHeight();
					imgH = $(context).find(".ct13current .ct13w15 img").outerHeight();
					if (imgH > 0) {
						if (imgH > contentH) {
							$(context).find(".ct13current .ct13w6").css({"min-height": imgH + "px"});
							slideH = imgH;
						} else {
							slideH = contentH;
						}
					} else {
						slideH = contentH;
					}
					$(context).find(".ct13w3").css({"min-height": slideH + "px"});
				} else if ($(context).hasClass("ct13v2")) {
					slideH = $(context).find(".ct13current .ct13w6").outerHeight();
					$(context).find(".ct13w3").css({"min-height": slideH + "px"});
				}
			}
		},
		_onWindowResized = function() {
			clearTimeout(_resizeTimeout);
			_resizeTimeout = setTimeout(function() {
				$(_componentClass).each( function (i, context) {
					_adjustMenuHeight(context);
				});
			}, 50);
		},
		/*_adjustCircleSize = function () {
			var txtW, txtH, comp, newW, pad = 28;
			$('.ohilite').each( function( i, cir) {
				txtW = $(cir).find('span').width();
				txtH = $(cir).find('span').height();
				comp = $(cir).width() + pad;
				if (txtW > comp || txtH > comp) {
					newW = txtW > txtH ? txtW : txtH;
					newW += pad;
					$(cir).height(newW);
					$(cir).width(newW);
				}
			});
		},*/
		_bindEvents = function (context, instance) {
			$(window).on( 'hashchange', function (e) {
			    $('.ct13').each( function (i, context) {
			    	if ($(context).find(window.location.hash)) {
			    		_jumpToId(context, instance);
			    	} else {
			    		return false;
			    	}
			    });
			});
			$(context).find(".ct13w3 a").on("click triggerclick", function (e) {
								//console.log('w3 ' + e.type)

				var targetId = $(e.currentTarget).attr("href"),
					overlayId = '#overlay-' + targetId.replace('#',''),
					li = $(e.currentTarget).closest("li"),
					ul = $(e.currentTarget).closest("ul");
				e.preventDefault();
				if (!$(e.currentTarget).closest(".ct13current")[0]) {
					$(context).find(".ct13w2 .ct13previous").removeClass("ct13previous");
					if (e.type == 'triggerclick') {
						$(context).find(".ct13w2 .ct13current").removeClass("ct13current").removeClass("ohilite-on");
					} else {
						$(context).find(".ct13w2 .ct13current").addClass("ct13previous").removeClass("ct13current").removeClass("ohilite-on");
					}
					//$(context).find(".ct13w2 .ct13current").addClass("ct13previous").removeClass("ct13current").removeClass("ohilite-on");
					$(context).find(".ct13w11 .ct13previous").removeClass("ct13previous");
					$(context).find(".ct13w11 .ct13current").addClass("ct13previous").removeClass("ct13current");
					$(li).addClass("ct13current");
					$(targetId).css({opacity:0});
					$(targetId).addClass("ct13current").addClass("ohilite-on");
					$(targetId).animate({opacity:1},250);

					// fix layout issue with hash change on firefox
					if (e.type == 'triggerclick' && $(targetId).closest('.ct13v2')[0]) {
						$(targetId).closest('.ct13v2').find('.ct13w14').not(targetId).hide();
						setTimeout( function () {
							$(targetId).closest('.ct13v2').find('.ct13w14').not(targetId).removeAttr('style');
						}, 10);
					}
					// end fix

					$(overlayId).addClass("ct13current");

					$(context).find(".ct13w4.ct13current").removeClass("ct13current");
					$(context).find('.ct13w4 a[href="' + targetId + '"]').closest(".ct13w4").addClass("ct13current");
					_adjustMenuHeight($(e.currentTarget).closest(".ct13"));
				}
			});
			$(context).find(".ct13w4 a").on("click triggerclick", function (e) {
								//console.log('w4 ' + e.type)

				var targetId = $(e.currentTarget).attr("href"),
					//overlayId = '#overlay-' + targetId.replace('#',''),
					w3 = $(context).find(".ct13w3");
				e.preventDefault();

				if (!$(e.currentTarget).closest(".ct13current")[0]) {
					$(e.currentTarget).closest(".ct13w2").find(".ct13previous").removeClass("ct13previous");
					$(e.currentTarget).closest(".ct13w2").find(".ct13current").addClass("ct13previous").removeClass("ct13current");
					$(context).find(".ct13w11 .ct13previous").removeClass("ct13previous");
					$(context).find(".ct13w11 .ct13current").addClass("ct13previous").removeClass("ct13current");
					$(w3).find('[href="' + targetId + '"]').closest("li").addClass("ct13current");
					$(e.currentTarget).closest(".ct13w4").addClass("ct13current");
					//$(overlayId).addClass("ct13current");
					$(targetId).addClass("ct13current");
				}
			});
			$(context).find(".ct13w7 a").on("click historynav", function (e) {
				//console.log('w7 ' + e.type)
				var targetId = $(e.currentTarget).attr("href"),
					overlayId = '#overlay-' + targetId.replace('#',''),
					w3 = $(context).find(".ct13w3"),
					curWindow = $(window).scrollTop(),
					current,
					currentH,
					linkH;
				e.preventDefault();
				if (!$(e.currentTarget).closest(".ct13current")[0]) {
					$(e.currentTarget).closest(".ct13w2").find(".ct13previous").removeClass("ct13previous");
					$(e.currentTarget).closest(".ct13w2").find(".ct13current").addClass("ct13previous").removeClass("ct13current");
					$(context).find(".ct13w2 .ct13previous").removeClass("ct13previous");
					$(context).find(".ct13w2 .ct13current").addClass("ct13previous").removeClass("ct13current");
					$(context).find(".ct13w11 .ct13previous").removeClass("ct13previous");

					current = $(context).find(".ct13w11 > .ct13current");
					currentH = $(current).outerHeight();
					linkH = $(current).find('.ct13w7').height();

					$(context).find(".ct13w11 .ct13current").addClass("ct13previous").removeClass("ct13current");
					$(w3).find('[href="' + targetId + '"]').closest("li").addClass("ct13current");

					$(e.currentTarget).closest(".ct13w7").addClass("ct13current");
					$(overlayId).addClass("ct13current");
					$(targetId).addClass("ct13current");


					if ($(e.currentTarget).closest(".ct13w12").index() > $(e.currentTarget).closest(".ct13w11").children('.ct13previous').index()) {
						$('html, body').scrollTop(curWindow - currentH + linkH);
					}
				}
			});
			$(context).find(".ct13current .ct13w15 img").on("load", function (e) {
				if ($(e.currentTarget).attr("src")) {
					_adjustMenuHeight($(e.currentTarget).closest(".ct13"));
				}
			});
		},
		_buildDesktopMenu = function (context) {
			var clone,
				newEl = $("<div class=\"ct13w3\"><ul></ul></div>");
			$(context).find(".ct13w4 a, .ct13w7 a").each( function (i, a) {
				clone = $(a).clone();
				target = $(a).attr("href");
				newEl.children("ul").append("<li></li>");
				newEl.find("li").last().html(clone);
			});
			$(context).find(".ct13w2").prepend(newEl);
			$(context).find(".ct13w3 li").first().addClass("ct13current");
		},
		_convert = function (context) {
			var className = $(context).find(".ct13w2").attr('class'),
				dkcolors = ['bgred','bgblack','bgdarkslate','bggrey','bgdarkgrey','bgorange','bgdarkorange','bgblue','bgdarkblue','bgvdarkblue','bgdarkgreen','bgburgundy','bgdarkburgundy'],
				length = dkcolors.length,
				re;
			// remove dark bgcolor from ct13w2 and inject class in section
			for( var i = 0; i < length; i++) {
				re = new RegExp(dkcolors[i],"g");
				if (className.match(re)) {
					if (!$(context).hasClass('ct13bgdark')) {
						$(context).addClass('ct13bgdark');
					}
				}
			}
			// remove bg, fill, txt classes
			$(context).find("[class*='bg'],[class*='fill'],[class*='txt']").each( function (i, inst) {
				$(inst).removeClass (function (j, name) {
				    return (name.match (/(^|\s)(bg|fill|txt)\S+/g) || []).join(' ');
				});
			});
			// remove ohilite
			//$(context).find(".ohilite").remove();

		},
		_getBreakpoint = function () {
			return window.getComputedStyle(document.querySelector('.ct13'), ':before').getPropertyValue('content').replace(/\"/g, '');
		},
		_fadeIn = function (context) {
			var el,
				natHt = 0;
			if ($(context).hasClass("ct13v2")) {
				$(context).waypoint(function() {
					el = $(context).find('.ct13w12.ct13current')[0];
					$(el).css({
						"text-indent": 0,
						"max-height": "800px",
						"transition": "none"
					});
					natHt = $(el).height();
					$(el).removeAttr('style');
					//$(el).height(natHt);
					$(context).addClass("ct13loaded");
					this.destroy(); 
				},{
					offset: '95%'
				});
			}
		},
		_addBgs = function () {
			$(_componentClass + '[data-bgimg],' + _componentClass + ' [data-bgimg]').each( function (i, context) {
				var bgimg = $(context).attr("data-bgimg");
				if ($(context).hasClass("ct13")) {
					$(context).find(".ct13w6").addClass("o-bgimg").attr("data-bgimg", bgimg);
				} //else if ($(context).hasClass("ct13w5")){
					//$(context).find(".ct13w6").append('<div class="ct13w15 o-bgimg" data-bgimg="' + bgimg + '"></div>');
				//}
			});
		},
		_imgCheck = function (context, i) {
			var imgs = $(context).find(".ct13w10 img"),
				fcnt;
			window.ct13Interval[i] = setInterval( function () {
				fcnt = 0;
				$(imgs).each( function (n, img) {
					if (!$(img).get(0).complete) {
						fcnt++;
					}
				});
				if (fcnt == 0) {
					clearInterval(window.ct13Interval[i]);
					_adjustMenuHeight(context);
					_jumpToId(context, i);
				}
			}, 125);
		},
		_jumpToId = function (context, instance) {
			hash = window.location.hash;
			//console.log(hash)
			//_onWindowResized();
			if ($(hash)[0]) {
				$(context).find('a[href="' + hash + '"]').trigger('triggerclick');
			}
			/*
			else {
				if (_getBreakpoint() == 'desktop') {
					$($('.ct13')[instance]).find('.ct13w3 a').first().trigger('historynav');
				} else {
					$($('.ct13')[instance]).find('.ct13w4 a').first().trigger('historynav');
				}
			}*/
		};
	component = function ct13($) {
		_componentClass = '.ct13';
		
		$(_componentClass).each( function (i, context) {
			_convert(context);
		});

		window.ct13CssInterval = setInterval( function(){ 
			if (Boolean($('link[href$="ocom-v1-styles.css"]')[0].sheet)) {
				clearInterval(ct13CssInterval);
				
				$(_componentClass).each( function (i, context) {
					_buildDesktopMenu(context);
					_addMobIcons(context);
					_bindEvents(context, i);
					_imgCheck(context, i);
				});
				_addBgs();
				window.OBGIMG.execute();
				$(window).off('resize.ct13').on('resize.ct13', _onWindowResized);
				window.OHILITE.execute();
				$(_componentClass).each( function (i, context) {
					_fadeIn(context);
				});



			}
		}, 250);
		
		
	};
	OCOM.register(component);
})(jQuery);

/*! CT14 */
OCOM.register(function ct14($) {
	'use strict';

	$('.ct14').each(function() {
		var ct14 = $(this);
		$('.ct14w2').attr('role', 'tablist');
		// $(this).find('.ct14w3 a').each(function() {
		// 	var index = $( '.ct14w3 a' ).index( this );
		// 	var href = $(this).attr('href');
		// 	$(this).attr('href', '#ct14panel-' + index);
		// });

		// $(this).find('.ct14w4').each(function() {
		// 	var index = $( '.ct14w4' ).index( this );
		// 	$(this).attr('id', 'ct14panel-' + index);
		// });

		$(ct14).find('.ct14w3 a').on('click', function(e, noopen) {

			var href = $(e.currentTarget).attr('href'),
					// fix for href rewrites by betamode - prevents $('?betamode=foo#targetId')
					ct14targetId = href.slice(Math.max(href.indexOf('#'), 0)),
					ct14w3 = $(e.currentTarget).closest('div.ct14w3'),
					ct14w2 = $(e.currentTarget).closest('div.ct14w2');

			e.preventDefault();

			// noopen set to true if called by openTabByHash
			if(!noopen) { $(ct14w2).toggleClass('open'); }

			if (!$(e.currentTarget).closest('.ct14current')[0]) {
				$(ct14).find('.ct14w2 .ct14current').removeClass('ct14current').find('a').removeClass('icn-cv-down');
				$(ct14).find('.ct14w4.ct14current').removeClass('ct14current');
				$(ct14w3).addClass('ct14current');
				$(ct14targetId).addClass('ct14current');
				$(ct14).find('.ct14w2 .ct14current a').addClass('icn-cv-down').attr('role', 'tab').attr('aria-selected', 'true');
				/* globals Waypoint */
				Waypoint.refreshAll();
			}

			if(window.history.pushState) {
				window.history.pushState(null, null, ct14targetId + '-tab');
			} else {
				window.location.hash = ct14targetId + '-tab';
			}

			if ($(ct14).find('.ct14w4.ct14current .cb82')[0]) {
				$(ct14).find('.cb82w1, .cb82w2').each(function() {
					// only call refresh if it's been initialized - this code runs before cb82 on pageload
					// okay to return false - we can bail after first check if needed
					return $(this).is('.slick-initialized') && $(this).slick('refresh');
				});
			}

			$(ct14).triggerHandler({
				type: 'ct14tabchange',
				currentTab: ct14targetId
			});
			$(ct14).find('.ct14w3 a').attr('role', 'tab').attr('aria-selected', 'false');
			if ($(this).parent().hasClass('ct14current')){
				$(this).addClass('icn-cv-down').attr('aria-selected', 'true');
			}
		});

		openTabByHash();

		$(ct14).find('.ct14w3 a').attr('role', 'tab').attr('aria-selected', 'false');
		$(ct14).find('.ct14w3.ct14current a').addClass('icn-cv-down').attr('aria-selected', 'true');

		function openTabByHash() {
			var hash = window.location.hash,
					tab = hash.replace(/-tab/, '');

			return hash &&
							ct14.find(tab).length &&
							// set a flag to prevent dropdown open
							ct14.find('.ct14w3 a[href="' + tab + '"]').trigger('click', true);
		}
	});
	var VK_ENTER = 13;
	$('.ct14w3 a').keyup(function(e) {
		if (e.keyCode === VK_ENTER) {
			$(this).click();
		}
	});
});


/*! CT16 */
OCOM.register(function ct16($) {
	'use strict';


//	var isTouch = false //var to indicate current input type (is touch versus no touch)
//	var isTouchTimer
//	var curRootClass = '' //var indicating current document root class ("ct16touch" or "")
//
//	function addtouchpcclass(e){
//		clearTimeout(isTouchTimer)
//		isTouch = true
//		if (curRootClass != 'ct16touchpc'){ //add "ct16touch' class if it's not already present
//			curRootClass = 'ct16touchpc'
//			document.documentElement.classList.add(curRootClass)
//		}
//		isTouchTimer = setTimeout(function(){isTouch = false}, 500) //maintain "istouch" state for 500ms so removetouchclass doesn't get fired immediately following a touch event
//	}
//
//	function removetouchclass(e){
//		if (!isTouch && curRootClass == 'ct16touchpc'){ //remove 'ct16touch' class if not triggered by a touch event and class is present
//			isTouch = false
//			curRootClass = ''
//			document.documentElement.classList.remove('ct16touchpc')
//		}
//	}
//
//	document.addEventListener('pointer*', addtouchpcclass, false) //this event only gets called when input type is touch
//	document.addEventListener('mouseover', removetouchclass, false) //this event gets called when input type is everything from touch to mouse/ trackpad


//	var ct16touching = false;
//	window.addEventListener('touchstart', function onFirstTouch() {
//		$('.ct16').addClass('ct16tch');
//		var ct16touching = true;
//		window.removeEventListener('touchstart', onFirstTouch, false);
//	}, false);
//
//	if(ct16touching){
//		console.log('touching000',ct16touching);
//	}
//	else {
//		console.log('touching000',ct16touching);
//	}

//	var ct16touching = false;

//	var ct16touching = false;
//	window.addEventListener('touchstart', function ct16onFirstTouch() {
//		 //document.body.classList.add('user-is-touching');
//		var ct16touching = true;
//		 //window.USER_IS_TOUCHING = true;
//		 window.removeEventListener('touchstart', ct16onFirstTouch, false);
//	}, false);
//
//	if(ct16touching){
//		console.log('is touching',ct16touching);
//	}
//	else {
//		console.log('not touching',ct16touching);
//	}

	var flag = false;
	var flagtwo = false;
	var ct16 = $('.ct16');
	var ct16t1count = $('.ct16t1 > li').length;
	var ct16t2count = $('.ct16t2 > li').length;
	
	
	var ct16RunCount = Math.max(ct16t1count, ct16t2count) - 2;
	var ct16sticky = '';
	var ct16counter = 1;

	$('.ct16t1 > li').each(function(i) {
		$(this).attr('data-position', i);
	});
	
	if (ct16t2count === 0) {
		$('.ct16-wrapper').addClass('ct16nosub');
	}

	function ct16sort() {
		$('.ct16t1 > li').sort(sort_li).appendTo('.ct16t1');
		function sort_li(a, b) {
			return ($(b).data('position')) < ($(a).data('position')) ? 1 : -1;
		}
	}

	//Create empty ul for more menus
	$('.ct16mainmore, .ct16submore').append('<ul class="ct16t3"></ul>');

	$('.ct16-wrapper').append('<div class="ct16shadow"></div>');

	// Create CV icon for main dropdown
	$('.ct16mainmore > a').append('<span class="icn-cv-down"></span>');

	//Create Mobile Menu icon
	$('.ct16w1 h2').append('<div class="ct16close" aria-role="button" tabindex="0"><span></span><span></span></div>');

	$('.ct16close').keyup(function(e) {
		if (e.keyCode === VK_ENTER) {
			$(this).click();
		}
	});


	function ct16Dropdowns() {
		$('.ct16t1 > li > a').removeClass('ct16link');
		$('.ct16t2 > li > ul li:not(.ct16more) a, .ct16submore ul li:not(.ct16more) a, .ct16mainmore ul li:not(.ct16more) a').each(function() {
			$(this).addClass('ct16link');
		});

		//Accessibility enhancements

		// $('.ct16t2 > li.ct16more').each(function() {
		// 	$(this).attr('tabindex', '0');
		// });

		$('.ct16t2 > li.ct16more > a').each(function() {
			$(this).attr('href', '#');
		});		

	}

	// Create top triangle for dropdowns
	//$('.ct16more > a').append('<span class="ct16icn"></span>');

	// Give t2 links with subs CV icons for mobile
	$('.ct16t2 > li.ct16more > a').each(function(){
		$(this).parent('li').attr('data-width', $(this).outerWidth(true));
		if($(this).next().is('.ct16t3')) {
			$(this).addClass('ct16mobilemore').attr('tabindex','0').append('<span class="icn-cv-down"></span>');
		}
	});

	$('.ct16w1 h2').on('click', function(){
		//console.log('h2 - click');
		$(this).toggleClass('ct16mobileopen');
		$(this).closest('.ct16').toggleClass('ct16mobileopenmain');
		$('.ct16w2').slideToggle(300);
	});

	//$('.ct16t2 > li.ct16submore > ul > li.ct16more > a').on('click touchstart', function(e){
	//	return false;
	//});

	// Main Nav
	function ct16Nav() {
		var NavWidth = 0;
		var mainNavWidth = 0;
		var mainLastItemWidth = 0;
		var mainLastItemSubWidth = 0;
		var mainlastItem;
		var mainlastItem = $('.ct16t1>li:visible').not('.current').last();
		var mainLastItemWidth = mainlastItem.outerWidth( true );
		var mainLastItemSubWidth = mainlastItem.find('> ul').width() || 0 ;
		$('.ct16t1>li').not(':hidden').not(':last-child').each(function(index) {
			NavWidth += parseInt($(this).width(), 10);
		});
		var mainLastItemTotalWidth = Math.max(mainLastItemWidth, mainLastItemSubWidth);
		var mainNavWidth = (NavWidth + mainLastItemTotalWidth);
		var mainavailablespace = $('.ct16w1').width();
		if (mainNavWidth > mainavailablespace) {
			var mainlastItemv = $('.ct16t1 > li:not(.ct16mainmore)').not('.current').last();
			mainlastItemv.attr('data-width', mainlastItemv.outerWidth(true));
			mainlastItemv.prependTo($('.ct16mainmore > ul'));
			ct16Dropdowns();
		} else {
			var firstSubMoreElement = $('.ct16mainmore > ul li').first();
			if (firstSubMoreElement.length > 0) {
				if (mainNavWidth + firstSubMoreElement.data('width') < (mainavailablespace)) {
					firstSubMoreElement.insertBefore($('.ct16mainmore'));
					ct16sort();
					ct16Dropdowns();
				}
			}
		}
		if ($('.ct16t1 .ct16mainmore > ul li').length > 0) {
			$('.ct16t1 .ct16mainmore').addClass('ct16submoreshow');
		} else {
			$('.ct16t1 .ct16mainmore').removeClass('ct16submoreshow');
		}
	}

	// Sub Nav
	function ct16SubNav() {
		var subNavWidth = 0;
		var submainNavWidth = 0;
		var submainLastItemWidth = 0;
		var submainLastItemSubWidth = 0;
		var submainlastItem;
		var submainlastItem = $('.ct16t1>li>.ct16t2>li:visible').not('.current').last();
		var submainLastItemWidth = submainlastItem.outerWidth( true );
		var submainLastItemSubWidth = submainlastItem.find('> ul').width() || 0 ;
		$('.ct16t1>li>.ct16t2>li:visible').each(function(index) {
			subNavWidth += parseInt($(this).width(), 10);
		});
		var submainLastItemTotalWidth = Math.max(submainLastItemWidth, submainLastItemSubWidth);
		var submainNavWidth = ((subNavWidth - submainLastItemWidth) + submainLastItemTotalWidth);
		var submainavailablespace = $('.ct16t2').width();
		if (submainNavWidth > submainavailablespace) {
			var lastItemv = $('.ct16t1 > li.current .ct16t2 > li:not(.ct16submore)').last();
			lastItemv.attr('data-width', lastItemv.outerWidth(true));
			lastItemv.prependTo($('.ct16submore > ul'));
			ct16Dropdowns();
		} else {
			var subfirstSubMoreElement = $('.ct16submore > ul li').first();
			if (subfirstSubMoreElement.length > 0) {
				if (submainNavWidth + subfirstSubMoreElement.data('width') < (submainavailablespace)) {
					subfirstSubMoreElement.insertBefore($('.ct16t1 > li .ct16submore'));
					ct16Dropdowns();
				}
			}
		}
		if ($('.ct16t1 > li.current .ct16submore > ul li').length > 0) {
			$('.ct16t1 > li.current .ct16submore').addClass('ct16submoreshow');
		} else {
			$('.ct16t1 > li.current .ct16submore').removeClass('ct16submoreshow');
		}
	}

	function ct16stickify() {
		ct16sticky = new Waypoint.Sticky({
			element: $('.ct16-wrapper')[0],
			wrapper: '<div class="ct16-sticky-wrapper" />',
			stuckClass: 'ct16stuck',
			handler: function (dir) {
				if (dir === "down") {
					if ($('.herotabs')[0]) {
						$('.ct16-wrapper').closest(".ct16-sticky-wrapper").addClass('ct16notransform');
					}
				} else {
					$('.ct16-wrapper').closest(".ct16-sticky-wrapper").removeClass('ct16notransform');
					Waypoint.disableAll();
					Waypoint.enableAll();
				}
			}
		});
	};

	function ct16setup() {
		if ($(window).outerWidth() >= 670 && $(window).outerHeight() > 375) {
			ct16Nav();
			ct16SubNav();
			var t1height = $('.ct16t1').height();
			var t2height = $('.ct16t2').height();
			var t3height = $('.ct16submore > .ct16t3').height();
			//if (!$(".ct16-sticky-wrapper")[0] && ($('.ct16-wrapper').attr('data-ct16sticky'))) {
			//	ct16stickify();
			//}
			//if ($(window).outerHeight() < (t1height + t2height + t3height)) {
			//	ct16sticky.destroy();
			//}
			$('.ct16subopen').each(function(){
				$(this).removeClass('ct16subopen').next('ul').slideDown();
			});
			$('.ct16shadow').css('height', t2height);
		} else {
			//if (ct16sticky != '') {
			//	ct16sticky.destroy();
			//}
			if ( $('.ct16t1 > li.ct16mainmore > ul').children().length > 0 ) {
				$('.ct16t1 > li.ct16mainmore > ul').children('li').each(function () {
					$(this).insertBefore($('.ct16mainmore'));
				});
			}
			if ( $('.ct16t1 > li.current .ct16submore > ul').children().length > 0 ) {
				$('.ct16t1 > li.current .ct16submore > ul').children('li').each(function () {
					$(this).insertBefore($('.ct16t1 > li.current .ct16submore'));
				});
			}
			ct16sort();
		}
		setupLastLinkListener();
	}

	function ct16init(){
		if (ct16counter < ct16RunCount){
			ct16counter++
			window.setTimeout(ct16init, 10);
			ct16setup();
			ct16sort();
			ct16Dropdowns();
		}
		else {
			$('.ct16-wrapper').addClass('ct16loaded');
		}
	}

	ct16init();

	$(window).on('resize',function(e){
		ct16setup();
	});

	$('.ct16').on('pointerleave focusout', '.ct16more.ct16hvr', ct16closetwoBtnFunction);
	function ct16closetwoBtnFunction(e){
		//console.log('pointerleave', e.type);
		if ($(window).outerWidth() >= 670) {
			if (e.pointerType === 'touch') {
				//console.log('ptype touch', e.pointerType);
				e.stopPropagation();
				e.preventDefault();
			}
			if (e.pointerType === 'mouse') {
				//console.log('ptype mouse', e.pointerType);
			}
		}
	}
	
	$('.ct16').on('mouseleave', '.ct16more.ct16hvr', ct16closeBtnFunction);
	function ct16closeBtnFunction(e){
		if ($(window).outerWidth() >= 670) {
			if (e.type === 'mouseleave') {
				//console.log('mouseleave', e.type);
				$('.ct16more').removeClass('ct16hvr');
				//e.stopPropagation();
				//e.preventDefault();
			}
		}
	}

//	const para = document.querySelector('.ct16more');
//
//	para.addEventListener('pointerleave', (event) => {
//		 console.log('Pointer left element');
//		 e.stopPropagation();
//		e.preventDefault();
//	});
//
//	if (window.PointerEvent) {
//		console.log('pointer events');
//	}

	//Creates dropdown mouseleave event
	//	$(document).on('mouseleave', '.ct16more.ct16hvr .ct16t3', ct16closeFunction);
	//	function ct16closeFunction(e){
	//		if(e.target.tagName.toLowerCase() === 'a'){
	//			return false;
	//		}
	//		if ($(window).outerWidth() >= 670) {
	//			$('.ct16more').removeClass('ct16hvr');
	//		}
	//		console.log('mouseleave2',e.type);
	//	}

	// $(document).on('focusin', '.ct16t1>li.ct16more, .ct16t2>li.ct16more', ct16focusFunction);



	function setupLastLinkListener() {
		if ($('.ct16t2>li').last().hasClass('ct16submoreshow')) {
			//More menu is showing
			$('.ct16submore').find('.ct16t3 a').last().on('focusout', ct16focusOutFunction);
		}
		else {
			$('.ct16t2>li').not('.ct16submore').last().find('a').last().on('focusout', ct16focusOutFunction);
		}
	}

	function ct16focusOutFunction(e){
		$('.ct16more').removeClass('ct16hvr');
		return false;
	}	

	$('.ct16').on('touchstart mouseover click', '.ct16t1>li.ct16more>a, .ct16t2>li.ct16more>a', ct16moreFunction);
	function ct16moreFunction(e){
		if (!flag) {
			flag = true;
			var ct16morelnk = $(e.currentTarget).parent('li');
			//MORE LINKS
			if($(ct16morelnk).is('.ct16submore, .ct16mainmore')) {
				if(ct16morelnk.is('.ct16hvr')) {
					ct16morelnk.removeClass('ct16hvr');
				}
				else {
					setTimeout(function(){
						$('.ct16more').removeClass('ct16hvr');
						ct16morelnk.addClass('ct16hvr');
					}, 10);
				}
			}
			//LINKS WITH DROPDOWNS
			else {
				//console.log('not more');
				//MOBILE
				if ($(window).outerWidth() < 670) {
					//console.log('mobile');
					if (e.type == 'click') {
						if($(ct16morelnk).is('.ct16hvr')) {
							$(ct16morelnk).removeClass('ct16hvr');
						}
						else {
							setTimeout(function(){
								$('.ct16more').removeClass('ct16hvr');
								$(ct16morelnk).addClass('ct16hvr');
							}, 10);
						}
						e.stopPropagation();
						e.preventDefault();
					}
					if (e.type == 'focus') {
						//console.log('focus',e.type);
					}
					if (e.type == 'focusin') {
						//console.log('focusin',e.type);
						//return false;
						e.stopPropagation();
						e.preventDefault();
					}
					if (e.type == 'touchstart') {
						//console.log('touchstart',e.type);
					}
					if (e.type == 'mouseover') {
						//console.log('mouseover',e.type);
					}
					if (!e.type == 'mouseover') {
						//debugger;
					}
				}
				//DESKTOP
				else {
					if (!flagtwo) {
						flagtwo = true;
						setTimeout(function(){ flagtwo = false; }, 100);
						//console.log('desktop e.type',e.type);
						if (e.type == 'touchstart') {
							//console.log('desktop touchstart',e.type);
							if($(ct16morelnk).is('.ct16hvr')) {
							 $(ct16morelnk).removeClass('ct16hvr');
							}
							else {
							 setTimeout(function(){
							 	$('.ct16more').removeClass('ct16hvr');
							 	$(ct16morelnk).addClass('ct16hvr');
							 }, 10);
							}
							e.stopPropagation();
							e.preventDefault();
							//console.log('desktop touchstart2',e.type);
						}
						if (e.type == 'click') {
							//console.log('desktop click',e.type);
						}
						if (e.type == 'focus') {
							//console.log('desktop focus',e.type);
						}
						if (e.type == 'focusin') {
							//console.log('desktop focusin',e.type);
							e.stopPropagation();
							e.preventDefault();
						}
						if (e.type == 'mouseover') {
							//console.log('desktop mouseover',e.type);
							if($(ct16morelnk).is('.ct16hvr')) {
								$(ct16morelnk).removeClass('ct16hvr');
							}
							else {
								setTimeout(function(){
									$('.ct16more').removeClass('ct16hvr');
									$(ct16morelnk).addClass('ct16hvr');
								}, 10);
							}
							e.stopPropagation();
							e.preventDefault();
							//console.log('desktop mouseover1',e.type);
						}
					}
				}
			}
			setTimeout(function(){ flag = false; }, 100);
		 }
	}

	//Prevent Click on More Links
	$('li.ct16submore > a, li.ct16mainmore > a').on('click', function(e){
		//console.log('prevent more clicks');
		return false;
	});

	$('.ct16t1>li.ct16more>a, .ct16t2>li.ct16more>a').on('touchstart', function(e){
		if (e.type == 'touchstart') {
			var ct16morelnk = $(e.currentTarget).parent('li');
			if($(ct16morelnk).is('.ct16hvr')) {
				$(ct16morelnk).removeClass('ct16hvr');
			}
			else {
				setTimeout(function(){
					$('.ct16more').removeClass('ct16hvr');
					$(ct16morelnk).addClass('ct16hvr');
				}, 10);
			}
			return false;
		}
		e.stopPropagation();
		e.preventDefault();
		//console.log('touchstart1',e.type);
	});


	// $('.ct16t1>li.ct16more>a, .ct16t2>li.ct16more>a').focusin(function(e) {
	// 	$( this ).find( "span" ).css( "display", "inline" ).fadeOut( 1000 );
	// });

	$(document).on('touchstart click', function(e) {
		if (!$(e.target).closest('.ct16').length)	 {
			//console.log('touchstart or click to close nav');
			$(".ct16more").removeClass("ct16hvr");
			$('.ct16w1 h2').removeClass('ct16mobileopen');
			$('.ct16w1 h2').closest('.ct16').removeClass('ct16mobileopenmain');
			if ($(window).outerWidth() < 670) {
				$('.ct16w2').slideUp(300);
			}
		}
	});

	var ct16resizeTimer;
	window.addEventListener("orientationchange", function() {
		clearTimeout(ct16resizeTimer);
		setTimeout(ct16setup, 300);
	});




	//Accessibility Enhancements
	var allHeadlines = '.ct16t2 > li > a';
	$(allHeadlines).attr('tabindex','0');

	var liHeadlines =  '.ct16t2 > li';

	// Define values for keycodes
	var VK_ENTER      = 13;
	var VK_TAB		  = 9;

	$('.ct16t2').attr('aria-role','menubar');
	$(liHeadlines).attr('role','none');
	$('.ct16mobilemore').attr('role','menuitem').attr('haspopup','true').attr('aria-expanded','false');
	$('.ct16t3').attr('aria-role','menu');
	$('.ct16t3').attr('aria-hidden','true');
	$('.ct16t3 > li').attr('role','none');
	$('.ct16t3 > li > a').attr('role','menuitem').attr('tabindex','-1');
	$('li:not(.ct16mainmore) .ct16t3').css('display','none');

	$(allHeadlines).keyup(function(e) {
		if (e.keyCode === VK_TAB) {
			
			var $menuItems = $(this).find('.ct16t3>li > a');
			$(this).find('a').not(".ct16more .ct16more a").first().attr('tabindex','-1').attr('role','menu-item');
			if ($(e.target).find('.ct16t3[aria-hidden="false"]')) {
				//console.log($(e.target),'forward tab');
			}
			else {
				$(e.target).next().focus();
			}
			
			// SHIFT + TAB
			if (e.shiftKey) {
				$(this).prev().focus();
			}
		}
	  });

	  $(liHeadlines).keyup(function(e) {
		//console.log(liHeadlines);
		if (e.keyCode === VK_ENTER) {
			if ( $(this).hasClass('ct16hvr') ) {
				//console.log('closing');
				$(this).find('a').first().attr('aria-expanded','false');
				$(this).find('.ct16t3').first().attr('aria-hidden','true').css('display','none');
				$(this).removeClass('ct16hvr');
			}
			else {
				$('.ct16more > a').attr('aria-expanded','false');
				$('.ct16t3').attr('aria-hidden','true').css('display','block');
				if ($('.ct16more a').is(":focus") || $('.ct16more').is(":focus")) {
					$('.ct16link').attr('tabindex','-1');
					$(this).find('a').attr('role','menuitem').attr('tabindex','0');
					$('.ct16more').removeClass('ct16hvr');
					$(this).addClass('ct16hvr');
					$(this).find('a').first().attr('aria-expanded','true');
					$(this).find('.ct16t3').first().attr('aria-hidden','false');
				}
				else {
					$('.ct16more').removeClass('ct16hvr');
					$(this).find('a').first().attr('aria-expanded','false');
					$(this).find('.ct16t3').first().attr('aria-hidden','true');
				}
			}
		}
	  });

	  //Mobile a11y enhancements

});

/*! CT17 */
OCOM.register(function ct17($) {
	'use strict';

	//Create Links
	$('.ct17w4 li a').each(function(i, ct17_links){
		$(ct17_links).attr("data-id","ct17id" + i);
	});
	
	//Create Targets
	$('.ct17w5 li').each(function(i, ct17_targets){
		$(ct17_targets).attr("id","ct17id" + i);
	});

	$('.ct17').each(function() {
		var ct17 = $(this);
		setTimeout(function(){
			$('.ct17current').find('a').each(function() {
				$('#' + $(this).data('id')).fadeIn(400);
			});
		}, 200);

		//Desktop
		$(ct17).find('.ct17w3').on('click', '.ct17w4:not(.ct17mobileopen) li a', function(e) {
			e.preventDefault();
			var ct17w4 = $(e.currentTarget).closest('.ct17w4');
			if (!$(e.currentTarget).closest('.ct17current')[0]) {
				$(ct17w4).find('li').removeClass('ct17current');
				setTimeout(function(){
					$(e.currentTarget).parent('li').addClass('ct17current');
				}, 150);
				$(ct17).find('.ct17w5 li').fadeOut(100);
				$('#' + $(this).data('id')).delay(100).fadeIn(400);
			}
			else {
				//Open mobile
				if ($(window).outerWidth() <= 450) {
					$(ct17w4).addClass('ct17mobileopen');
				}
				$(ct17w4).find('li:not(.ct17current)').show().removeClass('ct17current');
			}
		});

		//Mobile
		$(ct17).find('.ct17w3').on('click', '.ct17mobileopen li a', function(e) {
			e.preventDefault();
			var ct17w4 = $(e.currentTarget).closest('.ct17w4');
			if (!$(e.currentTarget).closest('.ct17current')[0]) {
				$(ct17w4).find('li').removeClass('ct17current');
				$(e.currentTarget).parent('li').addClass('ct17current');
				$(ct17w4).find('li:not(.ct17current)').hide();
				$(ct17).find('.ct17w5 li').fadeOut(100);
				$('#' + $(this).data('id')).delay(110).fadeIn(400);
				$(ct17w4).removeClass('ct17mobileopen');
			}
			else {
				$(ct17w4).find('li:not(.ct17current)').hide();
				$(ct17w4).removeClass('ct17mobileopen');
			}
		});

	});

});

/*! CW43 */
var cw43twinterval = 0;
$(document).ready(function(){
	if($('.cw43:not(.cw43v1,.cw43v2)')[0]){
		//despite the existence of twitter event callback, we still need to poll to determine when the dynamic events get styled
		cw43twinterval = setInterval (function() {return cw43twitCheck();}, 100);
	}

	$('.cw43').not(".cw43v1,.cw43v2").each(function(){
		var ht = $(this).attr('data-height');
		$(this).children('a.twitter-timeline').attr('height',ht).wrap('<div class="cw43w1"></div>');
		// for all but IE8
	    if(document.addEventListener){
			$(this).find('.cw43w1').css('opacity','0');
		}
	});

});
function cw43twitCheck() {
	$('.cw43').not(".cw43v1,.cw43v2").each(function(){
		var timeline = $(this).find('iframe').contents().find('.timeline-Body');
		if ($(timeline).length > 0) {
			cw43styleTimeline(this);
		}	
	});
}
function cw43styleTimeline(context) {
	var timeline = $(context).find('iframe').contents().find('.timeline-Widget');
	//need to wait until .timeline styles are dynamically applied before negating them
	if ($(timeline).find('.tweetauthor-avatar').css('display') != 'none') {
		clearInterval(cw43twinterval);
		//timeline.css('height',(parseInt(iframe.css('height')) - 2 ) + 'px');
		// css in a js file, fun right?
		timeline.append('\
			<style type="text/css">\
				.timeline-Widget {background:transparent}\
				.timeline-Body {border-radius:0;width:100%;background:none}\
				.timeline-Viewport {background-color:transparent;max-width:100%!important;margin-bottom:0}\
				.timeline {width:90%}\
				.timeline-Header{display:none!important}\
				.timeline-Tweet {padding:15px}\
				.timeline-Tweet:hover {background:transparent}\
				.SandboxRoot .timeline-Tweet .TweetAuthor-avatar,.TweetAuthor-avatar {width:48px;height:48px}\
				.timeline-Viewport .timeline-Tweet .timeline-Tweet-author,.timeline-Tweet-author {padding-left: 58px}\
				.timeline-Tweet-media,.timeline-Tweet-actions,.SandboxRoot .timeline-Tweet .timeline-Tweet-media,.SandboxRoot .timeline-Tweet .timeline-Tweet-actions {margin-left: 58px}\
				.timeline-TweetList-tweet .timeline-Tweet .timeline-Tweet-text {margin-left:58px;font-size:18px;line-height:1.2}\
				.timeline-TweetList-tweet {border-top:1px solid #cfd6da;background:transparent}\
				.timeline-Tweet-retweetCredit,.timeline-Tweet-brand {display:none}\
				.timeline-Tweet-media {border-radius:6px;overflow:hidden}\
				.timeline-Footer {display:none}\
			</style>\
		');
		// fade in twitter DIV
		$(context).find('.cw43w1').animate({ opacity: 1 }, 200 );
	}
}



$(window).on("load", function () {
	var interval = [], // interval IDs for object detection polling, ms
		pollingDelay = 10, // delay between object detection polls
		tweetLimit = 20, // number of tweets to display
		movers = 3, // number of tweets to transition at the top of the list
		refreshInterval = 1, // feed refresh interval, minutes
		lastID = '0', // last twitter ID, initialized as a string zero
		tweetCap = 100, // maximum number of tweets to display
		oldResults = {},
		isFirstRun = true,
		defaultHeight = 300, // default height if data-height is not set
		adaptToHeight = function (target, match) {
			var matchHt = $(match).outerHeight(),
				headerHt = $(target).closest('.cw43w1').find('.cw43head')[0] ? $(target).closest('.cw43w1').find('.cw43head').outerHeight() : 0,
				defaultHt = 0,
				items;
			if (breakpoint != 'desktop') {
				items = $(target).find(".cw43w3 > ul > li");
				for (var i=0; i < 3; i++) {
					if (items[i]) {
						if ($(items[i]).is(":visible")) {
							defaultHt = defaultHt + $(items[i]).outerHeight();
						} else {
							$(items[i]).css({display: "block", height: "auto","max-height":600,visibity:"hidden"});
							defaultHt = defaultHt + $(items[i]).outerHeight();
							$(items[i]).removeAttr("style");
						}
						
					}					
				}
			} else if (+$(target).closest('.cw43').attr('data-height') > 0) {
				defaultHt = $(target).closest('.cw43').attr('data-height') 
			} else {
				defaultHt = defaultHeight;
			}
			if (breakpoint() == "desktop") {
				$(target).find(".cw43w3 > ul").height(matchHt - headerHt - 1);
			} else {
				$(target).find(".cw43w3 > ul").height(defaultHt);
			}
		},
		AGreaterThanB = function (a, b) {
			if (typeof a === "string" && typeof b === "string") {
				if (a.length > b.length) {
					return true;
				} else if (a.length == b.length){
					if (a > b) {
						return true;
					}
				}
				return false;
			}
		},
		breakpoint = function () {
			return window.getComputedStyle(document.querySelector('.cw43'), ':before').getPropertyValue('content').replace(/\"/g,'');
		},
		display = function (current, count, movers, delay, targetAr) {
			var fuse = 0;
			if (current < movers) {
				fuse = delay * (movers - current);
				setTimeout(function () {
					$(targetAr[current]).css({display: "block", height: "auto"});
					$(targetAr[current]).animate({opacity: 1, "max-height": 600},750);
				}, fuse, "linear");	
			} else {
				$(targetAr[current]).css({display: "block", height: "auto", opacity: 1, "max-height": 600});
			}
		},
		injectFeed = function (target) {
			var feedsrc = $(target).attr("data-feedsrc"),
				template = $(target).attr("data-template");
			if (feedsrc && template) {
				window.HBSINJECT.initialize({
					feedsrc: feedsrc,
					targetObj: target,
					templateName: template,
					polling: true,
					pollDelay: refreshInterval,
					afterInjectionCallback: function () {
						if ($(target).closest('.ch13')[0]) {
							adaptToHeight(target, $(target).closest('.ch13').find('.bcvideo'));
							$(window).on('resize', function () {
								adaptToHeight(target, $(target).closest('.ch13').find('.bcvideo'));
							});
						} else {
							$(target).closest(".cw43v1,.cw43v2").each( function (i, cw43) {
								var ht = $(cw43).attr('data-height');
								if (ht) {
									$(cw43).find(".cw43w3 > ul").height(ht);
								}
							});
						}
						
						var targetAr = $(target).find(".cw43w3 > ul > li"),
							count = targetAr.length > tweetLimit ? tweetLimit : targetAr.length;
							timeout = 0,
							delay = 1500,
							tmpMovers = 0,
							tid = 0;
						if (lastID === '0') {
							// first time run; default number of "movers"
							tmpMovers = movers;
						}
						// set last tweet ID
						lastID = targetAr.first().children("div").attr("data-tweet-id");
						//console.log('after set:' + lastID)
						for (var j = 0; j < count; j++) {
							display(j, count, tmpMovers, delay, targetAr);
						}	
					},
					beforeInjectionCallback: function (jsonresults) {
						var count = jsonresults.statuses.length > tweetLimit ? tweetLimit : jsonresults.statuses.length,
							hasNewRecords = false,
							idAr = [],
							partial,
							targetAr = [],
							newTweets = 0;
						// determine if this is the first run
						if (isFirstRun) {
							isFirstRun = false;
							return jsonresults;
						} else {
							// iterate through json results and flag new tweets
							for (var i = count - 1; i > -1; i--) {
								partial = '';
								if (AGreaterThanB(jsonresults.statuses[i].id_str, lastID)) {
									jsonresults.statuses[i].newclass = "cw43new";
									newTweets++;
									if (!hasNewRecords) {
										hasNewRecords = true;
									}
									// inject the  record onto the top of the tweet list
									partial = WS.tpl["cw43tweetshell"](jsonresults.statuses[i]);
									if (partial) {
										$(target).find(".cw43tweets > ul").prepend(partial);
									}
								}
							}
							targetAr = $(target).find(".cw43w3 > ul > li");
							// remove excess tweets
							if (targetAr.length > tweetCap)	{
								for (var i = tweetCap - 1; i < targetAr.length; i++) {
									targetAr.eq(i).remove();
								}
							}
							for (var j = 0; j < count; j++) {
								display(j, count, newTweets, delay, targetAr);
							}
							// store/reset the id of the latest tweet
							lastID = targetAr.first().children("div").attr("data-tweet-id");
							// cancel the standard injection by returning false
							return false;
						}
					}
				});
			}
		};
	$(".cw43v1,.cw43v2").each( function (i, cw43) {
		var target = $(cw43).find(".cw43w2").first();
		if (propertyExists(target, "data-template")) {
			// poll to check if HBSINJECT is loaded
			interval[i] = setInterval( function () {
				if (objLoaded("HBSINJECT", "initialize")) {
					clearInterval(interval);
					injectFeed(target);
				}
			}, pollingDelay);
		}
	});
});

/*! CW60 */
OCOM.register(function cw60($) {
	'use strict';

	if(!$('.cw60')[0]) { return false; }

	var $window = $(window),
		$container = $('.cw60w1'),
		$categories = $('.cw60w2'),
		$counts = $('.cw60count'),
		$productLists = $('.cw60w3'),
		$pointer = $('<span class="pointer"></span>').prependTo('.cw60w1'),
		hash = window.location.hash,
		mobile = window.innerWidth <= 500,
		touch = $('html').hasClass('touch'),
		resizeTimeout;

	countProducts();
	labelCategories();
	addAriaAttributes();

	$container.on('click', '.cw60w2 > a', onCategoryClick);

	$container.on('click', '.cw60w3 .icn-close', function(e) {
		restoreProductList($('.cw60w3.open'));
	});

	$(document).off('esckeydown.cw60').on('esckeydown.cw60', function(e) {
		restoreProductList($('.cw60w3.open'));
	});

	$window.off('resize.cw60').on('resize.cw60', onWindowResized);

	$window.off('orientationchange.cw60').on('orientationchange.cw60', function(e) {
			// close any open product list on orientation change
			// to avoid layout/reflow issues
			restoreProductList($('.cw60w3.open'));
	});

	$window.off('load.cw60').on('load.cw60', function(e) {
		if(hash.length > 1) {
			// open the linked category on load
			$('a[href="' + hash + '"]').click();
		}
	});

	function countProducts() {

		$counts.each(function() {
			var $count = $(this),
				$products = $count.closest('.cw60w2').find('.cw60w4');

			$count
				.text($count.text().replace(/(#|\d+)/, $products.length))
				.css({ visibility: 'visible' });
		});
		return false;
	}

	function onCategoryClick(e) {

		var $category 	 = $(e.currentTarget).closest('.cw60w2'),
				$link        = $category.find('> a'),
				$currList    = $('.cw60w3.open'),
				categoryID   = $category.attr('data-guid'),
				$productList = $('[data-parent="' + categoryID + '"]'),
				$closeIcon   = $('<span class="icn-close beforelightslate"></span>'),
				currRow      = $category.attr('data-row'), // must use attr
				$rowLast     = $('[data-row="' + currRow + '"]:last'),
				offset, height;

		if(window.history.pushState) {
		    window.history.pushState(null, null, $link.attr('href'));
		} else {
		    window.location.hash = $link.attr('href');
		}

		if(!$productList.find('.icn-close').length) {
			$productList.prepend($closeIcon);
		}

		// toggle whether the list should open or close
		// use data so we don't force close
		$productList.data('open', !$productList.data('open'));
		$link.toggleClass('current');

		restoreProductList($currList);

		if(!mobile) {
			// kill the flexbox hack on mobile
			// since we have a one column view
			$productList.insertAfter($rowLast);
		}

		if($pointer.data('row') !== $category.attr('data-row')) {
			hidePointer();
		}

		// only set to current if this click has opened the products list
		if($productList.data('open')) {

			// get calculated height when open
			height = $productList
								.css({ height: '', padding: '' })
								.addClass('open')
								.outerHeight();

			$productList
				.outerHeight(0)
				.animate({
					height: height,
					paddingLeft: mobile ? '0' : '2em',
					paddingRight: mobile ? '0' : '2em',
					paddingTop: '2em',
					paddingBottom: '1em'
				}, {
					duration: 400,
					// easing: 'easeInOutSine',
					always: function() {
						 // gross hack to fix heading alignment due to flexbox space-around :(
						$productList.find('> h5').offset({
							left: $productList.find('.cw60w4:first').offset().left
						});
						// opacity change after animation
						$productList.addClass('current')
							.find('a')
							.removeAttr('aria-hidden')
							.attr('tabindex', 0);
						// due to browser inconsistencies, we have to
						// wait until animation is done to set pointer pos
						setPointerPos($link, $productList);

						// check if category is within viewport using generic-inviewport plugin
						// and scroll category to top if it is outside the viewport
						if(!$category.inViewport()) {
							// adjust for sticky nav height
							offset = $('[class*="stuck"]').first().outerHeight() || 0;
							$('html, body').animate({ scrollTop: $category.offset().top	- offset }, 400);
						}
					}
				});
		} else {
			// reset pointer row if product list is toggled closed
			$pointer.data('row', 0);
		}

		addAriaAttributes();

		return false;
	}

	function restoreProductList($currList) {

		var $parent,
			guid;

		// bail if nothing's open
		if($currList.length === 0) return false;

		guid = $currList.data('parent');
		$parent = $('[data-guid="' + guid + '"]');

		$currList
			.data('open', false)
			.removeClass('current')
			.animate({
				height: 0,
				padding: 0
			}, {
				duration: 400,
				// easing: 'easeInOutSine',
				always: function() {
					// use the always handler so that if we need
					// to kill the animation, the list still gets
					// put back into place
					hidePointer();
					$currList
						.removeClass('open')
						.appendTo($parent);
					$parent.find('> a').removeClass('current');
				}
			});
		return false;
	}

	function setPointerPos($target, $currList) {
		$categories.removeClass('current');
		$target.closest('.cw60w2').addClass('current');

		// var left = $target.position().left + ($target.outerWidth() / 2),
		// 		top = $currList.position().top - $pointer.outerHeight() * 1.5,
		// 		currRow = $target.closest($categories).attr('data-row'),
		// 		prevRow = $pointer.data('row') || 0;

		// if(currRow !==  prevRow) {
		// 	$pointer.addClass('initial');
		// 	setTimeout(function() {
		// 		$pointer.removeClass('initial');
		// 	}, 200);
		// }

		// $pointer.css({
		// 	left: left,
		// 	top: top,
		// 	opacity: 1
		// }).data('row', currRow);

		return false;
	}

	function hidePointer() {
		$categories.removeClass('current');
		// $pointer
		// 	.css({
		// 		opacity: 0
		// 	});
		return false;
	}

	function onWindowResized(e) {
		clearTimeout(resizeTimeout);
		resizeTimeout = setTimeout(function() {
			mobile = window.innerWidth <= 500;
			if(!touch) {
				// prevent scrolling (show/hide address bar)
				// from triggering resize on phone and closing the list
				restoreProductList($('.cw60w3.open'));
			}
			// preemptively kill animations to avoid layout bugs
			$productLists.finish();
			$pointer.data('row', 0);
			labelCategories();
		}, 100);
		return false;
	}

	function labelCategories() {

		var row = 1,
			prevoffset = 0,
			guid = 0,
			offset;
		$('.cw60w2.extra').remove();
		$categories.each(function() {

			var $category    = $(this),
					$productList = $category.find($productLists),
					$link        = $category.find('> a'),
					$categoryTitle, categoryHref;

			// only need to initialize these once
			if(!$category.attr('data-guid')) {

				$categoryTitle = $('<h5>' + $category.find('h6').text() + '</h5>');
				categoryHref = $link.attr('href');

				// set an id on parent/child to allow for easy reinsertion later
				$category
					.attr('data-guid', guid);
				$productList
					.attr('data-parent', guid)
					.attr('id', categoryHref.slice(1))
					.prepend($categoryTitle);

				guid++;
			}

			mobile ? $link.addClass('icn-plus') : $link.removeClass('icn-plus');

			// store row references
			offset = parseInt($category.offset().top);

			if(offset !== prevoffset) {
				row++;
				prevoffset = offset;
			}
			$category.attr('data-row', row);
		});
		
		var firstRow = $('.cw60w2:first').attr('data-row');
		var lastRow = $('.cw60w2:last').attr('data-row');
		var neededEls = $('[data-row="' + firstRow + '"]').length - $('[data-row="' + lastRow + '"]').length;
		for (var i=0;i<neededEls;i++){
			$('.cw60w1').append('<div class="cw60w2 extra"></div>');
		}
		return false;
	}

	function addAriaAttributes() {
		$productLists.not('.current').find('a')
			.attr('aria-hidden', 'true')
			.attr('tabindex', -1);
	}

});


/*! CW64 */
OCOM.register(function cw64($) {
	'use strict';

	$('.cw64').each(function() {

		var $cw64 = $(this),
				$cw64w3 = $cw64.find('.cw64w3'),
				$cw64w5 = $cw64.find('.cw64w5'),
				$img = $('.cw64w6 > img'),
				$links = $cw64w3.find('.icn-circle-list > li');

		convertLinks();

		$img
			.on('inview', preloadImgs)
			.inView();

		$cw64w5.prepareHeightTransition();

		ariaAttributes();

		// dupe button for centered on image, >1180px viewports
		// $cw64.find('.cw64w4 + .obttns').clone().appendTo('.cw64w6').addClass('obttn-center');

		$cw64.on('click', '.icn-circle-list > li', onItemClicked);
		$cw64.on('focus', '.icn-circle-list > li', addKeyUpHandler);

		$cw64.addClass('initialized');

		function convertLinks() {
			// wrap items in anchor tags for metrics tracking
			$links.find('> span').wrap(function() {
				return '<div class="cw64w7">'
									+' <a href="#open-'
										+ $(this).text().replace(/\W+/g, '-').toLowerCase()
									+ '"></a>'
								+ '</div>';
			});
		}

		function onItemClicked(e) {

			var $link = $(this),
					src = $link.data('img');

			if($(e.target).closest('.cw64w5').length) { return true; }
			if(!e.isTrigger) {

				e.preventDefault();

				$link.toggleClass('current');

				if($link.hasClass('current')) {

					$link
						.parent('.icn-list').addClass('cw64isopen').end()
						.find('a')
						.attr({
							'tabindex': '0'
						})
						.removeAttr('aria-hidden');

					// image swap
					$img
						.closest('.cw64w6')
						.css({
							backgroundImage: 'url(' + $img[0].src + ')'
						});
					$img
						.removeClass('inview')
						.attr('src', src);

					setTimeout(function() { $img.addClass('inview'); }, 400);

				} else {

					$link.parent('.icn-list').removeClass('cw64isopen');

					ariaAttributes();

					$link.blur();

				}

				$links.not($link).removeClass('current');

				// if the icon is clicked, we broadcast a click event from
				// the anchor tag for metrics, but check if isTrigger
				// to avoid double calling the handler
				return (!/^(A|SPAN)$/.test(e.target.tagName) &&
								$link.find('.cw64w7 > a').trigger('click')) || 1;
			}
		}

		function ariaAttributes() {
			$links
				.attr({ 'tabindex': 0 })
				.find('.cw64w7 > a').attr({ 'tabindex': -1 }).end()
				.find('.cw64w5')
				.each(function() {
					$(this).find('a').attr({
						'aria-hidden': true,
						'tabindex': '-1'
					});
				});
		}

		function addKeyUpHandler() {
			$links.off('keyup.cw64');
			$(this).on('keyup.cw64', function(e) {
				return (e.keyCode === 13) && // Enter key
					onItemClicked.call(this, e);
			});
		}

		function preloadImgs() {
			$cw64.find('[data-img]').each(function() {
				var img = new Image(),
						src = $(this).data('img');
				img.src = src;
			});
		}

	});
});


/*! CW65 */
OCOM.register(function cw65($) {
	'use strict';

	var $cw65v1arr = $('.cw65v1'),
			config = {
				default: function() {
					return {
						json: this.rss && this.rss.channel.item,
						link: this.link,
						description: this.description,
						title: this.title
					};
				},
				attributes: function() {
					return {
						json: this.rss && this.rss.channel.item,
						link: this.link && this.link['#text'],
						description: this.description && this.description['#text'],
						title: this.title && this.title['#text']
					};
				},
				compendium: function () {
					return {
						json: this,
						link: this.web_url,
						description: this.fields && this.fields.Description || this.body || this.body_text,
						title: this.title
					};
				}
			},
			interval;

	var prepJSON = function(endpoint, json) {

		var $cw65 = this,
				// only used for html entity conversion, just create it once
				$t = $('<textarea />'),
				colors = $cw65.data('colors') ?
					$cw65.data('colors').split(',')
					: [
						'orange',
						'burgundy',
						'darkblue',
						'green',
						'blue'
					],

				// set the interval to inject dynamic
				// 	feeds into the static markup
				inj = $cw65.data('pos') ? parseInt($cw65.data('pos'),10) - 1 : 2,
				i = 0,
				count = 0,
				// 	configType defined based on url endpoint path / query param
				configType = /\/api\//.test(endpoint) && 'compendium' ||
										/attributes=1/.test(endpoint) && 'attributes' ||
										'default',
				records = config[configType].call(json).json,
				maxfeeditems = (!$cw65.data('maxfeeditems')) ? 0 : $cw65.data('maxfeeditems'),
				blogtag = $cw65.data('blogtag'),
				panels = $cw65.find('a.col-item').get(),
				panelData = panels.map(function(panel) {

					var $panel = $(panel);

					return {
						link: $panel.attr('href'),
						tag: $panel.find('.cw65w2 .cw65tag').text(),
						title: $panel.find('.cw65w2 .bctxt').text(),
						// pass any publisher defined attrs into template
						//  IE doesn't support getAttributeNames, so need to use attributes prop
						attrs: Array.prototype.slice.call($panel[0].attributes)
							.map(function(attr) {
								return attr.name;
							})
							.reduce(function(obj, attr) {
								if(!/href|class/.test(attr)) {
									obj[attr] = $panel.attr(attr);
								}
								return obj;
							}, {}),
						description: $panel.find('.col-item-w2').html()
					};
				}),
				feedData = records.length && records.map(function(record) {

					var
							mapped = config[configType].call(record),
							orig = mapped.description,

							// weird trick to convert html entities by stuffing into
							// textarea and pulling innerText back out
							dsc = $t.html(orig).text()
								// to avoid breaking layout
								// 	strip out <a> tags
								// 	strip out <img> tags
								// 	strip out <em> Bylines
								// 	strip out style,class,id attributes
								// 	strip out <p>&nbsp;</p> tags
								.replace(/<\/?a(.*?)>/ig, '')
								.replace(/<img(.*?)>/ig, '')
								.replace(/<p.?><(strong|em)>(?:Written )?By(.*?)<\/p>/ig, '')
								.replace(/\s?(style|class|id|dir)=["'](.*?)["']/ig, '')
								.replace(/<p>(\s|&nbsp;)?<\/p>/ig, ''),

							// find first <p> that is not <img> or byline, at least 80 & up to 300 chars,
							// 	ending at closing tag or punctuation
							regexp = new RegExp('(?:<p(?:.*?)>)?\\s?(?!<em)(.{30,300})' +
																	'(?=([\\s,;.?!]+|<\\/p>))'),

							match = regexp.exec(dsc) && regexp.exec(dsc)[0];

					/* globals isStageSite */
					if(!match) {
						// if we didn't get a match, log the article title to
						//  the console, and return null to be filtered out
						/* eslint no-console:0 */
						(typeof isStageSite === 'function' && isStageSite() && console.log('CW65 Article Parsing Error: ' + mapped.title + '\n' + mapped.link));
						return null;
					}

					// replace <li> tags with <p> tags
					// strip out everything else but <p> tags
					record.description = match
						.replace(/(<\/?)li>/ig, '$1p>')
						.replace(/<\/?(em|span|div|strong)>/ig, '');

					// if there's no ending punctuation or closing tag in the first 300 chars
					// 	the description can run long - we have to truncate it manually
					// 	so look for a space after 300 chars
					// if(record.description.length > 300) {
					// 	record.description = record.description.slice(0, record.description.indexOf(' ', 300));
					// }

					record.tag = blogtag;

					record.link = mapped.link;
					record.title = mapped.title;

					return record;

				}).filter(function(record) {
					// filter out any null records that didn't
					// 	pass the regexp
					return !!record;
				});

		if(panelData.length > 0) {
			// inject a feed item for every third static item
			// 	starting at data-pos if defined or 2

			var postadded = 0;

			for(i = 0; i < panelData.length; i += 3) {
				if (postadded < maxfeeditems || maxfeeditems === 0) {
					panelData.splice(i + inj, 0, feedData.shift());
					postadded += 1;
				}
			}

			// add one more on the end if less than 3 - this ensures that
			// 	there is always at least 3 panels (if only 1 static)
			if(panelData.length < 3) {
				panelData.push(feedData.shift());
			}

			if (maxfeeditems === 0) {
				panelData = panelData.concat(feedData);
			}

		} else {
			// send all feed panels
			panelData = feedData;
		}

		return {

			item: panelData &&
				panelData.length &&
				panelData.map(function(item) {

					// add ellipses to the end of all
					item.description = item.description
						.replace(/([.?!]*\s*(&nbsp;)*(<\/p>)?\s*)$/,
							'&hellip;</p>');

					// get the next color
					item.color = colors[count];

					count++;
					count = count === colors.length ? 0 : count;

					return item;

				})
		};
	};

	/* globals propertyExists, objLoaded */
	interval = setInterval(function () {

		if(objLoaded('HBSINJECT', 'initialize')) {

			clearInterval(interval);

			$cw65v1arr.each(function(i, cw65) {

				var $cw65 = $(cw65),
						$cw65w0 = $cw65.find('.ofeed'),
						feedsrc = $cw65.attr('data-feedsrc'),
						template = $cw65.attr('data-template');

				if(propertyExists($cw65, 'data-template')) {

					if(feedsrc && template) {

						window.HBSINJECT.initialize({
							feedsrc: feedsrc,
							targetObj: $cw65w0,
							templateName: template,
							beforeInjectionCallback: prepJSON.bind($cw65, feedsrc),
							afterInjectionCallback: function() {
								OCOM.ocrsl($cw65);
								$cw65w0.addClass('hbs-initialized');
							}
						});
					}
				}
			});
		}
	}, 10);

});



/*! CW66 */
OCOM.register(function cw66($) {
	'use strict';
	
	$('.cw66').each(function(){

		var cw66 = $(this),
		links = cw66.find('.cw66w5'),
		imgclone = cw66.find('.cw66w10 img').clone(),
		bttnclone =  cw66.find('.cw66w3 .obttns').clone();
	
		if(imgclone[0] && cw66.find('.cw66w9 > .cw66head')[0]){
			cw66.find('.cw66w9 .cw66head').first().after(imgclone);
		}else if(imgclone[0]){
			cw66.find('.cw66w9 > p').first().before(imgclone);
		}

		if(bttnclone[0]){
			cw66.find('.cw66w4').append(bttnclone);
		}

		links
			.attr('data-lightbox','') // must use attr for lightbox target
			.data('theme', 'light')	// set to light theme, no background
			.data('container', 'body') // the container to append lightbox to
			.data('content', '.cw66w6')	// a selector for content, within this
			.data('context', 'this');	 // a context for content selector for content, use this to scope to lightbox link target

	});

});


/*! CW67 */
OCOM.register(function cw67($) {
	'use strict';

	var $cw67arr = $('.cw67'),
			numRecordsDefault = 8,
			resizeTimeout;

	var init = function(i) {

		var $cw67 = $(this),
				$panels = $cw67.find('.col-item'),
				$allPanes = $panels.find('.cw67w2, .cw67w3'),
				$ct14 = $cw67.closest('.ct14');

		$(this).find('.col-framework').addClass('inview');

		// skip js for non hover variation
		if($cw67.is('.cw67v2')) { return; }

		// trim whitespace from blockquote so that :before/:after
		// 	quotation marks don't inadvertantly wrap
		$cw67.find('blockquote').text(function() { return $(this).text().trim(); });

		// temporarily unhide all panels to calc height
		$panels.addClass('show');
		$allPanes.equalHeight(true);
		$panels.removeClass('show');

		// need to call explicitly since after $(document).ready
		OCOM.expandocols();

		$cw67.on('mouseenter mouseleave touchend', '.col-item',
			function(e) {
				// need to preventDefault to avoid multiple events
				// firing on touch, but allow cta button follow
				if(e.type === 'touchend' && e.target.tagName !== 'A') {
					e.preventDefault();
				}
				this.classList.toggle('active');
				$panels.not(this).removeClass('active');
			});

		// make sure resize handler is only attached once per instance
		$(window).off('resize.cw67-' + i).on('resize.cw67-' + i, onWindowResized.bind(null, $allPanes));

		// if within a tab content pane,
		// listen for tabchange and run equalHeight
		if($ct14.length) {
			$ct14.on('ct14tabchange', function(e) {
				var $tabpane = $cw67.closest('.ct14w4');
				return $tabpane.is(e.currentTab) && onWindowResized($allPanes);
			});
		}
	};

	var prepJSON = function(json) {

		var lookup = [],
				extras = [],
				numRecords = $(this).data('numrecords') || numRecordsDefault,
				records = json.contents[0].records
					.map(function(record) {

						var file = record.attributes.CustomerLogoFile[0],
								logo = file.slice(file.lastIndexOf('/')),
								match = /bctid=(\d+)/i.exec(record.attributes.DisplayURL),
								bcid = match && match[1] ? match[1] : null;

						record.attributes.CustomerLogoFile = /https:/.test(file) ?
							file : '//www.oracle.com/assets' + logo;
						record.attributes.isVideoLink = bcid ? true : false;
						record.attributes.isQuoteOnly = record.attributes.QuoteOnly &&
																						record.attributes.QuoteOnly[0] === 'Yes';
						if(record.attributes.isVideoLink) {
							record.attributes.DisplayURL = '?bcid=' + bcid;
						}


						if(lookup.indexOf(logo) > -1) {
							record.extra = true;
							extras.push(record);
						} else {
							record.extra = false;
							lookup.push(logo);
						}
						return record;

					})
					.filter(function(a) {
						return !a.extra;
					})
					.slice(0, numRecords);

		while(records.length < numRecords) {
			records.push(extras.shift());
		}

		return {
			text: $(this).data(),
			records: records
		};
	};

	var onWindowResized = function($panes) {
		clearTimeout(resizeTimeout);
		resizeTimeout = setTimeout(function() {
			$panes.equalHeight(true);
		}, 250);
	};
	/* replace icons with new redwood light pill icons */
	var replaceIcons = function(context) {
		$(context).find(".cw67w2 .icn-arrow").removeClass("icn-arrow").addClass("icn-plus-bttn");
		$(context).find(".cw67w2 .icn-vidplay").removeClass("icn-vidplay").addClass("icn-play-bttn");
	}
	/* globals propertyExists, objLoaded */
	$cw67arr.each(function(i, cw67) {
		var interval = [];
		replaceIcons(cw67);
		if(propertyExists(cw67, 'data-template')) {
			interval[i] = setInterval(function () {
				if(objLoaded('HBSINJECT', 'initialize')) {

					clearInterval(interval[i]);

					var num = $(cw67).data('numrecords') || numRecordsDefault,
							feedsrc = $(cw67).data('feedsrc').replace(/&(?:amp;)?Nrpp=\d+/i, ''),
							template = $(cw67).data('template');
					if(feedsrc && template) {
						window.HBSINJECT.initialize({
							feedsrc: feedsrc + '&Nrpp=' + Math.max(Math.ceil(num * 1.5), num + 10),
							targetObj: $(cw67).find('.col-w1'),
							templateName: template,
							beforeInjectionCallback: prepJSON.bind(cw67),
							afterInjectionCallback: init.bind(cw67, i)
						});
					}
				}
			}, 10);
		} else {
			init.call(cw67, i);
		}
	});

});


/*! CW68 */
OCOM.register(function cw68($) {
	'use strict';

	if(!$('.cw68v1')[0]) return false;

	var resizeTimeout;

	function trHeightCheck() {
		var checkHeight = setInterval(keepCheckingHeight, 250);

		function keepCheckingHeight() {
			var cards = $('.cw68w1 .tr-card').filter('[style*="visible"]');
			var maxHeight = 0;
			cards.each(function() {
					if ($(this).outerHeight() > maxHeight) {
						maxHeight = $(this).outerHeight();
					}
			});
			// console.log(maxHeight);
			if (maxHeight > 0) {
				$('.cw68v1 .trustradius-reviews').height(maxHeight + 20);
				clearInterval(checkHeight);
			}
		}
	}

	function onWindowResized(e) {
		clearTimeout(resizeTimeout);
		setTimeout(trHeightCheck, 250);
	}

	trHeightCheck();
	$('.cw68v1').on('click', 'a.tr-previous-link, .cw68w1 a.tr-next-link', trHeightCheck);
	$(window).resize(onWindowResized);

});


/*! CW69 */

OCOM.register(function cw69($) {
	'use strict';

    var filterSelectors = $('.cw69 #filters').find('input[type="checkbox"]');
    var filteredItems = $('.cw69 #filter-items').find('article');
    var showCount = $('.cw69 #show-count');
    
    showCount.text(filteredItems.length);
    
    //create an array of filters, based on name attribute of checkbox groups
    var filters = [];
    filterSelectors.each(function(){
	    var f = $(this).attr('name');
        filters.indexOf( f ) < 0 && filters.push(f);
	});
	
	disableNoMatches(filteredItems, null);
		
	//run filter when a box is checked
	filterSelectors.on('change', function(e){

		var visibleItems;
		var thisFilter = $(this).attr('name');
		
/* 		filterSelectors.prop("disabled", false); */

		
		//Animate items
		filteredItems.addClass('filtered');

		setTimeout(function () { 
		    filteredItems.removeClass('filtered');
		}, 100);

	        
		//loop through each item to see if they pass each filter
		filteredItems.removeClass('hidden').each(function(){
		    var item = $(this);
		    var hidden = false; //start with all pass
		   
			//check against each filter
			jQuery.each( filters, function( i, v ){
			     
				//get array of all checked of each filter
				 var matches = $('input[name="' + v + '"]:checked').map(function(){return $(this).attr('id');}).get();

				// only run filter if one of the boxes are checked
				if ( matches.length > 0) {

				    //get data attribure of filter
				    var itemVal = item.data(v);
                    
                    //if none match then hide element
				    if(typeof(itemVal) != "undefined") {
					    if(itemVal.constructor === Array) { 
					        if(!hasMatch(matches,itemVal)) { item.addClass('hidden'); }
					    } else {
					        if(matches.indexOf( itemVal ) < 0) { item.addClass('hidden'); }
					    }
				    }
			    } 
			});	
	    });
	    
	    visibleItems = $('.cw69 #filter-items article:not(.hidden)');

	    disableNoMatches(visibleItems, thisFilter);
	    
	    showCount.text(visibleItems.length);

	});
	
	//disable checkboxes if no visible items have that parameter
	function disableNoMatches(els, thisFilter ){

		jQuery.each( filters, function( i, v ){
			 var matches = els.map(function(){return $(this).data(v);}).get();
			 $('.cw69 #filters').find('input[name="' + v + '"]').each(function(){
			     var f = $(this).attr('id');
			     if (v == thisFilter) { 
				 	 if(matches.indexOf(f) > 0) {
					     $(this).prop("disabled", false);
				 	 }
			     } else {
				 	 if(matches.indexOf(f) < 0) {
					     $(this).prop("disabled", true);
						 $(this).prop("checked", false);
				     } else {
					     $(this).prop("disabled", false);
				     }
			     }			     
			 });
		});
	}
	
	function hasMatch(haystack, arr) {
	    return arr.some(function (v) {
	        return haystack.indexOf(v) >= 0;
	    });
	}
	
	
	//clear all filters
	$('#filter-reset').on('click',function(e){
	    e.preventDefault();
		filterSelectors.prop('checked', false).trigger("change");
	});
	
	// show & hide filter groups 
	$('#filter-toggle').on('click',function(e){
	    e.preventDefault();
	    $('#cw69v0-more-filters').toggleClass('expanded');
	    
	    if($(this).hasClass('icn-plus')) {
		    $(this).removeClass().addClass('icn-min').text('Fewer Criteria');
	    } else {
		    $(this).removeClass().addClass('icn-plus').text('More Criteria');
		    $('#cw69v0-more-filters').find('input[type="checkbox"]').prop('checked', false).trigger("change");
	    }
	});
	
});



/*! CW75 */
OCOM.register(function cw75($) {

	if($('.cw75')[0]){ // check for cw75 before running a clock internval -- this js is crashing pages
		var countDownDate = new Date($('.cw75 #clock').data('date')).getTime();
		countDown();
		var clock = setInterval(countDown, 1000);

		function countDown() {
		  var now = new Date().getTime();
		  var until = countDownDate - now;
		  $('#countdown-days').text(pad(Math.floor(until / (1000 * 60 * 60 * 24))));
		  $('#countdown-hours').text(pad(Math.floor((until % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60))));
		  $('#countdown-minutes').text(pad(Math.floor((until % (1000 * 60 * 60)) / (1000 * 60))));
		  $('#countdown-seconds').text(pad(Math.floor((until % (1000 * 60)) / 1000)));

		  if (until < 0) {
			  $('#countdown-days').text('00');
			  $('#countdown-hours').text('00');
			  $('#countdown-minutes').text('00');
			  $('#countdown-seconds').text('00');
			  clearInterval(clock);
		  }
		};

		function pad(d) {
			return (d < 10) ? '0' + d.toString() : d.toString();
		}
	}

	$('.cw75.cw75v1').each(function() {

		var $this = $(this);
		var eventDate = $(this).find('#clock').data('date');
		var $countdownDays =  $(this).find('.days');
		var $countdownHours =  $(this).find('.hours');
		var $countdownMinutes =  $(this).find('.minutes');

		countDown();
		var clock = setInterval(countDown, 1000 * 60); // run for every minute
		function countDown() {
			var now = new Date().getTime();
			var until = new Date( eventDate ) - now;
			var totalEventDays = 30 ;
			var minutesLeft = Math.floor((until % (1000 * 60 * 60)) / (1000 * 60));
			var hoursLeft = Math.floor((until % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
			var daysLeft = Math.floor(until / (1000 * 60 * 60 * 24));

			$countdownDays.text(pad(daysLeft));
			$countdownHours.text(pad(hoursLeft));
			$countdownMinutes.text(pad(minutesLeft));
			var initialOffset = 566;
			var minutesEndPercent =  minutesLeft * (initialOffset / 60);
			var hoursEndPercent = hoursLeft * (initialOffset / 24);
			totalEventDays = daysLeft > totalEventDays ? daysLeft : totalEventDays;
			var daysEndPercent =  daysLeft * (initialOffset / totalEventDays);

			$this.find('#minutes .cw75w4 .cw75circle').css('stroke-dashoffset',minutesEndPercent);
			$this.find('#hours .cw75w4 .cw75circle').css('stroke-dashoffset',hoursEndPercent);
			$this.find('#days .cw75w4 .cw75circle').css('stroke-dashoffset',daysEndPercent);

			if (until < 0) {
				$countdownDays.text('00');
				$countdownHours.text('00');
				$countdownMinutes.text('00');
				clearInterval(clock);
			}
		};

		function pad(d) {
			return (d < 10) ? '0' + d.toString() : d.toString();
		}
	});

});


/*! CW76 */
(function($) {
	var component,
	_insertPortraitsIntoModal = function () {
		var portrait;
		$(".cw76w1 .cw76portrait").each( function (i, context) {
			portrait = $(context).html();
			$(context).closest(".col-item").find(".cw76hidden .cw76w5").prepend($(portrait));
			$(context).closest(".col-item").find(".cw76hidden *").removeClass("txtwhite txtblue txtdarkblue txtlightblue txtred txtdarkred txtlightred txtgreen txtdarkgreen txtlightgreen txtorange txtdarkorange txtlightorange txtblack txtslate txtdarkslate txtlightslate txtburgundy txtdarkburgundy txtlightburgundy");
			$(context).closest(".col-item").find(".cw76hidden .cw76w2").unwrap("a");
		});
	};
	
	var _cw76interval = [];

	var _injectFeed = function(cw76) {
		var featuredAttribute = "Featured Speaker Flag";
		var featuredValueYes = "Yes";  
		var targetObj = $(cw76).find('[data-template]'),
				feedsrc = targetObj.attr('data-feedsrc'),
				template = targetObj.attr('data-template'),
				speakerNames = [];
		if(feedsrc && template) {
			window.HBSINJECT.initialize({
				feedsrc: feedsrc,
				targetObj: targetObj,
				templateName: template,
				beforeInjectionCallback: function(results) {
					var itemCount = results.sectionList[0].items.length,
							participantCount = 0;
					for(var i = 0; i < itemCount; i++) {
						if(results.sectionList[0].items[i].participants) {
							participantCount = results.sectionList[0].items[i].participants.length;
							for(var j = 0; j < participantCount; j++) {
								if(results.sectionList[0].items[i].participants[j].attributevalues  != null) {
									var isFeaturedSpeaker = false;
									var attributeCount = results.sectionList[0].items[i].participants[j].attributevalues.length;
									for(var z = 0; z < attributeCount; z++) {
										if(results.sectionList[0].items[i].participants[j].attributevalues[z].attribute == featuredAttribute) {
											//z = attributeCount + 1;
											if(results.sectionList[0].items[i].participants[j].attributevalues[z].value == featuredValueYes ) {
												//keep this here?
												z = attributeCount + 1;
												isFeaturedSpeaker = true;
											}
										}
									}
									if(isFeaturedSpeaker) {
										var hyphname = results.sectionList[0].items[i].participants[j].firstName.toLowerCase() +
																'-' + results.sectionList[0].items[i].participants[j].lastName.toLowerCase();
										var name = results.sectionList[0].items[i].participants[j].firstName +
																' ' + results.sectionList[0].items[i].participants[j].lastName;
										if(speakerNames.indexOf(name) < 0) {
											speakerNames.push(name);
											results.sectionList[0].items[i].participants[j].display = true;
										}
									}
								}
							}
						}
					}
					return results;
				},
				afterInjectionCallback: function() {
					_insertPortraitsIntoModal();
				}
			});
		}
	};

	var initialize = function() {
		$('.cw76v2').each(function(i, cw76) {
			if(propertyExists(cw76, 'data-template')) {
				_cw76interval[i] = setInterval(function() {
					if(objLoaded('HBSINJECT', 'initialize')) {
						clearInterval(_cw76interval[i]);
						_injectFeed(cw76);
					}
				}, 10);
			}
		});
	};
		
	component = function cw76($) {
		_insertPortraitsIntoModal();
		initialize();	
	};
	
	OCOM.register(component);
	
})(jQuery);

/*! CW77 */
OCOM.register(function cw77($) {
  'use strict';

	var $cw77 = $('.cw77').each(function(){

		var $container = $(this).find('.cw77w2'),
			$navslider = $container.find('.crsl-slider'),
			r2l = $container.closest('.rtl')[0] ? true : false,
			$nav = $('<div class="crsl-nav slick-nav"></div>').appendTo($container),
			$cntcontainer = $(this).find('.cw77w3'),
			$cntslider = $cntcontainer.find('.crsl-slider'),
			resizeTimeout;

		$cntslider.slick({
			appendArrows: $nav,
			infinite: false,
			dots: false,
			swipe: false,
			touchMove: false,
			rtl: r2l,
			slidesToShow: 1,
			slidesToScroll: 1,
			speed: 300,
			fade:true,
			adaptiveHeight: true,
			cssEase: 'cubic-bezier(0.175, 0.885, 0.32, 1.275)',
			useCSS: /(MSIE |Trident\/)/.test(window.navigator.userAgent) ? false : true

		});

		$navslider.slick({
			infinite: false,
			dots: false,
			arrows: false,
			swipe: false,
			touchMove: false,
			rtl: r2l,
			speed: 800,
			asNavFor: $cntslider,
			focusOnSelect: false,
			slidesToShow: 5,
			slidesToScroll: 5,
			useCSS: /(MSIE |Trident\/)/.test(window.navigator.userAgent) ? false : true,
			// these match cg19
			responsive: [
				{
					breakpoint: 1301,
					settings: {
						slidesToShow: 4,
						slidesToScroll: 4
					}
				},
				{
					breakpoint: 1080,
					settings: {
						slidesToShow: 3,
						slidesToScroll: 3
					}
				},
				{
					breakpoint: 600,
					settings: {
						slidesToShow: 2,
						slidesToScroll: 2
					}
				},
				{
					breakpoint: 450,
					settings: {
						slidesToShow: 1,
						slidesToScroll: 1
					}
				}
			]
		});

		$navslider.find('.slick-slide').on('click', function (event) {
			$(this).siblings().removeClass('slick-current');
			$cntslider.slick('slickGoTo', $(this).data('slickIndex'));
			$(this).addClass('slick-current');
		});

		$cntslider.on('afterChange', function (event, slick, currentSlide, nextSlide) {
			var current = $(this).find('.slick-current').data('slickIndex');
			$navslider.slick('slickGoTo', (current));
			$navslider.find('.slick-slide').removeClass('slick-current');
			$navslider.find('.slick-slide[data-slick-index="' + current + '"]').addClass('slick-current');
		});

		checkNavTotal()
		
		$(window).off('resize.cw77').on('resize.cw77', checkNavTotal);

		function checkNavTotal(e) {
			$('.cw77w2').each(function(){
				var w2 = $(this);
				clearTimeout(resizeTimeout);
				resizeTimeout = setTimeout(function() {
					if(w2.find('.slick-slide:not(.slick-active)').length == 0){
						w2.addClass('cw77nonav');
					}else{
						w2.removeClass('cw77nonav');
					}
				}, 100);

			});
			
		}

	});
});

//OCOM.register(function cw77inview($) {
//	$('.cw77').inView();
//}, true);


/*! CW78 */
OCOM.register(function cw78($) {
	'use strict';

	var $divs = $(".cw78w4 > li");

	$('#cw78company').on('click', function (e) {
		e.preventDefault();
		var cw78wrap = $(this).parent();
		if (cw78wrap.is('.asc')) {
			$('.sort-by').removeClass('asc desc selected');
			cw78wrap.addClass('desc selected');
			var sortByCompany = $divs.sort(function (a, b) {
				return ($(a).find(".cname a").text()) > ($(b).find(".cname a").text()) ? 1 : -1;
			});
		} else {
			$('.sort-by').removeClass('asc desc selected');
			cw78wrap.addClass('asc selected');
			var sortByCompany = $divs.sort(function (b, a) {
				return ($(a).find(".cname a").text()) > ($(b).find(".cname a").text()) ? 1 : -1;
			});
		}
		$(".cw78w4").html(sortByCompany);
	});

	$('#cw78adate').on('click', function (e) {
		e.preventDefault();
		var cw78wrap = $(this).parent();
		if (cw78wrap.is('.asc')) {
			$('.sort-by').removeClass('asc desc selected');
			cw78wrap.addClass('desc selected');
			var sortByDate = $divs.sort(function (a, b) {
				var aDate = $(a).find(".adate").attr("data-date").split("/");
				var a = aDate[1]+" "+aDate[0];
				//a = new Date(a).getTime();
				var bDate = $(b).find(".adate").attr("data-date").split("/");
				var b = bDate[1]+" "+bDate[0];
				//b = new Date(b).getTime();
				return a>b ? -1 : a<b ? 1 : 0;
			});
		} else {
			$('.sort-by').removeClass('asc desc selected');
			cw78wrap.addClass('asc selected');
			var sortByDate = $divs.sort(function (b, a) {
				var aDate = $(a).find(".adate").attr("data-date").split("/");
				var a = aDate[1]+" "+aDate[0];
				//a = new Date(a).getTime();
				var bDate = $(b).find(".adate").attr("data-date").split("/");
				var b = bDate[1]+" "+bDate[0];
				//b = new Date(b).getTime();
				return a>b ? -1 : a<b ? 1 : 0;
			});
		}
		$(".cw78w4").html(sortByDate);
	});

});



/*! CW79 */
OCOM.register(function cw79($) {
    if($('.cw79')[0]){
        var $this = $($('section.cw79')[0]);
        var pollConfig = {
            "doc_id": '',
            "ds": 5,
            "flow_id": '',
            "include_results": true,
            "kf": 1,
            "question_id": '',
            "responses": "",
            "results_only": false,
            "survey_id": ''
        };
        var responseText =  $this.data('reponsetext');
        var resultTitle =  $this.data('resultTitle');
        pollConfig.question_id =  $this.data('questionid');
        pollConfig.flow_id = $this.data('flowid');
        pollConfig.survey_id =  $this.data('surveyid');
        pollConfig.doc_id = pollConfig.question_id;
        //remove error mesage on value select
        $this.find('form input[name="poll"]').change(function(){

            $this.find('form .bttn-disabled').removeClass('bttn-disabled');
              $this.find('form button[type="submit"]').removeAttr('disabled');
            // if($this.find('form .oerrormsg').length !== 0){
            //     $this.find('form .oerrormsg').remove();
            // }
        });

        //check for pre selected value
        if($this.find('form input[name="poll"]:checked').val()){
             $this.find('form .bttn-darkgrey').removeClass('bttn-darkgrey');
              $this.find('form button[type="submit"]').removeAttr('disabled');
        }

        $this.find('form').submit(function(e){
            e.preventDefault();
			// $this.find('form .oerrormsg').remove();
            var selectedValue = $this.find('form input[name="poll"]:checked').val();
            if(selectedValue){
                //creating array object for pollConfig
                var a = [{
                    "id":   "q_" + pollConfig.question_id,
                    "response": selectedValue
                }];
                pollConfig.responses = JSON.stringify(a);
                submitPoll(encodeURIComponent(JSON.stringify(pollConfig)));
            }
            // else{
            //     $this.find('form').append('<span class="oerrormsg">Please select at least one value</span>');
            // }
        });

        function submitPoll(postData) {
            var pollURL = "https://ora-java.custhelp.com/ci/ds/get/sessionType/feedback/data/";
            jQuery.ajax({
                url: pollURL + postData + '/callback/response',
                type: 'GET',
                crossDomain: true,
                dataType: 'jsonp',
                jsonpCallback: "response",
                success: function(response) {
                    var results = processPollResult(response.question_results);
                    showPollResult(results);
                },
                error: function(status, message) {
                    console.log('Error: ' + status + ' - Message: ' + message);
                }
            });
        }
        function processPollResult(result) {
			var total = 0,
            percentAsInt = 0,
            remainder = 0;

			for (var i = 0; i < result.length; i++) {
				percentAsInt = parseInt(result[i].percent_total, 10);
				result[i].remainder = result[i].percent_total - percentAsInt;
				result[i].percent_total = percentAsInt;
				total += result[i].percent_total;
			}
			if (total < 100) {
				remainder = 100 - total;
				for (i = 0; i < remainder; i++) {
					if (result[i].percent_total > 0)
						result[i].percent_total++;
					else if (i < 10)
						remainder++;
				}
			}
			return result;
		}
        function showPollResult(results) {
            var results = JSON.parse(results);
            $this.find('.cw79w2 h2').text(resultTitle);
            if(responseText){$this.find('.cw79w2').append("<p>" + responseText + "</p>");}
            var ul = $('<ul class="cw79result">');
            results.forEach(function(v,k){
                var li = "<li><label>" + v.response + "</label><div class='cw79z" + (k+1) + "'>" + pad(Math.round(v.percent_total)) + "%<span style='width:" + Math.round(v.percent_total) + "%;'></span></div></li>";
                ul.append(li);
            });

            $this.find('.cw79w3').html(ul);
        }
        function pad(d) {
            return (d < 10) ? '0' + d.toString() : d.toString();
        }
    }
});


/*! CW81 */
(function($) {
	var component,
		_arrowPosition = {
			'lgdesktop': ['cw81p1','cw81p2','cw81p3','cw81p4'],
			'desktop': ['cw81p1','cw81p2','cw81p3'],
			'tablet': ['cw81p1','cw81p3'],
			'mobile': ['cw81p2']
		},
		_customtxt = {
			'btn':[],
			'cta':{}
		},
		_feedData = {},
		/*
		 * _feedMeta array indexes for attr, input, src.live.args, src.local.files, and type correspond to each
		 * other. This object will be simplified once all feeds are available from Oracle.
		 */
		_feedMeta = {
			'attr': ['data-industry','data-region','data-country','data-tech',null],
			'input': ['.cw81industry select','.cw81region select','.cw81country select','.cw81tech select',null],
			'src': {
				'live': {
					'url': '/wordmaptaxonomy/mapping.json',
					'args': ['industry','region','country','globalsolution','startups']
				},
				'local': {
					'files': [null,null,null,null,'cw81-startups.json']
				},
				'ws': {
					'url': '/ws-lib/helper-scripts/'
				}
			},
			'type': ['omcindustry','region','country','globalsolution','startups']
		},
		_interval,
		_itemsPerRow = {'lgdesktop': 4,'desktop':3,'tablet': 2,'mobile': 1},
		_noresultmsg = 'There are no matches for this filter criteria.',
		// mini-templates for injection  // <div class="cw81tri"></div>
		_snippet = {
			'panel':'<div class="col-item cw81infopanel"><div class="cw81w6"><div class="cw81close icn-img icn-close beforewhite"></div><div class="col-item-w1"><div class="cw81w7"></div></div></div></div>',
			'tag':'<li class="cw81tag" data-wordmapid=""><a><div class="icn-img icn-x-mark">&nbsp;</div><span></span></a></li>',
			'tagSearch': '<li class="cw81tag cw81searchterm"><a><div class="icn-img icn-x-mark">&nbsp;</div><span></span></a></li>',
			'blankcontainer':'<div class="col-w1 col-w1-placeholder">',
			'blankitem':'<div class="col-item cw81placeholder"><a><div class="col-item-w1"><div>&nbsp;</div></div><div class="col-item-w2"><h4>&nbsp;</h4></div></a></div>'
		},
		_startupFeed = '/a/ocom/docs/startup-catalogue.json',
		_startupNames = [],
		_visblocksize = {},
		_waypoints = [],
		/* 
		 * Recursively applies a set of filters in sequence and returns the results
		 */
		_applyFilter = function (collection, filters, counter) {
			var newCollection = $(collection).not('.cw81noresult').filter('[data-category~="' + filters[counter].value + '"]');
			if ($(newCollection).length > 0 && counter - 1 > -1) {
				newCollection = _applyFilter(newCollection, filters, counter - 1);
			}
			return newCollection;
		},
		/*
		 * Binds events.
		 */
		_bindEvents = function (context) {
			var selected = [],
				selectedLen,
				target = [],
				result,
				filteredResults,
				everything = $(context).find('.cw81w3 .col-item'),
				input,
				awesomplete;

			// search
			input = $(context).find('.cw81w2 form input[type="text"]').get(0);
			awesomplete = new Awesomplete(input);
			awesomplete.list = _startupNames;
			_tagHandler(context,selected,awesomplete);
			// select menu events
			for (var i = 0; i < _feedMeta.input.length; i++) {
				if (_feedMeta.input[i] && $(context).find(_feedMeta.input[i])[0]) {

					$(context).find(_feedMeta.input[i]).on('change', function (e) {
						var $items = $(context).find('.cw81w3 .col-w1[data-template] .col-item').not('.cw81noresult'),
							$collection = $(),
							selected = [],
							selectedLen = 0
							result;

						// close info panel if open
						if ($(context).find('.cw81close')[0]) {
							$(context).find('.cw81close').trigger('click');
						}
						$items.addClass('cw81hidden');
						$collection = _getSearchResult($items,awesomplete);
						selected = _getSelectValues(context);
						selectedLen = selected.length;
						if (selectedLen > 0) {
							result = _applyFilter($collection, selected, selectedLen - 1);
						} else {
							result = $collection;
						}
						// handle tags
						_tagHandler(context,selected,awesomplete);
						// set page to 1
						_page(context,1);
						_visibilityHandler(context,result);
					});
				}
			}
			// clicking on tag
			$(context).find('.cw81tags').on('click','li a', function (e) {
				var $items = $(context).find('.cw81w3 .col-w1[data-template] .col-item').not('.cw81noresult'),
					$collection = $(),
					selected = [],
					selectedLen = 0
					result;
				e.preventDefault();

				// close info panel if open
				if ($(context).find('.cw81close')[0]) {
					$(context).find('.cw81close').trigger('click');
				}
				$items.addClass('cw81hidden');

				if ($(e.currentTarget).closest('.cw81tagreset')[0]) {
					// reset search field
					$(context).find('form input').val('');
					// reset pulldowns
					$(context).find('select').each( function (i,select) {
						$(select).get(0).selectedIndex = 0;
					});
				} else {
					// if there's a wordmapid attr, it's a pulldown
					if ($(e.currentTarget).closest('li').attr('data-wordmapid')) {
						// reset pulldown
						$(context).find('option[value="' + $(e.currentTarget).closest('li').attr('data-wordmapid') + '"]').closest('select').get(0).selectedIndex = 0;
					} else {
						// reset search field
						$(context).find('form input').val('');
					}
					
				}
				$collection = _getSearchResult($items,awesomplete);
				selected = _getSelectValues(context);
				selectedLen = selected.length;
				if (selectedLen > 0) {
					result = _applyFilter($collection, selected, selectedLen - 1);
				} else {
					result = $collection;
				}
				// handle tags
				_tagHandler(context,selected,awesomplete);
				// set page to 1
				_page(context,1);
				_visibilityHandler(context,result);

			});
			// search field
			$(context).find('form').on('submit', function (e) {
				var $items = $(context).find('.cw81w3 .col-w1[data-template] .col-item').not('.cw81noresult'),
					$collection = $(),
					selected = [],
					selectedLen = 0
					result;

				e.preventDefault();
				// close info panel if open
				if ($(context).find('.cw81close')[0]) {
					$(context).find('.cw81close').trigger('click');
				}
				$items.addClass('cw81hidden');
				$collection = _getSearchResult($items,awesomplete);
				selected = _getSelectValues(context);
				selectedLen = selected.length;
				if (selectedLen > 0) {
					result = _applyFilter($collection, selected, selectedLen - 1);
				} else {
					result = $collection;
				}
				// handle tags
				_tagHandler(context,selected,awesomplete);
				// set page to 1
				_page(context,1);
				_visibilityHandler(context,result);

			});
			// clicking on autocomplete suggestion
			$(input).on('awesomplete-selectcomplete', function (e) {
				var $items = $(context).find('.cw81w3 .col-item'),
					$collection = $(),
					selected = [],
					selectedLen = 0
					result;

				e.preventDefault();
				// close info panel if open
				if ($(context).find('.cw81close')[0]) {
					$(context).find('.cw81close').trigger('click');
				}
				$items.addClass('cw81hidden');
				$collection = _getSearchResult($items,awesomplete);

				// reset pulldowns
				$(context).find('select').each( function (i,select) {
					$(select).get(0).selectedIndex = 0;
				});
				result = $collection;
				// handle tags
				_tagHandler(context,selected,awesomplete);
				// set page to 1
				_page(context,1);
				_visibilityHandler(context,result);
			});
			// open info panel
			$(context).find('.cw81w3 .col-w1').on('click', '.col-item > a', function (e) {
				var ar = _insertionPoint($(e.currentTarget)),
					insertionPoint = ar[0],
					arrow = ar[1],
					prevInsertionPoint,
					panel = $(_snippet.panel).clone(),
					$parent = $(e.currentTarget).closest(".col-w1"),
					content = {},
					oldTarget;

				e.preventDefault();

				if (!$(e.currentTarget).closest('.cw81current')[0]) {
					$oldTarget = $parent.find('.cw81current');
					$parent.find('.cw81current').removeClass('cw81current');
					content['title'] = $(e.currentTarget).find('.col-item-w2 h4').clone();
					content['desc'] = $(e.currentTarget).siblings('.cw81w5').html();
					$(e.currentTarget).closest('.col-item').addClass('cw81current');

					if ($parent.find('.col-item.cw81infopanel')[0]) {
						prevInsertionPoint = $parent.attr('data-panelindex');
						//if (insertionPoint !== +prevInsertionPoint) {
							// remove old panel
							$parent.find('.col-item.cw81infopanel').remove();
							// recalculate insertion point
							ar = _insertionPoint($(e.currentTarget));
							insertionPoint = ar[0];
							arrow = ar[1];
							// inject new panel
							$parent.find('.col-item').eq(insertionPoint).after(panel);
							$parent.attr('data-panelindex', insertionPoint);

						//} else {
							// remove arrow positioning class
						//	$parent.find('.cw81infopanel').removeClass('cw81p1').removeClass('cw81p2').removeClass('cw81p3');
						//}
					} else {
						$parent.find('.col-item').eq(insertionPoint).after(panel);
						$parent.attr('data-panelindex', insertionPoint);
					}
					// add arrow positioning class
					$parent.find('.cw81infopanel').addClass(_arrowPosition[_getBreakpoint()][arrow]);
					// inject panel content
					$parent.find('.cw81infopanel .cw81w7').html(content['title']);
					$parent.find('.cw81infopanel .cw81w7').append(content['desc']);

				}
			});

			// close info panel
			$(context).find('.cw81w3 .col-w1').on('click','.cw81close', function (e) {

				$(e.currentTarget).closest('.col-w1').removeAttr('data-panelindex');
				$(e.currentTarget).closest('.col-w1').find('.cw81current').removeClass('cw81current');
				$(e.currentTarget).closest('.cw81infopanel').remove();
			});
			$(window).off('resize.cw81').on('resize.cw81', function (e) {
				if ($(context).find('.cw81close')[0]) {
					$(context).find('.cw81close').trigger('click');
					
				}
				_page(context,1);
				_visibilityHandler(context,$(context).find('.cw81w3 .col-w1[data-template] .col-item').not('.cw81hidden').not('.cw81noresult'));
			});
			// view more
			$(context).find('.cw81w3').on('click','.cw81expand',function (e){
				$(context).find('.cw81close').trigger('click');
				_viewMore(context);
			});
		},
		/*
		 * Builds collections of <option> tags based on the feeds and injects them into the proper <select>.
		 */
		_buildMenu = function (context) {
			var feedTargetLength = _feedMeta.input.length - 1,
				sortedKeys = [],
				arLength,
				opts,
				obj,
				value,
				label;

			for (var i = 0; i < _feedMeta.input.length; i++) {

				if (_feedMeta.input[i]) {

					obj = _feedData[_feedMeta.src.live.args[i]];
					sortedKeys = _sortObjByPropVal(obj,'label');
					arLength = sortedKeys.length;

					for (var j = 0; j < arLength; j++) {
						// for some reason, one of the region feed entries is actually 'Region'
						if (obj[sortedKeys[j]].label  && _feedMeta.src.live.args[i] !== obj[sortedKeys[j]].label.toLowerCase() && $(context).find('div[data-category~="' + sortedKeys[j] + '"]')[0]) {
							// region mapping exceptions
							if (_feedMeta.src.live.args[i] == 'region') {
								switch(obj[sortedKeys[j]].label) {
									case 'JAPAN':
										label = "Japan";
									break;
									case 'LAD':
										label = "Latin America Division";
									break;
									case 'NA':
										label = "North America";
									break;
									case 'WORLDWIDE':
										label = "Worldwide";
									break;
									default:
										label = obj[sortedKeys[j]].label;;
									break;
								}
							} else {
								label = obj[sortedKeys[j]].label;
							}
							value = sortedKeys[j];
							$(context).find(_feedMeta.input[i]).append('<option value="' + value + '">' + label + '</option>'); 
						}
					}
				}
			}
		},
		_getBreakpoint = function () {
			return window.getComputedStyle(document.querySelector('.cw81'), ':before').getPropertyValue('content').replace(/\"/g, '');
		},
		_getSearchResult = function (items, awesomplete) {
			var $target,
				$collection = $(),
				s = awesomplete.suggestions ? awesomplete.suggestions.length : 0,
				pattern,
				value = awesomplete.val;

			if (value == '') {
				// return untouched set
				return $(items);
			}
			// apply search term
			for (var i = 0; i < s; i++) {
				$target = $(items).find('h4:contains("'+ awesomplete.suggestions[i].label +'")');
				pattern = new RegExp('^' + awesomplete.suggestions[i].label + '$', "i");
				if (value.match(pattern)) {
					return $target.closest('.col-item');
				}
				if ($target[0]) {
					$collection = $collection.add($target.closest('.col-item'));
				}
			}
			return $collection;
		},
		_getSelectValues = function (context) {
			var selected = [];
			$(context).find('form select').each ( function (i, select) {
				if ($(select).find('option:selected').attr('value')) {
					selected.push({
						'value':$(select).find('option:selected').attr('value'),
						'label':$(select).find('option:selected').text()
					});
				}
			});
			return selected;
		},
		_importJSON = function (url, args) {
			var index,
				data;

			// Use local startup json file. This code should be removed once the feed becomes available from Oracle
			if (args == _feedMeta.src.live.args[4]) {
				//url = _feedMeta.src.ws.url + _feedMeta.src.startups.files[4];
				url = _startupFeed;
				data = '';
			} else {
				data = 'taxonomy=' + args;
			}

			return $.ajax({
				dataType: "json",
				url: url,
				data: data,
				success: function (data) {
					var processedData = {},
						dlen = data.length;
						startuplen = 0;
					for (var i = 0; i < dlen; i++) {
						// process wordmapid keys
						if (data[i].hasOwnProperty("wordmapid")) {
							processedData[data[i]["wordmapid"]] = {};

							for (var prop in data[i]) {
								if (data[i].hasOwnProperty(prop) && prop !== 'wordmapid') {
									processedData[data[i]["wordmapid"]][prop] =  data[i][prop];
								}
							}
						} else {
							// process startups
							if (data[i][0]) {
								if (!Array.isArray(processedData)) {
									processedData = new Array();
								}
								processedData[i] = {};
								processedData[i]['name'] = data[i][0];
								processedData[i]['region'] = data[i][1];
								processedData[i]['country'] = data[i][2];
								processedData[i]['logo_url'] = data[i][3];
								processedData[i]['industry'] = data[i][4];
								processedData[i]['solution'] = data[i][5];
								processedData[i]['description'] = data[i][6];
								processedData[i]['email'] = data[i][7];
								processedData[i]['url'] = data[i][8];
								_startupNames.push(data[i][0]);
							}
						}
					}

					if (args == 'startups') {
						// sort by startup name
						processedData.sort( function (a,b) {
							if (a['name'].toLowerCase() < b['name'].toLowerCase()) {
								return -1;
							} else if (a['name'].toLowerCase() > b['name'].toLowerCase())  {
								return 1;
							} else {
								return 0;
							}
						})
					}
					_feedData[args] = processedData;
				},
				error: function (error) {
					console.log('Error')
					console.log(error)
				}
			});
		},
		_initialize = function (context) {
			var target = $(context).find('.cw81w3 .col-w1[data-template]'),
				template = $(context).find('.cw81w3 .col-w1[data-template]').attr('data-template');
			// set pagination to beginnning
			_page(context,1);
			// establish button text
			_customtxt['btn'][0] = $(context).attr('data-cw81more');
			_customtxt['btn'][1] = $(context).attr('data-cw81less');
			// establish info panel cta text
			_customtxt['cta']['url'] = $(context).attr('data-cw81ctaurl');
			_customtxt['cta']['email'] = $(context).attr('data-cw81ctaemail');
			// no result text
			if ($(context).attr('data-cw81noresult')) {
				_noresultmsg = $(context).attr('data-cw81noresult');
			}
			// apply feed data to template
			if(_feedData.hasOwnProperty('startups') && template) {
				window.HBSINJECT.initialize({
					cache: true,
					data: _feedData,
					targetObj: target,
					templateName: template,
					afterInjectionCallback: function () {
						//$(target).closest('.col-framework').addClass('inview').removeClass('col-noanimation');

						window.setTimeout( function () {
							$(context).find('.cw81w3 .col-w1-placeholder').animate({opacity:0},300, function () {
								$(context).find('.cw81w3 .col-w1-placeholder').remove();
								$(context).find('.cw81w3').removeAttr('style');
							});
							$(context).find('.cw81w3 .col-w1.cw81hidden').removeClass('cw81hidden');
							_visibilityHandler(context, $(context).find('.cw81w3 .col-w1[data-template] .col-item'));
							$(context).find('.cw81noresult > div').text(_noresultmsg);
						},1200)
						
					},
					beforeInjectionCallback: function (result) {
						var startups = result.startups,
							startupLen = startups.length,
							name,
							pattern = /\{\{self\}\}/g;
						for (var i = 0; i < startupLen; i++) {
							name = startups[i].name;
							// display email CTA if cw81ctaemail attribute isn't blank
							if ($(context).attr('data-cw81ctaemail')) {
								result.startups[i]['cta_email'] = _customtxt.cta.email.replace('{{self}}',name);
							} else {
								result.startups[i]['email'] = '';
							}
							result.startups[i]['cta_url'] = _customtxt.cta.url.replace('{{self}}',name);
						}
						return result;
					}
				});
			}
			_buildMenu(context);
			_bindEvents(context);
			
		},
		_injectButton = function (context,mode) {
			var btn;
			if (mode) {
				// remove button

			} else {
				// inject button
				btn = $('<div class="obttns obttn-center cw81expand"><div><a>' + _customtxt['btn'][0] + '</a></div></div>');
				$(context).find(".cw81w3").append(btn);
			}
		},
		_injectPlaceholder = function (context) {
			var itemHt,
				rows,
				bp = _getBreakpoint(),
				$newSet = $();
			// establish number of items per 'page'
			_visblocksize.lgdesktop = +$(context).attr('data-visblocksize') > 0 ? +$(context).attr('data-visblocksize') : 12;
			_visblocksize.desktop = Math.ceil(_visblocksize.lgdesktop * 0.75);
			_visblocksize.tablet = Math.ceil(_visblocksize.lgdesktop * 0.50);
			_visblocksize.mobile = Math.ceil(_visblocksize.lgdesktop * 0.25);
			
			$newSet = $(_snippet.blankcontainer);
			// build placeholder grid
			for (var i = 0; i < _visblocksize[bp]; i++) {
				$(context).find('.cw81w3 .col-w1-placeholder').append($(_snippet.blankitem));
				$newSet.append($(_snippet.blankitem));
			}
			// inject placeholder grid
			$(context).find('.cw81w3').prepend($(_snippet.blankcontainer));
			// calculate desired height of container
			rows = Math.ceil(_visblocksize[bp] / _itemsPerRow[bp]);
			$(context).find('.cw81w3').prepend($newSet);
			$(context).find('.cw81w3').css({'height': ($(context).find('.cw81w3 .col-w1-placeholder .col-item').height() + parseInt($(context).find('.cw81w3 .col-w1-placeholder .col-item').css('margin-bottom'))) * rows});

		},
		/*
		 * Returns array containing two elements: 
		 * 0: index where info panel should be injected relative to all visible items
		 * 1: index of the clicked tile relative to its row
		 */
		_insertionPoint = function (context) {
			var cols = _itemsPerRow[_getBreakpoint()],
				index = $(context).closest('.col-item').index(),
				visMax = $(context).closest('.col-w1').find('.col-item:visible').not('.cw81infopanel').length,
				visIndex,
				visPos,
				visRow,
				visRowLast,
				visPoint,
				slot;
			// find index of selected item relative to all visible items
			for (var i = 0; i < visMax; i++) {
				if ($($(context).closest('.col-w1').find('.col-item:visible')[i]).index() == index) {
					visIndex = i;
					break;
				}
			}

			// calculate row of selected tile among all visible tiles
			visRow = Math.ceil((visIndex + 1) / cols);

			// calculate total number of visible rows
			visRowLast = Math.ceil(visMax / cols);

			// set the injection point at the last tile when the info panel will create a new row
			visPoint = visRow == visRowLast ? (visMax - 1) : (cols * visRow) - 1;
			
			// convert visible item index to one that is relative to all items, visible or not
			actualPoint = $($(context).closest('.col-w1').find('.col-item:visible')[visPoint]).index();
			
			// index of item relative to items in row
			slot = visIndex % cols;
			
			//console.log('visindex: ' + visIndex + ', visrow: ' + visRow + ', vispoint: ' + visPoint + ', vismax: ' + (visMax - 1) + ', visrowlast: ' + visRowLast + ', actualpoint: ' + actualPoint);
			
			return [actualPoint,slot];
		},
		_page = function (context,modifier) {
			if (modifier) {
				$(context).find('.cw81w3').attr('data-cw81page', modifier);
			}
			return $(context).find('.cw81w3').attr('data-cw81page') ? +$(context).find('.cw81w3').attr('data-cw81page') : 1;
		},
		_removeTag = function (context,label) {
			$(context).find('.cw81tags a > span:contains("' + label + '")').closest('.cw81tag').remove();
		},
		/*
		 * Given a multi-dimensional object, returns an array of keys sorted alphanumerically through
		 * a second level property name.
		 */
		_sortObjByPropVal = function (obj,prop) {
			var keys = Object.keys(obj);
				sortedKeys = keys.sort( function (a,b) {
					if (obj[a][prop] < obj[b][prop]) {
						return -1;
					} else if (obj[a][prop] > obj[b][prop]) {
						return 1;
					} else {
						return 0;
					}
				});
			return sortedKeys;
		},
		/*
		 *
		 */
		_tagHandler = function (context, filters, awesomeplete) {
			var newTag;
			$(context).find('.cw81tags ul .cw81tag').remove();
			if (awesomeplete && $.trim(awesomeplete.val)) {
				displayClear = true;
				newTag = $(_snippet.tagSearch);
				newTag.find('span').text('"' + awesomeplete.val + '"');
				$(context).find('.cw81tags ul').prepend(newTag);
			}
			for (var i = 0; i < filters.length; i++) {
				if (filters[i].label) {
					newTag = $(_snippet.tag);
					newTag.attr('data-wordmapid',filters[i].value);
					newTag.find('span').text(filters[i].label);
					$(context).find('.cw81tags ul').prepend(newTag);
				}
			}
			// show or hide clear tag
			if ($(context).find('.cw81tag')[0]) {
				$(context).find('.cw81tagreset').show();
			} else {
				$(context).find('.cw81tagreset').hide();
			}
			
		},
		_viewMore = function (context) {
			var $items = $(context).find('.cw81w3 .col-w1[data-template] .col-item').not('.cw81hidden').not('.cw81noresult');
				itemTotal = $items.length,
				page = +_page(context) + 1,
				visblocksize = _visblocksize[_getBreakpoint()],
				maxVisItems = visblocksize * page,
				maxPages = Math.ceil(itemTotal / visblocksize),
				$btn = $(context).find(".cw81expand");

			if (page <= maxPages) {
				// update page
				_page(context,page);
			} else {
				// reset the page counter
				_page(context,1);
				maxVisItems = visblocksize * 1;
			}
			// mark tiles vis/invis
			for (var i = 0; i < itemTotal; i++) {
				if (i < maxVisItems) {
					$($items[i]).removeClass('cw81trunc');
				} else {
					$($items[i]).addClass('cw81trunc');
				}
			}
			// change button text
			if (page == maxPages) {
				$btn.find('a').text(_customtxt['btn'][1]);
				$btn.addClass('cw81minus');
			} else {
				$btn.find('a').text(_customtxt['btn'][0]);
				$(context).find('.cw81expand.cw81minus').removeClass('cw81minus');
			}
		},
		_visibilityHandler = function (context, collection) {
			var itemTotal = $(collection).length,
				visblocksize = _visblocksize[_getBreakpoint()],
				maxVisItems = visblocksize * _page(context),
				adaptiveVisItems;

			// expose filtered results	
			$(collection).not('.cw81noresult').removeClass('cw81hidden');

			if (window.cw81waypoints.length < 1) {
				window.cw81waypoints = olazysrc({attrName:'data-cw81lazy-src',debug:false,offset:window.innerHeight * 1.1}); // global lazy load function
			} else {
				_waypointRefresh(context, collection);
			}

			// hide truncated items
			for (var i = 0; i < itemTotal; i++) {
				if (!$($(collection)[i]).hasClass('cw81noresult')) {
					if (i < maxVisItems) {
						$($(collection)[i]).removeClass('cw81trunc');
					} else {
						$($(collection)[i]).addClass('cw81trunc');
					}
				}
			}

			// display/hide no result message
			if (itemTotal > 0) {
				$(context).find('.cw81noresult').addClass('cw81hidden');
			} else {
				$(context).find('.cw81noresult').removeClass('cw81hidden');
			}
			// determine 'view more' button placement
			if (itemTotal > maxVisItems) {
				if (!$(context).find('.cw81expand')[0]) {
					_injectButton(context);
				}
			} else {
				if ($(context).find('.cw81expand')[0]) {
					$(context).find('.cw81expand').remove();
				}
			}	
		},
		_waypointRefresh = function (context, collection) {
			var length = window.cw81waypoints.length;
			for (var i = 0; i < length; i++) {
				if (window.cw81waypoints[i]) {
					window.cw81waypoints[i].destroy();
				}
			}
			window.cw81waypoints = olazysrc({attrName:'data-cw81lazy-src',collection:$(collection),debug:false,offset:window.innerHeight * 1.1}); // global lazy load function

		};
	component = function cw81($) {
		$('.cw81').each( function (i, cw81) {
			_injectPlaceholder(cw81);
		});
		// poll until HBSINJECT is loaded
		_interval = setInterval( function () {
			/* globals objLoaded */
			if(objLoaded('HBSINJECT','initialize')) {
				clearInterval(_interval);
				// promise that the feeds are complete
				jQuery.when(
					_importJSON(_feedMeta.src.live.url, _feedMeta.src.live.args[0]),
					_importJSON(_feedMeta.src.live.url, _feedMeta.src.live.args[1]),
					_importJSON(_feedMeta.src.live.url, _feedMeta.src.live.args[2]),
					_importJSON(_feedMeta.src.live.url, _feedMeta.src.live.args[3]),
					_importJSON(_feedMeta.src.live.url, _feedMeta.src.live.args[4])
				).done(
					function (d) {
						//console.log('cw81 json import complete.')
						$('.cw81').each( function (i, cw81) {
							_initialize(cw81);
						});
						//console.log(_feedData)
					}
				).fail(
					function (d) {
						//console.log('fail')
						//console.log(d);
					}
				);
			}
		}, 10);
	};
	OCOM.register(component);
})(jQuery);
window.cw81waypoints = []

/*! CW82 */
OCOM.register(function cw82($) {
	'use strict';

	return $('.cw82[data-feedsrc]').each(init);

	function init() {

		var $cw82 = $(this),
				$ofeed = $cw82.find('.ofeed'),
				feedsrc = $cw82.attr('data-feedsrc'),
				template = $cw82.attr('data-template');

		// skeleton markup while loading
		if(!$cw82.data('initialized')) {
			injectSkeleton.call($ofeed, 5);
			$cw82.data('initialized', true);
		}

		// if handlebars is not ready, bail and try again
		if(!window.WS || !window.WS.tpl) {
			return setTimeout(init.bind(this), 50);
		}

		// preload profile imgs only on hover
		$cw82.on('mouseenter touchstart', '.cw82session-open', loadLbxImages);

		window.HBSINJECT.initialize({
			feedsrc: feedsrc,
			targetObj: $ofeed,
			templateName: template,
			beforeInjectionCallback: prepJSON.bind($cw82),
			afterInjectionCallback: $cw82.addClass.bind($cw82, 'hbs-initialized')
		});
	}

	function prepJSON(json) {

		var items = json.sectionList[0].items,
				downloadText = $(this).attr('data-downloadtxt') || 'Download session presentation',
				slots;

		// create a lookup object by session start times
		slots = items.reduce(function(slots, item) {

			// no time set - bail
			if(!item.times) { return slots; }

			// iterate through the session's times to assign it to a slot
			item.times.forEach(function(time) {

				var key = time.dayTimeSort, // like "20190521t0800"
						// make a copy to prevent mutation
						itemCopy = jQuery.extend(true, {}, item);

				// check if time slot exists
				slots[key] = slots[key] || {};
				slots[key].displayTime = slots[key].displayTime ||
					// break up displayTime to output multiple spans
					// ('09:00 AM') => { hr: '09', min: '00', ampm: 'AM'}
					displayTimeToObj(time.startTimeFormatted);

				// check if sessions array exists for time slot
				slots[key].sessions = slots[key].sessions || [];

				// create item copy's time from the matching time slot
				itemCopy.time = item.times.filter(function(time) {
					return time.dayTimeSort === key;
				}).shift();

				// set a flag to create lightbox only for sessions
				// with applicable details, eg. abstract, speakers
				// not general events, eg. 'Registration Open'
				itemCopy.hasDetail =
					Boolean(itemCopy.abstract && itemCopy.abstract.trim().length) ||
					Boolean(itemCopy.participants && itemCopy.participants.length);

				if(itemCopy.files) {
					itemCopy.files.forEach(function(file) {
						var idx = file.filename.lastIndexOf('.') + 1;
						file.type = idx && file.filename.slice(idx).toUpperCase();
					});
				}

				// push into sessions array for this time slot
				slots[key].sessions.push(itemCopy);
			});

			return slots;

		}, {});

		slots = Object.keys(slots)
			.reduce(function(arr, slot) {
				// convert the lookup key into a prop
				arr.push(jQuery.extend({ slot: slot }, slots[slot]));
				return arr;
			}, [])
			// sort ascending on lookup key
			.sort(sortBySlotTime);

		return {
			agenda: slots,
			downloadText: downloadText
		};
	}

	function injectSkeleton(i) {

		var $ctr = $(this),
				skeleton = '<div class="cw82w2">'
									+	'	<div class="cw82w3">'
									+ '		<h4 class="cw82skeleton">\n&nbsp;\n&nbsp;</h4>'
									+	'	</div>'
									+	'	<div class="cw82w4"><div class="cw82session cw82skeleton">&nbsp;</div></div>'
									+	'</div>';

		return function inject() {
			var hasLoaded = Boolean($ctr.closest('.hbs-initialized').length);
			if(i > 0 && !hasLoaded) {
				$ctr.append(skeleton);
				setTimeout(inject.bind($ctr), 100);
				i--;
			}
		}.call($ctr);
	}

	function displayTimeToObj(str) {
		var map = ['hr', 'min', 'ampm'];
		return (
			str.split(/[: ]/g)
				.reduce(function(obj, part, i) {
					obj[map[i]] = part;
					return obj;
				}, {})
		);
	}

	function sortBySlotTime(a, b) {
		return (
			a.slot === b.slot ? 0
				: a.slot < b.slot ? -1
					: 1
		);
	}

	function loadLbxImages() {

		var href = $(this).attr('href'),
				// ensure we're getting a valid id selector (betamode rewrite)
				$lbx = $(href.slice(Math.max(href.indexOf('#'), 0)));

		// bail if unfound or already started
		if(!$lbx.length || $lbx.data('lazyloading')) { return; }

		return (
			$lbx
				.data('lazyloading', true)
				.find('img').each(function() {
					var $img = $(this);
					return (
						$img
							.attr('src', $img.attr('data-lazy-src'))
							.removeAttr('data-lazy-src')
					);
				})
		);
	}

});


/*! F19 */
OCOM.register(function f19($) {
	'use strict';

	$('.f19[data-feedsrc]').each(function() {

		var $f19 = $(this),
				endpoint = $f19.data('feedsrc');

		return jQuery.getJSON(endpoint, init.bind($f19));
	});

	function init(json) {

		if(!window.WS || !window.WS.tpl) {
			// handlebars is not ready, bail and try again
			return setTimeout(init.bind(this, json), 50);
		}

		var $f19 = $(this),
				$main = $f19.find('.f19main .cc01w1'),
				$sidebar = $f19.find('.f19side .s21w2'),
				$author = $f19.find('.f19main .cb147'),
				$share = $f19.find('.f19side .cb143'),
				templateMain,
				templateSidebar;

		templateMain = window.WS.tpl['f19-articlemain'];
		templateSidebar = window.WS.tpl['f19-sidebarlinks'];

		return (
			// we assume that JSON is server-sorted by date desc
			// 	(most recent first)
			$main.html(templateMain(json[0])) &&

			// limit to 5 links, regardless of JSON length
			$sidebar.html(templateSidebar(json.slice(1, 6))) &&

			$author.find('.f19skeleton')
				.text(json[0].author.name)
				.removeClass('f19skeleton') &&

			$share.find('.sharelink').each(function() {
				return shareLinkData.call(this, json[0]);
			}) &&

			$f19.addClass('hbs-initialized')
		);
	}

	/**
	 * Sets attributes on a given .sharelink from
	 *  provided json based on data-sharetype
	 */
	function shareLinkData(data) {

		var $link = $(this);

		switch($link.data('sharetype')) {

			case 'twitter':
				return $link.attr({
					'data-url': data['web_url'],
					'data-text': data['title']
				});
			case 'email':
				return $link.attr({
					'data-url': data['web_url'],
					'data-esubject': data['title'],
					'data-ebody': data['title']
				});
			default:
				// most implementations just need a data-url attr
				return $link.attr({
					'data-url': data['web_url']
				});
		}
	}

});


/*! U22 */
$(document).ready(function() {
	if(document.location.href.indexOf('?screenshot') < 0){

		$('body').append('<div class="u22"><a id="u22" class="icn-img icn-arrow-up" href="#top">&nbsp;<b>TOP</b></a></div>');
	
		//Check to see if the window is top if not then display button
		$(window).scroll(function(){
			u20check($(this));
		});

		$(window).resize(function(){
			u20check($(this));
		});

		function u20check(thisw){

			var widthadj = ($('.f11v6')[0]) ? 1560 : 1360;
	
			if((thisw.scrollTop() >= ($(document).height() - thisw.height() - 60)) && thisw.outerWidth() < widthadj){
				$('#u22').removeClass('u22show');
			}else if(thisw.scrollTop() > (thisw.height() - 150)){
				$('#u22').addClass('u22show');
			}else{
				$('#u22').removeClass('u22show');
			}
		}

		//Click event to scroll to top
		$('#u22').click(function(){
			$('html, body').animate({scrollTop:0}, 800);
			return false;
		});

	}

});


/*! U28 */
$( document ).ready(function() {

	if($('.u28')[0]){
		//Cheack if on staging
		var u28staging = false;
		var w_url = window.location.href;

		//test search terms
		//aoshtest
		//download
		
		if (w_url.indexOf('www-stage') > -1 || w_url.indexOf('www-portal-stage') > -1 || w_url.indexOf('www.stage') > -1 || w_url.indexOf('www-sites') > -1) {
			//console.log('loading staging assets');
			var u28staging = true;
		}
	
		var u28 = $('.u28');
		var mobile = false;
		var u28qCount = 0;
		var askoracleform = $('#askoracle');
		var elem = $('#askoracleinput');
		var inst = setInterval(change, 3000);
		var dropdown = $('.u28w4');
		var searchresults = $('.u28w8');
		var u28nav = $('.u28nav');
		var u28profile = $('.u28-profile');
		var u28profiledropdown = $('.u28-profilew1');
		
		var liSelected;
		var ctryfilterdis = false;
		var navbgloaded = false;
		var u28questions = [];
		var u28searchpg = 0;
		var u28questionPrefix = elem.data("prefix");
		if (!u28questionPrefix) { 
			var u28questionPrefix = 'Ask';
		}

		// Hide Header on on scroll down
		var u28didScroll;
		var lastScrollTop = 0;

		var contctry = '';
		var contlang = '';
		
		var u28height = u28.outerHeight();
		var delta = u28height;

		//Get suggested text for rotation
		$('.u28w7 li').each(function() {
			var suggestedtext = $(this).text();
			u28questions.push(suggestedtext);
		});

		// cookie to test hello, name cookie on localhost - DO NOT COMMIT THIS FILE WITH THIS UNCOMMENTED!!!!
		// fakeuser
		//document.cookie = "ORA_UCM_INFO=3~93446F2E9B0E5ADEE040548C2D706F69~JeanLuc~Picard~jeanluc.picard@oracle.com";
		// no name
		//document.cookie = "ORA_UCM_INFO=3~93446F2E9B0E5ADEE040548C2D706F69~NOT_FOUND~NOT_FOUND~jeanluc.picard@oracle.com";
		// no acct
		//document.cookie = "ORA_UCM_INFO=3~93446F2E9B0E5ADEE040548C2D706F69~Jean Luc~Picard";

		if (USER.guid){
			if (USER.username && USER.username != "NOT_FOUND"){
				//console.log('username found');
				//$('.u28l-in').prepend('<li><a href="PLACEHOLDER.html">'+USER.username+'</a></li>');
			}
			if (USER.firstname && USER.firstname != "NOT_FOUND" && USER.lastname && USER.lastname != "NOT_FOUND"){
				//console.log('first and lastname found');
				$('.u28l-in').prepend('<li><a href="PLACEHOLDER.html">'+USER.firstname+' '+USER.lastname+'</a></li>');
			}else if (USER.firstname && USER.firstname != "NOT_FOUND"){
				//console.log('just firstname found');
				$('.u28l-in').prepend('<li><a href="PLACEHOLDER.html">'+USER.firstname+'</a></li>');
			}
			u28profile.addClass('loggedin');
		}

		/*
		if (window.history && window.history.pushState) {
			//window.history.pushState(null, "", window.location.href);        
			window.onpopstate = function() {
				//window.history.pushState(null, "", window.location.href);
				if (u28.is('.u28navactive')) {
					//console.log('u28navactive');
					u28closeNav();
					if (mobile) {
						u28unlockpage();
					}
				}
				if (u28.is('.dropdownactive')) {
					//window.history.pushState(null, "", window.location.href);
					console.log('dropdownactive');
					elem.val('');
					closedropdown();
				}
			};
		}
		*/

		/*
		if (window.history && window.history.pushState) {
			$(window).on('popstate', function() {
				var hashLocation = location.hash;
				var hashSplit = hashLocation.split("#!/");
				var hashName = hashSplit[1];
				if (hashName !== '') {
					var hash = window.location.hash;
					if (hash === '') {
						alert('2 Back button was pressed.');
					}
				}
			});
			window.history.pushState('forward', null, './#search');
		}
		*/
		
		$(document).keyup(function(e) {
			if (e.key === "Escape" && u28.hasClass('u28navactive')) {
				u28closeNav();
				if (mobile) {
					u28unlockpage();
				}
			}
			if (e.key === "Escape" && u28.hasClass('dropdownactive')) {
				//console.log('tring to close suggest and results with escape key');
				elem.val('');
				closedropdown();
			}
 		});

		//Hide Search Bar
		function u28hasScrolled() {
			if (!u28.hasClass('dropdownactive') || !u28.hasClass('u28navactive')) {
				var st = $(document).scrollTop();
				if (st <= 1) {
					u28.removeClass('u28-down u28-up').addClass('u28-top');
				}
				if(Math.abs(lastScrollTop - st) <= delta) {
					return;
				}
				if (st > lastScrollTop && st > u28height){
					// Scroll Up
					u28.removeClass('u28-top u28-down').addClass('u28-up');
					setTimeout(function() {
						if (!u28.hasClass('u28-past')) {
							u28.addClass('u28-past');
						}
					}, 400);
					
				} else {
					// Scroll Down
					if(st + $(window).height() < $(document).height()) {
						u28.removeClass('u28-top u28-up').addClass('u28-down');
					}
				}
				/*
				//old remove-past
				if (st <= 100) {
					console.log('remove-past');
					u28.removeClass('u28-down u28-up u28-past').addClass('u28-top');
				}
				*/
				lastScrollTop = st;
			}
		}

		$('.u28nav>ul>li>h3').each(function () {
			$(this).not(':has(a)').css('opacity', '0.6');
			if ($(this).siblings('ul').length) {
				$(this).parent().prepend('<span class="mclose"></span>');
			}
		});

		/*
		window.SpeechRecognition = window.webkitSpeechRecognition || window.SpeechRecognition;
		var finalTranscript = '';
		var recognition = new window.SpeechRecognition();
		recognition.interimResults = false;
		recognition.maxAlternatives = 10;
		recognition.continuous = true;
		
		recognition.onresult = function (event) {
			var interimTranscript = '';
			for (var i = event.resultIndex, len = event.results.length; i < len; i++) {
				var transcript = event.results[i][0].transcript;
				if (event.results[i].isFinal) {
					finalTranscript += transcript;
				} else {
					interimTranscript += transcript;
				}
			}
			//document.querySelector('body').innerHTML = finalTranscript + '<i style="color:#ddd;">' + interimTranscript + '</>';
			//elem.val(finalTranscript + '<i style="color:#ddd;">' + interimTranscript + '</>');
			$('.u28placeholder').addClass('u28hidden');
			addInputFocus();
			elem.val(finalTranscript);
		};
		*/

		var scrollToTop = function scrollToTop() {
			var c = document.documentElement.scrollTop || document.body.scrollTop;
			if (c > 0) {
				window.requestAnimationFrame(scrollToTop);
				window.scrollTo(0, c - c / 8);
			}
		};
	
		$('.u28input').append('<div class="u28placeholder"><span>'+u28questionPrefix+' </span></div>');
		$('.u28w2').append('<ul class="u28suggestw1"></ul>');
		$('.u28suggestw1').append('<ul class="u28suggest"></ul>');
		u28.prepend('<span class="u28bttop"></span>');

		//Create Skeleton
		searchresults.append('<ul class="u28skel"></ul>');
		var cont = []; //Initialize an array to build the content
		for (var i = 0;i<10;i++) cont.push('<li>test</li>');
		$('.u28skel').html(cont.join(''));

		/*ES6
		function u28delay(fn, ms) {
			let timer = 0
			return function(...args) {
				clearTimeout(timer)
				timer = setTimeout(fn.bind(this, ...args), ms || 0)
			}
		}
		*/

		function u28delay(fn, ms) {
			var timer = 0;
			return function () {
				clearTimeout(timer);
				for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
					args[_key] = arguments[_key];
				}
				timer = setTimeout(fn.bind.apply(fn, [this].concat(args)), ms || 0);
			};
		}

		var u28debouncenum = 600;

		//Input form back < btn
		elem.on("click", function(e) {
			addInputFocus();
		});

		//Nav
		$('.u28ham').on("mouseover touchstart", function(e) {
			if (!navbgloaded) {
				navbgloaded = true;
				u28nav.addClass('bgload');
			}
		});

		function u28closeNav() {
			u28nav.removeClass('u28fadeIn');
			u28.removeClass('u28cover');
			setTimeout(function() {
				u28.removeClass('u28navactive');
			}, 400);
		}
		
		$('.u28ham').on("click", function(e) {
			removeInputFocus();
			if (!u28nav.hasClass("u28fadeIn")) {
				if (mobile) {
					u28lockpage();
				}
				u28.addClass('u28navactive u28cover');
				u28nav.addClass('u28fadeIn');
			}
			else {
				u28closeNav();
				if (mobile) {
					u28unlockpage();
				}
			}
		});

		//Mobile Nav Back Btn
		$('.mnavback').on("click", function(e) {
			u28closeNav();
		});

		//Search Icon
		$('.u28-searchicon').on("click", function(e) {
			//console.log('searchicon clicked');
			e.preventDefault();
			return false;
		});

		//Mobile Nav Expand/Collapse Nav
		$('.mclose').on("click", function(e) {
			$(e.target).toggleClass('open');
			$(e.target).siblings('ul').slideToggle(300);
		});
	
		//Microphone
		/*
		$('.u28-microphone').on("click", function(e) {
			recognition.start();
			e.preventDefault();
			return false;
		});
		*/
	
		$(".u28prof, .u28actbck").on("click", function(e) {
			if (!u28profiledropdown.hasClass('u28fadeIn')) {
				u28profiledropdown.addClass('u28fadeIn');
				u28.addClass('profactive');
				if (mobile) {
					u28lockpage();
				}
			}
			else {
				//setTimeout(function() {
					u28profiledropdown.removeClass('u28fadeIn');
					u28.removeClass('profactive');
					if (mobile) {
						u28unlockpage();
					}
				//}, 250);
			}
			e.preventDefault();
			return false;
		});
	
		//Rotate Placeholder Text
		function change() {
			$('.u28placeholder span').text(''+u28questionPrefix+' "' +u28questions[u28qCount]+ '"');
			u28qCount++;
			if (u28qCount >= u28questions.length) {
				u28qCount = 0;
			}
		}

		//Video Check
		function u28videocheck() {
			setTimeout(function() {
				bc_embedsetup(searchresults);
			}, 200);
		}

		function u28lockpage() {
			//console.log('lock page');
			$('html, body').css({
				overflow: 'hidden',
				height: '100%'
			});
		}

		function u28unlockpage() {
			//console.log('unlock page');
			$('html, body').css({
				overflow: 'inherit',
				height: 'auto'
			});
		}
		
		//Create Clear Input Button
		/*
		if($('.u28clear').length == 0) {
			$('<div class="u28clear rw-close" tabindex="0"></div>').insertBefore('.u28-microphone');
			var clearbtn = $('.u28clear');
			//clearbtn.on("click", function(e) {
			//	clearInput();
			//});
		}
		*/

		//Input form back < btn
		//$(".u28 a.u28-back, .u28clear ").on("click", function(e) {
		$(".u28 a.u28-back").on("click", function(e) {
			//clearbtn.css("opacity", 1.0).animate({"opacity": 0.0}, 300).delay(300).css("visibility", "hidden");
			e.preventDefault();
			elem.val('');
			//if (!u28.hasClass("u28navactive")) {
			closedropdown();
			//}
			//if (!$(e.target).hasClass("u28clear")) {
			//	removeInputFocus();
			//}
			//else {
			//	elem.focus();
			//	addInputFocus()
			//}
			return false;
		});
	
		/*
		function clearInput() {
			closedropdown();
			$('.u28suggest').removeClass('active');
			elem.val('');
			clearbtn.css("opacity", 1.0).animate({"opacity": 0.0}, 300).delay(300).css("visibility", "hidden");
			elem.focus();
		}
		*/
		
		function opendropdown() {
			if (!u28.hasClass("dropdownactive")) {
				u28.addClass('dropdownactive');
				dropdown.addClass('u28dropfadeIn');
				elem.removeAttr('placeholder');
				adjustDropdown();
				u28lockpage();
				setTimeout(function() {
					dropdown.addClass('dropdownopen');
				}, 501);
			}
		}
	
		function closedropdown() {
			$('.u28suggest').removeClass('active');
			$('.u28w3').removeClass('u28typing');
			searchresults.addClass('hidden');
			$('.u28placeholder').removeClass('u28hidden');
			u28.removeClass('dropdownactive');
			dropdown.addClass('u28move');
			u28unlockpage();
			setTimeout(function() {
				dropdown.removeClass('u28move');
				dropdown.removeClass('u28dropfadeIn');
				dropdown.removeClass('dropdownopen');
				u28unlockpage();
			}, 401);
		}
	
		function removeInputFocus() {
			u28.removeClass('u28focus');
			//recognition.stop();
		}
	
		function addInputFocus() {
			u28.addClass('u28focus');
		}
	
		//Sumbit Autocomplete link
		$('.u28w2').on("click", "a.u28complete", function(e) {
			e.preventDefault();
			var lnk = $(e.currentTarget).text();
			elem.val(lnk);
			$('.u28suggest').html('');
			$('.u28suggest').removeClass('active');
			searchresults.removeClass('hidden');
			askoracleform.submit();
			return false;
		});

		searchresults.on("click", ".u28w7 li", function(e) {
			var nosuglnk = $(this).text();
			elem.val(nosuglnk);
			askoracleform.submit();
		});
		
		function buildResults(u28count){
			searchresults.addClass('loading');
			if (!u28count) {
				var u28count = 0;
			}
			var num = 0;
			var Ntt = $('.u28w3 input[name=Ntt]').val().toLowerCase();
			var nty = $('.u28w2 input[name=Nty]').val();
			var ntk = $('.u28w2 input[name=Ntk]').val();
			var Dy = $('.u28w2 input[name=Dy]').val();
			var cty = $('.u28w2 input[name=cty]').val();
			var lang = $('.u28w2 input[name=lang]').val();

			var filtertxt = elem.data("filtertxt");
			var ctytxt = elem.data("ctytxt");

			if (u28count <= 0) {
				searchresults.removeClass('u28found');
			}

			//if(!u28staging) {
				if (ctryfilterdis) {
					var searchurl = '/search-authoring/results-nodim?No='+u28count+'&Ntt='+Ntt+'&Dy='+Dy+'&Nty='+nty+'&Ntk='+ntk+'&format=json';
				}
				else if (cty && lang) {
					if(cty === 'us' && lang === 'en'){
						var searchurl = '/search-authoring/results-nodim?No='+u28count+'&Ntt='+Ntt+'&Dy='+Dy+'&Nty='+nty+'&Ntk='+ntk+'&format=json';
					}
					else {
						var searchurl = '/search-authoring/results-nodim?No='+u28count+'&Ntt='+Ntt+'&Dy='+Dy+'&Nty='+nty+'&Ntk='+ntk+'&cty='+cty+'&lang='+lang+'&format=json';
					}
				}
				else {
					var searchurl = '/search-authoring/results-nodim?No='+u28count+'&Ntt='+Ntt+'&Dy='+Dy+'&Nty='+nty+'&Ntk='+ntk+'&format=json'
				}
			//}
			//else {
				//stage
				//var searchurl = 'https://www.oracle.com/search/results-nodim?No='+u28count+'&Ntt='+Ntt+'&Dy='+Dy+'&Nty='+nty+'&Ntk='+ntk+'&cty='+cty+'&lang='+lang+'&format=json';
				//console.log('production searchurl',searchurl);
			//}
			var i = 0;
			var pub = '';

			jQuery.getJSON(searchurl, function(data) {
				u28.removeClass('u28navactive');
				var results = data.contents[0].records;
				if(typeof data.contents[1] != 'undefined') {
					var reccomendedresult = data.contents[1].url;
				}
				if (!results) {
					var results = data.contents[1].records;
					if(typeof data.contents[0] != 'undefined') {
						var reccomendedresult = data.contents[0].url;
					}
				}
				var ctryfilter = '';
				var sitelinkmarkup = '';
				var reccomendedmarkup = '';
				var resultsmarkup = '';
				var executed = false;
				//if(results){
					if(results.length > 0){
						for (var i = 0; i < results.length; i++) {
							var title = results[i].attributes.Title;
							var description = results[i].attributes.Description;
							var displayurl = results[i].attributes.DisplayURL;
							//Display SiteLinks
							var sitelinks = results[i].attributes.SiteLink;
							//console.log('sitelinks',sitelinks);
							if(typeof sitelinks != 'undefined') {
								sitelinkmarkup += '<div class="u28sitelinkw1 u28site'+i+'">';
								sitelinkmarkup += '<div class="u28sitelinks u28result u28sitelinksp">';
								sitelinkmarkup += '<h4><a href="'+displayurl+'">'+title+'</a></h4>';
								sitelinkmarkup += '<cite><a href="'+displayurl+'">'+displayurl+'</a></cite>';
								sitelinkmarkup += '<p>'+description+'</p>';
								sitelinkmarkup += '</div>';
								for (var u = 0; u < sitelinks.length; u++) {
									var sitesplitString = sitelinks[u].split("~");
									//testing
									//var sitesplitString = ["siteLinkTitles1=siteLinkTitles1", "siteLinkDescriptions2=siteLinkDescriptions2", "siteLinkDescriptions3=siteLinkDescriptions3", "siteLinkTitles3=siteLinkTitles3", "siteLinkTitles2=siteLinkTitles2", "siteLinkDescriptions1=siteLinkDescriptions1", "siteLinkDescriptions6=siteLinkDescriptions6", "siteLinkDescriptions4=siteLinkDescriptions4", "siteLinkDescriptions5=siteLinkDescriptions5", "siteLinkUrls4=siteLinkUrls4", "siteLinkUrls3=siteLinkUrls3", "siteLinkUrls2=siteLinkUrls2", "siteLinkUrls1=siteLinkUrls1", "siteLinkTitles5=siteLinkTitles5", "siteLinkTitles4=siteLinkTitles4", "siteLinkTitles6=siteLinkTitles6", "siteLinkUrls6=siteLinkUrls6", "siteLinkUrls5=siteLinkUrls5"];
									var titlearray = [0];
									var descrarray = [0];
									var urlarray = [0];
									for (var q = 0; q < sitesplitString.length; q++) {
										var sitelinkcnt = parseInt(sitesplitString.length / 3);
										var sitelinkdesc = sitesplitString[q].split('=')[0];
										var sitelinkdata = sitesplitString[q].substring(sitesplitString[q].indexOf('=')+1);
										for (var t = 0; t <= sitelinkcnt;) {
											var siteLinkTitles = 'siteLinkTitles'+t;
											var siteLinkDescriptions = 'siteLinkDescriptions'+t;
											var siteLinkUrls = 'siteLinkUrls'+t;
											if (sitelinkdesc === siteLinkTitles) {
												titlearray[t-1] = sitelinkdata;
											}
											if (sitelinkdesc === siteLinkDescriptions) {
												descrarray[t-1] = sitelinkdata;
											}
											if (sitelinkdesc === siteLinkUrls) {
												urlarray[t-1] = sitelinkdata;
											}
											t++
										}
										
									}
									if (titlearray.length === sitelinkcnt && descrarray.length === sitelinkcnt && urlarray.length === sitelinkcnt) {
										for (var y = 0; y < (sitelinkcnt+1);) {
											if (descrarray[y] && titlearray[y] && urlarray[y]) {
												var url = urlarray[y];
												var descr = descrarray[y];
												var title = titlearray[y];
												if (url && descr && title) {
													sitelinkmarkup += '<div class="u28sitelinks u28result u28sitelinksc">';
													sitelinkmarkup += '<div class="u28rw1">';
													sitelinkmarkup += '<div class="u28rw2">';
													sitelinkmarkup += '<h4><a href="'+urlarray[y]+'">'+titlearray[y]+'</a></h4>';
													//sitelinkmarkup += '<cite><a href="'+urlarray[y]+'">'+urlarray[y]+'</a></cite>';
													sitelinkmarkup += '<p>'+descrarray[y]+'</p>';
													sitelinkmarkup += '</div>';
													sitelinkmarkup += '</div>';
													sitelinkmarkup += '</div>';
												}
											}
											y++
										}
									}
									u++;
								}
								sitelinkmarkup += '</div>';
							}
							if(typeof reccomendedresult != 'undefined') {
								if (!executed) {
									executed = true;
									reccomendedmarkup += reccomendedresult;
									//markup in JSON
									//console.log(reccomendedmarkup);
								}
							}

							//Display Promotional Content
							var promotionalcontent = results[i].attributes.PromotionalContent;
							if(typeof promotionalcontent != 'undefined') {
								for (var q = 0; q < promotionalcontent.length; q++) {
									const splitString = promotionalcontent[q].split("~");
									var promotionalurl = splitString[1];
									var promotionaltitle = splitString[3];
									var promotionaltype = splitString[5];
									var promotionalimg = splitString[7];
									var promotionaldescription = splitString[9];
									if(promotionalurl != undefined && promotionaltitle != undefined && promotionaldescription != undefined){
										resultsmarkup += '<div class="u28promotion u28result '+promotionaltype+'">';
										resultsmarkup += '<div class="u28rw1">';
										resultsmarkup += '<div class="u28rw2">';
										if(promotionalimg != undefined) {
											resultsmarkup += '<img src="'+promotionalimg+'" alt="'+promotionaltitle+'"></img>';
										}
										resultsmarkup += '<h4><a href="'+promotionalurl+'">PROMOTIONAL '+promotionaltitle+'</a></h4>';
										resultsmarkup += '<cite><a href="'+promotionalurl+'">'+promotionalurl+'</a></cite>';
										resultsmarkup += '<p>'+promotionaldescription+'</p>';
										resultsmarkup += '</div>';
										resultsmarkup += '</div>';
										resultsmarkup += '</div>';
										num++;
									}
								}
							}
	
							//Display Regular Results
							if(typeof promotionalcontent === 'undefined') {
								//console.log('--promotionalcontent',promotionalcontent);
								//console.log('--sitelinks',sitelinks);
								if(title != undefined && description != undefined && displayurl != undefined){
									if (results[i].attributes.SourceTag == null){
										var srctagfound = false;
									}
									else {
										var srctagfound = true;
										var srctag = results[i].attributes.SourceTag.toString().toLowerCase();
										if (srctag === 'video') {
											var videofound = true;
											var videosrc = results[i].attributes.Id[0];
										}
										else {
											var videofound = false;
										}
									}
									if (videofound) {
										resultsmarkup += '<div class="u28result u28video">';
									}
									else {
										resultsmarkup += '<div class="u28result">';
									}
									resultsmarkup += '<div class="u28rw1">';
									resultsmarkup += '<div class="u28rw2">';
									if (videofound) {
										//Your Platform Einführung Video
										//ocom:en-us:search:sitelink:title:cta:machine learning
										//ocom:en-us:search:sitelink:link1:cta:product powered
										//resultsmarkup += '<a class="bcembed bcthumbnail" href="'+videosrc+'" data-bcid="'+videosrc+'" rel="vbox"></a>';
										resultsmarkup += '<div class="bcembed bcthumbnail" data-bcid="'+videosrc+'" rel="vbox"></div>';
										//console.log('videofound',videofound);
										//console.log('------');
									}
									resultsmarkup += '<h4><a href="'+displayurl+'">'+title+'</a></h4>';
									if (!srctagfound){
										resultsmarkup += '<cite><a href="'+displayurl+'">'+displayurl+'</a></cite>';
									}
									else {
										if (videofound) {
											resultsmarkup += '<cite><a href="'+displayurl+'">'+displayurl+'</a></cite>';
										}
										else {
											resultsmarkup += '<cite><div class="u28type"><span>'+results[i].attributes.SourceTag+'</span><a href="'+displayurl+'">'+displayurl+'</a></div></cite>';
										}
									}
									resultsmarkup += '<p>'+description+'</p>';
									
									resultsmarkup += '</div>';
									
									resultsmarkup += '</div>';
									resultsmarkup += '</div>';
									var videofound = false;
									var srctagfound = false;
									num++;
								}
							}
						}
						if (u28count <= 0) {
							//searchresults.html('');
							searchresults.find('*').not('.u28skel').not('.u28skel li').remove();
						}

						setTimeout(function() {
							//create country filter
							if (filtertxt && ctytxt && !ctryfilterdis) {
								ctryfilter += '<div class="ctryfilter">';
								ctryfilter += '<div class="ctryfilterw1">';
								ctryfilter += '<a class="filtertxt" href="'+filtertxt+'">'+filtertxt+'</a>';
								//ctryfilter += '<a class="ctry" href="'+ctytxt+'">'+ctytxt+'</a>';
								ctryfilter += '<span class="ctytxt">'+ctytxt+'</span>';
								ctryfilter += '<span class="clrctry"></span>';
								ctryfilter += '</div>';
								ctryfilter += '</div>';
								searchresults.append(ctryfilter);
								$(".clrctry").on("click", function(e) {
									ctryfilterdis = true;
									searchresults.find('*').not('.u28skel').not('.u28skel li').remove();
									//contsearch
									//contctry = 'us';
									//contlang = 'en';
									buildResults(0);
								});
							}
							searchresults.append(sitelinkmarkup);
							searchresults.append(reccomendedmarkup);
							searchresults.append(resultsmarkup);
							u28videocheck();
							//if (u28count <= 0) {
								searchresults.removeClass('hidden').addClass('u28found');
							//}

							if ($('.cb19v2').length){
								$('.cb19v2').each(function() {
									if ($(this).find('img').length) {
										$(this).closest('.cb19v2').addClass('u28proimg');
									}
								});
							}
							
							removeInputFocus();
							var input = document.getElementById("askoracleinput");
							input.selectionEnd = input.selectionStart;
							input.blur();
							adjustDropdown();
						}, 100);
						//setTimeout(function() {
							searchresults.removeClass('loading');
						//}, 300);

					}
					else {
						setTimeout(function() {
							//console.log('no results found');
							if (!$('.u28w8 .u28noresults')[0]) {
								searchresults.removeClass('hidden');
								searchresults.addClass('u28found');
								$('.u28w9').clone(true, true).contents().appendTo(searchresults);
								$('.u28w7').clone().appendTo('.u28w8 .u28noresults .u28rw2');
								adjustDropdown();
							}
						}, 200);
					}
				//}
				
			})
			.done(function( data ) {
				var u28bottom = true;
				searchresults.addClass('u28loaded');
				setTimeout(function() {
					$('.u28w4').scroll(function() {
						var a = searchresults.offset().top;
						var b = searchresults.height();
						var c = $(window).height();
						var d = $(window).scrollTop();
						if ((c+d)>(a+b)) {
							if(u28bottom){
								//console.log('reached search bottom');
								if (u28searchpg >= 0) {
									u28searchpg = u28searchpg + 10;
								}
								buildResults(u28searchpg);
								u28bottom=false;
							} 
						}
					});
				}, 200);

			});
		};

		askoracleform.submit(function(e) {
			opendropdown();
			//searchresults.html('');
			searchresults.find('*').not('.u28skel').not('.u28skel li').remove();
			buildResults();
			setTimeout(function() {
				searchresults.addClass('u28fadeIn').siblings('.u28trgt').removeClass('u28fadeIn');
				$('.u28suggest').removeClass('active');
				//searchresults.addClass('hidden');
			}, 200);
			//recognition.stop();
			e.preventDefault();
		});
	
		function adjustDropdown() {
			//console.log('adjustDropdown');
			var formheight = $('.u28w1').outerHeight();
			var inputwrapoffset = $(".u28w2").offset();
			var inputwidth = $(".u28w3").outerWidth();
			var windowheight = window.innerHeight;
			var windowwidth = $(window).width();
			if (windowwidth <= 974 ) {
				mobile = true;
				u28unlockpage();
			}
			else {mobile = false;}

			var u28profilebtn = $('.u28prof');
			var profileright = ($(window).width() - (u28profilebtn.offset().left + u28profilebtn.outerWidth()));
			if (profileright <= (u28profiledropdown.outerWidth() - 30)) {
				u28profiledropdown.addClass('right');
			}
			if (profileright >= u28profiledropdown.outerWidth()) {
				u28profiledropdown.removeClass('right');
			}
			$('.u28w4').css({'margin-top':(formheight+'px')});
			searchresults.css("width", inputwidth).css({'left':(inputwrapoffset.left+'px')});
			$('.u28w2 ul.u28suggest li a, .u28w2 ul.u28suggest li cite').each( function(){
				$(this).css({'margin-left':(inputwrapoffset.left+6+'px')});
			});
			var maxHeight = Math.max.apply(null, $('.u28nav>ul').map(function () {
				return this.clientHeight; // or $(this).height()
			}));
			if (formheight + maxHeight + 88 >= windowheight) {
				$('.u28nav').addClass('u28shortnav');
			}
			else {
				$('.u28nav').removeClass('u28shortnav');
			}
		}

		function showsuggest() {
			setTimeout(function() {
				$('.u28suggest').addClass('active');
				searchresults.removeClass('hidden');
			}, 300);
			$('.u28navactive .u28nav').removeClass('u28fadeIn');
			u28.removeClass('u28navactive');
			if ( elem.css('opacity') == '0' || elem.css("visibility") == "hidden"){
				//console.log('why run');
				elem.css("opacity", 0.0).css("visibility", "visible").delay(300).animate({"opacity": 1.0}, 300);
			}
			//if ( clearbtn.css('display') == 'none' || clearbtn.css("visibility") == "hidden"){
			//	clearbtn.css("opacity", 0.0).css("visibility", "visible").delay(300).animate({"opacity": 1.0}, 300);
			//}
		}
	
		$( window ).resize(function() {
			adjustDropdown();
		});
	
		setTimeout(function() {
			adjustDropdown();
			$(window).scroll(function(event){
				u28didScroll = true;
				var pgst = $(document).scrollTop();
				if (pgst <= 1 && u28.hasClass('u28-past')) {
					u28.removeClass('u28-down u28-up u28-past').addClass('u28-top');
				}
			});
			setInterval(function() {
				if (u28didScroll) {
					u28hasScrolled();
					u28didScroll = false;
				}
			}, 50);
			u28.addClass('dropdownloaded');
		}, 200);

		Autocomplete = {
			init: function(opts) {
				inputField = opts.inputField;
				lastComplete = null;
			},
			//autocomplete: function(value, array) {
			//	for (var i=0; i < array.length; i++) {
			//		var word = array[i];
			//		if (word.toLowerCase().indexOf(value.toLowerCase()) === 0) {
			//			return word;
			//		}
			//	}
			//	return null;
			//},
			clearTypeAhead: function(id) {
				//inputField.val('');
				//$('.' + id + ' .u28hiddentxt').empty();
				//$('.' + id + ' .u28typeaheadtxt').empty();
			},
			onload: function() {
	
				Autocomplete.init({
					inputField: $('#askoracleinput')
				});

				inputField.on('input', function() {
					var u28length = this.value.length;
					if (u28length > 0) {
						$('.u28placeholder').addClass('u28hidden');
						$('.u28w3').addClass('u28typing');
					}
				});

				inputField.keydown(function(event) {
					var u28code = event.keyCode;
					var li = $('.u28suggest li');

					if(u28code === 40 || u28code === 9) {
						if ($('.u28suggest').hasClass('active')) {
							//Down Arrow or Tab
							if(liSelected) {
								liSelected.attr('aria-selected', 'false');
								next = liSelected.next();
								if(next.length > 0) {
									liSelected = next.attr('aria-selected', 'true');
								} else {
									liSelected = li.eq(0).attr('aria-selected', 'true');
								}
							} else {
								liSelected = $(".u28suggest li[aria-selected!='true']").eq(0).attr('aria-selected', 'true');
								liSelected.siblings().attr('aria-selected', 'false');
							}
							if(liSelected) {
								var selecttxt = liSelected.find('a').text();
								elem.val(selecttxt);
							}
							return false;
						}
					} else if(u28code === 38) {
						//Up Arrow
						if(liSelected) {
							liSelected.attr('aria-selected', 'false');
							next = liSelected.prev();
							if(next.length > 0) {
								liSelected = next.attr('aria-selected', 'true');
							} else {
								liSelected = li.last().attr('aria-selected', 'true');
							}
						} else {
							liSelected = li.last().attr('aria-selected', 'true');
						}
						if(liSelected) {
							var selecttxt = liSelected.find('a').text();
							elem.val(selecttxt);
						}
						return false;
					}
				});
				
				inputField.keyup(u28delay(function(event){
					var inputval = this.value;
					var u28code = event.keyCode;
					var u28length = this.value.length;
					var u28match = false;
					var li = $('.u28suggest li');
					var firstsugtxt = '';
					if(!u28staging) {
						var AutosuggestJsonUrl = '/search/askoraclesuggest/json?Ntt=' +this.value + '';
						var AutocompleteJsonUrl = '/search/autosuggest.json/browse?Dy=1&contentPaths=%2Fcontent%2FWeb%2FShared%2FAuto-Suggest%20Panel&templateTypes=AutoSuggestPanel&Ntt=' +this.value + '*';
					}
					else {
						//stage
						//var AutosuggestJsonUrl = 'https://www-portal-stage.oracle.com/search/askoraclesuggest/json?Ntt=' +this.value + '';
						//production
						var AutosuggestJsonUrl = 'https://www.oracle.com/search/askoraclesuggest/json?Ntt=' +this.value + '';
						var AutocompleteJsonUrl = 'https://www.oracle.com/search/autosuggest.json/browse?Dy=1&contentPaths=%2Fcontent%2FWeb%2FShared%2FAuto-Suggest%20Panel&templateTypes=AutoSuggestPanel&Ntt=' +this.value + '*';
					}

					//Keycodes

					//8=backspace 46=delete
					if( u28code == 8 || u28code == 46 ) {
						return false;
					}
					
					//Return
					if (u28code == 13) {
						//check to see if suggest link is selected, then follow link
						$('.u28suggestlnk').each( function(){
							if ($(this).parent().attr('aria-selected') == 'true' && $('.u28suggest').is(':visible')) {
								closedropdown();
								$('.u28suggest').hide();
								var url = $(this).attr('href');
								window.location = url;
								return false;
							}
						});
						scrollToTop();
						$('.u28suggest').removeClass('active');
						//searchresults.addClass('hidden');
						return false;
					}

					if(u28code === 40 || u28code === 9) {
						return false;
					} else if(u28code === 38) {
						return false;
					}

					if(u28code === 39 || u28code === 9) {
						if(u28code === 9) { 
							event.preventDefault() 
						}
						if(lastComplete) {
							Autocomplete.clearTypeAhead();
							inputField.val(lastComplete);
						}
					}

					//Length
					if (u28length === 0 || inputField.val() === '') {
						Autocomplete.clearTypeAhead('u28typeahead');
						//$('.u28-microphone').fadeIn(100);
						//clearbtn.css("opacity", 1.0).animate({"opacity": 0.0}, 300).delay(300).css("visibility", "hidden");
						$('.u28w3').removeClass('u28typing');
					}
					if (u28length > 0) {
						addInputFocus();
						//if ( clearbtn.css('display') == 'none' || clearbtn.css("visibility") == "hidden"){
						//	clearbtn.css("opacity", 0.0).css("visibility", "visible").delay(300).animate({"opacity": 1.0}, 300);
						//}
					}
					if (u28length > 2 && !searchresults.hasClass('loading')) {
						var autosuggest = false;
						var autocomplete = false;
						//Get Autosuggest
						var ajax1 = jQuery.ajax({ 
							dataType: 'json',
							url: AutosuggestJsonUrl,
							async: true,
							error: function(){
								console.log('Autosuggest fail');
							}
						});
						//Get Autocomplete
						var ajax2 = jQuery.ajax({
							dataType: 'json',
							url: AutocompleteJsonUrl,
							async: true,
							error: function(){
								console.log('Autocomplete fail');
							}
						});
						jQuery.when( ajax1 , ajax2  ).then(function( a1, a2 ) {
							$('.u28suggest').html('');
							//Display Autosuggest
							if (a1[0].contents[0].numResults > 0) {
								jQuery.each(a1[0].contents[0].records, function (key, val) {
									if (key <= 2) {
										var title = val.attributes.Title;
										var url = val.attributes.aoDestinationURL;
										var type = val.attributes.aoDestinationType;
										var typeclass = 'u28-globe';
										var titleTxt = title.toString();
										var rep_regex = new RegExp(inputval,"gi");
										var suggestb = titleTxt.replace(rep_regex,"<b>" + inputval + "</b>");
										if (type) {
											if (type[0] === 'Video') {
												var typeclass = 'icn-video';
											}
											if (type[0] === 'Coversation') {
												var typeclass = 'icn-chat';
											}
										}
										$('.u28suggest').append('<li aria-selected="false"><a class="'+typeclass+' u28suggestlnk" href="'+url+'">'+suggestb+'</a><cite>'+url+'</cite></li>');
									}
								});
								var autosuggest = true;
							}
							//Display Autocomplete
							if(a2[0].contents[0].autoSuggest[0].totalNumResults > 0){
								jQuery.each(a2[0].contents[0].autoSuggest[0].dimensionSearchGroups[0].dimensionSearchValues, function (key, val) {
									var rep_regex = new RegExp(inputval,"gi");
									var completeb = val.label.replace(rep_regex,"<b>" + inputval + "</b>");
									$('.u28suggest').append('<li aria-selected="false"><a class="u28-search u28complete" href="#">'+completeb+'</a></li>');
								});
								var autocomplete = true;
							}
							//Display dropdown if autocomplete or autosuggest gets results
							if(autosuggest || autocomplete) {
								//adjustDropdown();
								//opendropdown();
								//showsuggest();
								if ($('.u28suggest li:first a').length > 0) {
									var firstsug = $('.u28suggest li:first');
									var firstsugtxt = $('.u28suggest li:first a').text();
									if (firstsugtxt.indexOf(inputval) === 0) {
										//search term found in first list item
										var complete = firstsugtxt;
										var lastComplete = complete;
										if(complete === null) {
											Autocomplete.clearTypeAhead('u28typeahead');
										} else {
											//Look for matches to inputval in text of dropdown, if not insert one with inputval after
											$('.u28suggest li a').each(function(){
												if (inputval === $(this).text()) {
													//u28match = true;
													if (!$(this).hasClass("u28suggestlnk")) {
														$(this).parent().remove();
													}
												}
											});
											//if (!u28match) {
											$('<li aria-selected="false"><a class="u28-search u28complete" href="#">'+inputval+'</a></li>').insertAfter(firstsug);
											
											//}
											var begin = complete.substr(0,u28length);
											var end = complete.substr(u28length);
											var input = document.getElementById("askoracleinput");
											var y = u28length+end.length;
											elem.val(begin + end);
											input.focus();
											// Highlights
											input.setSelectionRange(u28length, y);
											firstsug.attr('aria-selected', 'true');
											setTimeout(function() {
												adjustDropdown();
											}, 100);
										}
									}
									else {
										Autocomplete.clearTypeAhead('u28typeahead');
										firstsug.attr('aria-selected', 'false');
										$('.u28suggest').prepend('<li aria-selected="true"><a class="u28-search u28complete" href="#">'+inputval+'</a></li>');
									}
									adjustDropdown();
									opendropdown();
									//showsuggest();
								}
								
							}
							else {
								//console.log('no autocomplete results');
								$('.u28suggest').append('<li aria-selected="true"><a class="u28-search u28complete" href="#">'+inputval+'</a></li>');
								adjustDropdown();
								opendropdown();
								//showsuggest();
							}
							showsuggest()
						});
					}
				},u28debouncenum));
				
			}
		};
		
		$(Autocomplete.onload);
	
	}

});

/*! S20 */
OCOM.register(function s20($) {
	'use strict';

	// don't do anything if more than one s20 on the page
	if($('.s20').length == 1 && $('.f19')[0]){

		// set up links/anchors when using generated s20 links
		if($('#s20autolinks')[0]){
			var s20ul = $('#s20autolinks');
			jQuery('[data-s20anchors]').each(function(){
				$(this).find($(this).attr('data-s20anchors')).each(function(i){
					var anchor = $(this);
					var anchortxt = anchor.text();
					var anchorid = 'anchor_'+(i+1);
					anchor.attr('id',anchorid);
                    s20ul.append('<li><a href="#'+anchorid+'">'+anchortxt+'</a></li>');
				});
			});
		}
					
		// set up link/anchors when using static s20
		$('.s20w2 a[href^="#"]').each(function(){
			var id = $(this).attr('href').split('#')[1];
			$('#'+id).addClass('s20anchor');
			$(this).parent().attr('data-anchorid',id)

			$(this).on('click',function(){
				if($('#'+id)[0]){
					var delta = Math.abs($('#'+id).offset().top - $(document).scrollTop())
					var velo = Math.floor(delta * .5);
					var atop = ($('.ct12')[0]) ? 98 : 18;

					$('.s20current').removeClass('s20current');
					$('.s20').addClass('s20scroll');
					$('html, body').animate({scrollTop:$('#'+id).offset().top - atop}, velo, function(){
						$('.s20').removeClass('s20scroll');
						$('li[data-anchorid="'+id+'"]').addClass('s20current');
					});
				}
			});
		});
	
		var s20 = $('.s20');
		s20.wrapAll('<div class="s20-sticky-wrapper" />');
		var s20wrap = $('.s20-sticky-wrapper');
		var wayoff = '22px';
		//if($('.ct12')[0]){
		//	s20wrap.addClass('s20hastabs');
		//	wayoff = '95px'
		//}
		
		// waypoint for nav, will not stick if nav AND any following components do not fit in the viewport
		var s20sticky = s20wrap.waypoint(function(dir) {
			if (dir === "down") {
				var h = $('.s20').outerHeight();
				 $('.s20').parent().nextAll().each(function(){
					h = h + $(this).outerHeight();
				 });
		
				if(h <= ($(window).height() - 40)){
					s20wrap.addClass('s20stuck');
					s20wrap.css('width',s20wrap.outerWidth());
					s20wrap.css('height',s20.outerHeight());
				}
			}else{
				s20wrap.removeClass('s20stuck');
				s20wrap.css('width','');
				s20wrap.css('height','');
			}
		},{
			offset: wayoff
		});

		// waypoint for anchors to trigger highlighting 
		$('.s20anchor').each(function() {
			var eid = this.id;
			var el = $(this);
			el.waypoint(function(dir) {
				if (!$('.s20').hasClass('s20scroll')){ // don't add class if auto scrolling, gets to trippy
					if (dir === "down") {
						$('li.s20current').removeClass('s20current');
						$('li[data-anchorid="'+eid+'"]').addClass('s20current');
					}else{
						var cli = $('li[data-anchorid="'+eid+'"]');
						$('.s20current').removeClass('s20current');
						if(cli.prev()[0]){
							cli.prev().addClass('s20current');
						}
					}
				}
			},{
				offset: wayoff
			});
		});

		// waypoint to track the end of the f19 hitting the viewport and turning the stuck nav into a absolutely positioned one
		var f19 = $('.f19');
		var f19sticky = f19.waypoint(function(dir) {
			if(s20wrap.hasClass('s20stuck')){
				if (dir === "down") {
					f19.addClass('s20pos');
					s20.css('top',(f19.outerHeight() - $(window).height() - 35));
				}else{
					f19.removeClass('s20pos');
					s20.css('top','');
				}
			}
		},{
			offset: 'bottom-in-view'
		});

		var onWindowResized = function() {
			var s20stk = $('div.s20stuck');
			// unlike when origionally test the size before sticking, on resize we only check height
			// of nav since other things are already hidden 
			if(s20stk[0] && s20stk.find('.s20').outerHeight() <= ($(window).height() - 40) && !$('.s20pos')[0]){
				s20stk.css('width','');
				s20stk.css('width',s20stk.outerWidth());
			}else if(s20stk[0]){
				s20stk.find('.s20').css('top','');
				s20stk.css('width','');
				s20stk.css('height','');
				$('.s20pos').removeClass('s20pos');
				s20stk.removeClass('s20stuck');
			}
		};

		$(window).off('resize.s20').on('resize.s20',onWindowResized.bind());

	}

});


/*! S21 */
OCOM.register(function s21($) {
	'use strict';

	$('.s21[data-feedsrc]').each(hbsCheck);

	/* globals propertyExists, objLoaded */
	function hbsCheck() {
		return (
			objLoaded('HBSINJECT', 'initialize') &&
			propertyExists(this, 'data-feedsrc') &&
			propertyExists(this, 'data-template') &&
			init.call(this) ||
			setTimeout(hbsCheck.bind(this), 10)
		);
	}

	function init() {

		var $s21 = $(this),
				$s21w2 = $s21.find('.ofeed'),
				feedsrc = $s21.attr('data-feedsrc'),
				template = $s21.attr('data-template');

		window.HBSINJECT.initialize({
			feedsrc: feedsrc,
			targetObj: $s21w2,
			templateName: template,
			beforeInjectionCallback: prepJSON,
			afterInjectionCallback: $s21w2.addClass.bind($s21w2, 'hbs-initialized')
		});

		return this;
	}

	function prepJSON(json) {
		return (
			'object' === typeof json &&
			'contents' in json &&
			'records' in json.contents[0] &&
			json.contents[0].records.length &&
			{ records: json.contents[0].records.map(mapRecord) }
		);
	}

	function mapRecord(record) {
		return (
			'object' === typeof record &&
			'attributes' in record &&
			{
				date: record.attributes.DisplayDate,
				title: record.attributes.Title,
				description: record.attributes.Description,
				url: record.attributes.DisplayURL
			}
		);
	}
});


